<?php

namespace App\Http\Controllers;

use App\Models\Huawei;
use App\Models\Hw_site_work;
use App\Models\Hw_access_works;
use App\Models\Hw_vertical_works;
use App\Models\Kir;
use App\Models\Kir_access_works;
use App\Models\Hw_site_equipment;
use App\Models\Kir_required_equipment;
use App\Models\Kir_vertical_works;
use App\Models\Required_equipment;
use App\Models\Terrain_ammounts;
use App\Models\Construction_images;
use App\Models\Image_types;
use App\Models\Storage_logs;
use App\Models\Storage_equipment;
use App\Models\Worker_equipment;
use App\Models\Worker_storage_logs;
use App\Traits\Util;
use Illuminate\Http\Request;
use App\Oprema;
use App\Models\Equipment;
use App\Models\Site_equipment;
use App\Models\Site_work;
use Intervention\Image\ImageManager as Img;


class AjaxController extends Controller
{

    private function updateChangeLog($equipmentId, $storageId, $quantity, $montEquipmentId = null, $fitterId=null, $receiveNumber=null, $from=null, $packageNumber=null){
        if($quantity != 0){
            Storage_logs::create([
                'equipment_id' => $equipmentId,
                'mont_equipment_id' => $montEquipmentId,
                'user_id' => Util::userId(),
                'fitter_id' => $fitterId,
                'receive_number' => $receiveNumber,
                'from' => $from,
                'storage_id' => $storageId,
                'quantity' => $quantity,
                'package_number' => $packageNumber
            ]);
        }
    }

    /**
     * @param Request $request
     * funkcija za dodavanje i oduzimanje opreme iz magacina
     */
    public function operation(Request $request){
        $idOprema = $request->input('id_oprema');
        $operation = $request->input('operation');
        $broj = $request->input('broj');

        $oprema = Oprema::all()->where('id', $idOprema)->toArray();

        foreach($oprema as $opr)
            $stanje = $opr['magacin_stanje'];

        switch ($operation){
            case 'plus':
                $stanje += $broj;
                break;
            case 'minus':
                $stanje -= $broj;
                break;
        }

        Oprema::find($idOprema)->update([
            'magacin_stanje' => $stanje
        ]);

    }

    protected function check_quantity($quantity){
        if(is_numeric($quantity))
        {
            if($quantity < 0)
                return 0;
            else
                return $quantity;
        }
        else 
        {
            return 0;
        }
    }

    public function equipment_populate(Request $request){
        $output = '';
        $id = $request->get('id');
        $equipModel = new Equipment();
        $equipment = $equipModel->equipment($id);
        foreach($equipment as $equip){
            $output .= '<option value="'.$equip->id.'">'.$equip->equipment.' ('.$equip->code.')'.'</option>';
        }
        return $output;
    }

    public function mont_equipment_populate(Request $request){
        $output = '';
        $id = $request->get('id');
        $equipModel = new Oprema();
        $equipment = $equipModel->equipment($id);
        foreach($equipment as $equip){
            $output .= '<option value="'.$equip->id.'">'.$equip->naziv.' ('.$equip->code.')'.'</option>';
        }
        return $output;
    }

    public function work_populate(Request $request){
        $output = '';
        $id = $request->get('id');
        $param = $request->get('param');
        if($param == 'huawei'){
            $workModel = new Hw_access_works();
            $works = $workModel->works($id);
        }
        else {
            $workModel = new Kir_access_works();
            $works = $workModel->works($id);
        }
        foreach($works as $work){
            $output .= '<option value="'.$work->id.'">'.$work->work.' ('.$work->code.')'.'</option>';
        }
        return $output;
    }

    public function worker_equipment_populate(Request $request){
        $id = $request->get('id');
        $param = $request->get('param');
        $weMod = new Worker_equipment();
        $output = '';
        if($param == 'montage'){
            $workerEquipment = $weMod->mont_equipment_for_user($id);
            foreach($workerEquipment as $equip){
                $output .= '<option value="'.$equip->equipment_id.'">'.$equip->equipment." ($equip->quantity)".'</option>';
            }
        }
        else{
            $workerEquipment = $weMod->equipment_for_user($id);
            foreach($workerEquipment as $equip){
                $output .= '<option value="'.$equip->equipment_id.'">'.$equip->equipment.' ('.$equip->code.')'." ($equip->quantity)".'</option>';
            }
        }
        return $output;
    }

    public function add_construction_equipment(Request $request){
        $idConstrucitonSite = $request->get('id_site');
        $idEquipment = $request->get('idEquipment');
        $quantity = $request->get('quantity');
        $worker = $request->get('worker');
        $quantity = $this->check_quantity($quantity);
        //if it's construction worker or monter, or admin is adding equipment instead of worker
        if(Util::isConstructionWorker() || Util::isMonter() || $worker){
            $eModel = new Worker_equipment();
            if($worker)
                $userId = $worker;
            else
                $userId = Util::userId();
            $equipment = $eModel->specific_equipment($userId, $idEquipment);
            if($equipment->quantity >= $quantity && $idEquipment) {
                $eModel->equipment_update($userId, $idEquipment, -$quantity);
                Site_equipment::create([
                    'id_construction_site' => $idConstrucitonSite,
                    'id_equipment' => $idEquipment,
                    'quantity' => $quantity
                ]);
                Worker_storage_logs::create([
                    'equipment_id' => $idEquipment,
                    'worker_id' => $userId,
                    'client_type' => 5,
                    'client_id' => $idConstrucitonSite,
                    'quantity' => -$quantity
                ]);
            }
            else {
                return __("workers do not have that much equipment");
            }
        }
        else {
            if($idEquipment){
                Site_equipment::create([
                    'id_construction_site' => $idConstrucitonSite,
                    'id_equipment' => $idEquipment,
                    'quantity' => $quantity
                ]);
            }
        }

    }

    public function add_construction_work(Request $request){
        $quantity = $request->get('quantity');
        $quantity = $this->check_quantity($quantity);
        $param = $request->get('param');
        $idSite = $request->get('id_site');
        $idWork = $request->get('idWork');
        //ajax refreshing page (access works)
        if($param == 'access' && $idWork){
            if($quantity > 0){
                $specWork = Kir_access_works::where('id', $idWork)->first();
                $price = $specWork->price;
                //update price on site
                if($price > 0){
                    $kMod = new Kir();
                    $kMod->updatePrice($price*$quantity, $idSite);
                }
                Site_work::create([
                    'id_construction_site' => $idSite,
                    'access_work_id' => $idWork,
                    'quantity' => $quantity,
                    'price' => $price
                ]);
            }
        }
        else {
            //this is not ajax (vertical works)
            $siteId = $request->get('site_id');
            $workId = $request->get('vertical_work_id');
            $operation = $request->get('operation');
            if($operation == 'minus')
                $quantity = -$quantity;
            if($workId) {
                if(env('SERVER_ID') != 3)
                    $specWork = Kir_vertical_works::where('id', $workId)->first();
                else
                    $specWork = Hw_access_works::where('id', $idWork)->first();
                $price = $specWork->price;
                //update price on site
                if($price > 0){
                    $kMod = new Kir();
                    $kMod->updatePrice($price*$quantity, $siteId);
                }
                Site_work::create([
                    'id_construction_site' => $siteId,
                    'vertical_work_id' => $workId,
                    'quantity' => $quantity,
                    'price' => $price
                ]);
            }
            return redirect(url()->previous().'#vWorks');
        }
    }

    public function fill_storage(Request $request){
        $storageId = $request->input('magId');
        $param = $request->input('param');
        $equipmentId = $request->input('equipmentId');
        if(!$equipmentId){
            return __("you must choose equipment");
        }
        $quantity = $request->input('quantity');
        $operation = $request->input('operation');
        $sModel = new Storage_equipment();
        $storageEquipment = $sModel->specific_equipment($storageId, $equipmentId);

        if($operation == 'minus'){
            $quantity = -$quantity;
        }

        //if storage equipment have values, but quantity is 0.
        if($storageEquipment)
            $storageAmmount = $storageEquipment->quantity;
        else 
            $storageAmmount = 0;

        //putting stuff in storage
        if($param == 'storage'){
            $receiveNumber = $request->input('receive_number');
            $from = $request->input('from');
            //value can't be recorded if it's less then zero
            if($storageAmmount + $quantity < 0){
                return __("there are not that many goods in the warehouse");
            }
            if($storageEquipment){
                $sModel->storage_update($storageId, $equipmentId, $quantity);
                $this->updateChangeLog($equipmentId, $storageId, $quantity, null, null, $receiveNumber, $from);
            }
            else {
                Storage_equipment::create([
                    'mag_id' => $storageId,
                    'equipment_id' => $equipmentId,
                    'mont_equipment_id' => null,
                    'quantity' => $quantity
                ]);
                $this->updateChangeLog($equipmentId, $storageId, $quantity, null, null, $receiveNumber, $from);
            }
        }
        /*giving stuff to worker and removing stuff from selected storage.
          worker equipment can have values, but with quantity 0.*/
        else {
            $userId = $request->input('userId');
            $wModel = new Worker_equipment();
            $workerEquipment = $wModel->specific_equipment($userId, $equipmentId);
            if(isset($workerEquipment->quantity))
                $workerQuantity = $workerEquipment->quantity;
            else
                $workerQuantity = 0;
            if($workerQuantity + $quantity < 0)
                return __("Worker doesn't have goods in his inventory");
            if($storageAmmount >= $quantity){
                if($workerEquipment){
                    $wModel->equipment_update($userId, $equipmentId, $quantity);
                    //if equipment is not created in storage_equipment, null can't be incremented, so it has to be created.
                    if(empty($storageEquipment) && $quantity < 0){
                        Storage_equipment::create([
                            'mag_id' => $storageId,
                            'equipment_id' => $equipmentId,
                            'quantity' => -$quantity
                        ]);
                    }
                    else {
                        $sModel->storage_update($storageId, $equipmentId, -$quantity);
                    }
                    $this->updateChangeLog($equipmentId, $storageId, -$quantity, null, $userId);
                    Worker_storage_logs::create([
                        'equipment_id' => $equipmentId,
                        'worker_id' => $userId,
                        'storage_id' => $storageId,
                        'quantity' => $quantity
                    ]);
                }
                else{
                    Worker_equipment::create([
                        'user_id' => $userId,
                        'equipment_id' => $equipmentId,
                        'mont_equipment_id' => null,
                        'storage_id' => $storageId,
                        'quantity' => $quantity
                    ]);
                    Worker_storage_logs::create([
                        'equipment_id' => $equipmentId,
                        'worker_id' => $userId,
                        'storage_id' => $storageId,
                        'quantity' => $quantity
                    ]);
                    $sModel->storage_update($storageId, $equipmentId, -$quantity);
                    $this->updateChangeLog($equipmentId, $storageId, -$quantity, null, $userId);
                }
            }
            else {
                return __("not enough goods in warehouse");
            }
        }
        return __("goods successfully added");
    }

    public function mont_fill_storage(Request $request){
        $storageId = $request->input('magId');
        $param = $request->input('param');
        $equipmentId = $request->input('equipmentId');
        $quantity = $request->input('quantity');
        $operation = $request->input('operation');
        $packageNumber = $request->input('package_number');
        if(!$equipmentId){
            return __("you must choose equipment");
        }
        /* check if specific equipment needs number of packages */
        $specificEquipment = Oprema::where('id', $equipmentId)->first();
        // return $specificEquipment;
        if($specificEquipment->package != null)
            $packageIsset = true;
        else 
            $packageIsset = false;
        if($packageIsset && !$packageNumber){
            return __("You must enter package number for this equipment");
        }
        
        if(!$packageIsset){
            $packageNumber = null;
        }

        $sModel = new Storage_equipment();
        $storageEquipment = $sModel->specific_equipment_mont($storageId, $equipmentId, $packageNumber);
        $packageAvailable = $sModel->packageAvailable($storageId, $equipmentId, $packageNumber);
        if($packageIsset && !$packageAvailable){
            return __("Other equipment is already on that package");
        }

        if($operation == 'minus'){
            $quantity = -$quantity;
        }

        //if storage equipment have values, but quantity is 0.
        if($storageEquipment)
            $storageAmmount = $storageEquipment->quantity;
        else 
            $storageAmmount = 0;

        //putting stuff in storage
        if($param == 'storage'){
            //value can't be recorded if it's less then zero
            $receiveNumber = $request->input('receive_number');
            $from = $request->input('from');
            if($storageAmmount + $quantity < 0){
                return __("there are not that many goods in the warehouse");
            }
            if($storageEquipment){
                $sModel->storage_update_mont($storageId, $equipmentId, $quantity, $packageNumber);
                $this->updateChangeLog(null, $storageId, $quantity, $equipmentId, null, $receiveNumber, $from, $packageNumber);
            }
            else {
                Storage_equipment::create([
                    'mag_id' => $storageId,
                    'equipment_id' => null,
                    'mont_equipment_id' => $equipmentId,
                    'quantity' => $quantity,
                    'package_number' => $packageNumber
                ]);
                $this->updateChangeLog(null, $storageId, $quantity, $equipmentId, null, $receiveNumber, $from, $packageNumber);
            }
        }
        /*giving stuff to worker and removing stuff from selected storage
          worker equipment can have values, but with quantity 0.*/
        else {
            $userId = $request->input('userId');
            $wModel = new Worker_equipment();
            $workerEquipment = $wModel->specific_equipment_mont($userId, $equipmentId);
            if(isset($workerEquipment->quantity))
                $workerQuantity = $workerEquipment->quantity;
            else
                $workerQuantity = 0;
            if($workerQuantity + $quantity < 0)
                return __("Worker doesn't have goods in his inventory");
            if($storageAmmount >= $quantity){
                if($workerEquipment){
                    $wModel->equipment_update_mont($userId, $equipmentId, $quantity, $storageId);
                    $sModel->storage_update_mont($storageId, $equipmentId, -$quantity, $packageNumber);
                    $this->updateChangeLog(null, $storageId, -$quantity, $equipmentId, $userId, null, null, $packageNumber);
                    Worker_storage_logs::create([
                        'mont_equipment_id' => $equipmentId,
                        'worker_id' => $userId,
                        'storage_id' => $storageId,
                        'quantity' => $quantity,
                        'package_number' => $packageNumber
                    ]);
                }
                else{
                    Worker_equipment::create([
                        'user_id' => $userId,
                        'equipment_id' => null,
                        'mont_equipment_id' => $equipmentId,
                        'quantity' => $quantity
                    ]);
                    Worker_storage_logs::create([
                        'mont_equipment_id' => $equipmentId,
                        'worker_id' => $userId,
                        'storage_id' => $storageId,
                        'quantity' => $quantity,
                        'package_number' => $packageNumber
                    ]);
                    $sModel->storage_update_mont($storageId, $equipmentId, -$quantity, $packageNumber);
                    $this->updateChangeLog(null, $storageId, -$quantity, $equipmentId, $userId, null, null, $packageNumber);
                }
            }
            else {
                return __("not enough goods in warehouse");
            }
        }

        return __("goods successfully added");
        
    }

    public function add_picture(Request $request){
        $imageType = $request->input('image_type');
        $file = $request->file('image');
        $site = $request->input('site_id');
        $create = false;
        $img = new Img();
        $folder = 'uploads/construction_images/'.quartal();
        if($request->hasFile('image') && $folder)
            create_folder($folder);
        if ($imageType){
            $extension = $file->getClientOriginalExtension();
            $filename = date('Y-m-d').'-'.rand(1,100).'izgradnja'.rand(1,100000).'.'.$extension;
            $fileIntervention = $img->make($file->getRealPath());
            $fileIntervention->save($folder.'/'.$filename, 50);
            $description = Image_types::find($imageType);
            $create = Construction_images::create([
                'url' => '/'.$folder.'/'.$filename,
                'id_construction_site' => $site,
                'image_type' => $imageType,
                'description' => $description->type
            ]);
        }
        if($create){
            return __("Image successfully added");
        }
        else {
            return __("Image upload failed");
        }
    }

    public function add_terrain_ammount(Request $request){
        $userId = $request->input('user_id');
        $date = database_date($request->input('date'));
        $ammount = $request->input('ammount');
        if(!is_numeric($ammount)){
            return __("value has to be a number");
        };
        $terrainModal = new Terrain_ammounts();
        $allreadyInserted = $terrainModal->allreadyInserted($date, $userId);
        if($allreadyInserted){
            Terrain_ammounts::where('date', $date)->where('user_id', $userId)->delete();
        }
        if($userId && $date){
            $addAmmount = Terrain_ammounts::create([
                'user_id' => $userId,
                'date' => $date,
                'ammount' => $ammount
            ]);
        }
        if($addAmmount){
            return __("Data successfully added");
        }
    }

    public function add_hw_equipment(Request $request){
        $idSite = $request->get('id_site');
        $idEquipment = $request->get('idEquipment');
        $quantity = $request->get('quantity');
        $worker = $request->get('worker');
        if(!$quantity)
            return __("Quantity has to be positive number.");
        $quantity = $this->check_quantity($quantity);
        //if admin is adding equipment instead of worker
        if(Util::isConstructionWorker() || Util::isMonter() || $worker){
            $eModel = new Worker_equipment();
            if($worker)
                $userId = $worker;
            else
                $userId = Util::userId();
            $equipment = $eModel->specific_equipment($userId, $idEquipment);
            if($equipment->quantity >= $quantity && $idEquipment) {
                $eModel->equipment_update($userId, $idEquipment, -$quantity);
                Hw_site_equipment::create([
                    'id_site' => $idSite,
                    'id_equipment' => $idEquipment,
                    'quantity' => $quantity
                ]);
                Worker_storage_logs::create([
                    'equipment_id' => $idEquipment,
                    'worker_id' => $userId,
                    'client_type' => 6,
                    'client_id' => $idSite,
                    'quantity' => -$quantity
                ]);
            }
            else {
                return __("workers do not have that much equipment");
            }
        }
        else {
            if($idEquipment){
                Hw_site_equipment::create([
                    'id_site' => $idSite,
                    'id_equipment' => $idEquipment,
                    'quantity' => $quantity
                ]);
            }
        }
    }
    public function add_hw_work(Request $request){
        
        $quantity = $request->get('quantity');
        $quantity = $this->check_quantity($quantity);
        $param = $request->get('param');
        $idSite = $request->get('id_site');
        $idWork = $request->get('idWork');
        
        //ajax refreshing page (access works)
        if($param == 'access' && $idWork){
            if($quantity > 0){
                $specWork = Hw_access_works::where('id', $idWork)->first();
                $price = $specWork->price;
                //update price on site
                if($price > 0){
                    $hMod = new Huawei();
                    $hMod->updatePrice($price*$quantity, $idSite);
                }
                Hw_site_work::create([
                    'site_id' => $idSite,
                    'access_work_id' => $idWork,
                    'quantity' => $quantity,
                    'price' => $price
                ]);
            }
        }
        else {
            //this is not ajax (vertical works)
            $siteId = $request->get('site_id');
            $workId = $request->get('vertical_work_id');
            $operation = $request->get('operation');
            if($operation == 'minus')
                $quantity = -$quantity;
            if($workId) {
                $specWork = Hw_vertical_works::where('id', $workId)->first();
                $price = $specWork->price;
                //update price on site
                if($price > 0){
                    $hMod = new Huawei();
                    $hMod->updatePrice($price*$quantity, $siteId);
                }
                Hw_site_work::create([
                    'site_id' => $siteId,
                    'vertical_work_id' => $workId,
                    'quantity' => $quantity,
                    'price' => $price
                ]);
            }
            return redirect(url()->previous().'#vWorks');
        }
    }

    public function add_required_equipment(Request $request)
    {
        $equipmentId = $request->input('equipment_id');
        $quantity = $request->input('quantity');
        $siteId = $request->input('site_id');
        $param = $request->input('param');
        $eMod = new Storage_equipment();
        if ($param == 'kir') {
            if (Util::isConstructionManager()) {
                $availableGoods = $eMod->equipmentSum($equipmentId);
                $reMod = new Kir_required_equipment();
                $requiredGoods = $reMod->sum_equipment($siteId, $equipmentId);
                if ($availableGoods >= $quantity + $requiredGoods) {
                    Kir_required_equipment::create([
                        'equipment_id' => $equipmentId,
                        'site_id' => $siteId,
                        'quantity' => $quantity,
                        'created_by' => Util::userId()
                    ]);
                    return __("Equipment successfully required");
                } else {
                    return __("Not enough equipment in warehouse");
                }
            } else {
                Kir_required_equipment::create([
                    'equipment_id' => $equipmentId,
                    'site_id' => $siteId,
                    'quantity' => $quantity,
                    'created_by' => Util::userId()
                ]);
                return __("Equipment successfully added");
            }
        }
        else {
            if (Util::isConstructionManager()) {
                $availableGoods = $eMod->equipmentSum($equipmentId);
                $reMod = new Required_equipment();
                $requiredGoods = $reMod->sum_equipment($siteId, $equipmentId);
                if ($availableGoods >= $quantity + $requiredGoods) {
                    Required_equipment::create([
                        'equipment_id' => $equipmentId,
                        'site_id' => $siteId,
                        'quantity' => $quantity,
                        'created_by' => Util::userId()
                    ]);
                    return __("Equipment successfully required");
                } else {
                    return __("Not enough equipment in warehouse");
                }
            } else {
                Required_equipment::create([
                    'equipment_id' => $equipmentId,
                    'site_id' => $siteId,
                    'quantity' => $quantity,
                    'created_by' => Util::userId()
                ]);
                return __("Equipment successfully added");
            }
        }
    }

    public function find_equipment($equipment){
        
    }
}