<?php

namespace App\Http\Controllers;

use App\Models\States;
use App\Models\Cities;
use Illuminate\Http\Request;

class CityController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $cityModel = new Cities();
        $cities = $cityModel->citiesIndex();
        return view('city.index', ['cities' => $cities]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $states = States::all();
        return view('city.create', ['states' => $states]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate(['city' => 'required', 'state' => 'required']);
        $city = Cities::create([
            'city' => trim($request->input('city')),
            'id_state' => $request->input('state')
        ]);

        if ($city){
            return redirect()->route('city.index')->with('success', __("Data successfully added"));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Cities  $city
     * @return \Illuminate\Http\Response
     */
    public function show(Cities $city)
    {
        $cityModel = new Cities();
        $city = $cityModel->citiesIndex($city->id);
        return view('city.show', ['city' => $city]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Cities  $city
     * @return \Illuminate\Http\Response
     */
    public function edit(Cities $city)
    {
        $cityModel = new Cities();
        $city = $cityModel->citiesIndex($city->id);
        $states = States::all();
        return view('city.edit', ['city' => $city, 'states' => $states]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Cities  $city
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Cities $city)
    {
        $request->validate(['city' => 'required', 'state' => 'required']);
        $cityUpdate = Cities::where('id', $city->id)->update([
            'city' => trim($request->input('city')),
            'id_state' => $request->input('state')
        ]);

        if ($cityUpdate){
            return redirect()->route('city.show', ['city' => $city])->with('success', __("Data successfully changed"));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findCity = Cities::find($request->input('id_city'));

        try{
            $findCity->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Item can't be deleted because it's in use"));
        }

        return back()->withInput()->with('error', __("Data cannot be deleted"));
    }
}
