<?php

namespace App\Http\Controllers;

use App\Traits\Util;
use Illuminate\Http\Request;
use App\Models\Const_teams;
use App\Models\Const_team_worker;

class ConstTeamController extends Controller
{
    public function index()
    {
        $teamModel = new Const_teams();
        $teams = $teamModel->teams();
        return view('const_teams.index', [
            'teams' => $teams,
            'teamModel' => $teamModel
        ]);
    }

    public function create()
    {
        return view('const_teams.create', [
            'leaders' => Util::columnLeaders(),
            'workers' => Util::workers()
        ]);
    }

    public function store(Request $request)
    {
        $request->validate([
            'team' => 'required',
            'leader' => 'required',
            'worker' => 'required'
        ]);
        $team = $request->input('team');
        $leader = $request->input('leader');
        $workers = $request->input('worker');

        $team = Const_teams::create([
           'team' => $team,
           'column_leader' => $leader
        ]);
        if ($team){
            foreach ($workers as $worker)
            Const_team_worker::create([
                'team_id' => $team->id,
                'worker_id' => $worker
            ]);
        }

        return redirect()->route('constTeam.index');

    }

    public function show(Const_teams $constTeam)
    {
        $tModel = new Const_teams();
        $team = $tModel->teamData($constTeam->id);
        $workers = $tModel->workers($constTeam->id);
        return view('const_teams.show', [
           'team' => $team,
           'workers' => $workers
        ]);
    }

    public function edit(Const_teams $constTeam)
    {
        $tModel = new Const_teams();
        $workers = $tModel->workers($constTeam->id);

        return view('const_teams.edit', [
            'team' => $constTeam,
            'leaders' => Util::columnLeaders(),
            'allWorkers' => Util::workers(),
            'workers' => $workers
        ]);
    }

    public function update(Request $request, Const_teams $constTeam)
    {
        $request->validate([
            'team' => 'required',
            'leader' => 'required',
            'worker' => 'required'
        ]);
        $team = $request->input('team');
        $leader = $request->input('leader');
        $workers = $request->input('worker');

        $teamUpdate = Const_teams::where('id', $constTeam->id)->update([
            'team' => $team,
            'column_leader' => $leader
        ]);
        if ($teamUpdate){
            if ($workers){
                foreach ($workers as $worker) {
                    Const_team_worker::create([
                        'team_id' => $constTeam->id,
                        'worker_id' => $worker
                    ]);
                }
            }
        }

        return redirect()->route('constTeam.show', ['constTeam' => $constTeam->id])->with('success', __("Data successfully changed"));
    }

    public function destroy(Request $request)
    {
        $findTeam = Const_teams::find($request->input('id_team'));

        if ($findTeam){
            $findTeam->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }

    public function worker_delete(Request $request){
        $idTeam = $request->input('id_team');
        $idWorker = $request->input('id_worker');
        $delete = Const_team_worker::where('team_id', $idTeam)->where('worker_id', $idWorker)->delete();
        if ($delete)
            return back()->withInput()->with('success', __("Data successfully deleted"));
        else
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
