<?php

namespace App\Http\Controllers;

use App\Models\Units;
use App\Models\Construction_works;
use App\Models\Work_categories;
use Illuminate\Http\Request;

class ConstWorkController extends Controller
{
    private function categories(){
        $categories = Work_categories::all();
        return $categories;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $wcModel = new Construction_works();
        $works = $wcModel->const_works();
        return view('constWork.index', ['works' => $works]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $units = Units::all();
        return view('constWork.create', ['categories' => $this->categories(), 'units' => $units]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'code' => 'required',
            'work' => 'required',
            'category' => 'required'
        ]);
        $workCreate = Construction_works::create([
            'code' => trim($request->input('code')),
            'work' => trim($request->input('work')),
            'id_category' => trim($request->input('category')),
            'unit_id' => $request->input('unit')
        ]);

        $cwModel = new Construction_works();
        $works = $cwModel->const_works();
        if ($workCreate){
            return view('constWork.index', ['works' => $works]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\construction_works  $const_work
     * @return \Illuminate\Http\Response
     */
    public function show(construction_works $const_work)
    {
        $wModel = new Construction_works();
        $work = $wModel->workData($const_work->id);
        return view('constWork.show', ['work' => $work]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\construction_works  $const_work
     * @return \Illuminate\Http\Response
     */
    public function edit(construction_works $const_work)
    {
        $wModel = new Construction_works();
        $work = $wModel->workData($const_work->id);
        $units = Units::all();

        return view('constWork.edit', ['work' => $work, 'categories' => $this->categories(), 'units' => $units]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\construction_works  $construction_works
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, construction_works $const_work)
    {
        $request->validate([
            'code' => 'required',
            'work' => 'required',
            'category' => 'required'
        ]);
        $workUpdate = Construction_works::where('id', $const_work->id)->update([
            'code' => trim($request->input('code')),
            'work' => trim($request->input('work')),
            'id_category' => trim($request->input('category')),
            'unit_id' => trim($request->input('unit'))
        ]);

        if ($workUpdate){
            return redirect()->route('const_work.show', ['const_work' => $const_work->id])->with('success',  __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\construction_works  $construction_works
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findWork = Construction_works::find($request->input('id_work'));

        try{
            $findWork->delete();
            return back()->withInput()->with('success', __("Work successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
