<?php

namespace App\Http\Controllers;

use App\Change_history;
use App\Models\Construction_prices;
use App\Models\Construction_works;
use App\Models\Files;
use App\Models\Site_work;
use App\Models\Site_equipment;
use App\Models\Work_categories;
use App\Models\Equipment_categories;
use App\Models\Areas;
use App\Models\Cities;
use App\Models\Construction_comments;
use App\Models\Construction_images;
use App\Models\Construction_sites;
use App\Models\Construction_status;
use App\Models\Contractors;
use App\Models\Currency;
use App\Models\Image_types;
use App\Models\States;
use App\Models\Worker_equipment;
use App\Traits\Util;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use Intervention\Image\ImageManager as Img;

class ConstructionSitesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $isAdmin = Util::isAdmin();
        $constructModel = new Construction_sites();
        if ($isAdmin)
            $constructionSites = $constructModel->construction_index();
        elseif (Util::isConstructionAreaAdmin())
            $constructionSites = $constructModel->construction_index(null, Util::userPlace());
        elseif(Util::isConstructionManager())
            $constructionSites = $constructModel->construction_index(null, null, Util::userId());
        else
            $constructionSites = $constructModel->construction_index(Util::userId());

        session(['search_route' => false]);

        return view('construction.index', [
            'constructionSites' => $constructionSites,
            'search'=>false,
            'isAdmin' => $isAdmin,
            'isSuperAdmin'=>Util::isSuperAdmin(),
            'isConstructionAreaAdmin' => Util::isConstructionAreaAdmin()
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $states = States::all();
        $cities = Cities::all();
        $areas = Areas::all();
        $statuses = Construction_status::all();
        $currencies = Currency::all();
        $contractors = Contractors::all();
        $builders = Util::builders();
        $monters = Util::monteri();
        $workers = $builders->merge($monters);
        $constructionManagers = Util::constructionManagers();
        return view('construction.create', [
            'states' => $states,
            'cities' => $cities,
            'areas' => $areas,
            'statuses' => $statuses,
            'currencies' => $currencies,
            'contractors' => $contractors,
            'workers' => $workers,
            'constructionManagers' => $constructionManagers
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'address' => 'required',
            'state' => 'required',
            'city' => 'required',
            'area' => 'required',
            'currency' => 'required'
        ]);

        $discount = $request->input('discount_percent');
        $transport = $request->input('transport_costs');
        if ($discount != null) {
            if (!is_numeric($discount))
                return back()->with('error', __("Discount has to be number or empty field"));
        }
        if ($transport != null) {
            if (!is_numeric($transport))
                return back()->with('error', __("Transport has to be number or empty field"));
        }

        if(Util::isConstructionAreaAdmin() || Util::isConstructionWorker()){
            $area = Util::userPlace();
        }
        else{
            $area = $request->input('area');
        }

        if(Util::isConstructionManager())
            $constructionManager = Util::userId();
        else
            $constructionManager = $request->input('construction_manager');

        $construction = Construction_sites::create([
            'name' => $request->input('name'),
            'tis_id' => $request->input('tis_id'),
            'contact_person' => $request->input('contact_person'),
            'tel1' => $request->input('tel1'),
            'tel2' => $request->input('tel2'),
            'tel3' => $request->input('tel3'),
            'address' => $request->input('address'),
            'id_state' => $request->input('state'),
            'id_city' => $request->input('city'),
            'id_area' => $area,
            'id_status' => $request->input('status'),
            'id_currency' => $request->input('currency'),
            'discount_percent' => $request->input('discount_percent'),
            'discount_percent_customer' => $request->input('discount_percent_customer'),
            'transport_costs' => $request->input('transport_costs'),
            'project_manager' => $request->input('project_manager'),
            'construction_manager' => $constructionManager,
            'id_contractor' => $request->input('contractor'),
            'id_user' => $request->input('builder'),
            'created_by' => Util::userId()
        ]);

        if($construction){
            if ($request->input('comment')) {
                Construction_comments::create([
                    'comment' => $request->input('comment'),
                    'id_user' => Util::userId(),
                    'id_construction_site' => $construction->id
                ]);
            }
            return redirect()->route('construction_sites.show', ['construction_site' => $construction->id])->with('success', __("Data successfully added"));
        }

        return back()->with('error', __("Error"));

    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Construction_sites  $construction_site
     * @return \Illuminate\Http\Response
     */
    public function show(Construction_sites $construction_site)
    {
        $constModel = new Construction_sites();
        $site = $constModel->construction_data($construction_site->id);
        $comMod = new Construction_comments();
        $comments = $comMod->comments($construction_site->id);
        $imgModel = new Construction_images();
        $images = $imgModel->images($construction_site->id);
        $seModel = new Site_equipment();
        $swModel = new Site_work();
        $equipment = $seModel->equipment($construction_site->id);
        $works = $swModel->works($construction_site->id);

        $isAdmin = Util::isAdmin() || Util::isConstructionAreaAdmin();
        $isAreaAdmin = Util::isConstructionAreaAdmin();
        $isConstructionManager = Util::isConstructionManager();
        if (Util::userId() != $site->id_user && !$isAdmin && !$isConstructionManager)
        {
             return view('missing_page');
        }
        if($isAreaAdmin && Util::userPlace() != $site->id_area){
            return view('missing_page');
        }
        if($isConstructionManager && $site->construction_manager != Util::userId()){
            return view('missing_page');
        }

        $equipmentSum = 0;
        $workSum = 0;
        $other = 0;
        $priceModel = new Construction_prices();
        foreach($equipment as $equip){
            $price = $priceModel->price($construction_site->id_area, $construction_site->id_currency, $equip->id_equipment,
                null, $construction_site->created_at);
            $equip->price = $price;
            $equip->sum = $price*$equip->quantity;
            $equipmentSum += $equip->sum;
        }

        foreach($works as $work){
            $price = $priceModel->price($construction_site->id_area, $construction_site->id_currency, null,
                $work->id_construction_work, $construction_site->created_at);
            $work->price = $price;
            $work->sum = $price*$work->quantity;
            $workSum += $work->sum;
            $otherWork = Construction_works::find($work->id);
            if ($otherWork->id_category == 25)
                $other += $work->sum;
        }

        $total = $equipmentSum + $workSum;
        $profit = $total;
        if(Util::firmaId() != 1) {
            if ($construction_site->discount_percent_customer) {
                $profit = $profit - $total * $construction_site->discount_percent_customer / 100;
            }
            if ($construction_site->discount_percent) {
                $profit = $profit - $total * $construction_site->discount_percent / 100;
            }
            if ($construction_site->transport_costs) {
                $profit = $profit + $profit * $construction_site->transport_costs / 100;
            }
            $profit = $profit*config('app.construction_profit_percent');
        }
        else {
            //other works have no transport
            $profit = $profit + ($profit-$other)*$construction_site->transport_costs/100;
        }

        $chModel = new Change_history();
        $history = $chModel->historyConstruction($construction_site->id);

        $files = Files::where('id_construction_site', $construction_site->id)->get();

        return view('construction.show', [
            'site' => $site,
            'comments' => $comments,
            'images' => $images,
            'equipment' => $equipment,
            'works' => $works,
            'superAdminOnly' => Util::isSuperAdmin(),
            'equipmentSum' => $equipmentSum,
            'workSum' => $workSum,
            'total' => $total,
            'profit' => $profit,
            'history' => $history,
            'files' => $files
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Construction_sites  $construction_site
     * @return \Illuminate\Http\Response
     */
    public function edit(Construction_sites $construction_site)
    {
        $states = States::all();
        $cities = Cities::all();
        $areas = Areas::all();
        $statuses = Construction_status::all();
        $currencies = Currency::all();
        $contractors = Contractors::all();
        $builders = Util::builders();
        $monters = Util::monteri();
        $workers = $builders->merge($monters);
        $constModel = new Construction_sites();
        $site = $constModel->construction_data($construction_site->id);
        $comMod = new Construction_comments();
        $comments = $comMod->comments($construction_site->id);
        $imageTypes = Image_types::all();
        $imgModel = new Construction_images();
        $images = $imgModel->images($construction_site->id);
        $equipmentCategories = Equipment_categories::all();
        $workCategories = Work_categories::all();
        $seModel = new Site_equipment();
        $swModel = new Site_work();
        $equipment = $seModel->equipment($construction_site->id, $construction_site->id_area);
        $works = $swModel->works($construction_site->id, $construction_site->id_area);
        $constructionManagers = Util::constructionManagers();

        $isAdmin = Util::isAdmin() || Util::isConstructionAreaAdmin();
        $isAreaAdmin = Util::isConstructionAreaAdmin();
        $isConstructionManager = Util::isConstructionManager();
        if (Util::userId() != $site->id_user && !$isAdmin && !$isConstructionManager)
        {
             return view('missing_page');
        }
        if($isAreaAdmin && Util::userPlace() != $site->id_area){
            return view('missing_page');
        }
        if($isConstructionManager && $site->construction_manager != Util::userId()){
            return view('missing_page');
        }

        $priceModel = new Construction_prices();
        foreach($equipment as $equip){
            $price = $priceModel->price($construction_site->id_area, $construction_site->id_currency, $equip->id_equipment, null,
                $construction_site->created_at);
            $equip->price = $price;
            $equip->sum = $price*$equip->quantity;
        }

        foreach($works as $work){
            $price = $priceModel->price($construction_site->id_area, $construction_site->id_currency, null,
                $work->id_construction_work, $construction_site->created_at);
            $work->price = $price;
            $work->sum = $price*$work->quantity;
        }

        $storageModel = new Worker_equipment();
        $workerEquipment = $storageModel->equipment_for_user(Util::userId());

        $files = Files::where('id_construction_site', $construction_site->id)->get();

        return view('construction.edit', [
            'states' => $states,
            'cities' => $cities,
            'areas' => $areas,
            'statuses' => $statuses,
            'currencies' => $currencies,
            'contractors' => $contractors,
            'workers' => $workers,
            'site' => $site,
            'comments' => $comments,
            'id_user' => Util::userId(),
            'isAdmin' => $isAdmin,
            'imageTypes' => $imageTypes,
            'images' => $images,
            'equipmentCategories' => $equipmentCategories,
            'workCategories' => $workCategories,
            'equipment' => $equipment,
            'works' => $works,
            'isSuperAdmin' => Util::isSuperAdmin() || Util::isConstructionAreaAdmin(),
            'superAdminOnly' => Util::isSuperAdmin(),
            'workerEquipment' => $workerEquipment,
            'files' => $files,
            'constructionManagers' => $constructionManagers
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Construction_sites  $construction_site
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Construction_sites $construction_site)
    {
        $request->validate([
            'name' => 'required',
            'address' => 'required',
            'state' => 'required',
            'city' => 'required',
            'area' => 'required',
            'currency' => 'required',
            'document' => 'mimes:xlsx,xls,pdf,dwg,zip,sor,doc,docx'
        ]);

        $document = $request->file('document');
        if($document){
            $originalFile = $document->getClientOriginalName();
            $filename = strtotime(date('d.m.Y. H:i:s')).'_'.$originalFile;
            $folder = 'uploads/documents/'.quartal();
            create_folder($folder);
            $document->move($folder, $filename);
            Files::create([
                'file_url' => '/'.$folder.'/'.$filename,
                'id_construction_site' => $construction_site->id,
                'filename' => $originalFile
            ]);
        }

        //admin i radnik automatski upisuju svoje podrucje. ne mogu da biraju iz liste
        if(Util::isConstructionAreaAdmin() || Util::isConstructionWorker()){
            $area = Util::userPlace();
        }
        else{
            $area = $request->input('area');
        }

        $discount = $request->input('discount_percent');
        $discountCustomer = $request->input('discount_percent_customer');
        $transport = $request->input('transport_costs');
        if ($discount != null) {
            if (!is_numeric($discount))
                return back()->with('error', __("Discount has to be number or empty field"));
        }
        if ($discountCustomer != null) {
            if (!is_numeric($discountCustomer))
                return back()->with('error', __("Discount has to be number or empty field"));
        }
        if ($transport != null) {
            if (!is_numeric($transport))
                return back()->with('error', __("Transport has to be number or empty field"));
        }

        if ($request->input('appointment_date'))
            $appointmentDate = date('Y-m-d', strtotime($request->input('appointment_date')));
        else   
            $appointmentDate = null;
        if ($request->input('delay_date'))
            $delayDate = date('Y-m-d', strtotime($request->input('delay_date')));
        else   
            $delayDate = null;
        if ($request->input('realization_date'))
            $realizationDate = date('Y-m-d', strtotime($request->input('realization_date')));
        else   
            $realizationDate = null;
        if ($request->input('withdrawal_date'))
            $withDrawalDate = date('Y-m-d', strtotime($request->input('withdrawal_date')));
        else   
            $withDrawalDate = null;


        if ($appointmentDate && $request->input('appointment_time'))
            $appointmentDate = date('Y-m-d', strtotime($appointmentDate)).' '.$request->input('appointment_time').':'.date('s');
        if ($delayDate && $request->input('delay_time'))
            $delayDate = date('Y-m-d', strtotime($delayDate)).' '.$request->input('delay_time').':'.date('s');

        if(Util::isAdmin() || Util::isConstructionAreaAdmin() || Util::isConstructionManager()){
            $construction = Construction_sites::where('id',$construction_site->id)->update([
                'name' => $request->input('name'),
                'tis_id' => $request->input('tis_id'),
                'contact_person' => $request->input('contact_person'),
                'tel1' => $request->input('tel1'),
                'tel2' => $request->input('tel2'),
                'tel3' => $request->input('tel3'),
                'address' => $request->input('address'),
                'id_state' => $request->input('state'),
                'id_city' => $request->input('city'),
                'id_area' => $area,
                'id_status' => $request->input('status'),
                'id_currency' => $request->input('currency'),
                'discount_percent' => $request->input('discount_percent'),
                'discount_percent_customer' => $request->input('discount_percent_customer'),
                'transport_costs' => $request->input('transport_costs'),
                'project_manager' => $request->input('project_manager'),
                'construction_manager' => $request->input('construction_manager'),
                'id_contractor' => $request->input('contractor'),
                'id_user' => $request->input('builder'),
                'appointment_date' => $appointmentDate,
                'delay_date' => $delayDate,
                'realization_date' => $realizationDate,
                'withdrawal_date' => $withDrawalDate,
                'cluster' => $request->input('cluster'),
                'odo' => $request->input('odo'),
                'izvod' => $request->input('izvod'),
                'connector' => $request->input('connector'),
                'created_by' => Util::userId()
            ]);
        }
        else {
            $construction = Construction_sites::where('id',$construction_site->id)->update([
                'id_status' => $request->input('status'),
            ]);
        }

        if($construction){
            Change_history::create([
                'id_user' => Util::userId(),
                'id_construction_site' => $construction_site->id
            ]);
            if ($request->input('comment')) {
                Construction_comments::create([
                    'comment' => $request->input('comment'),
                    'id_user' => Util::userId(),
                    'id_construction_site' => $construction_site->id
                ]);
            }

            $imageType = $request->input('image_type');
            $images = $request->file('images');
            $img = new Img();
            $folder = 'uploads/construction_images/'.quartal();

            if (!file_exists($folder)){
                mkdir($folder, 0755, true);
            }

            if($images) {
                $this->validate($request, [
                    'images.*' => 'image|mimes:jpeg,png,jpg,gif',
                    'image_type' => 'required'
                ]);
                foreach ($images as $num=>$file) {
                    $extension = $file->getClientOriginalExtension();
                    $filename = time().'-'.$num.'-construction'.'.'.$extension;
                    $fileIntervention = $img->make($file->getRealPath());
                    $fileIntervention->save($folder . '/' . $filename, 50);
                    $description = Image_types::find($imageType);
                    Construction_images::create([
                        'url' => '/' . $folder . '/' . $filename,
                        'id_construction_site' => $construction_site->id,
                        'image_type' => $imageType,
                        'description' => $description->type
                    ]);
                }
            }

            return redirect()->route('construction_sites.show', ['construction_site' => $construction_site->id])->with('success', __("Data successfully changed"));
        }

        return back()->with('error', __("Error"));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Construction_sites  $construction_site
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findSite = Construction_sites::find($request->input('id_site'));

        try{
            $images = Construction_images::where('id_construction_site', $request->input('id_site'))->get();
            $files = Files::where('id_construction_site', $request->input('id_site'))->get();
            if($findSite->delete()){
                foreach ($images as $img){
                    $file = ltrim($img->url,'/');
                    if (file_exists($file)){
                        unlink($file);
                    }
                }
                foreach ($files as $fl){
                    $file = ltrim($fl->file_url,'/');
                    if (file_exists($file)){
                        unlink($file);
                    }
                }
            }
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Item can't be deleted because it's in use"));
        }


        return back()->withInput()->with('error', __("Data cannot be deleted"));
    }

    public function import_equipment(){
        $areas = Areas::all();
        $currencies = Currency::all();
        return view('construction.import_equipment', [
            'areas' => $areas,
            'currencies' => $currencies
        ]);
    }

    public function import_construction_works(){
        $areas = Areas::all();
        $currencies = Currency::all();
        return view('construction.import_cworks', [
            'areas' => $areas,
            'currencies' => $currencies
        ]);
    }

    public function delete_comment(Request $request){
        $findComment = Construction_comments::find($request->input('id_comment'));
        if($findComment->delete()){
            return back()->with('success', __("Data successfully deleted"));
        }
        else {
            return back()->with('errors', __("Data cannot be deleted"));
        }
    }

    public function delete_construction_image(Request $request){
        $findImage = Construction_images::find($request->input('id_image'));
        $file = ltrim($findImage->url,'/');

        if(file_exists($file)){
            unlink($file);
        }

        if($findImage->delete()){
            return back()->with('success', __("Image successfully deleted"));
        }
        else {
            return back()->with('errors', __("Error"));
        }
    }

    public function delete_equipment_works(Request $request){
        $idEquipment = $request->input('id_equipment');
        $idConstructionWork = $request->input('id_construction_work');
        $idSite = $request->input('id_site');
        $text = '';
        if($idEquipment){
            Site_equipment::where('id_construction_site', $idSite)->where('id_equipment', $idEquipment)->delete();
            $text = __("Equipment successfully deleted");
        }
        elseif($idConstructionWork){
            Site_work::where('id_construction_site', $idSite)->where('id_construction_work', $idConstructionWork)->delete();
            $text = __("Work successfully deleted");
        }
        return back()->with('success', $text);
    }

    public function construction_search(){
        $states = States::all();
        $cities = Cities::all();
        $areas = Areas::all();
        $statuses = Construction_status::all();
        $currencies = Currency::all();
        $contractors = Contractors::all();
        $builders = Util::builders();
        return view('construction.search', [
            'states' => $states,
            'cities' => $cities,
            'areas' => $areas,
            'statuses' => $statuses,
            'currencies' => $currencies,
            'contractors' => $contractors,
            'builders' => $builders
        ]);
    }

    public function construction_advanced_search(){
        $states = States::all();
        $cities = Cities::all();
        $areas = Areas::all();
        $statuses = Construction_status::all();
        $currencies = Currency::all();
        $contractors = Contractors::all();
        $builders = Util::builders();
        $constructionManagers = Util::constructionManagers();
        return view('construction.advanced_search', [
            'states' => $states,
            'cities' => $cities,
            'areas' => $areas,
            'statuses' => $statuses,
            'currencies' => $currencies,
            'contractors' => $contractors,
            'builders' => $builders,
            'constructionManagers' => $constructionManagers
        ]);
    }

    public function construction_search_result(Request $request){
        $param = $request->input('param');
        $name = $request->input('name');
        $tisId = $request->input('tis_id');
        $contactPerson = $request->input('contact_person');
        $tel1 = $request->input('tel1');
        $tel2 = $request->input('tel2');
        $tel3 = $request->input('tel3');
        $address = $request->input('address');
        $state = $request->input('state');
        $city = $request->input('city');
        $status = $request->input('status');
        $currency = $request->input('currency');
        $discount1 = $request->input('discount_percent');
        $discount2 = $request->input('discount_percent_customer');
        $transport = $request->input('transport_costs');
        $manager = $request->input('project_manager');
        $contractor = $request->input('contractor');
        $appointmentDate = $request->input('appointment_date');
        $delayDate = $request->input('delay_date');
        $realizationDate = $request->input('realization_date');
        $withdrawalDate = $request->input('withdrawal_date');
        $noStatus = $request->input('no_status');
        $realStart = $request->input('realization_start');
        $realEnd = $request->input('realization_end');
        $cluster = $request->input('cluster');
        $odo = $request->input('odo');
        $izvod = $request->input('izvod');
        $connector = $request->input('connector');
        $constructionManager = $request->input('construction_manager');

        if(Util::isConstructionAreaAdmin() || Util::isConstructionWorker()){
            $area = Util::userPlace();
        }
        else{
            $area = $request->input('area');
        }

        if(Util::isConstructionManager())
            $constructionManager = Util::userId();

        if(Util::isConstructionWorker()){
            $worker = Util::userId();
        }
        else{
            $worker = $request->input('builder');
        }

        if ($appointmentDate)
            $appointmentDate = date('Y-m-d', strtotime($appointmentDate));
        if ($delayDate)
            $delayDate = date('Y-m-d', strtotime($delayDate));
        if ($realizationDate)
            $realizationDate = date('Y-m-d', strtotime($realizationDate));
        if ($withdrawalDate)
            $withdrawalDate = date('Y-m-d', strtotime($withdrawalDate));

        if ($realStart && $realEnd){
            $realStart = date('Y-m-d', strtotime($realStart));
            $realEnd = date('Y-m-d', strtotime($realEnd));
        }
        else {
            $realStart = null;
            $realEnd = null;
        }

        $csModel = new Construction_sites();
        if($param == 'advanced'){
            $result = $csModel->search($name, $tisId, $contactPerson, $tel1, $tel2, $tel3, $address, $state, $city, $area, $status, $currency, $discount1,
                                        $discount2, $transport, $contractor, $worker, $manager, $appointmentDate, $delayDate, $realizationDate, $withdrawalDate,
                                        $noStatus, $realStart, $realEnd, $cluster, $odo, $izvod, $connector,$constructionManager, true);
            $noPagination = $csModel->search($name, $tisId, $contactPerson, $tel1, $tel2, $tel3, $address, $state, $city, $area, $status, $currency, $discount1,
                                        $discount2, $transport, $contractor, $worker, $manager, $appointmentDate, $delayDate, $realizationDate, $withdrawalDate,
                                        $noStatus, $realStart, $realEnd, $cluster, $odo, $izvod, $connector, $constructionManager);

        }
        else {
            $result = $csModel->search($name, $tisId, $contactPerson, null, null, null, null, null, null, $area, null, null, null,
                                        null, null, $contractor, $worker, $manager, $appointmentDate, $delayDate, $realizationDate, $withdrawalDate, $noStatus,
                                        null, null, null, null, null, null, $constructionManager, true);
            $noPagination = $csModel->search($name, $tisId, $contactPerson, null, null, null, null, null, null, $area, null, null, null,
                                         null, null, $contractor, $worker, $manager, $appointmentDate, $delayDate, $realizationDate, $withdrawalDate, $noStatus, $constructionManager);
        }

        $ids = Arr::pluck($noPagination, 'id');
        $count = count($ids);
        $ids = json_encode($ids);
        session(['ids_export' => $ids]);

        session(['search_route' => url()->full()]);

        return view('construction.search_result', [
            'constructionSites' => $result,
            'search'=>true,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin'=>Util::isSuperAdmin(),
            'isConstructionAdmin' => Util::isConstructionAreaAdmin(),
            'count' => $count
        ]);

    }

}
