<?php

namespace App\Http\Controllers;

use App\Models\Contractors;
use Illuminate\Http\Request;

class ContractorController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $contractors = Contractors::all();
        return view('contractor.index', ['contractors' => $contractors]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('contractor.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'contractor' => 'required'
        ]);
        $contractor = Contractors::create([
            'contractor' => trim($request->input('contractor'))
        ]);

        $contractors = Contractors::all();
        if ($contractor){
            return view('contractor.index', ['contractors' => $contractors]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Contractors  $contractor
     * @return \Illuminate\Http\Response
     */
    public function show(Contractors $contractor)
    {
        $contractor = Contractors::find($contractor->id);
        return view('contractor.show', ['contractor' => $contractor]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Contractors  $contractor
     * @return \Illuminate\Http\Response
     */
    public function edit(Contractors $contractor)
    {
        $contractor = Contractors::find($contractor->id);

        return view('contractor.edit', ['contractor' => $contractor]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Contractors  $contractor
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Contractors $contractor)
    {
        $request->validate([
            'contractor' => 'required'
        ]);
        $contractorUpdate = Contractors::where('id', $contractor->id)->update([
            'contractor'=>trim($request->input('contractor'))
        ]);

        if ($contractorUpdate){
            return redirect()->route('contractor.show', ['contractor' => $contractor->id])->with('success',  __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Contractors  $contractor
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findContractor = Contractors::find($request->input('id_contractor'));

        try{
            $findContractor->delete();
            return back()->withInput()->with('success',  __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
