<?php

namespace App\Http\Controllers;

use App\Models\Currency;
use Illuminate\Http\Request;

class CurrencyController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $currencies = Currency::all();
        return view('currency.index', ['currencies' => $currencies]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('currency.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'currency' => 'required',
            'currency_short' => 'required'
        ]);
        $currencyCreate = Currency::create([
            'currency' => trim($request->input('currency')),
            'currency_short' => trim($request->input('currency_short'))
        ]);

        $currencies = Currency::all();
        if ($currencyCreate){
            return view('currency.index', ['currencies' => $currencies]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Currency  $currency
     * @return \Illuminate\Http\Response
     */
    public function show(Currency $currency)
    {
        $currency = Currency::find($currency->id);
        return view('currency.show', ['currency' => $currency]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Currency  $currency
     * @return \Illuminate\Http\Response
     */
    public function edit(Currency $currency)
    {
        $currency = Currency::find($currency->id);

        return view('currency.edit', ['currency' => $currency]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Currency  $currency
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Currency $currency)
    {
        $request->validate([
            'currency' => 'required',
            'currency_short' => 'required'
        ]);
        $currencyUpdate = Currency::where('id', $currency->id)->update([
            'currency'=>trim($request->input('currency')),
            'currency_short' => trim($request->input('currency_short'))
        ]);

        if ($currencyUpdate){
            return redirect()->route('currency.show', ['currency' => $currency->id])->with('success',  __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Currency  $currency
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findCurrency = Currency::find($request->input('id_currency'));

        try{
            $findCurrency->delete();
            return back()->withInput()->with('success',  __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
