<?php

namespace App\Http\Controllers;

use App\Models\Areas;
use App\Models\Clusters;
use App\Models\De_change_history;
use App\Models\De_images;
use App\Models\De_works;
use App\Models\De_construction_sites;
use Illuminate\Http\Request;
use App\Traits\Util;
use App\Models\Const_teams;
use App\Models\De_absent_workers;
use App\Models\De_comments;
use App\Models\De_device_history;
use App\Models\De_files;
use App\Models\De_mounted_devices;
use App\Models\De_site_equipment;
use App\Models\De_site_materials;
use App\Models\De_site_work;
use App\Models\De_statuses;
use App\Models\De_target;
use App\Models\DistributiveKnot;
use App\Models\Materials;
use App\Models\Pans;
use App\Models\Polish_logs;
use App\Models\Providers;
use App\Models\Worker_equipment;
use App\Models\Worker_materials;
use App\Oprema;
use App\Uredjaji;
use App\User;
use DateTime;
use Illuminate\Support\Arr;
use Intervention\Image\ImageManager as Img;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use Symfony\Component\HttpFoundation\StreamedResponse;

class DeConstructionSitesController extends Controller
{
    private function linkValidationCheck($leader)
    {
        if(!Util::isSuperAdmin() && !Util::isAdmin()){
            if($leader != Util::userId() && !Util::isConstructionManager()){
                echo 'sta ces ovde be'; exit;
            }
        }
    }

    private function someAdmin(){
        return Util::isConstructionManager() || Util::isAdmin() || Util::isSuperAdmin();
    }

    private function isMoreThan31Days($date1, $date2){
        $datetime1 = new DateTime($date1);
        $datetime2 = new DateTime($date2);
        $interval = $datetime1->diff($datetime2);
        $daysDifference = $interval->days;
        return $daysDifference > 31;
    }

    public function index()
    {
        $deMod = new De_construction_sites();
        if(Util::isColumnLeader()){
            $constructionSites = $deMod->index(Util::userId(), null, Util::providers());
        }
        elseif(Util::isConstructionManager()){
            $constructionSites = $deMod->index(null, null,Util::providers());
        }
        elseif(Util::isAdmin() || Util::isSuperAdmin()){
            $constructionSites = $deMod->index();
        }
        else {
            return back()->with('error', __('Error'));
        }

        $tMod = new Const_teams();
        return view('deConstructionSites.index', ['constructionSites' => $constructionSites, 'isSuperAdmin' => Util::isSuperAdmin(), 'deMod' => $deMod, 'tMod' => $tMod]);
    }

    public function create()
    {
        if(!$this->someAdmin())
            return back()->with('error', "Only admin can see this page");
        $leaders = Util::columnLeaders();
        $areas = Areas::all();
        $providers = Providers::all();
        $pans = Pans::all();
        $knots = DistributiveKnot::all();
        return view('deConstructionSites.create', [
            'leaders' => $leaders, 
            'areas' => $areas, 
            'isColumnLeader' => Util::isColumnLeader(), 
            'providers' => $providers,
            'isSuperAdmin' => Util::isSuperAdmin(),
            'clusters' => Clusters::all(),
            'pans' => $pans,
            'statuses' => De_statuses::all(),
            'knots' => $knots
        ]);
    }

    public function store(Request $request)
    {
        if(!$this->someAdmin())
            return back()->with('error', "Only admin can see this page");
        $date = database_date($request->input('date'));
        $polisherReport = $request->input('polisher_report');
        $leader = $request->input('leader');
        $area = $request->input('area');
        $insertDate = $request->input('insert_date');
        $cluster = $request->input('cluster');
        $maintenance = $request->input('maintenance');
        $status = $request->input('status');
        $tMod = new Const_teams();
        if($insertDate){
            $polishDate = date('Y-m-d');
        }
        else {
            $polishDate = database_date($request->input('polish_date'));
        }
        if($request->input('number_of_workers')){
            $numberOfWorkers = $request->input('number_of_workers');
        }
        else{
            $numberOfWorkers = count($tMod->workersLead($leader = $request->input('leader')));
        }
        $comment = $request->input('comment');
        $workStart = $request->input('work_start');
        $workEnd = $request->input('work_end');
        $pause = $request->input('pause');
        $place = $request->input('place');
        $street = $request->input('street');
        $pan = $request->input('pan');
        $dp = $request->input('dp');
        $knot = $request->input('knot');
        $connectionId = $request->input('connection_id');
        $workOrderNumber = $request->input('work_order_number');

        $provider = $request->input('provider');

        if(Util::isColumnLeader())
            $leader = Util::userId();

        $request->validate([
            'date' => 'required',
            'work_start' => 'required',
            'work_end' => 'required',
            'pause' => 'required',
            'connection_id' => 'nullable|numeric'
        ]);

        $create = De_construction_sites::create([
            'date' => $date,
            'polisher_report' => $polisherReport,
            'polish_date' => $polishDate,
            'leader' => $leader,
            'area' => $area,
            'number_of_workers' => $numberOfWorkers,
            'work_start' => $workStart,
            'work_end' => $workEnd,
            'pause' => $pause,
            'place' => $place,
            'street' => $street,
            'provider' => $provider,
            'pan_id' => $pan,
            'dp' => $dp,
            'cluster' => $cluster,
            'maintenance' => $maintenance?1:0,
            'status_id' => $status,
            'knot_id' => $knot,
            'connection_id' => $connectionId,
            'work_order_number' => $workOrderNumber
        ]);

        if($create && $comment){
            De_comments::create([
                'comment' => $comment,
                'id_site' => $create->id,
                'id_user' => Util::userId()
            ]);
        }

        if($create){
            De_change_history::create([
                'id_user' => Util::userId(),
                'id_site' => $create->id
            ]);
            if($insertDate){
                Polish_logs::create([
                    'user_id' => Util::userId(),
                    'site_id' => $create->id
                ]);
            }
            return redirect()->route('de_construction_sites.show', [$create->id])->with('success', __("Data successfully added"));
        }
        else
            return back()->with('error', __("Error"));
    }

    public function show(De_construction_sites $de_construction_site)
    {
        $this->linkValidationCheck($de_construction_site->leader);
        $deMod = new De_construction_sites();
        $site = $deMod->data($de_construction_site->id);
        $hMod = new De_change_history();
        $history = $hMod->history($de_construction_site->id);
        $cMod = new De_comments();
        $comments = $cMod->comments($de_construction_site->id);
        $iMod = new De_images();
        $images = $iMod->images($de_construction_site->id);
        $wMod = new De_site_work();
        $works = $wMod->works($de_construction_site->id);
        $workHours = timeDifference($de_construction_site->work_start, $de_construction_site->work_end);
        $logMod = new Polish_logs();
        $logs = $logMod->logs($de_construction_site->id, false);
        $changedBy = $logMod->logs($de_construction_site->id, true);
        $files = De_files::where('site_id', $de_construction_site->id)->get();
        $devLogModel = new De_device_history();
        $deviceLog = $devLogModel->deviceLog($de_construction_site->id);
        if($changedBy){
            $changedBy = $changedBy->name.' '.$changedBy->surname.' ('.date('d.m.Y', strtotime($changedBy->created_at)).')';
        }

        //equipment
        $equipModel = new De_site_equipment();
        $equipment = $equipModel->equipment($de_construction_site->id);
        //materials
        $maMod = new De_site_materials();
        $spentMaterial = $maMod->spentMaterial($de_construction_site->id);

        $mountMod = new De_mounted_devices();
        $mountedDevices = $mountMod->mountedDevices($de_construction_site->id);

        return view('deConstructionSites.show', [
            'site' => $site, 
            'history' => $history, 
            'comments' => $comments,
            'images' => $images,
            'files' => $files,
            'works' => $works,
            'workHours' => $workHours,
            'isColumnLeader' => Util::isColumnLeader(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'logs' => $logs,
            'changedBy' => $changedBy,
            'isSubcontractor' => Util::isSubcontractor(),
            'equipment' => $equipment,
            'spentMaterial' => $spentMaterial,
            'deviceLog' => $deviceLog,
            'mountedDevices' => $mountedDevices
        ]);
    }

    public function edit(De_construction_sites $de_construction_site)
    {
        $this->linkValidationCheck($de_construction_site->leader);
        $leaders = Util::columnLeaders();
        $areas = Areas::all();
        $providers = Providers::all();
        $iMod = new De_images();
        $cMod = new De_comments();
        $deMod = new De_works();
        $wsMod = new De_site_work();
        $absMod = new De_absent_workers();
        $images = $iMod->images($de_construction_site->id);
        $comments = $cMod->comments($de_construction_site->id);
        $absentWorkers = $absMod->absentWorkers($de_construction_site->id);
        $files = De_files::where('site_id', $de_construction_site->id)->get();
        $clusters = Clusters::all();
        if(Util::isSuperAdmin()){
            $statuses = De_statuses::all();
        }
        elseif(Util::isAdmin()){
            $statuses = De_statuses::whereNotIn('id', [6])->get();
        }
        else {
            $statuses = De_statuses::whereNotIn('id', [4,6])->get();
        }
        $knots = DistributiveKnot::all();

        $tMod = new Const_teams();
        $workers = $tMod->workersLead($de_construction_site->leader);

        if($de_construction_site->provider){
            $worksAll = De_works::orderBy('code')->where('provider', $de_construction_site->provider)->get();
        }
        else{
            $worksAll = De_works::all();
        }
        $workIds = Arr::pluck($worksAll, 'id');
        $works = array();
        foreach($workIds as $key=>$id){
            $work = $deMod->work_data($id);
            $quantity = $wsMod->workQuantity($de_construction_site->id, $id);
            $works[$key]['id'] = $id;
            $works[$key]['code'] = $work->code;
            $works[$key]['work'] = $work->work;
            $works[$key]['unit'] = $work->unit_short;
            $works[$key]['quantity'] = $quantity;
        }

        //devices

        $devices = Uredjaji::devicesByType(config('app.dev_type_optika'));
        $mountMod = new De_mounted_devices();
        $mountedDevices = $mountMod->mountedDevices($de_construction_site->id);

        //equipment
        $equipModel = new De_site_equipment();
        $equipment = $equipModel->equipment($de_construction_site->id);

        if(Util::isAdmin() || Util::isConstructionManager()){
            $oprema = Oprema::all()->where('is_active', 1);
        }
        else {
            $storageModel = new Worker_equipment();
            $oprema = $storageModel->mont_client_equipment(Util::userId());
        }

        //materials
        $maMod = new De_site_materials();
        $spentMaterial = $maMod->spentMaterial($de_construction_site->id);

        if(Util::isAdmin()){
            $materials = Materials::all();
        }
        else {
            $maMod = new Worker_materials();
            $materials = $maMod->materials_for_user(Util::userId());
        }

        $leaders = Util::columnLeaders();

        return view('deConstructionSites.edit', [
            'leaders' => $leaders,
            'areas' => $areas,
            'providers' => $providers,
            'site' => $de_construction_site,
            'images' => $images,
            'files' => $files,
            'comments' => $comments,
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isColumnLeader' => Util::isColumnLeader(),
            'works' => $works,
            'isColumnLeader' => Util::isColumnLeader(),
            'isConstructionManager' => Util::isConstructionManager(),
            'someAdmin' => $this->someAdmin(),
            'workers' => $workers,
            'absentWorkers' => $absentWorkers,
            'clusters' => $clusters,
            'equipment' => $equipment,
            'oprema' => $oprema,
            'materials' => $materials,
            'spentMaterial' => $spentMaterial,
            'columnLeaders' => $leaders,
            'mountedDevices' => $mountedDevices,
            'devices' => $devices,
            'isAdmin' => Util::isAdmin(),
            'pans' => Pans::all(),
            'statuses' => $statuses,
            'knots' => $knots
        ]);
    }

    public function update(Request $request, De_construction_sites $de_construction_site)
    {
        $date = database_date($request->input('date'));
        $polisherReport = $request->input('polisher_report');
        $area = $request->input('area');
        $comment = $request->input('comment');
        $workStart = $request->input('work_start');
        $workEnd = $request->input('work_end');
        $pause = $request->input('pause');
        $place = $request->input('place');
        $street = $request->input('street');
        $pan = $request->input('pan');
        $dp = $request->input('dp');
        $images = $request->file('images');
        $confirmReport = $request->input('confirm_report');
        $cluster = $request->input('cluster');
        $absentWorkers = $request->input('absent_workers');
        $absMod = new De_absent_workers();
        $provider = $request->input('provider');
        $maintenance = $request->input('maintenance');
        $status = $request->input('status');
        $knot = $request->input('knot');
        $connectionId = $request->input('connection_id');
        $workOrderNumber = $request->input('work_order_number');

        if($confirmReport){
            $polishDate = date('Y-m-d');
        }
        else {
            $polishDate = database_date($request->input('polish_date'));
        }
        if(Util::isColumnLeader())
            $leader = Util::userId();
        else
            $leader = $request->input('leader');
            
        if($request->input('number_of_workers') && Util::isSuperAdmin()){
            $numberOfWorkers = $request->input('number_of_workers');
        }
        else{
            $tMod = new Const_teams();
            $numberOfWorkers = count($tMod->workersLead($leader = $leader));
        }
        $request->validate([
            'date' => 'required',
            'work_start' => 'required',
            'work_end' => 'required',
            'pause' => 'required',
            'connection_id' => 'nullable|numeric'
        ]);

        if($this->someAdmin()){
            $update = De_construction_sites::where('id', $de_construction_site->id)->update([
                'date' => $date,
                'polisher_report' => $polisherReport,
                'polish_date' => $polishDate,
                'leader' => $leader,
                'area' => $area,
                'number_of_workers' => $numberOfWorkers,
                'work_start' => $workStart,
                'work_end' => $workEnd,
                'pause' => $pause,
                'place' => $place,
                'street' => $street,
                'provider' => $provider,
                'pan_id' => $pan,
                'dp' => $dp,
                'cluster' => $cluster,
                'report_confirmed' => $confirmReport?1:0,
                'maintenance' => $maintenance?1:0,
                'status_id' => $status,
                'knot_id' => $knot,
                'connection_id' => $connectionId,
                'work_order_number' => $workOrderNumber
            ]);
        }
        else {
            if($de_construction_site->report_confirmed == 0)
                $update = true;
            else
                $update = false;
        }

        if($update && $images){
            if($images){
                $this->validate($request, [
                    'images.*' => 'image|mimes:jpeg,png,jpg,gif'
                ]);
                $num = 0;
                $img = new Img();
                $folder = 'uploads/de_images/'.quartal();
                if (!file_exists($folder)){
                    mkdir($folder, 0755, true);
                }
                foreach($images as $file){
                    $extension = $file->getClientOriginalExtension();
                    $filename = time().'-'.$num.'-de'.'.'.$extension;
                    $num++;
                    $fileInt = $img->make($file->getRealPath());
                    $fileInt->save($folder.'/'.$filename, 50);
                    De_images::create([
                        'url' => '/'.$folder.'/'.$filename,
                        'id_site' => $de_construction_site->id
                    ]);
                }
            }
        }

        $files = $request->file('files');
        if($update && $files){
            $request->validate([
                'files.*' => 'mimes:xlsx,xls,pdf,dwg,zip,sor,doc,docx'
            ]);
            $num = 0;
            foreach($files as $file){
                $originalFile = $file->getClientOriginalName();
                $filename = pathinfo($originalFile, PATHINFO_FILENAME);
                $extension = pathinfo($originalFile, PATHINFO_EXTENSION);
                $filename = $filename.'-'.time().'-'.$num.'.'.$extension;
                $folder = 'uploads/documents/'.quartal();
                create_folder($folder);
                $file->move($folder, $filename);
                De_files::create([
                    'file_url' => '/'.$folder.'/'.$filename,
                    'site_id' => $de_construction_site->id,
                    'filename' => $originalFile
                ]);
                $num++;
             }
        }


        if($update && $comment){
            De_comments::create([
                'comment' => $comment,
                'id_site' => $de_construction_site->id,
                'id_user' => Util::userId()
            ]);
        }

        if($update){
            De_change_history::create([
                'id_user' => Util::userId(),
                'id_site' => $de_construction_site->id
            ]);
            if($confirmReport){
                Polish_logs::create([
                    'user_id' => Util::userId(),
                    'site_id' => $de_construction_site->id
                ]);
            }
            if($absentWorkers){
                foreach($absentWorkers as $id => $worker){
                    $exists = De_absent_workers::where('site_id',$de_construction_site->id)->where('worker_id',$id)->first();
                    if(!$exists){
                        De_absent_workers::create([
                            'worker_id' => $id,
                            'site_id' => $de_construction_site->id
                        ]);
                    }
                }
                $numberOfWorkers = count($tMod->workersLead($leader = $leader)) - $absMod->count($de_construction_site->id);
                De_construction_sites::where('id', $de_construction_site->id)->update([
                    'number_of_workers' => $numberOfWorkers
                ]);
            }
            else {
                De_absent_workers::where('site_id',$de_construction_site->id)->delete();
            }
            return redirect()->route('de_construction_sites.show', [$de_construction_site->id])->with('success', __("Data successfully added"));
        }
        else
            return back()->with('error', __("Report is confirmed and cannot be changed"));
    }

    public function destroy(Request $request)
    {
        $findSite = De_construction_sites::find($request->input('id_site'));

        try{
            $images = De_images::where('id_site', $request->input('id_site'))->get();
            $files = De_files::where('site_id', $request->input('id_site'))->get();
            if($findSite->delete()){
                foreach ($images as $img){
                    $file = ltrim($img->url,'/');
                    if (file_exists($file)){
                        unlink($file);
                    }
                }
                foreach ($files as $file){
                    $file = ltrim($file->url,'/');
                    if (file_exists($file)){
                        unlink($file);
                    }
                }
            }
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Item can't be deleted because it's in use"));
        }

        return back()->withInput()->with('error', __("Data cannot be deleted"));
    }

    public function delete_comment(Request $request){
        $findComment = De_comments::find($request->input('id_comment'));
        if($findComment->delete()){
            return back()->with('success', __("Comment successfully deleted"));
        }
        else {
            return back()->with('errors', __("Error"));
        }
    }

    public function delete_image(Request $request){
        $findImage = De_images::find($request->input('id_image'));
        $file = ltrim($findImage->url,'/');

        if(file_exists($file)){
            unlink($file);
        }

        if($findImage->delete()){
            return back()->with('success', __("Image successfully deleted"));
        }
        else {
            return back()->with('errors', __("Error"));
        }
    }

    public function add_de_work(Request $request){
        $siteId = $request->get('site_id');
        $workId = $request->get('work_id');
        $operation = $request->get('operation');
        $quantity = $request->get('work_quantity');
        $confirmed = $request->get('confirmed');
        if(Util::isColumnLeader() && $confirmed != 0){
            return redirect(url()->previous().'#deWorks');
        }
        $request->validate([
            'work_quantity' => 'required|numeric'
        ]);
        if($operation == 'minus')
            $quantity = -$quantity;
        if($workId) {
            $specWork = De_works::where('id', $workId)->first();
            $price = $specWork->price;
            $subPrice = $specWork->sub_price;
            De_site_work::create([
                'site_id' => $siteId,
                'work_id' => $workId,
                'quantity' => $quantity,
                'price' => $quantity*$price,
                'sub_price' => $quantity*$subPrice
            ]);
        }
        return redirect(url()->previous().'#deWorks');
    }

    public function search(){
        $leaders = Util::columnLeaders();
        return view('deConstructionSites.search', [
            'leaders' => $leaders, 
            'isAdmin' => Util::isSuperAdmin() || Util::isAdmin(), 
            'isConstructionManager' => Util::isConstructionManager()
        ]);
    }

    public function advanced_search(){
        $leaders = Util::columnLeaders();
        $areas = Areas::all();
        $providers = Providers::all();
        $clusters = Clusters::all();
        $pans = Pans::all();
        return view('deConstructionSites.advanced_search', [
            'leaders' => $leaders, 
            'isAdmin' => Util::isSuperAdmin() || Util::isAdmin(), 
            'areas' => $areas, 
            'providers' => $providers,
            'isConstructionManager' => Util::isConstructionManager(), 
            'clusters' => $clusters, 
            'pans' => $pans, 
            'statuses' => De_statuses::all(),
            'knots' => DistributiveKnot::all()
        ]);
    }

    public function search_result(Request $request){
        $deMod = new De_construction_sites();
        $dateStart = database_date($request->input("date_start"));
        $dateEnd = database_date($request->input("date_end"));
        $columnLeader = $request->input('column_leader');
        $numberOfWorkers = $request->input('number_of_workers');
        $area = $request->input('area');
        $place = $request->input('place');
        $street = $request->input('street');
        $pan = $request->input('pan');
        $polishDate = database_date($request->input('polish_date'));
        $reportConfirmed = $request->input('report_confirmed')?1:0;
        $cluster = $request->input('cluster');
        $maintenance = $request->input('maintenance');
        $status = $request->input('status');
        $withoutStatus = $request->input('without_status');
        $knot = $request->input('knot');
        $connectionId = $request->input('connection_id');
        $workOrderNumber = $request->input('work_order_number');
        if(Util::isColumnLeader()){
            $constructionSites = $deMod->filter(Util::userId(), $dateStart, $dateEnd, $numberOfWorkers, $area, $place, $street, $pan, $polishDate, $reportConfirmed, $cluster,
            Util::providers(), $maintenance, $status, $withoutStatus, $knot, $connectionId, $workOrderNumber, true);
            $noPagination = $deMod->filter(Util::userId(), $dateStart, $dateEnd, $numberOfWorkers, $area, $place, $street, $pan, $polishDate, $reportConfirmed, $cluster,
            Util::providers(), $maintenance, $status, $withoutStatus,$knot, $connectionId, $workOrderNumber);
        }
        else{
            $constructionSites = $deMod->filter($columnLeader, $dateStart, $dateEnd, $numberOfWorkers, $area, $place, $street, $pan, $polishDate, $reportConfirmed, $cluster,
             Util::providers(), $maintenance, $status, $withoutStatus,$knot,$connectionId,$workOrderNumber,true);
            $noPagination = $deMod->filter($columnLeader, $dateStart, $dateEnd, $numberOfWorkers, $area, $place, $street, $pan, $polishDate, $reportConfirmed, $cluster,
             Util::providers(), $maintenance, $status, $withoutStatus, $knot, $connectionId, $workOrderNumber);
        }

        $ids = Arr::pluck($noPagination, 'id');
        $count = count($ids);
        $ids = json_encode($ids);
        session(['ids_export' => $ids]);
        session(['search_route' => url()->full()]);
       
        return view('deConstructionSites.search_result', ['constructionSites' => $constructionSites, 'isSuperAdmin' => Util::isSuperAdmin(), 'deMod' => $deMod, 'count' => $count]);
    }

    public function statistic(Request $request){
        $start = $request->input('start');
        $end = $request->input('end');

        if ($start && $end){
            $from = date('Y-m-d', strtotime($start));
            $to = date('Y-m-d', strtotime($end));
        }
        else {
            $from = date('Y-m-01');
            $to = date('Y-m-t');
        }


        $workMod = new De_site_work();
        if(Util::isSuperAdmin()){
            $leaders = Util::columnLeaders();
        }
        else {
            $leaders = User::where('id',Util::userId())->get();
        }

        return view ('deConstructionSites.statistic', ['workMod' => $workMod, 'totalP' => 0, 'totalN' => 0, 'totalPSub' => 0, 'totalNSub' => 0, 'leaders' => $leaders, 
                    'from' => $from, 'to' => $to, 'isSuperAdmin' => Util::isSuperAdmin()]);
    }

    public function synt_form(){
        $leaders = Util::columnLeaders();
        $providers = Providers::all();
        $clusters = Clusters::all();
        $pans = Pans::all();
        return view('deConstructionSites.syntForm', ['leaders' => $leaders, 'providers' => $providers, 'clusters' => $clusters, 'pans' => $pans]);
    }

    public function work_form(){
        $leaders = Util::columnLeaders();
        $providers = Providers::all();
        $clusters = Clusters::all();
        $pans = Pans::all();
        return view('deConstructionSites.workForm', ['leaders' => $leaders, 'providers' => $providers, 'clusters' => $clusters, 'pans' => $pans]);
    }

    public function equipment_form(){
        $leaders = Util::columnLeaders();
        $providers = Providers::all();
        $clusters = Clusters::all();
        $pans = Pans::all();
        return view('deConstructionSites.equipmentForm', ['leaders' => $leaders, 'providers' => $providers, 'clusters' => $clusters, 'pans' => $pans]);
    }

    public function statistic_synt(Request $request){
        $start = $request->input('start');
        $end = $request->input('end');
        $cluster = $request->input('cluster');
        $pan = $request->input('pan');
        $leaders = $request->input('leaders');
        $provider = $request->input('provider');

        if(!$leaders){
            $leaders = Arr::pluck(Util::columnLeaders(), 'id');
        }

        $wMod = new De_site_work();
        
        
        if ($start && $end){
            $from = date('Y-m-d', strtotime($start));
            $to = date('Y-m-d', strtotime($end));
        }
        else {
            $from = date('Y-m-01');
            $to = date('Y-m-t');
        }
                
        $statistic = [];            
        foreach($leaders as $leader){
            $user = User::find($leader);
            $totalPolished = 0;
            $totalUnpolished = 0;
            $polishedWorks = $wMod->syntStatistic($from,$to,$leader,$cluster,$pan,$provider,1);;
            $unpolishedWorks = $wMod->syntStatistic($from,$to,$leader,$cluster,$pan,$provider,0);;
            if($polishedWorks){
                foreach($polishedWorks as $pw){
                    if($user->is_subcontractor != 1){
                        $totalPolished += $pw->price;
                    }
                    else{
                        $totalPolished += $pw->sub_price;
                    }
                }
            }
            if($unpolishedWorks){
                foreach($unpolishedWorks as $uw){
                    if($user->is_subcontractor != 1){
                        $totalUnpolished += $uw->price;
                    }
                    else{
                        $totalUnpolished += $uw->sub_price;
                    }
                }
            }
            $statistic[$user->ime.' '.$user->prezime] = ['totalPolished' => $totalPolished, 'totalUnpolished' => $totalUnpolished];
        }

        return view ('deConstructionSites.statisticSynt', ['statistic' => $statistic]);
    }

    public function statistic_works(Request $request){
        $start = $request->input('start');
        $end = $request->input('end');
        $cluster = $request->input('cluster');
        $pan = $request->input('pan');
        $leaders = $request->input('leaders');
        $provider = $request->input('provider');
        $filterImages = $request->input('filter_images');

        if(!$leaders){
            $leaders = Arr::pluck(Util::columnLeaders(), 'id');
        }

        $wMod = new De_site_work();
        
        
        if ($start && $end){
            $from = date('Y-m-d', strtotime($start));
            $to = date('Y-m-d', strtotime($end));
        }
        else {
            $from = date('Y-m-01');
            $to = date('Y-m-t');
        }
                
        $statisticPw = [];            
        $statisticUw = [];            
        $polishedWorks = $wMod->syntStatistic($from,$to,$leaders,$cluster,$pan,$provider,1);
        $unpolishedWorks = $wMod->syntStatistic($from,$to,$leaders,$cluster,$pan,$provider,0);
        $siteMod = new De_construction_sites();
        $sites = $siteMod->sites($from,$to,$leaders,$cluster,$pan,$provider);
        $imgMod = new De_images();
        $comMod = new De_comments();

        if(!$filterImages && $this->isMoreThan31Days($start,$end)){
            $sites = [];
        }

        if($polishedWorks){
            foreach($polishedWorks as $pw){
                $statisticPw[] = ['work' => $pw->work, 'quantity' => $pw->quantity, 'price' => $pw->price, 'sub_price' => $pw->sub_price];
            }
        }
        
        if($unpolishedWorks){
            foreach($unpolishedWorks as $uw){
                $statisticUw[] = ['work' => $uw->work, 'quantity' => $uw->quantity, 'price' => $uw->price, 'sub_price' => $uw->sub_price];
            }
        }

        return view ('deConstructionSites.workStatistic', ['statisticPw' => $statisticPw, 'statisticUw' => $statisticUw, 
        'total' => 0, 'totalSub' => 0, 'imgMod' => $imgMod, 'sites' => $sites, 'comMod' => $comMod]);
    }

    public function statistic_equipment(Request $request){
        $start = $request->input('start');
        $end = $request->input('end');
        $cluster = $request->input('cluster');
        $pan = $request->input('pan');
        $leaders = $request->input('leaders');
        $provider = $request->input('provider');

        if(!$leaders){
            $leaders = Arr::pluck(Util::columnLeaders(), 'id');
        }

        $eMod = new De_site_equipment();
        $dMod = new De_mounted_devices();
        $mMod = new De_site_materials();
        
        
        if ($start && $end){
            $from = date('Y-m-d', strtotime($start));
            $to = date('Y-m-d', strtotime($end));
        }
        else {
            $from = date('Y-m-01');
            $to = date('Y-m-t');
        }
                
        $statisticDevices = [];
        $statisticEquipment = [];
        $statisticMaterials = [];
        $equipment = $eMod->siteEquipment($from,$to,$leaders,$cluster,$pan,$provider);
        $devices = $dMod->siteDevices($from,$to,$leaders,$cluster,$pan,$provider);
        $materials = $mMod->siteMaterials($from,$to,$leaders,$cluster,$pan,$provider);
        if($equipment){
            foreach($equipment as $e){
                $statisticEquipment[] = ['equipment' => $e->equipment, 'quantity' => $e->quantity];
            }
        }
        
        if($devices){
            foreach($devices as $dev){
                $statisticDevices[] = ['device' => $dev->device, 'quantity' => $dev->quantity];
            }
        }

        if($materials){
            foreach($materials as $mat){
                $statisticMaterials[] = ['material' => $mat->material, 'quantity' => $mat->quantity];
            }
        }


        return view ('deConstructionSites.equipmentStatistic', [
            'statisticEquipment' => $statisticEquipment, 
            'statisticDevices' => $statisticDevices, 
            'statisticMaterials' => $statisticMaterials
            ]);
    }


    public function target(){
        $workers = Util::columnLeaders();
        return view('deConstructionSites.target', ['workers' => $workers]);
    }

    public function target_calculate(Request $request){
        $start = $request->input('start');
        $end = $request->input('end');

        if ($start && $end){
            $from = date('Y-m-d', strtotime($start));
            $to = date('Y-m-d', strtotime($end));
        }
        else {
            $from = date('Y-m-01');
            $to = date('Y-m-t');
        }
        $worker = $request->input('worker'); 

        $workingDaysCount = workingDaysCount($from,$to);
        //daily target price is considered in calculation
        $targetPrice = De_target::orderBy('id', 'DESC')->first();
        if($targetPrice){
            $targetPrice = $targetPrice->target_price;
        }
        else{
            $targetPrice = 0;
        }

        $expectedPrice = $targetPrice*$workingDaysCount;
        
        // $deMod = new De_construction_sites();
        $wMod = new De_site_work();
        $user = User::find($worker);
        
        $totalPolished = 0;
        $totalUnpolished = 0;
        $polishedWorks = $wMod->workStatistic($from,$to,$worker,1);
        $unpolishedWorks = $wMod->workStatistic($from,$to,$worker,0);
        if($polishedWorks){
            foreach($polishedWorks as $pw){
                if($user->is_subcontractor != 1){
                    $totalPolished += $pw->price;
                }
                else{
                    $totalPolished += $pw->sub_price;
                }
            }
        }
        if($unpolishedWorks){
            foreach($unpolishedWorks as $uw){
                if($user->is_subcontractor != 1){
                    $totalUnpolished += $uw->price;
                }
                else{
                    $totalUnpolished += $uw->sub_price;
                }
            }
        }

        $percentagePolished = ($totalPolished*100)/$expectedPrice;
        $percentageUnpolished = ($totalUnpolished*100)/$expectedPrice;

        $data = ['percentagePolished' => $percentagePolished, 'precentageUnpolished' => $percentageUnpolished, 'worker' => $user->ime.' '.$user->prezime];
        
        
        return view('deConstructionSites.target_calculate', ['data' => $data]);
    }

    public function create_target(){
        $currentPrice = De_target::latest()->first();
        return view('deConstructionSites.targetSettings', ['currentPrice' => $currentPrice?$currentPrice->target_price:0]);
    }

    public function set_target(Request $request){
        $price = $request->input('price');
        $request->validate(['price' => 'required']);
        $create = De_target::create([
            'target_price' => $price
        ]);

        if($create){
            return back()->with('success', __("Data successfully added"));
        }
        else {
            return back()->with('error', __("Error"));
        }

    }

    public function group_entry(){
        $ids = json_decode(session('ids_de_sites'));
        $statuses = De_statuses::all();
        return view('deConstructionSites.group_entry', ['ids' => $ids, 'statuses' => $statuses]);
    }

    public function group_action(Request $request){
        $statusId = $request->input('data');
        $param = $request->input('param');
        $ids = json_decode(session('ids_de_sites'));
        if($param == 'status'){
            foreach($ids as $id){
                De_construction_sites::where('id', $id)->update([
                    'status_id' => $statusId
                ]);
            }
        }

        return back()->with('success', __('Data successfully changed'));
    }

    public function export(Request $request){
        require '../vendor/autoload.php';
        $ids = session('ids_export');
        $ids = json_decode($ids);

        $withComments = $request->input('comments');

        $cMod = new De_construction_sites();
        $clients = $cMod->export($ids);

        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();

        $sheet->getColumnDimension('A')->setAutoSize(true);
        $sheet->getColumnDimension('B')->setAutoSize(true);
        $sheet->getColumnDimension('C')->setAutoSize(true);
        $sheet->getColumnDimension('D')->setAutoSize(true);
        $sheet->getColumnDimension('E')->setAutoSize(true);
        $sheet->getColumnDimension('F')->setAutoSize(true);
        $sheet->getColumnDimension('G')->setAutoSize(true);
        $sheet->getColumnDimension('H')->setAutoSize(true);
        $sheet->getColumnDimension('I')->setAutoSize(true);
        $sheet->getColumnDimension('J')->setAutoSize(true);
        $sheet->getColumnDimension('K')->setAutoSize(true);
        $sheet->getColumnDimension('L')->setAutoSize(true);
        $sheet->getColumnDimension('M')->setAutoSize(true);
        $sheet->getColumnDimension('N')->setAutoSize(true);
        $sheet->getColumnDimension('O')->setAutoSize(true);
        $sheet->getColumnDimension('P')->setAutoSize(true);
        $sheet->getColumnDimension('Q')->setAutoSize(true);
        $sheet->getColumnDimension('R')->setAutoSize(true);
        $sheet->getColumnDimension('S')->setAutoSize(true);
        $sheet->getColumnDimension('T')->setAutoSize(true);
        $sheet->getColumnDimension('U')->setAutoSize(true);
        $sheet->getColumnDimension('V')->setAutoSize(true);
        $sheet->getColumnDimension('W')->setAutoSize(true);
        $sheet->getColumnDimension('X')->setAutoSize(true);
        $sheet->getColumnDimension('Y')->setAutoSize(true);
        $sheet->getColumnDimension('Z')->setAutoSize(true);
        $sheet->getColumnDimension('AA')->setAutoSize(true);
        $sheet->getColumnDimension('AB')->setAutoSize(true);
        $sheet->getColumnDimension('AC')->setAutoSize(true);
        $sheet->getColumnDimension('AD')->setAutoSize(true);
        $sheet->getColumnDimension('AE')->setAutoSize(true);
        $sheet->getColumnDimension('AF')->setAutoSize(true);
        $sheet->getColumnDimension('AG')->setAutoSize(true);
        $sheet->getColumnDimension('AH')->setAutoSize(true);
        $sheet->getColumnDimension('AI')->setAutoSize(true);
        $sheet->getColumnDimension('AJ')->setAutoSize(true);
        $sheet->getColumnDimension('AK')->setAutoSize(true);
        $sheet->getColumnDimension('AL')->setAutoSize(true);
        $sheet->getColumnDimension('AM')->setAutoSize(true);
        $sheet->getColumnDimension('AN')->setAutoSize(true);
        $sheet->getColumnDimension('AO')->setAutoSize(true);
        $sheet->getColumnDimension('AP')->setAutoSize(true);
        $sheet->getColumnDimension('AQ')->setAutoSize(true);
        $sheet->getColumnDimension('AR')->setAutoSize(true);
        $sheet->getColumnDimension('AS')->setAutoSize(true);
        $sheet->getColumnDimension('AT')->setAutoSize(true);
        $sheet->getColumnDimension('AU')->setAutoSize(true);
        $sheet->getColumnDimension('AV')->setAutoSize(true);
        $sheet->getColumnDimension('AW')->setAutoSize(true);
        $sheet->getColumnDimension('AX')->setAutoSize(true);
        $sheet->getColumnDimension('AY')->setAutoSize(true);
        $sheet->getColumnDimension('AZ')->setAutoSize(true);
        $sheet->getColumnDimension('BA')->setAutoSize(true);
        $sheet->getColumnDimension('BB')->setAutoSize(true);
        $sheet->getColumnDimension('BC')->setAutoSize(true);
        $sheet->getColumnDimension('BD')->setAutoSize(true);
        $sheet->getColumnDimension('BE')->setAutoSize(true);
        $sheet->getColumnDimension('BF')->setAutoSize(true);
        $sheet->getColumnDimension('BG')->setAutoSize(true);
        $sheet->getColumnDimension('BH')->setAutoSize(true);
        $sheet->getColumnDimension('BI')->setAutoSize(true);
        $sheet->getColumnDimension('BJ')->setAutoSize(true);
        $sheet->getColumnDimension('BK')->setAutoSize(true);
        $sheet->getColumnDimension('BL')->setAutoSize(true);
        $sheet->getColumnDimension('BM')->setAutoSize(true);
        $sheet->getColumnDimension('BN')->setAutoSize(true);
        

        $sheet->setCellValue('A1', __("Date"));
        $sheet->setCellValue('B1', __("Column leader"));
        $sheet->setCellValue('C1', __("Number of workers"));
        $sheet->setCellValue('D1', __("Place"));
        $sheet->setCellValue('E1', __("Street"));
        $sheet->setCellValue('F1', __("Polisher report"));
        $sheet->setCellValue('G1', __("Work").' '.__('start'));
        $sheet->setCellValue('H1', __("Work").' '.__('end'));
        $sheet->setCellValue('I1', __("Pause"));
        $sheet->setCellValue('J1', __("Pan"));
        $sheet->setCellValue('K1', __("DP"));
        $sheet->setCellValue('L1', __("Area"));
        $sheet->setCellValue('M1', __("Provider"));
        $sheet->setCellValue('N1', __("Polish date"));
        $sheet->setCellValue('O1', __("Cluster"));
        $sheet->setCellValue('P1', __("Report confirmed"));
        $sheet->setCellValue('Q1', __("Maintenance"));
        $sheet->setCellValue('R1', __("Status"));
        $sheet->setCellValue('S1', __("Distributive knot"));
        $sheet->setCellValue('T1', __("Connection ID"));
        $sheet->setCellValue('U1', __("Work order number"));
        $sheet->setCellValue('V1', __("Total"));
        $sheet->setCellValue('W1', __("Comments"));

        $sheet->getStyle('A1:W1')->getAlignment()->setHorizontal('center');

        $sheet->getStyle('A1:W1')->getFill()->setFillType(\PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID)->getStartColor()->setARGB('8c8c8c');

        $commentText = '';
        $comMod = new De_comments();
        foreach ($clients as $br=>$client){
            if($withComments) {
                $comments = $comMod->comments($client->id);
                foreach ($comments as $comment)
                    $commentText .= $comment->comment . " (" . $comment->ime . ' ' . $comment->prezime . ' ' . date('d.m.Y H:i:s', strtotime($comment->created_at)) . ') ';
            }

            $sheet->getStyle('A'.($br+2).':T'.($br+2))->getAlignment()->setHorizontal('left');
            $sheet->setCellValue('A'.($br+2), $client->date?date('d.m.Y.', strtotime($client->date)):'');
            $sheet->setCellValue('B'.($br+2), $client->name.' '.$client->surname);
            $sheet->setCellValue('C'.($br+2), $client->number_of_workers);
            $sheet->setCellValue('D'.($br+2), $client->place);
            $sheet->setCellValue('E'.($br+2), $client->street);
            $sheet->setCellValue('F'.($br+2), $client->polisher_report);
            $sheet->setCellValue('G'.($br+2), $client->work_start);
            $sheet->setCellValue('H'.($br+2), $client->work_end);
            $sheet->setCellValue('I'.($br+2), $client->pause);
            $sheet->setCellValue('J'.($br+2), $client->pan);
            $sheet->setCellValue('K'.($br+2), $client->dp);
            $sheet->setCellValue('L'.($br+2), $client->area);
            $sheet->setCellValue('M'.($br+2), $client->provider);
            $sheet->setCellValue('N'.($br+2), $client->polish_date);
            $sheet->setCellValue('O'.($br+2), $client->cluster);
            $sheet->setCellValue('P'.($br+2), $client->report_confirmed);
            $sheet->setCellValue('Q'.($br+2), $client->maintenance);
            $sheet->setCellValue('R'.($br+2), $client->status);
            $sheet->setCellValue('S'.($br+2), $client->knot);
            $sheet->setCellValue('T'.($br+2), $client->connection_id);
            $sheet->setCellValue('U'.($br+2), $client->work_order_number);
            $sheet->setCellValue('V'.($br+2), $cMod->totalForSite($client->id));
            $sheet->setCellValue('W'.($br+2), $commentText);

            $commentText = '';

        }

        $streamedResponse = new StreamedResponse();
        $streamedResponse->setCallback(function() use ($spreadsheet){
            $writter = new Xlsx($spreadsheet);
            $writter->save('php://output');
        });

        $streamedResponse->setStatusCode(200);
        $streamedResponse->headers->set('Content-Type', 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        $streamedResponse->headers->set('Content-Disposition', 'attachment; filename="construction.xlsx"');
        return $streamedResponse->send();
    }

}