<?php

namespace App\Http\Controllers;

use App\Models\De_works;
use App\Models\Providers;
use App\Models\Units;
use Illuminate\Http\Request;

class DeWorksController extends Controller
{
    public function index()
    {
        $works = De_works::orderBy('code')->paginate(50);
        return view('deWorks.index', ['works' => $works]);
    }

    public function create()
    {
        $units = Units::all();
        $providers = Providers::all();
        return view('deWorks.create', ['units' => $units, 'providers' => $providers]);
    }

    public function store(Request $request)
    {
        $request->validate([
            'code' => 'required',
            'work' => 'required',
            'price' => 'nullable|numeric',
            'sub_price' => 'nullable|numeric'
        ]);
        $create = De_works::create([
            'code' => trim($request->input('code')),
            'work' => trim($request->input('work')),
            'unit_id' => $request->input('unit'),
            'fixed' => $request->input('fixed'),
            'price' => $request->input('price')?$request->input('price'):0,
            'sub_price' => $request->input('sub_price')?$request->input('sub_price'):0,
            'target_price' => $request->input('target_price')?$request->input('target_price'):0,
            'provider' => $request->input('provider')
        ]);

        if ($create){
            return redirect()->route('de_works.show', $create->id)->with('success', __("Data successfully added"));
        }
    }

    public function show(De_works $de_work)
    {
        $wMod = new De_works();
        $work = $wMod->work_data($de_work->id);
        return view('deWorks.show', ['work' => $work]);
    }

    public function edit(De_works $de_work)
    {
        $units = Units::all();
        $providers = Providers::all();
        return view('deWorks.edit', ['work' => $de_work, 'units' => $units, 'providers' => $providers]);
    }

    public function update(Request $request, De_works $de_work)
    {
        $request->validate([
            'code' => 'required',
            'work' => 'required',
            'price' => 'nullable|numeric',
            'sub_price' => 'nullable|numeric'
        ]);
        $workUpdate = De_works::where('id', $de_work->id)->update([
            'code' => trim($request->input('code')),
            'work' => trim($request->input('work')),
            'unit_id' => $request->input('unit'),
            'fixed' => $request->input('fixed'),
            'price' => $request->input('price')?$request->input('price'):0,
            'sub_price' => $request->input('sub_price')?$request->input('sub_price'):0,
            'target_price' => $request->input('target_price')?$request->input('target_price'):0,
            'provider' => $request->input('provider')
        ]);

        if ($workUpdate){
            return redirect()->route('de_works.show', $de_work->id)->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    public function destroy(Request $request)
    {
        $findWork = De_works::find($request->input('id_work'));

        try{
            $findWork->delete();
            return back()->withInput()->with('success', __("Work successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
