<?php

namespace App\Http\Controllers;

use App\Models\Demand_comments;
use App\Magz;
use App\Models\Demand_devices;
use App\Models\Demand_equipment;
use App\Models\Demand_statuses;
use App\Models\Demands;
use App\Models\Kir_demand_equipment;
use App\Models\Kir_required_equipment;
use App\Models\Required_equipment;
use App\Models\Storage_equipment;
use App\Models\Storage_logs;
use App\Models\Worker_equipment;
use App\Models\Worker_storage_logs;
use App\Oprema;
use App\Revers_roba;
use App\Traits\Util;
use App\Uredjaji;
use Illuminate\Http\Request;

class DemandController extends Controller
{
    private function updateChangeLog($equipmentId, $storageId, $quantity, $fitterId, $package=null){
        if($quantity != 0){
            Storage_logs::create([
                'mont_equipment_id' => $equipmentId,
                'user_id' => Util::userId(),
                'fitter_id' => $fitterId,
                'storage_id' => $storageId,
                'quantity' => $quantity,
                'package_number' => $package
            ]);
        }
    }

    public function index(){
        $demMod = new Demands();
        if(Util::isSuperAdmin())
            $demands = $demMod->demandsIndex();
        else
            $demands = $demMod->demandsIndex(Util::userId());
        return view('demand.index', [
            'demands' => $demands, 
            'fitters' => Util::monteri(),
            'isSuperAdmin' => Util::isSuperAdmin()
        ]);
    }

    public function demand_warehouse(){
        $demMod = new Demands();
        $demands = $demMod->demandsIndex();
        return view('demand.demand_warehouse', ['demands' => $demands]);
    }

    public function personal_list($demand){
        $eMod = new Demand_equipment();
        $dMod = new Demand_devices();
        if(Util::isSuperAdmin()){
            $equipmentList = $eMod->demandList(null, $demand);
            $deviceList = $dMod->demandList(null, $demand);
        }
        else{
            $equipmentList = $eMod->demandList(Util::userId(), $demand);
            $deviceList = $dMod->demandList(Util::userId(), $demand);
        }
        $statuses = Demand_statuses::all();
        $commentMod = new Demand_comments();
        $comments = $commentMod->comments($demand);
        return view('demand.personal_list', [
            'devices' => Uredjaji::where('category_id', 1)->get(),
            'equipment' => Oprema::all(),
            'equipmentList' => $equipmentList,
            'deviceList' => $deviceList,
            'statuses' => $statuses,
            'demandId' => $demand,
            'comments' => $comments
        ]);
    }

    public function store(Request $request){
        if(Util::isSuperAdmin())
            $fitter = $request->input('fitter');
        else
            $fitter = Util::userId();
        $create = Demands::create([
            'fitter' => $fitter,
            'status' => 6
        ]);
        if($create)
            return redirect()->route('demand_personal_list', [$create->id]);
    }

    public function store_demand_item(Request $request){
        $deviceId = $request->input('device');
        $equipmentId = $request->input('equipment');
        $deviceQuantity = $request->input('device_quantity');
        $equipmentQuantity = $request->input('equipment_quantity');
        $status = $request->input('status');
        $demandId = $request->input('demand_id');

        $request->validate([
            'device_quantity' => 'nullable|numeric',
            'equipment_quantity' => 'nullable|numeric'
        ]);

        if($equipmentQuantity > 0){
            Demand_equipment::create([
                'equipment_id' => $equipmentId,
                'quantity' => $equipmentQuantity,
                'status' => $status,
                'created_by' => Util::userId(),
                'demand_id' => $demandId
            ]);
        }

        if($deviceQuantity > 0){
            Demand_devices::create([
                'device_id' => $deviceId,
                'quantity' => $deviceQuantity,
                'status' => $status,
                'created_by' => Util::userId(),
                'demand_id' => $demandId
            ]);
        }

        return back()->with('success', 'Data successfully added');
    }

    public function general_list($demand){
        $eMod = new Demand_equipment();
        $dMod = new Demand_devices();
        $equipmentList = $eMod->generalDemandList($demand);
        $deviceList = $dMod->generalDemandList($demand);
        $statuses = Demand_statuses::all();
        $warehouses = Magz::all();
        $commentMod = new Demand_comments();
        $comments = $commentMod->comments($demand);
        $weMod = new Worker_equipment();
        $revMod = new Revers_roba();
        return view('demand.general_list', [
            'devices' => Uredjaji::all()->where('category_id', '=', 1),
            'equipment' => Oprema::all(),
            'equipmentList' => $equipmentList,
            'deviceList' => $deviceList,
            'statuses' => $statuses,
            'warehouses' => $warehouses,
            'comments' => $comments,
            'weMod' => $weMod,
            'revMod' => $revMod
        ]);
    }

    public function supply(Request $request){
        $id = $request->input('demand_id');
        $param = $request->input('param');
        $supplyQuantity = $request->input('supply_quantity');
        $warehouse = $request->input('warehouse');
        $package = $request->input('package');
        $request->validate(['supply_quantity' => 'required|numeric']);

        //devices
        if($param == 'device'){
            $dMod = new Demand_devices();
            $findRecord = Demand_devices::find($id);
            if($findRecord->edited_quantity)
                $demandQuantity = $findRecord->edited_quantity;
            else
                $demandQuantity = $findRecord->quantity;
            if($supplyQuantity + $findRecord->supplied_quantity <= $demandQuantity) {
                $dMod->addDevices($id, $supplyQuantity);
                if($supplyQuantity + $findRecord->supplied_quantity == $demandQuantity)
                    Demand_devices::where('id', $id)->update(['supplied' => 1]);
                else
                    Demand_devices::where('id', $id)->update(['supplied' => 0]);

                return back()->with('success', __("Goods successfully supplied"));
            }
            else{
                return back()->with('error', __("You can't supply more than requested amount"));
            }
        }

        //equipment
        if($param == 'equipment'){
            $deMod = new Demand_equipment();
            $findRecord = Demand_equipment::find($id);
            if($findRecord->edited_quantity)
                $demandQuantity = $findRecord->edited_quantity;
            else
                $demandQuantity = $findRecord->quantity;
            $weMod = new Worker_equipment();
            $storageMod = new Storage_equipment();
            $workerEquipmentExists = $weMod->specific_equipment_mont($findRecord->created_by, $findRecord->equipment_id);
            $storageEquipmentExists = $storageMod->specific_equipment_mont($warehouse, $findRecord->equipment_id);

            if($supplyQuantity + $findRecord->supplied_quantity <= $demandQuantity) {
                if($storageEquipmentExists){
                    if($storageEquipmentExists->quantity >= $supplyQuantity) {
                        $storageMod->storage_update_mont($warehouse, $findRecord->equipment_id, -$supplyQuantity);
                        $this->updateChangeLog($findRecord->equipment_id, $warehouse, $supplyQuantity, $findRecord->created_by);
                    }
                    else
                        return back()->with('error', __("there are not that many goods in the warehouse"));
                }
                else{
                    return back()->with('error', __("there are not that many goods in the warehouse"));
                }
                if($workerEquipmentExists){
                    $weMod->equipment_update_mont($findRecord->created_by, $findRecord->equipment_id, $supplyQuantity);
                    Worker_storage_logs::create([
                        'equipment_id' => null,
                        'mont_equipment_id' => $findRecord->equipment_id,
                        'worker_id' => $findRecord->created_by,
                        'storage_id' => $warehouse,
                        'quantity' => $supplyQuantity
                    ]);
                }
                else{
                    Worker_equipment::create([
                        'user_id' => $findRecord->created_by,
                        'equipment_id' => null,
                        'mont_equipment_id' => $findRecord->equipment_id,
                        'storage_id' => $warehouse,
                        'quantity' => $supplyQuantity
                    ]);
                    Worker_storage_logs::create([
                        'equipment_id' => null,
                        'mont_equipment_id' => $findRecord->equipment_id,
                        'worker_id' => $findRecord->created_by,
                        'storage_id' => $warehouse,
                        'quantity' => $supplyQuantity
                    ]);
                }
                $deMod->addEquipment($id, $supplyQuantity);
                if($supplyQuantity + $findRecord->supplied_quantity == $demandQuantity)
                    Demand_equipment::where('id', $id)->update(['supplied' => 1]);
                else
                    Demand_equipment::where('id', $id)->update(['supplied' => 0]);

                return back()->with('success', __("Goods successfully supplied"));
            }
            else{
                return back()->with('error', __("You can't supply more than requested amount"));
            }
        }

        //kir demand
        if($param == 'kir_demand'){
            $deMod = new Kir_demand_equipment();
            $findRecord = Kir_demand_equipment::find($id);
            $demandQuantity = $findRecord->quantity;
            $weMod = new Worker_equipment();
            $storageMod = new Storage_equipment();
            $workerEquipmentExists = $weMod->specific_equipment_mont($findRecord->created_by, $findRecord->equipment_id);
            $storageEquipmentExists = $storageMod->specific_equipment_mont($warehouse, $findRecord->equipment_id, $package);

            if($supplyQuantity + $findRecord->supplied_quantity <= $demandQuantity) {
                if($storageEquipmentExists){
                    if($storageEquipmentExists->quantity >= $supplyQuantity) {
                        $storageMod->storage_update_mont($warehouse, $findRecord->equipment_id, -$supplyQuantity, $package);
                        $this->updateChangeLog($findRecord->equipment_id, $warehouse, $supplyQuantity, $findRecord->created_by, $package);
                    }
                    else
                        return back()->with('error', __("there are not that many goods in the warehouse"));
                }
                else{
                    return back()->with('error', __("there are not that many goods in the warehouse"));
                }
                if($workerEquipmentExists){
                    $weMod->equipment_update_mont($findRecord->created_by, $findRecord->equipment_id, $supplyQuantity);
                    Worker_storage_logs::create([
                        'equipment_id' => null,
                        'mont_equipment_id' => $findRecord->equipment_id,
                        'worker_id' => $findRecord->created_by,
                        'storage_id' => $warehouse,
                        'quantity' => $supplyQuantity
                    ]);
                }
                else{
                    Worker_equipment::create([
                        'user_id' => $findRecord->created_by,
                        'equipment_id' => null,
                        'mont_equipment_id' => $findRecord->equipment_id,
                        'storage_id' => $warehouse,
                        'quantity' => $supplyQuantity
                    ]);
                    Worker_storage_logs::create([
                        'equipment_id' => null,
                        'mont_equipment_id' => $findRecord->equipment_id,
                        'worker_id' => $findRecord->created_by,
                        'storage_id' => $warehouse,
                        'quantity' => $supplyQuantity
                    ]);
                }
                $deMod->addEquipment($id, $supplyQuantity);
                if($supplyQuantity + $findRecord->supplied_quantity == $demandQuantity)
                    Kir_demand_equipment::where('id', $id)->update(['supplied' => 1]);
                else
                    Kir_demand_equipment::where('id', $id)->update(['supplied' => 0]);

                return back()->with('success', __("Goods successfully supplied"));
            }
            else{
                return back()->with('error', __("You can't supply more than requested amount"));
            }
        }
    }

    public function item_update(Request $request){
        $id = $request->input('demand_id_status');
        $type = $request->input('type');
        $status = $request->input('status');
        $quantity = $request->input('quantity');
        $constructionType = $request->input('construction_type_e');
        $ready = $request->input('e_ready');
        if($ready)
            $ready = 1;
        else
            $ready = 0;

        $request->validate([
            'quantity' => 'nullable|numeric'
        ]);

        if($type == 'device'){
            $update = Demand_devices::where('id', $id)->update([
                'status' => $status,
                'edited_quantity' => $quantity
            ]);
        }
        elseIf($type == 'hw_equipment'){
            if($constructionType == 'huawei'){
                $update = Required_equipment::where('id', $id)->update([
                    'edited_quantity' => $quantity,
                    'ready' => $ready
                ]);
            }
            else{
                $update = Kir_required_equipment::where('id', $id)->update([
                    'edited_quantity' => $quantity,
                    'ready' => $ready
                ]);
            }
        }
        else{
            $update = Demand_equipment::where('id', $id)->update([
                'status' => $status,
                'edited_quantity' => $quantity
            ]);
        }

        if($update)
            return back()->with('success', __('Data successfully changed'));
        else
            return back()->with('error', 'Error');
    }

    public function edit(Demands $demand){
        $statuses = Demand_statuses::all();
        $magz = Magz::all();
        return view('demand.edit', ['statuses' => $statuses, 'demand' => $demand, 'magz' => $magz]);
    }

    public function update(Demands $demand, Request $request){
        $status = $request->input('status');
        $comment = $request->input('comment');
        $storage = $request->input('storage');
        $estimatedSendDate = database_date($request->input('estimated_send_date'));
        $update = Demands::where('id', $demand->id)->update([
            'status' => $status,
            'estimated_send_date' => $estimatedSendDate,
            'storage_id' => $storage
        ]);
        if($update) {
            if($comment) {
                Demand_comments::create([
                    'comment' => $comment,
                    'user_id' => Util::userId(),
                    'demand_id' => $demand->id
                ]);
            }
            return redirect()->route('demand_warehouse')->with('success', __("Data successfully changed"));
        }
        else
            return back()->with('error', __('Error'));
    }

    public function add_comment(Request $request, $demand){
        $comment = $request->input('comment');
        $request->validate(['comment' => 'required']);
        Demand_comments::create([
            'comment' => $comment,
            'demand_id' => $demand,
            'user_id' => Util::userId()
        ]);
        return back()->with("success", __("Comment successfully added"));
    }


    public function destroy(Request $request){
        $id = $request->input('demand_id');
        $param = $request->input('param');
        if($param == 'device'){
            $findDemand = Demand_devices::find($id);
            if($findDemand->delete())
                return back()->with('success', __('Data successfully deleted'));
            else
                return back()->with('error', __('Error'));
        }
        if($param == 'equipment'){
            $findDemand = Demand_equipment::find($id);
            if($findDemand->delete())
                return back()->with('success', __('Data successfully deleted'));
            else
                return back()->with('error', __("Error"));
        }
    }

}
