<?php

namespace App\Http\Controllers;

use App\Models\Device_types;
use Illuminate\Http\Request;

class DeviceTypeController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $typeModel = new Device_types();
        $deviceTypes = $typeModel->deviceTypes();
        return view('deviceType.index', ['deviceTypes' => $deviceTypes]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('deviceType.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate(['type' => 'required']);
        $type = Device_types::create([
            'type' => trim($request->input('type'))
        ]);

        if ($type){
            return redirect()->route('device_type.index')->with('success',  __("Data successfully added"));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Device_types  $type
     * @return \Illuminate\Http\Response
     */
    public function show(Device_types $type)
    {
        $typeModel = new Device_types();
        $type = $typeModel->deviceTypes($type->id);
        return view('deviceType.show', ['type' => $type]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Device_types  $device_types
     * @return \Illuminate\Http\Response
     */
    public function edit(Device_types $type)
    {
        $typeModel = new Device_types();
        $type = $typeModel->deviceTypes($type->id);
        return view('deviceType.edit', ['type' => $type]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Device_types  $type
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Device_types $type)
    {
        $request->validate(['type' => 'required']);
        $typeUpdate = Device_types::where('id', $type->id)->update([
            'type' => trim($request->input('type'))
        ]);

        if ($typeUpdate){
            return redirect()->route('device_type.show', ['type' => $type])->with('success',  __("Data successfully changed"));
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findType = Device_types::find($request->input('id_type'));

        try{
            $findType->delete();
            return back()->withInput()->with('success',  __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error',  __("Data cannot be deleted"));
        }

        return back()->withInput()->with('error', __("Data cannot be deleted"));
    }
}
