<?php

namespace App\Http\Controllers;

use App\Models\Doc_works;
use App\Models\Units;
use Illuminate\Http\Request;

class DocWorksController extends Controller
{

    public function index()
    {
        $wModel = new Doc_works();
        $works = $wModel->doc_works();
        return view('docWorks.index', ['works' => $works]);
    }

    public function create()
    {
        return view('docWorks.create', ['units' => Units::all()]);
    }

    public function store(Request $request)
    {
        $request->validate([
            'code' => 'required',
            'work' => 'required',
            'price' => 'nullable|numeric'
        ]);
        $workCreate = Doc_works::create([
            'code' => trim($request->input('code')),
            'work' => trim($request->input('work')),
            'unit_id' => $request->input('unit'),
            'fixed' => $request->input('fixed'),
            'price' => $request->input('price')?$request->input('price'):0
        ]);

        if ($workCreate){
            return redirect()->route('doc_work.index')->with('success', __("Data successfully added"));
        }
    }

    public function show(Doc_works $doc_work)
    {
        $wModel = new Doc_works();
        $work = $wModel->workData($doc_work->id);
        return view('docWorks.show', ['work' => $work]);
    }

    public function edit(Doc_works $doc_work)
    {
        $wModel = new Doc_works();
        $work = $wModel->workData($doc_work->id);
        $units = Units::all();

        return view('docWorks.edit', ['work' => $work, 'units' => $units]);
    }

    public function update(Request $request, Doc_works $doc_work)
    {
        $request->validate([
            'code' => 'required',
            'work' => 'required',
            'price' => 'nullable|numeric'
        ]);
        $workUpdate = Doc_works::where('id', $doc_work->id)->update([
            'code' => trim($request->input('code')),
            'work' => trim($request->input('work')),
            'unit_id' => $request->input('unit'),
            'fixed' => $request->input('fixed'),
            'price' => $request->input('price')?$request->input('price'):0
        ]);

        if ($workUpdate){
            return redirect()->route('doc_work.show', ['doc_work' => $doc_work->id])->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findWork = Doc_works::find($request->input('id_work'));

        try{
            $findWork->delete();
            return back()->withInput()->with('success', __("Work successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
