<?php

namespace App\Http\Controllers;

use App\Models\Mont_equipment_categories;
use Illuminate\Http\Request;

class EquipmentCategoryController extends Controller
{
    public function index()
    {
        $categories = Mont_equipment_categories::all();
        return view('equipmentCategory.index', ['categories' => $categories]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('equipmentCategory.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'equipment_category' => 'required'
        ]);
        $typeCreate = Mont_equipment_categories::create([
            'category' => trim($request->input('equipment_category'))
        ]);

        $categories = Mont_equipment_categories::all();
        if ($typeCreate){
            return view('equipmentCategory.index', ['categories' => $categories]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Mont_equipment_categories  $mont_equipment_category
     * @return \Illuminate\Http\Response
     */
    public function show(Mont_equipment_categories $mont_equipment_category)
    {
        $equipmentCategory = Mont_equipment_categories::find($mont_equipment_category->id);
        return view('equipmentCategory.show', ['category' => $equipmentCategory]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Mont_equipment_categories  $mont_equipment_category
     * @return \Illuminate\Http\Response
     */
    public function edit(Mont_equipment_categories $mont_equipment_category)
    {
        $equipmentCategory = Mont_equipment_categories::find($mont_equipment_category->id);

        return view('equipmentCategory.edit', ['category' => $equipmentCategory]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Mont_equipment_categories  $mont_equipment_category
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Mont_equipment_categories $mont_equipment_category)
    {
        $request->validate([
            'category' => 'required'
        ]);
        $categoryUpdate = Mont_equipment_categories::where('id', $mont_equipment_category->id)->update([
            'category'=>trim($request->input('category'))
        ]);

        if ($categoryUpdate){
            return redirect()->route('mont_equipment_category.show', ['mont_equipment_category' => $mont_equipment_category->id])->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findCategory = Mont_equipment_categories::find($request->input('id_category'));

        try{
            $findCategory->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
