<?php

namespace App\Http\Controllers;

use App\Klijent;
use App\Klijenti_optika;
use App\Models\Hw_site_equipment;
use App\Models\Montage_prices;
use App\Models\Worker_equipment;
use App\Device_history;
use App\Change_history;
use App\Magacin;
use App\Models\De_change_history;
use App\Models\De_device_history;
use App\Models\De_mounted_devices;
use App\Models\De_site_equipment;
use App\Models\Kir_required_equipment;
use App\Models\Required_equipment;
use App\Models\Rune_logs;
use App\Models\Rune_optics;
use App\Models\Worker_storage_logs;
use App\Montirani_uredjaji;
use App\Oprema_klijent;
use App\Revers;
use App\Revers_roba;
use App\Traits\Util;
use App\Uredjaji;
use App\Vraceni_uredjaji;
use Illuminate\Http\Request;

class EquipmentController extends Controller
{
    private function updateMsatPrice($client, $price){
        $kMod = new Klijent();
        $kMod->priceUpdate($client, $price);
    }
    private function updateOpticsPrice($client, $price){
        $kMod = new Klijenti_optika();
        $kMod->priceUpdate($client, $price);
    }
    private function msatPrice($device,$client){
        $price = Montage_prices::where('device_id', $device)->where('type', 1)->orderBy('id', 'DESC')->first();
        if($device == 2){
            if(!$this->stickPrice('msat', $client)){
                return 0;
            }
        }
        if(isset($price->price))
            return $price->price;
        else
            return 0;
    }
    private function opticsPrice($device,$client,$type){
        $price = Montage_prices::where('device_id', $device)->where('type', 2)->where('optics_type', $type)->first();
        if($device == 18 || $device == 23){
            if(!$this->stickPrice('optics', $client)){
                return 0;
            }
        }
        if(isset($price->price))
            return $price->price;
        else
            return 0;
    }
    //checks if stb is counted. only extra stb-s are counted and lnb-s are ignored if packet is not "extra stb"
    private function stickPrice($param, $client){
        $muMod = new Montirani_uredjaji();
        if($param == 'msat'){
            if($muMod->countStbsMsat($client) > 1)
                return true;
            else
                return false;
        }
        elseif($param == 'optics'){
            if($muMod->countStbsOptics($client) > 1)
                return true;
            else
                return false;
        }
    }
    public function add_device(Request $request){
        $param = $request->input('param');
        $idKlijent = $request->input('id_klijent');
        $uredjaj = $request->input('uredjaj');
        $montDevice = $request->input('monter_device');
        $deviceDateInput = $request->input('device_date');
        $deviceTime = $request->input('device_time');
        $type = $request->input('montage_type');
        $serijskiBroj = serialTrim($request->input('serijski_broj'));
        $request->validate(['serijski_broj', 'uredjaj']);

        if(!$param)
            $param = 'dth';

        $deviceOrigin = null;
        $clientOrigin = null;
        $originCheck = false;
        if($param == 'optika') {
            $findDevice = Uredjaji::find($uredjaj);
            $findClient = Klijenti_optika::find($idKlijent);
            if ($findDevice && $findClient) {
                $deviceOrigin = $findDevice->origin_id;
                $clientOrigin = $findClient->origin_id;
                if($deviceOrigin && $clientOrigin)
                    $originCheck = true;
            }
        }
        if($param == 'rune') {
            $findDevice = Uredjaji::find($uredjaj);
            $findClient = Rune_optics::find($idKlijent);
            if ($findDevice && $findClient) {
                $deviceOrigin = $findDevice->origin_id;
                $clientOrigin = $findClient->origin_id;
                if($deviceOrigin && $clientOrigin)
                    $originCheck = true;
            }
        }
        $validTime = checkTimeFormat($deviceTime);

        if($deviceDateInput && $validTime){
            $deviceDate = date('Y-m-d '.$deviceTime.':'.date('s'), strtotime($deviceDateInput));
        }
        else {
            $deviceDate = date('Y-m-d H:i:s');
        }

        $montModel = new Montirani_uredjaji();
        $magModel = new Magacin();
        $revModel = new Revers();

        if ($montModel->montiran($serijskiBroj))
            return back()->withInput()->with('error',  __("Error! Device is already mounted!"));
        if ($uredjaj == 0)
            return back()->withInput()->with('error', __("Add rejected! You must select a device."));
        if (!$magModel->checkSerial($serijskiBroj, true, $uredjaj))
            return back()->withInput()->with('error', __("Add rejected! The device does not exist in stock."));
        if ($revModel->checkSerialRevers($serijskiBroj, Util::userId()) && Util::isMonter())
            return back()->withInput()->with('error', __("Add rejected! The device does not exist on the reverse."));
        if($deviceDateInput && !$validTime)
            return back()->withInput()->with('error', __("Time format is not correct"));
        if($deviceOrigin != $clientOrigin && $originCheck)
            return back()->withInput()->with('error', __("The origin of the device does not match the origin of the client."));
        if(!$type && $param == 'optika')
            return back()->withInput()->with('error', __("You must select montage type"));



        if ($param == 'optika')
            $field = 'id_opticki_klijent';
        elseif($param == 'copper')
            $field = 'id_bakar_klijent';
        elseif($param == 'supernova')
            $field = 'id_supernova_klijent';
        elseif($param == 'rune')
            $field = 'id_rune';
        else
            $field = 'id_klijent';

        if ($montDevice) {
            $idMonter = $montDevice;
        }
        else{
            $idMonter = Util::userId();
        }

        $deviceData = $magModel->deviceBySerial($serijskiBroj);

        $createMontirani = Montirani_uredjaji::create([
            $field => $idKlijent,
            'id_uredjaj' => $uredjaj,
            'serijski_broj' => $serijskiBroj,
            'mac1' => $deviceData->mac1,
            'mac2' => $deviceData->mac2,
            'id_monter' => $idMonter,
            'created_at' => $deviceDate,
            'updated_at' => $deviceDate
        ]);

        if ($createMontirani){
            Change_history::create([
                'id_user' => $idMonter,
                $field => $idKlijent
            ]);
            Device_history::create([
                $field => $idKlijent,
                'id_device' => $uredjaj,
                'serijski_broj' => $serijskiBroj,
                'id_user' => $idMonter,
                'adjusted_date' => $deviceDate
            ]);
            Magacin::where('serijski_broj', $serijskiBroj)->delete();
            Revers_roba::where('serijski_broj', $serijskiBroj)->update(['mounted' => 1]);

            if($param == 'dth'){
                $this->updateMsatPrice($idKlijent, $this->msatPrice($uredjaj,$idKlijent));
            }
            elseIf($param == 'optika'){
                $this->updateOpticsPrice($idKlijent, $this->opticsPrice($uredjaj,$idKlijent,$type));
            }

            return back()->withInput()->with('success', __("Device added"));
        }
        else
            return back()->withInput()->with('errors', __("Device not added"));
    }

    public function add_device_construction(Request $request){
        $param = $request->input('param');
        $siteId = $request->input('id_site');
        $device = $request->input('device');
        $fitter = $request->input('fitter_device');
        $deviceDateInput = $request->input('device_date');
        $deviceTime = $request->input('device_time');
        $serial = serialTrim($request->input('serial'));
        $request->validate(['serial', 'device']);

        // if($param == 'rune') {
        //     $findDevice = Uredjaji::find($device);
        //     $findSite = De_construction_sites::find($siteId);
        //     if ($findDevice && $findSite) {
        //         $deviceOrigin = $findDevice->origin_id;
        //         $clientOrigin = $findClient->origin_id;
        //         if($deviceOrigin && $clientOrigin)
        //             $originCheck = true;
        //     }
        // }
        $validTime = checkTimeFormat($deviceTime);

        if($deviceDateInput && $validTime){
            $deviceDate = date('Y-m-d '.$deviceTime.':'.date('s'), strtotime($deviceDateInput));
        }
        else {
            $deviceDate = date('Y-m-d H:i:s');
        }

        $montModel = new De_mounted_devices();
        $magModel = new Magacin();
        $revModel = new Revers();

        if ($montModel->isMounted($serial))
            return back()->withInput()->with('error',  __("Error! Device is already mounted!"));
        if ($device == 0)
            return back()->withInput()->with('error', __("Add rejected! You must select a device."));
        if (!$magModel->checkSerial($serial, true, $device))
            return back()->withInput()->with('error', __("Add rejected! The device does not exist in stock."));
        if ($revModel->checkSerialRevers($serial, Util::userId()) && Util::isMonter())
            return back()->withInput()->with('error', __("Add rejected! The device does not exist on the reverse."));
        if($deviceDateInput && !$validTime)
            return back()->withInput()->with('error', __("Time format is not correct"));
        // if($deviceOrigin != $clientOrigin && $originCheck)
        //     return back()->withInput()->with('error', __("The origin of the device does not match the origin of the client."));
        // if(!$type && $param == 'optika')
        //     return back()->withInput()->with('error', __("You must select montage type"));



        if ($fitter) {
            $fitterId = $fitter;
        }
        else{
            $fitterId = Util::userId();
        }

        $create = De_mounted_devices::create([
            'site_id' => $siteId,
            'device_id' => $device,
            'serial' => $serial,
            'fitter_id' => $fitterId,
            'created_at' => $deviceDate,
            'updated_at' => $deviceDate
        ]);

        if ($create){
            De_change_history::create([
                'id_user' => $fitterId,
                'id_site' => $siteId
            ]);
            De_device_history::create([
                'user_id' => $fitterId,
                'device_id' => $device,
                'serial' => $serial,
                'site_id' => $siteId
            ]);
            Magacin::where('serijski_broj', $serial)->delete();
            Revers_roba::where('serijski_broj', $serial)->update(['mounted' => 1]);

            return back()->withInput()->with('success', __("Device added"));
        }
        else{
            return back()->withInput()->with('errors', __("Device not added"));
        }
    }

    public function delete_device(Request $request){
        $param = $request->input('param');
        $id = $request->input('id_montiran');
        $idKlijent = $request->input('id_klijent');
        $findDevice = Montirani_uredjaji::find($id);

        if ($param == 'optika')
            $field = 'id_opticki_klijent';
        elseif($param == 'copper')
            $field = 'id_bakar_klijent';
        elseif($param == 'supernova')
            $field = 'id_supernova_klijent';
        elseif($param == 'rune')
            $field = 'id_rune';
        else
            $field = 'id_klijent';

        if ($findDevice->delete()){
            Revers_roba::where('serijski_broj', $findDevice->serijski_broj)->update(['mounted' => 0]);
            if($param == 'rune'){
                Rune_logs::create([
                    'user_id' => Util::userId(),
                    'client_id' => $idKlijent
                ]);
            }
            else {
                Change_history::create([
                    'id_user' => Util::userId(),
                    $field => $idKlijent
                ]);
            }
            Device_history::create([
                $field => $idKlijent,
                'id_device' => $findDevice->id_uredjaj,
                'serijski_broj' => $findDevice->serijski_broj,
                'id_user' => Util::userId(),
                'deleted' => 1
            ]);
            return back()->withInput()->with('success', __("Device successfully deleted"));
        }
        else{
            return back()->withInput()->with('error', __("Error"));
        }

    }

    public function delete_device_construction(Request $request){
        $param = $request->input('param');
        $id = $request->input('id_mounted');
        $siteId = $request->input('id_site_d');

        if($param == 'de')
            $findDevice = De_mounted_devices::find($id);
        else
            $findDevice = null;

        if ($findDevice->delete()){
            De_device_history::create([
                'user_id' => Util::userId(),
                'device_id' => $findDevice->device_id,
                'serial' => $findDevice->serial,
                'site_id' => $findDevice->site_id,
                'deleted' => 1
            ]);
            Revers_roba::where('serijski_broj', $findDevice->serial)->update(['mounted' => 0]);
            if($param == 'de'){
                De_change_history::create([
                    'id_user' => Util::userId(),
                    'id_site' => $siteId
                ]);
            }
            return back()->withInput()->with('success', __("Device successfully deleted"));
        }
        else{
            return back()->withInput()->with('error', __("Error"));
        }

    }

    public function add_equipment(Request $request){
        $idOprema = $request->input('oprema');
        $idKlijent = $request->input('id_klijent');
        $kol = $request->input('kol');
        $param = $request->input('param');
        $monterEquipment = $request->input('monter_equipment');
        

        if ($param == 'optika') {
            $field = 'id_opticki_klijent';
            $clientType = 2;
        }
        elseif($param == 'copper') {
            $field = 'id_bakar_klijent';
            $clientType = 3;
        }
        elseif($param == 'supernova') {
            $field = 'id_supernova_klijent';
            $clientType = 4;
        }
        elseif($param == 'rune') {
            $field = 'id_rune';
            $clientType = 5;
        }
        else {
            $field = 'id_klijent';
            $clientType = 1;
        }

        if ($idOprema == 0)
            return back()->withInput()->with('error', __("Add rejected! You must select equipment."));
        if (!$kol)
            return back()->withInput()->with('error', __("Add rejected! You must enter quantity."));
        if (!is_float($kol) && $kol<1)
            return back()->withInput()->with('error', __("Quantity has to be positive number."));

        if($monterEquipment){
            $idMonter = $monterEquipment;
        }
        else {
            $idMonter = Util::userId();
        }

        $weModel = new Worker_equipment();

        if(!Util::isAdmin()){
            $equipment = $weModel->specific_equipment_mont($idMonter, $idOprema);
            if(isset($equipment->quantity))
                $equipmentQuantity = $equipment->quantity;
            else
                $equipmentQuantity = 0;
            if($kol > $equipmentQuantity)
                return back()->withInput()->with('error', __("Not enough equipment in warehouse"));
            if($kol < 0)
                return back()->withInput()->with('error', __("Quantity has to be positive number."));
            $opremaCreate = Oprema_klijent::create([
                'id_oprema' => $idOprema,
                $field => $idKlijent,
                'kol' => $kol,
                'id_monter' => $idMonter
            ]);
            if($opremaCreate){
                Change_history::create([
                    'id_user' => $idMonter,
                    $field => $idKlijent
                ]);
                Worker_storage_logs::create([
                    'mont_equipment_id' => $idOprema,
                    'worker_id' => $idMonter,
                    'client_type' => $clientType,
                    'client_id' => $idKlijent,
                    'quantity' => -$kol
                ]);
                $weModel->equipment_update_mont($idMonter, $idOprema, -$kol);
                return back()->withInput()->with('success', __("Equipment successfully added"));
            }
        }
        else {
            //if admin adds equipment in his name
            if(!$monterEquipment){
                $opremaCreate = Oprema_klijent::create([
                    'id_oprema' => $idOprema,
                    $field => $idKlijent,
                    'kol' => $kol,
                    'id_monter' => $idMonter
                ]);
            }
            //if fitter is selected
            else{
                $equipment = $weModel->specific_equipment_mont($idMonter, $idOprema);
                if(isset($equipment->quantity))
                    $equipmentQuantity = $equipment->quantity;
                else
                    $equipmentQuantity = 0;
                if($kol > $equipmentQuantity)
                    return back()->with('error', __("The fitter does not have as much goods in stock"));
                $opremaCreate = Oprema_klijent::create([
                    'id_oprema' => $idOprema,
                    $field => $idKlijent,
                    'kol' => $kol,
                    'id_monter' => $idMonter
                ]);
            }

            if ($opremaCreate){
                if($param == 'rune'){
                    Rune_logs::create([
                        'user_id' => $idMonter,
                        'client_id' => $idKlijent
                    ]);
                }
                else{
                    Change_history::create([
                        'id_user' => $idMonter,
                        $field => $idKlijent
                    ]);
                }
                if($monterEquipment){
                    Worker_storage_logs::create([
                        'mont_equipment_id' => $idOprema,
                        'worker_id' => $idMonter,
                        'client_type' => $clientType,
                        'client_id' => $idKlijent,
                        'quantity' => -$kol
                    ]);
                    $weModel->equipment_update_mont($idMonter, $idOprema, -$kol);
                }
            }
            return back()->withInput()->with('success', __("Equipment successfully added"));
        }
    }

    public function delete_equipment(Request $request){
        $idOprema = $request->input('id_oprema');
        $idKlijent = $request->input('id_klijent');
        $param = $request->input('param');
        $createdAt = $request->input('created_at');

        if ($param == 'optika')
            $field = 'id_opticki_klijent';
        elseif($param == 'copper')
            $field = 'id_bakar_klijent';
        elseif($param == 'supernova')
            $field = 'id_supernova_klijent';
        elseif($param == 'rune')
            $field = 'id_rune';
        else
            $field = 'id_klijent';

        Oprema_klijent::where('id_oprema', $idOprema)->where('created_at', $createdAt)->where($field, $idKlijent)->delete();
        if($param == 'rune'){
            Rune_logs::create([
                'user_id' => Util::userId(),
                'client_id' => $idKlijent
            ]);
        }
        else{
            Change_history::create([
                'id_user' => Util::userId(),
                $field => $idKlijent
            ]);
         }
        return back()->withInput()->with('success', __("Equipment successfully deleted"));
    }

    public function return_device(Request $request){
        $idUredjaj = $request->input('return_device');
        $serial = serialTrim($request->input('return_serial'));
        $razlog = $request->input('razlog');
        $param = $request->input('param');
        $idKlijent = $request->input('id_klijent');
        $montReturn = $request->input('monter_return');
        $returnDate = $request->input('return_date');
        $returnTime = $request->input('return_time');
        $jmbg = $request->input('return_jmbg');
        $tisId = $request->input("return_tis");

        $request->validate(['return_device' => 'required']);

        if($returnDate){
            $returnDate = date('Y-m-d '.$returnTime.':'.date('s'), strtotime($returnDate));
        }
        else {
            $returnDate = date('Y-m-d H:i:s');
        }

        $isDth = false;
        switch ($param){
            case 'dth':
                $isDth = true;
                $field = 'id_klijent';
                break;
            case 'optika':
                $field = 'id_opticki_klijent';
                break;
            case 'supernova':
                $field = 'id_supernova_klijent';
                break;
            case 'bakar':
                $field = 'id_bakar_klijent';
                break;
            case 'rune':
                $field = 'id_rune';
                break;
            default :
                $field = null;
        }

        $returnModel = new Vraceni_uredjaji();
        $inStock = $returnModel->checkSerial($serial);

        if ($inStock)
            return back()->withInput()->with('error', __("The device is already in the warehouse"));

        // if device is returned in the name of the fitter
        if ($montReturn) {
            $idMonter = $montReturn;
        }
        else {
            $idMonter = Util::userId();
        }

        $mountModel = new Montirani_uredjaji();
        $deviceData = $mountModel->deviceBySerial($serial);
        if ($deviceData){
            $mac1 = $deviceData->mac1;
            $mac2 = $deviceData->mac2;
        }
        else{
            $mac1 = null;
            $mac2 = null;
        }

        $returned = Vraceni_uredjaji::create([
            'serijski_broj' => $serial,
            'mac1' => $mac1,
            'mac2' => $mac2,
            'id_uredjaj' => $idUredjaj,
            $field => $idKlijent,
            'id_razlog_vracanja' => $razlog,
            'id_monter' => $idMonter,
            'created_at' => $returnDate,
            'updated_at' => $returnDate
        ]);

        Revers_roba::where('serijski_broj', $serial)->update(['mounted' => 0, 'obsolete' => 1]);

        if ($returned){
            $devModel = new Device_history();
            if ($devModel->logSearch($serial, false)->isEmpty()){
                Device_history::create([
                    $field => $idKlijent,
                    'id_device' => $idUredjaj,
                    'serijski_broj' => $serial,
                    'id_user' => $idMonter,
                    'vraceni' => 1,
                    'adjusted_return_date' => $returnDate
                ]);
            }
            else {
                $devModel->logUpdate($serial, $returnDate, $idMonter);
            }
            if($isDth)
                $mountModel->deleteMountedDevice($serial,$jmbg, $tisId);
            else
                Montirani_uredjaji::where('serijski_broj', $serial)->delete();
        }


        return back()->withInput()->with('success', __("Device successfully inserted into the warehouse"));
    }

    public function delete_required_equipment(Request $request){
        $id = $request->input('required_equipment_id');
        if($request->input('param') == 'kir')
            Kir_required_equipment::find($id)->delete();
        else
            Required_equipment::find($id)->delete();
        return back()->with('success', __("Equipment successfully deleted"));
    }

    public function take_back(Request $request){
        $quantity = $request->input('tb_quantity');
        $equipmentId = $request->input('tb_equipment_id');
        $siteId = $request->input('tb_site_id');
        $weMod = new Worker_equipment();
        $seMod = new Hw_site_equipment();
        $siteEquipment = $seMod->specificEquipmentById($siteId, $equipmentId);
        $available = $weMod->specific_equipment(Util::userId(), $equipmentId);
        if(!$quantity)
            return back()->with('error', __("You must enter quantity"));
        if(!$available)
            return back()->with('error', __("Worker doesn't have goods in his inventory"));
        if($quantity > $siteEquipment)
            return back()->with('error', __("Not enough equipment on construction site"));

        $weMod->equipment_update(Util::userId(), $equipmentId, $quantity);
        $seMod->equipment_update($siteId, $equipmentId, -$quantity);

        return back()->with('success', __("Equipment successfully added"));
    }

    public function add_site_equipment(Request $request){
        $equipmentId = $request->input('oprema');
        $siteId = $request->input('site_id');
        $quantity = $request->input('quantity');
        $param = $request->input('param');
        $fitterEquipment = $request->input('fitter_equipment');

        if($param == 'de')
            $clientType = 6;
        else
            $clientType = 0;
        

        if ($equipmentId == 0)
            return back()->withInput()->with('error', __("Add rejected! You must select equipment."));
        if (!$quantity)
            return back()->withInput()->with('error', __("Add rejected! You must enter quantity."));
        if (!is_float($quantity) && $quantity<1)
            return back()->withInput()->with('error', __("Quantity has to be positive number."));

        if($fitterEquipment){
            $fitterId = $fitterEquipment;
        }
        else {
            $fitterId = Util::userId();
        }

        $weModel = new Worker_equipment();

        if(!Util::isAdmin()){
            $equipment = $weModel->specific_equipment_mont($fitterId, $equipmentId);
            if(isset($equipment->quantity))
                $equipmentQuantity = $equipment->quantity;
            else
                $equipmentQuantity = 0;
            if($quantity > $equipmentQuantity)
                return back()->withInput()->with('error', __("Not enough equipment in warehouse"));
            if($quantity < 0)
                return back()->withInput()->with('error', __("Quantity has to be positive number."));
            $eCreate = De_site_equipment::create([
                'equipment_id' => $equipmentId,
                'site_id' => $siteId,
                'quantity' => $quantity,
                'worker_id' => $fitterId
            ]);
            if($eCreate){
                if($param == 'de'){
                    De_change_history::create([
                        'id_user' => $fitterId,
                        'id_site' => $siteId
                    ]);
                }
                Worker_storage_logs::create([
                    'mont_equipment_id' => $equipmentId,
                    'worker_id' => $fitterId,
                    'client_type' => $clientType,
                    'quantity' => -$quantity,
                    'client_id' => $siteId
                ]);
                $weModel->equipment_update_mont($fitterId, $equipmentId, -$quantity);
                return back()->withInput()->with('success', __("Equipment successfully added"));
            }
        }
        else {
            //if admin adds equipment in his name
            if(!$fitterEquipment){
                $eCreate = De_site_equipment::create([
                    'equipment_id' => $equipmentId,
                    'site_id' => $siteId,
                    'quantity' => $quantity,
                    'worker_id' => $fitterId
                ]);
            }
            //if fitter is selected
            else{
                $equipment = $weModel->specific_equipment_mont($fitterId, $equipmentId);
                if(isset($equipment->quantity))
                    $equipmentQuantity = $equipment->quantity;
                else
                    $equipmentQuantity = 0;
                if($quantity > $equipmentQuantity)
                    return back()->with('error', __("The fitter does not have as much goods in stock"));
                $eCreate = De_site_equipment::create([
                    'equipment_id' => $equipmentId,
                    'site_id' => $siteId,
                    'quantity' => $quantity,
                    'worker_id' => $fitterId
                ]);
            }
            if ($eCreate){
                if($param == 'de'){
                    De_change_history::create([
                        'id_user' => $fitterId,
                        'id_site' => $siteId
                    ]);
                }
                Worker_storage_logs::create([
                    'mont_equipment_id' => $equipmentId,
                    'worker_id' => $fitterId,
                    'client_type' => $clientType,
                    'quantity' => -$quantity,
                    'client_id' => $siteId
                ]);
                $weModel->equipment_update_mont($fitterId, $equipmentId, -$quantity);
            }
            return back()->withInput()->with('success', __("Equipment successfully added"));
        }
    }

    public function return_equipment_to_worker(Request $request){
        $id = $request->input('return_id');
        $qty = $request->input('return_qty');
        if($qty){
            $request->validate(['return_qty' => 'numeric']);
        }
        $data = De_site_equipment::find($id);
        if(!$qty || $qty >= $data->quantity) $qty = $data->quantity;
        $wMod = new Worker_equipment();
        $wMod = $wMod->equipment_update_mont($data->worker_id, $data->equipment_id, $qty);
        if($qty >= $data->quantity || !$qty){
            De_site_equipment::where('id', $id)->delete();
        }
        else {
            De_site_equipment::where('id', $data->id)->increment('quantity', -$qty);
        }
        Worker_storage_logs::create([
            'mont_equipment_id' => $data->equipment_id,
            'worker_id' => $data->worker_id,
            'client_type' => 6,
            'quantity' => $qty,
            'client_id' => $data->site_id
        ]);

        return back()->withInput()->with('success', __("Equipment successfully added"));
    }

    public function delete_site_equipment(Request $request){
        $equipmentId = $request->input('equipment_id');
        $siteId = $request->input('site_id');
        $param = $request->input('param');
        $createdAt = $request->input('created_at');

        De_site_equipment::where('equipment_id', $equipmentId)->where('created_at', $createdAt)->where('site_id', $siteId)->delete();
        if($param == 'de'){
            De_change_history::create([
                'id_user' => Util::userId(),
                'id_site' => $siteId
            ]);
        }
        return back()->withInput()->with('success', __("Equipment successfully deleted"));
    }
}
