<?php

namespace App\Http\Controllers;

use App\Firma;
use App\Models\Clusters;
use App\Models\Fobos_files;
use App\Models\Fobos_rune;
use App\Models\Fobos_rune_comments;
use App\Models\Fobos_rune_images;
use App\Models\Fobos_status_logs;
use App\Models\Fobos_statuses;
use App\Models\Pans;
use App\Models\Rune_optics;
use App\Models\User_cluster;
use App\Traits\Util;
use App\Teams;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use Symfony\Component\HttpFoundation\StreamedResponse;
use Intervention\Image\ImageManager as Img;

class FobosRuneController extends Controller
{
    private function sellersIds(){
        if(Util::isProdavac()){
            $ids = [Util::userId()];
        }
        else {
            $tMod = new Teams();
            $sellersIds = $tMod->sellersLead(Util::userId());
            $ids = Arr::pluck($sellersIds, 'id');
            array_push($ids, Util::userId());
        }

        return $ids;
    }

    private function statuses(){
        $statuses = Fobos_statuses::all();
        return $statuses;
    }

    private function firmId(){
        $firmModel = new Firma();
        $firma = $firmModel->podaci_o_firmi();
        return $firma->id;
    }

    private function linkCheck(){
        if (Util::isLider()){
            $sellersIds = $this->sellersIds();
            array_push($sellersIds, Util::userId());
        }
        else{
            $sellersIds = [Util::userId()];
        }
        return $sellersIds;
    }
    
    public function index()
    {
        $fobosModel = new Fobos_rune();
        if (Util::isAdmin()){
            $clients = $fobosModel->clientsIndex();
        }
        elseif (Util::isProdavac()){
            $clients = $fobosModel->clientsIndex(Util::userId());
        }
        elseif (Util::isLider()){
            $clients = $fobosModel->clientsIndex(null, Util::userId());
        }
        elseif (Util::isProjectAdmin() || Util::isProjectManager()){
            $clients = $fobosModel->clientsIndex(null, Util::userId(), null, Arr::pluck(Util::allProjectManagers(), 'id'));
        }
        else{
            $clients = array();
        }
        session(['search_route' => false]);
        return view ('fobosRune.index', [
            'clients' => $clients,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isLider' => Util::isLider()
        ]);
    }

    public function create()
    {
        return view('fobosRune.create', [
            'isAdmin' => Util::isAdmin(),
            'sellers' => Util::prodavci(),
            'statuses' => $this->statuses(),
            'projectManagers' => Util::allProjectManagers(),
            'teamLeaders' => Util::teamLeaders(),
            'clusters' => Clusters::all(),
            'pans' => Pans::all()
        ]);
    }

    public function store(Request $request)
    {
        $request->validate([
            'street' => 'required',
            'status' => 'required',
            'cluster' => 'required',
            'pan' => 'required'
        ]);

        $clientWithSameId = Fobos_rune::where('fobos_id', $request->input('fobos_id'))->first();
        if($clientWithSameId){
            return back()->withInput()->with('error', __('ID is already in database'));
        }

        if (Util::isProdavac())
            $seller = Util::userId();
        else
            $seller = $request->input('seller');

        if($seller){
            $sellerAssignDate = date('Y-m-d');
        }
        else {
            $sellerAssignDate = null;
        }

        if (Util::isLider())
            $teamLeader = Util::userId();
        else
            $teamLeader = $request->input('team_leader');

        if($teamLeader){
            $leaderAssignDate = date('Y-m-d');
        }
        else {
            $leaderAssignDate = null;
        }

        $fobos = Fobos_rune::create([
            'cluster' => $request->input('cluster'),
            'name' => $request->input('name'),
            'surname' => $request->input('surname'),
            'street' => $request->input('street'),
            'home_no' => $request->input('home_no'),
            'pan_id' => $request->input('pan'),
            'home_no' => $request->input('home_no'),
            'enterance' => $request->input('enterance'),
            'floor' => $request->input('floor'),
            'apartment' => $request->input('apartment'),
            'tel1' => $request->input('tel1'),
            'tel2' => $request->input('tel2'),
            'tel3' => $request->input('tel3'),
            'network_group' => $request->input('network_group'),
            'eta' => $request->input('eta'),
            'fobos_id' => $request->input('fobos_id'),
            'county' => $request->input('county'),
            'city' => $request->input('city'),
            'settlement' => $request->input('settlement'),
            'household' => $request->input('household'),
            'households' => $request->input('households'),
            'state' => $request->input('state'),
            'state_services' => $request->input('state_services'),
            'packet' => $request->input('packet'),
            'black_list' => $request->input('black_list')?1:0,
            'recomended_tariff' => $request->input('recomended_tariff'),
            'first_offer' => $request->input('first_offer'),
            'operator' => $request->input('operator'),
            'month' => $request->input('month'),
            'year' => $request->input('year'),
            'status_id' => $request->input('status'),
            'withdrawal_date' => database_date($request->input('withdrawal_date')),
            'contract_expire_date' => database_date($request->input('contract_expire_date')),
            'withdrawal_reason' => $request->input('withdrawal_reason'),
            'seller_id' => $seller,
            'seller_assign_date' => $sellerAssignDate,
            'team_leader' => $teamLeader,
            'leader_assign_date' => $leaderAssignDate,
            'created_by' => Util::userId(),
            'updated_by' => Util::userId(),
            'project_manager' => $request->input('project_manager'),
            'points' => $request->input('points'),
            'cable' => $request->input('cable'),
            'thread' => $request->input('thread'),
            'tube' => $request->input('tube'),
            'case' => $request->input('case'),
            'x_coordinate' => $request->input('x_coordinate'),
            'y_coordinate' => $request->input('y_coordinate')
        ]);

        if($fobos){
            Fobos_status_logs::create([
                'user_id' => Util::userId(),
                'status_id' => $request->input('status'),
                'fobos_id' => $fobos->id
            ]);
        }

        if ($request->input('comment') && $fobos) {
            Fobos_rune_comments::create([
                'comment' => $request->input('comment'),
                'user_id' => Util::userId(),
                'fobos_id' => $fobos->id
            ]);
        }

        return redirect()->route('fobos_rune.index')->with('success', __("Data successfully added"));
    }

    public function show(Fobos_rune $fobos_rune)
    {
        $fobosModel = new Fobos_rune();
        $fobos = $fobosModel->clientData($fobos_rune->id);
        $commentModel = new Fobos_rune_comments();
        $comments = $commentModel->comments($fobos_rune->id);
        $sellersIds = $this->linkCheck();
        $iMod = new Fobos_rune_images();
        $images = $iMod->images($fobos_rune->id);
        $files = Fobos_files::where('client_id', $fobos_rune->id)->get();

        return view('fobosRune.show', [
            'fobos' => $fobos,
            'isAdmin' => Util::isAdmin(),
            'isLider' => Util::isLider(),
            'comments' => $comments,
            'sellersIds' => $sellersIds,
            'images' => $images,
            'files' => $files
        ]);
    }

    public function edit(Fobos_rune $fobos_rune)
    {
        $fModel = new Fobos_rune();
        $fobos = $fModel->clientData($fobos_rune->id);
        $statuses = Fobos_statuses::all();
        $sellers = Util::prodavci();

        //kod biz proneta se samo natasa spasic pojavljuje u select
        if($this->firmId() == 1){
            $sellers = $sellers->merge(Util::lideri());
        }

        $comModel = new Fobos_rune_comments();
        $comments = $comModel->comments($fobos_rune->id);

        //link abuse prevention
        $sellersIds = $this->linkCheck();

        $iMod = new Fobos_rune_images();
        $images = $iMod->images($fobos_rune->id);
        $pans = Pans::all();

        $files = Fobos_files::where('client_id', $fobos_rune->id)->get();

        return view('fobosRune.edit', [
            'fobos' => $fobos,
            'isAdmin' => Util::isAdmin(),
            'comments' => $comments,
            'isSuperAdmin' => Util::isSuperAdmin(),
            'sellersIds' => $sellersIds,
            'statuses' => $statuses,
            'sellers' => $sellers,
            'projectManagers' => Util::allProjectManagers(),
            'teamLeaders' => Util::teamLeaders(),
            'clusters' => Clusters::all(),
            'images' => $images,
            'pans' => $pans,
            'files' => $files
        ]);
    }

    public function update(Request $request, Fobos_rune $fobos_rune)
    {
        $request->validate([
            'street' => 'required',
            'cluster' => 'required',
            'status' => 'required',
            'pan' => 'required',
            'document' => 'mimetypes:application/vnd.openxmlformats-officedocument.spreadsheetml.sheet,application/vnd.ms-excel,application/pdf,audio/mpeg,audio/wav,audio/ogg,audio/x-wav,audio/mp4', // allow documents and audio files by MIME type

        ]);

        $images = $request->file('images');
        $status = $request->input('status');

        if(Fobos_rune_images::where('id_site', $fobos_rune->id)->first()){
            $hasImage = true;
        }
        else{
            $hasImage = false;
        }

        if(is_array($images))
            $hasImage = true;

        if($status == 5 && $hasImage == false){
            return back()->with('error', __('If you want to update this status, you have to upload picture'));
        }

        if (Util::isProdavac())
            $seller = Util::userId();
        else
            $seller = $request->input('seller');

        if($seller && $seller != $fobos_rune->seller_id){
            $sellerAssignDate = date('Y-m-d');
        }
        else {
            $sellerAssignDate = $fobos_rune->seller_assign_date;
        }

        if (Util::isLider())
            $teamLeader = Util::userId();
        else
            $teamLeader = $request->input('team_leader');

        if($teamLeader && $teamLeader != $fobos_rune->team_leader){
            $leaderAssignDate = date('Y-m-d');
        }
        else {
            $leaderAssignDate = null;
        }

        if($request->input('status') != $fobos_rune->status_id){
            Fobos_status_logs::create([
                'user_id' => Util::userId(),
                'status_id' => $request->input('status'),
                'fobos_id' => $fobos_rune->id
            ]);
        }

        $fobosUpdate = Fobos_rune::where('id', $fobos_rune->id)->update([
            'cluster' => $request->input('cluster'),
            'name' => $request->input('name'),
            'surname' => $request->input('surname'),
            'street' => $request->input('street'),
            'home_no' => $request->input('home_no'),
            'pan_id' => $request->input('pan'),
            'enterance' => $request->input('enterance'),
            'floor' => $request->input('floor'),
            'apartment' => $request->input('apartment'),
            'tel1' => $request->input('tel1'),
            'tel2' => $request->input('tel2'),
            'tel3' => $request->input('tel3'),
            'network_group' => $request->input('network_group'),
            'eta' => $request->input('eta'),
            'fobos_id' => $request->input('fobos_id'),
            'county' => $request->input('county'),
            'city' => $request->input('city'),
            'settlement' => $request->input('settlement'),
            'household' => $request->input('household'),
            'households' => $request->input('households'),
            'state' => $request->input('state'),
            'state_services' => $request->input('state_services'),
            'packet' => $request->input('packet'),
            'black_list' => $request->input('black_list')?1:0,
            'recomended_tariff' => $request->input('recomended_tariff'),
            'first_offer' => $request->input('first_offer'),
            'operator' => $request->input('operator'),
            'month' => $request->input('month'),
            'year' => $request->input('year'),
            'status_id' => $status,
            'withdrawal_date' => database_date($request->input('withdrawal_date')),
            'contract_expire_date' => database_date($request->input('contract_expire_date')),
            'withdrawal_reason' => $request->input('withdrawal_reason'),
            'seller_id' => $seller,
            'seller_assign_date' => $sellerAssignDate,
            'team_leader' => $teamLeader,
            'leader_assign_date' => $leaderAssignDate,
            'created_by' => Util::userId(),
            'updated_by' => Util::userId(),
            'project_manager' => $request->input('project_manager'),
            'points' => $request->input('points'),
            'cable' => $request->input('cable'),
            'thread' => $request->input('thread'),
            'tube' => $request->input('tube'),
            'case' => $request->input('case'),
            'x_coordinate' => $request->input('x_coordinate'),
            'y_coordinate' => $request->input('y_coordinate')
        ]);

        if($fobosUpdate && $images){
            if($images){
                $this->validate($request, [
                    'images.*' => 'image|mimes:jpeg,png,jpg,gif'
                ]);
                $num = 0;
                $img = new Img();
                $folder = 'uploads/fobos_rune_images/'.quartal();
                if (!file_exists($folder)){
                    mkdir($folder, 0755, true);
                }
                foreach($images as $file){
                    $extension = $file->getClientOriginalExtension();
                    $filename = time().'-'.$num.'-fobos'.'.'.$extension;
                    $num++;
                    $fileInt = $img->make($file->getRealPath());
                    $fileInt->save($folder.'/'.$filename, 50);
                    Fobos_rune_images::create([
                        'url' => '/'.$folder.'/'.$filename,
                        'id_site' => $fobos_rune->id
                    ]);
                }
            }
        }
        
        $document = $request->file('document');
        if($fobosUpdate && $document){
            $folder = 'uploads/documents/'.quartal();
            if (!file_exists($folder)){
                mkdir($folder, 0755, true);
            }
            if($document){
                $originalFile = $document->getClientOriginalName();
                $filename = strtotime(date('d.m.Y. H:i:s')).'_'.$originalFile;
                $folder = 'uploads/documents/'.quartal();
                create_folder($folder);
                $document->move($folder, $filename);
                Fobos_files::create([
                    'file_url' => '/'.$folder.'/'.$filename,
                    'client_id' => $fobos_rune->id,
                    'filename' => $originalFile
                ]);
            }
        }

        $penetration = null;
        switch($status){
            case 1 : 
                if($fobos_rune->status != 1){
                    $fMod = new Fobos_rune();
                    /** penetration is updated if status is set KU. formula: totalKU/(total-totalNN) **/
                    if($fMod->totalByStatus($fobos_rune->pan_id) > 0)
                        $penetration = $fMod->totalByStatus($fobos_rune->pan_id, 1)/($fMod->totalByStatus($fobos_rune->pan_id)-$fMod->totalByStatus($fobos_rune->pan_id, 5))*100;
                    Fobos_rune::where('id', $fobos_rune->id)->update(['penetration' => $penetration]);
                }
                if(!$fobos_rune->date_ku){
                    Fobos_rune::where('id', $fobos_rune->id)->update(['date_ku' => date('Y-m-d'), 'penetration' => $penetration]);
                }
            break;
            case 2 : 
                Fobos_rune::where('id', $fobos_rune->id)->update(['penetration' => $penetration]);
                if(!$fobos_rune->date_rp){
                    Fobos_rune::where('id', $fobos_rune->id)->update(['date_rp' => date('Y-m-d')]);
                }
            break;
            case 3 : 
                Fobos_rune::where('id', $fobos_rune->id)->update(['penetration' => $penetration]);
                if(!$fobos_rune->date_nz){
                    Fobos_rune::where('id', $fobos_rune->id)->update(['date_nz' => date('Y-m-d')]);
                }
            break;
            case 4 : 
                Fobos_rune::where('id', $fobos_rune->id)->update(['penetration' => $penetration]);
                if(!$fobos_rune->date_nzv){
                    Fobos_rune::where('id', $fobos_rune->id)->update(['date_nzv' => date('Y-m-d'), 'penetration']);
                }
            break;
            case 5 : 
                Fobos_rune::where('id', $fobos_rune->id)->update(['penetration' => $penetration]);
                if(!$fobos_rune->date_nn){
                    Fobos_rune::where('id', $fobos_rune->id)->update(['date_nn' => date('Y-m-d'), 'penetration']);
                }
            break;
            case 6 : 
                Fobos_rune::where('id', $fobos_rune->id)->update(['penetration' => $penetration]);
                if(!$fobos_rune->date_ro){
                    Fobos_rune::where('id', $fobos_rune->id)->update(['date_ro' => date('Y-m-d')]);
                }
            break;
            case 7 : 
                Fobos_rune::where('id', $fobos_rune->id)->update(['penetration' => $penetration]);
                if(!$fobos_rune->date_nnn){
                    Fobos_rune::where('id', $fobos_rune->id)->update(['date_nnn' => date('Y-m-d')]);
                }
            break;
        }

        if ($request->input('comment') && $fobosUpdate) {
            Fobos_rune_comments::create([
                'comment' => $request->input('comment'),
                'user_id' => Util::userId(),
                'fobos_id' => $fobos_rune->id
            ]);
        }

        if ($fobosUpdate){
            return redirect()->route('fobos_rune.show', ['fobos_rune'=>$fobos_rune->id])->with('success', __("Data successfully changed"));
        }

        return back()->withInput();
    }

    /**
     * @param Request $request
     * @return $this
     */
    public function destroy(Request $request)
    {
        $findFobos = Fobos_rune::find($request->input('id_fobos'));
        try{
            $findFobos->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Data cannot be deleted"));
        }
    }

    public function delete_comment(Request $request){
        $findComment = Fobos_rune_comments::find($request->input('id_comment'));
        if($findComment->delete()){
            return back()->with('success', __("Data successfully deleted"));
        }
    }

    public function search(){
        return view('fobosRune.search', [
            'isAdmin' => Util::isAdmin(),
            'sellers' => Util::prodavci(),
            'statuses' => $this->statuses(),
            'projectManagers' => Util::allProjectManagers(),
            'teamLeaders' => Util::teamLeaders(),
            'clusters' => Clusters::all(),
            'pans' => Pans::all()
        ]);
    }

    public function search_result(Request $request){
        $cluster = $request->input('cluster');
        $street = $request->input('street');
        $homeNo = $request->input('home_no');
        $enterance = $request->input('enterance');
        $tel1 = $request->input('tel1');
        $tel2 = $request->input('tel2');
        $tel3 = $request->input('tel3');
        $floor = $request->input('floor');
        $apartment = $request->input('apartment');
        $eta = $request->input('eta');
        $networkGroup = $request->input('network_group');
        $fobosId = $request->input('fobos_id');
        $packet = $request->input('packet');
        $county = $request->input('county');
        $blackList = $request->input('black_list')?1:0;
        $recommendedTariff = $request->input('recomended_tariff');
        $city = $request->input('city');
        $settlement = $request->input('settlement');
        $household = $request->input('household');
        $households = $request->input('households');
        $state = $request->input('state');
        $stateServices = $request->input('state_services');
        $pan = $request->input('pan');
        $seller = $request->input('seller');
        $status = $request->input('status');
        $points = $request->input('points');
        $cable = $request->input('cable');
        $thread = $request->input('thread');
        $tube = $request->input('tube');
        $case = $request->input('case');
        $firstOffer = $request->input('first_offer');
        $operator = $request->input('operator');
        $month = $request->input('month');
        $year = $request->input('year');
        $withdrawalDate = database_date($request->input('withdrawal_date'));
        $contractExpireDate = database_date($request->input('contract_expire_date'));
        $withdrawalReason = $request->input('withdrawal_reason');
        $accepted = $request->input('accepted');
        $projectManager = $request->input('project_manager');
        $xCoordinate = $request->input('x_coordinate');
        $yCoordinate = $request->input('y_coordinate');
        $statusLog = $request->input('status_log');
        $statusStart = database_date($request->input('status_start'));
        $statusEnd = database_date($request->input('status_end'));
        if($accepted){
            $accepted = 1;
        }
        else {
            $accepted = 0;
        }

        if (Util::isProdavac())
            $seller = [Util::userId()];
        else
            $seller = $request->input('seller');

        if (Util::isLider()){
            $teamLeader = Util::userId();
        }
        else{
            $teamLeader = $request->input('team_leader');
        }
        
        if(Util::isProjectManager() || Util::isProjectAdmin())
            $projectManager = Util::userId();

        $fmodel = new Fobos_rune();
        //if all three variables have value, search status change logs only
        // if($statusLog && $statusStart && $statusEnd){
        //     $fobos = $fmodel->searchStatusLogs($statusLog,$statusStart,$statusEnd,true);
        //     $noPagination = $fmodel->searchStatusLogs($statusLog,$statusStart,$statusEnd);
        // }
        // else {
        $fobos = $fmodel->search($cluster,$street,$pan,$homeNo,$enterance,$floor,$apartment,$tel1,$tel2,$tel3,$networkGroup,$eta,$fobosId,$county,$city,$settlement,
            $household,$households,$state,$stateServices,$packet,$recommendedTariff,$blackList,$firstOffer,$operator,$month,$year,$seller,$status,$withdrawalDate,$withdrawalReason,
            $contractExpireDate,$projectManager,$points,$cable,$thread,$tube,$case,$xCoordinate,$yCoordinate,$teamLeader,$accepted,$statusLog,$statusStart,$statusEnd,true);

        $noPagination = $fmodel->search($cluster,$street,$pan,$homeNo,$enterance,$floor,$apartment,$tel1,$tel2,$tel3,$networkGroup,$eta,$fobosId,$county,$city,$settlement,
            $household,$households,$state,$stateServices,$packet,$recommendedTariff,$blackList,$firstOffer,$operator,$month,$year,$seller,$status,$withdrawalDate,$withdrawalReason,
            $contractExpireDate,$projectManager,$points,$cable,$thread,$tube,$case,$xCoordinate,$yCoordinate,$teamLeader,$accepted,$statusLog,$statusStart,$statusEnd);
        // }

        $ids = Arr::pluck($noPagination, 'id');
        $count = count($ids);
        $ids = json_encode($ids);
        session(['ids_export' => $ids]);
        session(['search_route' => url()->full()]);
        if($pan){
            $penetration = $fmodel->totalByStatus($pan,1)/($fmodel->totalByStatus($pan)-$fmodel->totalByStatus($pan,5))*100;
        }
        else{
            $penetration = null;
        }
        return view('fobosRune.search_result', [
            'fobos' => $fobos,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isLider' => Util::isLider(),
            'count' => $count,
            'penetration' => $penetration
        ]);
    }

    public function expedition(Request $request){
        $id = $request->input('id_expedition');
        Fobos_rune::where('id', $id)->update(['expedited' => 1, 'status_id' => 1, 'returned' =>0]);
        return back()->withInput()->with('success', __("Expedited"));
    }

    public function accept(Request $request){
        $id = $request->input('fobos_accept');
        $constructionManager = null;
        $fobos = Fobos_rune::find($id);
        if(env('SERVER_ID') == 3){
            $ucMod = new User_cluster();
            $constructionManager = $ucMod->defaultUser($fobos->cluster);
        }
        $create = Rune_optics::create([
            'cluster' => $fobos->cluster,
            'name' => $fobos->name,
            'surname' => $fobos->surname,
            'street' => $fobos->street,
            'home_no' => $fobos->home_no,
            'pan' => $fobos->pan,
            'enterance' => $fobos->enterance,
            'floor' => $fobos->floor,
            'apartment' => $fobos->apartment,
            'tel1' => $fobos->tel1,
            'tel2' => $fobos->tel2,
            'tel3' => $fobos->tel3,
            'network_group' => $fobos->network_group,
            'eta' => $fobos->eta,
            'fobos_id' => $fobos->fobos_id,
            'county' => $fobos->county,
            'city' => $fobos->city,
            'settlement' => $fobos->settlement,
            'household' => $fobos->household,
            'households' => $fobos->households,
            'state' => $fobos->state,
            'state_services' => $fobos->state_services,
            'packet' => $fobos->packet,
            'black_list' => $fobos->black_list,
            'recomended_tariff' => $fobos->recomended_tariff,
            'first_offer' => $fobos->first_offer,
            'operator' => $fobos->operator,
            'month' => $fobos->month,
            'year' => $fobos->year,
            'withdrawal_date' => database_date($fobos->withdrawal_date),
            'contract_expire_date' => database_date($fobos->contract_expire_date),
            'withdrawal_reason' => $fobos->withdrawal_reason,
            'seller_id' => $fobos->seller_id,
            'created_by' => Util::userId(),
            'updated_by' => Util::userId(),
            'project_manager' => $fobos->project_manager,
            'construction_manager' => $constructionManager,
            'points' => $fobos->points,
            'cable' => $fobos->cable,
            'thread' => $fobos->thread,
            'tube' => $fobos->tube,
            'case' => $fobos->case,
            'x_coordinate' => $fobos->x_coordinate,
            'y_coordinate' => $fobos->y_coordinate,
            'construction_manager'
        ]);
        if($create){
            Fobos_rune::where('id', $id)->update(['expedited' => 0, 'accepted' => 1, 'returned' => 0]);
        }
        return back()->withInput()->with('success', __("Accepted"));
    }

    public function return(Request $request){
        $id = $request->input('fobos_return');
        Fobos_rune::where('id', $id)->update(['expedited' => 0, 'accepted' => 0, 'returned' => 1]);
        return back()->withInput()->with('success', __("Returned"));
    }

    public function claims(){
        $fmodel = new Fobos_rune();
        if(Util::isAdmin())
            $clients = $fmodel->clientsIndex(null, null, 1);
        else
            $clients = $fmodel->clientsIndex($this->sellersIds(), null, 1);
        return view ('fobosRune.claims', [
            'clients' => $clients,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isLider' => Util::isLider()
        ]);
    }

    public function import_index(){
        return view('fobosRune.import');
    }
    public function import(Request $request){
        require '../vendor/autoload.php';
        $file = $request->file('import');
        $user = auth()->user();

        $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();
        if ($file){
            $allowedExtensions = array('xls', 'xlsx');
            $extension = $file->getClientOriginalExtension();
            if (in_array($extension, $allowedExtensions)){

                $spreadsheet = $reader->load($file);
                $sheetData = $spreadsheet->getActiveSheet()->toArray();
                $errorMessages = array();

                foreach ($sheetData as $br=>$data){
                    if ($br == 0 || (!$data[2] && !$data[3]))
                        continue;
                        // if($br==2)
                        // dd($data[18]);
                    if(!is_int($data[0]) && $data[0] != null)
                        $errorMessages[] = "ID has to be integer: cell number".' '.($br+1);
                    if(!is_int($data[8]) && $data[8] != null)
                        $errorMessages[] = "Household has to be integer: cell number".' '.($br+1);
                    if(!is_int($data[9]) && $data[9] != null)
                        $errorMessages[] = "Households has to be integer: cell number".' '.($br+1);
                    if(!is_int($data[10]) && $data[10] != null)
                        $errorMessages[] = "State has to be integer: cell number".' '.($br+1);
                    if(!is_int($data[11]) && $data[11] != null)
                        $errorMessages[] = "Eta services has to be integer: cell number".' '.($br+1);
                    if(!is_int($data[12]) && $data[12] != null)
                        $errorMessages[] = "State services has to be integer: cell number".' '.($br+1);
                    if(!is_int($data[14]) && $data[14] != null)
                        $errorMessages[] = "X coordinate has to be integer: cell number".' '.($br+1);
                    if(!is_int($data[15]) && $data[15] != null)
                        $errorMessages[] = "Y coordinate has to be integer: cell number".' '.($br+1);
                    if(!Fobos_statuses::find($data[18]) && $data[18] != null)
                        $errorMessages[] = "Status not found: cell number".' '.($br+1);
                    if(!User::find($data[21]) && $data[21] != null)
                        $errorMessages[] = "User not found: cell number".' '.($br+1);

                }

                if (!empty($errorMessages))
                    return view('fobosRune.import', ['errorMessages'=>$errorMessages]);

                foreach ($sheetData as $key=>$data){
                    if ($key == 0 || (!$data[2] && !$data[3]))
                        continue;

                    $fobosCreate = Fobos_rune::create([
                        'fobos_id' => $data[0],
                        'county' => $data[1],
                        'city' => $data[2],
                        'settlement' => $data[3],
                        'street' => $data[4],
                        'home_no' => $data[5],
                        'cluster' => $data[6],
                        'pan_id' => $data[7],
                        'household' => $data[8],
                        'households' => $data[9],
                        'state' => $data[10],
                        'eta' => $data[11],
                        'state_services' => $data[12],
                        'x_coordinate' => $data[14],
                        'y_coordinate' => $data[15],
                        'created_by' => $user->id,
                        'status_id' => $data[18],
                        'seller_id' => $data[21]
                    ]);

                    if($fobosCreate){
                        if($data[13] && $data[13] != 0){
                            Fobos_rune_comments::create([
                                'comment' => $data[13],
                                'user_id' => Util::userId(),
                                'fobos_id' => $fobosCreate->id
                            ]);
                        }
                    }
                }

                return redirect()->route('fobos_rune_import_index')->with('success', __("Data successfully imported to database"));

            }
            else {
                return redirect()->route('fobos_rune_import_index')->with('errors', __("Valid file extension is xls or xslx"));
            }
        }
        else {
            return redirect()->route('fobos_rune_import_index')->with('errors', __("Import excel file"));
        }
    }

    public function expire_list(){
        $fobosModel = new Fobos_rune();
        if(Util::isAdmin())
            $clients = $fobosModel->expireList();
        else
            $clients = $fobosModel->expireList(Util::userId());
        session(['search_route' => false]);
        session(['expire_list' => false]);
        return view ('fobosRune.expire_list', [
            'clients' => $clients,
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isLider' => Util::isLider()
        ]);
    }

    public function group_entry(){
        $ids = json_decode(session('ids_rune'));
        $sellers = Util::allSellers();
        return view('fobosRune.group_entry', ['ids' => $ids, 'sellers' => $sellers, 'teamLeaders' => Util::teamLeaders()]);
    }

    public function group_action(Request $request){
        $param = $request->input('param');
        $data = $request->input('data');
        $ids = json_decode(session('ids_rune'));
        if ($ids) {
            switch($param){
                case 'seller' :
                    foreach ($ids as $id) {
                        Fobos_rune::where('id', $id)->update([
                            'seller_id' => $data
                        ]);
                    }
                    return back()->with('success', __('Fitter successfully added'));
                    break;
                case 'leader' :
                        foreach ($ids as $id) {
                            Fobos_rune::where('id', $id)->update([
                                'team_leader' => $data
                            ]);
                        }
                        return back()->with('success', __('Fitter successfully added'));
                        break;
                case 'accept' :
                    foreach ($ids as $id) {
                        $find = Fobos_rune::find($id);
                        if($find->accepted == 0){
                            $fobosUpdate = Fobos_rune::where('id', $id)->where('accepted', '=', 0)->update(['expedited' => 0, 'accepted' => 1, 'returned' => 0]);
                            if ($fobosUpdate){
                                $fobos = Fobos_rune::find($id);
                                Rune_optics::create([
                                    'cluster' => $fobos->cluster,
                                    'name' => $fobos->name,
                                    'surname' => $fobos->surname,
                                    'street' => $fobos->street,
                                    'home_no' => $fobos->home_no,
                                    'pan_id' => $fobos->pan_id,
                                    'enterance' => $fobos->enterance,
                                    'floor' => $fobos->floor,
                                    'apartment' => $fobos->apartment,
                                    'tel1' => $fobos->tel1,
                                    'tel2' => $fobos->tel2,
                                    'tel3' => $fobos->tel3,
                                    'network_group' => $fobos->network_group,
                                    'eta' => $fobos->eta,
                                    'fobos_id' => $fobos->fobos_id,
                                    'county' => $fobos->county,
                                    'city' => $fobos->city,
                                    'settlement' => $fobos->settlement,
                                    'household' => $fobos->household,
                                    'households' => $fobos->households,
                                    'state' => $fobos->state,
                                    'state_services' => $fobos->state_services,
                                    'packet' => $fobos->packet,
                                    'black_list' => $fobos->black_list,
                                    'recomended_tariff' => $fobos->recomended_tariff,
                                    'first_offer' => $fobos->first_offer,
                                    'operator' => $fobos->operator,
                                    'month' => $fobos->month,
                                    'year' => $fobos->year,
                                    'status' => $fobos->status_id,
                                    'withdrawal_date' => database_date($fobos->withdrawal_date),
                                    'contract_expire_date' => database_date($fobos->contract_expire_date),
                                    'withdrawal_reason' => $fobos->withdrawal_reason,
                                    'seller_id' => $fobos->seller_id,
                                    'created_by' => Util::userId(),
                                    'updated_by' => Util::userId(),
                                    'project_manager' => $fobos->project_manager,
                                    'points' => $fobos->points,
                                    'cable' => $fobos->cable,
                                    'thread' => $fobos->thread,
                                    'tube' => $fobos->tube,
                                    'case' => $fobos->case,
                                    'x_coordinate' => $fobos->x_coordinate,
                                    'y_coordinate' => $fobos->y_coordinate
                                ]);
                            }
                        }
                    }
                    return back()->with('success', __('Data successfully imported'));
                    break;
                default :
                    return back()->with('error', __('Error'));
            }
        }
        else
            return back()->with('errors', __('Session is empty'));
    }

    public function export(Request $request){
        require '../vendor/autoload.php';
        $ids = session('ids_export');
        $ids = json_decode($ids);

        $withComments = $request->input('comments');

        $cMod = new Fobos_rune();
        $clients = $cMod->export($ids);

        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();

        $sheet->getColumnDimension('A')->setAutoSize(true);
        $sheet->getColumnDimension('B')->setAutoSize(true);
        $sheet->getColumnDimension('C')->setAutoSize(true);
        $sheet->getColumnDimension('D')->setAutoSize(true);
        $sheet->getColumnDimension('E')->setAutoSize(true);
        $sheet->getColumnDimension('F')->setAutoSize(true);
        $sheet->getColumnDimension('G')->setAutoSize(true);
        $sheet->getColumnDimension('H')->setAutoSize(true);
        $sheet->getColumnDimension('I')->setAutoSize(true);
        $sheet->getColumnDimension('J')->setAutoSize(true);
        $sheet->getColumnDimension('K')->setAutoSize(true);
        $sheet->getColumnDimension('L')->setAutoSize(true);
        $sheet->getColumnDimension('M')->setAutoSize(true);
        $sheet->getColumnDimension('N')->setAutoSize(true);
        $sheet->getColumnDimension('O')->setAutoSize(true);
        $sheet->getColumnDimension('P')->setAutoSize(true);
        $sheet->getColumnDimension('Q')->setAutoSize(true);
        $sheet->getColumnDimension('R')->setAutoSize(true);
        $sheet->getColumnDimension('S')->setAutoSize(true);
        $sheet->getColumnDimension('T')->setAutoSize(true);
        $sheet->getColumnDimension('U')->setAutoSize(true);
        $sheet->getColumnDimension('V')->setAutoSize(true);
        $sheet->getColumnDimension('W')->setAutoSize(true);
        $sheet->getColumnDimension('X')->setAutoSize(true);
        $sheet->getColumnDimension('Y')->setAutoSize(true);
        $sheet->getColumnDimension('Z')->setAutoSize(true);
        $sheet->getColumnDimension('AA')->setAutoSize(true);
        $sheet->getColumnDimension('AB')->setAutoSize(true);
        $sheet->getColumnDimension('AC')->setAutoSize(true);
        $sheet->getColumnDimension('AD')->setAutoSize(true);
        $sheet->getColumnDimension('AE')->setAutoSize(true);
        $sheet->getColumnDimension('AF')->setAutoSize(true);
        $sheet->getColumnDimension('AG')->setAutoSize(true);
        $sheet->getColumnDimension('AH')->setAutoSize(true);
        $sheet->getColumnDimension('AI')->setAutoSize(true);
        $sheet->getColumnDimension('AJ')->setAutoSize(true);
        $sheet->getColumnDimension('AK')->setAutoSize(true);
        $sheet->getColumnDimension('AL')->setAutoSize(true);
        $sheet->getColumnDimension('AM')->setAutoSize(true);
        $sheet->getColumnDimension('AN')->setAutoSize(true);
        $sheet->getColumnDimension('AO')->setAutoSize(true);
        $sheet->getColumnDimension('AP')->setAutoSize(true);
        $sheet->getColumnDimension('AQ')->setAutoSize(true);
        $sheet->getColumnDimension('AR')->setAutoSize(true);
        $sheet->getColumnDimension('AS')->setAutoSize(true);
        $sheet->getColumnDimension('AT')->setAutoSize(true);
        $sheet->getColumnDimension('AU')->setAutoSize(true);
        $sheet->getColumnDimension('AV')->setAutoSize(true);
        $sheet->getColumnDimension('AW')->setAutoSize(true);
        $sheet->getColumnDimension('AX')->setAutoSize(true);
        $sheet->getColumnDimension('AY')->setAutoSize(true);
        $sheet->getColumnDimension('AZ')->setAutoSize(true);
        $sheet->getColumnDimension('BA')->setAutoSize(true);
        $sheet->getColumnDimension('BB')->setAutoSize(true);
        $sheet->getColumnDimension('BC')->setAutoSize(true);
        $sheet->getColumnDimension('BD')->setAutoSize(true);
        $sheet->getColumnDimension('BE')->setAutoSize(true);
        $sheet->getColumnDimension('BF')->setAutoSize(true);
        $sheet->getColumnDimension('BG')->setAutoSize(true);
        $sheet->getColumnDimension('BH')->setAutoSize(true);
        $sheet->getColumnDimension('BI')->setAutoSize(true);
        $sheet->getColumnDimension('BJ')->setAutoSize(true);
        $sheet->getColumnDimension('BK')->setAutoSize(true);
        $sheet->getColumnDimension('BL')->setAutoSize(true);
        $sheet->getColumnDimension('BM')->setAutoSize(true);
        $sheet->getColumnDimension('BN')->setAutoSize(true);
        $sheet->getColumnDimension('BO')->setAutoSize(true);
        $sheet->getColumnDimension('BP')->setAutoSize(true);
        

        $sheet->setCellValue('A1', __("Cluster"));
        $sheet->setCellValue('B1', __("Street"));
        $sheet->setCellValue('C1', __("PAN"));
        $sheet->setCellValue('D1', __("Home number"));
        $sheet->setCellValue('E1', __("Enterance"));
        $sheet->setCellValue('F1', __("Floor"));
        $sheet->setCellValue('G1', __("Apartment"));
        $sheet->setCellValue('H1', __("Statement type"));
        $sheet->setCellValue('I1', __("ID"));
        $sheet->setCellValue('J1', __("Network group"));
        $sheet->setCellValue('K1', __("Phone").' 1');
        $sheet->setCellValue('L1', __("Phone").' 2');
        $sheet->setCellValue('M1', __("Phone").' 3');
        $sheet->setCellValue('N1', __("Packet"));
        $sheet->setCellValue('O1', __("BL"));
        $sheet->setCellValue('P1', __("County"));
        $sheet->setCellValue('Q1', __("City"));
        $sheet->setCellValue('R1', __("Settlement"));
        $sheet->setCellValue('S1', __("Household"));
        $sheet->setCellValue('T1', __("Households"));
        $sheet->setCellValue('U1', __("Country"));
        $sheet->setCellValue('V1', __("State services"));
        $sheet->setCellValue('W1', __("Country"));
        $sheet->setCellValue('X1', __("Recommended tariff"));
        $sheet->setCellValue('Y1', __("First offer"));
        $sheet->setCellValue('Z1', __("Operater"));
        $sheet->setCellValue('AA1', __("Month"));
        $sheet->setCellValue('AB1', __("Year"));
        $sheet->setCellValue('AC1', __("Email"));
        $sheet->setCellValue('AD1', __("Status"));
        $sheet->setCellValue('AE1', __("Date of withdrawal"));
        $sheet->setCellValue('AF1', __("Reason of withdrawal"));
        $sheet->setCellValue('AG1', __("Expiration date"));
        $sheet->setCellValue('AH1', __("Points"));
        $sheet->setCellValue('AI1', __("Project manager"));
        $sheet->setCellValue('AJ1', __("Cable"));
        $sheet->setCellValue('AK1', __("Thread"));
        $sheet->setCellValue('AL1', __("Tube"));
        $sheet->setCellValue('AM1', __("Case"));
        $sheet->setCellValue('AN1', __("X-coordinate"));
        $sheet->setCellValue('AO1', __("Y-coordinate"));
        $sheet->setCellValue('AP1', __("Name"));
        $sheet->setCellValue('AQ1', __("Surname"));
        $sheet->setCellValue('AR1', __("Request created by"));
        $sheet->setCellValue('AS1', __("Address"));
        $sheet->setCellValue('AT1', __("Request"));
        $sheet->setCellValue('AU1', __("Seller"));
        $sheet->setCellValue('AV1', __("Request date"));
        $sheet->setCellValue('AW1', __("Points"));
        $sheet->setCellValue('AX1', __("Montage date"));
        $sheet->setCellValue('AY1', __("Withdrawal date"));
        $sheet->setCellValue('AZ1', __("Delay date"));
        $sheet->setCellValue('BA1', __("Assigned to fitter"));
        $sheet->setCellValue('BB1', __("Appointment date"));
        $sheet->setCellValue('BC1', __("Withdrawal reason"));
        $sheet->setCellValue('BD1', __("Intervention status"));
        $sheet->setCellValue('BE1', __("Intervention date"));
        $sheet->setCellValue('BF1', __("Reclamation fitter"));
        $sheet->setCellValue('BG1', __("Reclamation date"));
        $sheet->setCellValue('BH1', __("Montage type"));
        $sheet->setCellValue('BI1', __("Origin"));
        $sheet->setCellValue('BJ1', __("Helper"));
        $sheet->setCellValue('BK1', __("Terrain"));
        $sheet->setCellValue('BL1', __("Extra STB"));
        $sheet->setCellValue('BM1', __("Note"));
        $sheet->setCellValue('BN1', __("Datum izmene"));
        $sheet->setCellValue('BO1', __("Izmenio"));
        $sheet->setCellValue('BP1', __("Callisto ID"));

        $sheet->getStyle('A1:BM1')->getAlignment()->setHorizontal('center');

        $sheet->getStyle('A1:BM1')->getFill()->setFillType(\PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID)->getStartColor()->setARGB('8c8c8c');

        $commentText = '';
        $comMod = new Fobos_rune_comments();
        foreach ($clients as $br=>$client){
            if($withComments) {
                $comments = $comMod->comments($client->id);
                foreach ($comments as $comment)
                    $commentText .= $comment->comment . " (" . $comment->ime . ' ' . $comment->prezime . ' ' . date('d.m.Y H:i:s', strtotime($comment->created_at)) . ') ';
            }
            if (in_array($client->status_id, [3,4]))
                $sheet->getStyle('A'.($br+2).':BM'.($br+2))->getFill()->setFillType(\PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID)->getStartColor()->setARGB('ebe134');

            $sheet->getStyle('A'.($br+2).':BM'.($br+2))->getAlignment()->setHorizontal('left');
            $sheet->setCellValue('A'.($br+2), $client->cluster);
            $sheet->setCellValue('B'.($br+2), $client->street);
            $sheet->setCellValue('C'.($br+2), $client->pan);
            $sheet->setCellValue('D'.($br+2), $client->home_no);
            $sheet->setCellValue('E'.($br+2), $client->enterance);
            $sheet->setCellValue('F'.($br+2), $client->floor);
            $sheet->setCellValue('G'.($br+2), $client->apartment);
            $sheet->setCellValue('H'.($br+2), $client->eta);
            $sheet->setCellValue('I'.($br+2), $client->fobos_id);
            $sheet->setCellValue('J'.($br+2), $client->network_group);
            $sheet->setCellValue('K'.($br+2), $client->tel1);
            $sheet->setCellValue('L'.($br+2), $client->tel2);
            $sheet->setCellValue('M'.($br+2), $client->tel3);
            $sheet->setCellValue('N'.($br+2), $client->packet);
            $sheet->setCellValue('O'.($br+2), $client->black_list);
            $sheet->setCellValue('P'.($br+2), $client->county);
            $sheet->setCellValue('Q'.($br+2), $client->city);
            $sheet->setCellValue('R'.($br+2), $client->settlement);
            $sheet->setCellValue('S'.($br+2), $client->household);
            $sheet->setCellValue('T'.($br+2), $client->households);
            $sheet->setCellValue('U'.($br+2), $client->household);
            $sheet->setCellValue('V'.($br+2), $client->state_services);
            $sheet->setCellValue('W'.($br+2), $client->state);
            $sheet->setCellValue('X'.($br+2), $client->recomended_tariff);
            $sheet->setCellValue('Y'.($br+2), $client->first_offer);
            $sheet->setCellValue('Z'.($br+2), $client->operator);
            $sheet->setCellValue('AA'.($br+2), $client->month);
            $sheet->setCellValue('AB'.($br+2), $client->year);
            $sheet->setCellValue('AD'.($br+2), $client->status);
            $sheet->setCellValue('AE'.($br+2), $client->withdrawal_date ? date('d.m.Y.', strtotime($client->withdrawal_date)) : null);
            $sheet->setCellValue('AF'.($br+2), $client->withdrawal_reason);
            $sheet->setCellValue('AG'.($br+2), $client->contract_expire_date ? date('d.m.Y.', strtotime($client->contract_expire_date)) : null);
            $sheet->setCellValue('AH'.($br+2), $client->points);
            $sheet->setCellValue('AI'.($br+2), $client->pm_name.' '.$client->pm_surname);
            $sheet->setCellValue('AJ'.($br+2), $client->cable);
            $sheet->setCellValue('AK'.($br+2), $client->thread);
            $sheet->setCellValue('AL'.($br+2), $client->tube);
            $sheet->setCellValue('AM'.($br+2), $client->case);
            $sheet->setCellValue('AN'.($br+2), $client->x_coordinate);
            $sheet->setCellValue('AO'.($br+2), $client->y_coordinate);
            $sheet->setCellValue('AP'.($br+2), $client->name);
            $sheet->setCellValue('AQ'.($br+2), $client->surname);
            $sheet->setCellValue('AU'.($br+2), $client->seller_name.' '.$client->seller_surname);
            $sheet->setCellValue('AW'.($br+2), $client->points);
            $sheet->setCellValue('BM'.($br+2), $commentText);
            $sheet->setCellValue('BN'.($br+2), $client->updated_name.' '.$client->updated_surname);
            $sheet->setCellValue('BO'.($br+2), $client->updated_at ? date('d.m.Y.', strtotime($client->updated_at)) : null);
            $sheet->setCellValue('BP'.($br+2), $client->id);

            $commentText = '';

        }

        $streamedResponse = new StreamedResponse();
        $streamedResponse->setCallback(function() use ($spreadsheet){
            $writter = new Xlsx($spreadsheet);
            $writter->save('php://output');
        });

        $streamedResponse->setStatusCode(200);
        $streamedResponse->headers->set('Content-Type', 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        $streamedResponse->headers->set('Content-Disposition', 'attachment; filename="rune_db.xlsx"');
        return $streamedResponse->send();
    }

    public function statistic(Request $request){
        $start = database_date($request->input('start'));
        $end = database_date($request->input('end'));
        if(!$start && !$end){
            $start = date('Y-m-d');
            $end = date('Y-m-d');
        }

        $fMod = new Fobos_rune();
        $tMod = new Teams();

        if(Util::isLider()){
            $sellers = $tMod->sellersForTl(Util::userId());
            $teamLeaders = User::where('id', Util::userId())->get();
        }
        else {
            $sellers = Util::allSellers();
            $teamLeaders = Util::teamLeaders();
        }

        $statuses = Fobos_statuses::all();
        $sellerStat = [];
        $leadStat = [];
        foreach($sellers as $seller){
            $totalAssigned = $fMod->totalAssigned($seller->id);
            $totalAssignedInRange = $fMod->totalAssignedInRange($seller->id,$start,$end);
            foreach($statuses as $status){
                $count = $fMod->countForStatus($seller->id,$status->id,$start,$end);
                if($count > 0){
                    $sellerStat[$seller->ime.' '.$seller->prezime.' ('.$totalAssigned.')'][] = ['count' => $count, 'status' => $status->status, 
                                'totalAssigned' => $totalAssignedInRange];
                }
            }
        }
        foreach($teamLeaders as $tl){
            $totalAssigned = $fMod->totalAssignedLead($tl->id);
            $sellers = Arr::pluck($tMod->sellersLead($tl->id), 'id');
            array_push($sellers, $tl->id);
            $totalAssignedInRange = $fMod->totalAssignedInRangeLead($sellers,$start,$end);
            foreach($statuses as $status){
                $count = $fMod->countForStatus(null,$status->id,$start,$end,$sellers);
                if($count>0){
                    $leadStat[$tl->ime.' '.$tl->prezime.' ('.$totalAssigned.')'][] = ['count' => $count, 'status' => $status->status, 
                                'totalAssigned' => $totalAssignedInRange];
                }
            }
        }

        return view('fobosRune.statistic', ['sellerStat' => $sellerStat, 'leadStat' => $leadStat, 'start' => strtotime($start), 'end' => strtotime($end)]);
    }

    public function export_statistic(Request $request){
        require '../vendor/autoload.php';

        $start = database_date($request->input('start'));
        $end = database_date($request->input('end'));

        $fMod = new Fobos_rune();
        $tMod = new Teams();

        if(Util::isLider()){
            $sellers = $tMod->sellersForTl(Util::userId());
            $teamLeaders = User::where('id', Util::userId())->get();
        }
        else {
            $sellers = Util::allSellers();
            $teamLeaders = Util::teamLeaders();
        }

        $statuses = Fobos_statuses::all();
        $sellerStat = [];
        $leadStat = [];
        foreach($sellers as $seller){
            $totalAssigned = $fMod->totalAssigned($seller->id);
            $totalAssignedInRange = $fMod->totalAssignedInRange($seller->id,$start,$end);
            foreach($statuses as $status){
                $count = $fMod->countForStatus($seller->id,$status->id,$start,$end);
                if($count > 0){
                    $sellerStat[$seller->ime.' '.$seller->prezime.' ('.$totalAssigned.')'][] = ['count' => $count, 'status' => $status->status, 
                                'totalAssigned' => $totalAssignedInRange];
                }
            }
        }
        foreach($teamLeaders as $tl){
            $totalAssigned = $fMod->totalAssignedLead($tl->id);
            $sellers = Arr::pluck($tMod->sellersLead($tl->id), 'id');
            array_push($sellers, $tl->id);
            $totalAssignedInRange = $fMod->totalAssignedInRangeLead($sellers,$start,$end);
            foreach($statuses as $status){
                $count = $fMod->countForStatus(null,$status->id,$start,$end,$sellers);
                if($count>0){
                    $leadStat[$tl->ime.' '.$tl->prezime.' ('.$totalAssigned.')'][] = ['count' => $count, 'status' => $status->status, 
                                'totalAssigned' => $totalAssignedInRange];
                }
            }
        }

        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();

        $sheet->getColumnDimension('A')->setAutoSize(true);
        $sheet->getColumnDimension('B')->setAutoSize(true);
        $sheet->getColumnDimension('C')->setAutoSize(true);
        $sheet->getColumnDimension('D')->setAutoSize(true);
        $sheet->getColumnDimension('E')->setAutoSize(true);

        $spreadsheet->getActiveSheet()->getStyle('A1:E1')->getFill()->setFillType(\PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID)->getStartColor()->setARGB('FFFFFFFF');

        $sheet->setCellValue('A1', __('Seller'));
        $sheet->setCellValue('B1', __('Status'));
        $sheet->setCellValue('C1', __('Sve promene na dan'));
        $sheet->setCellValue('D1', __('% upotrebe'));
        $sheet->setCellValue('E1', __('Broj adresaa na koje je napravio promenu'));

        $styleArray = [
            'borders' => [
                'bottom' => ['borderStyle' => 'thick', 'color' => ['argb' => '00000000']]
            ],
        ];
       
        $sheet->getStyle("A1:E1")->applyFromArray($styleArray);
        $num=2;
        foreach($sellerStat as $seller=>$statuses){
            $sheet->setCellValue('A'.($num), $seller);
            foreach($statuses as $stat){
                $sheet->setCellValue('B'.($num), $stat['status']);
                $sheet->setCellValue('C'.($num), $stat['totalAssigned']);
                $sheet->setCellValue('D'.($num), $stat['totalAssigned']?number_format($stat['count']/$stat['totalAssigned']*100, 2).'%':0);
                $sheet->setCellValue('E'.($num), $stat['count']);
                $num++;
            }
            $sheet->getStyle("A$num:E$num")->applyFromArray($styleArray);
            $num++;
        }

        $num+=3;
        foreach($leadStat as $leader=>$statuses){
            $sheet->setCellValue('A'.($num), $leader);
            foreach($statuses as $stat){
                $sheet->setCellValue('B'.($num), $stat['status']);
                $sheet->setCellValue('C'.($num), $stat['totalAssigned']);
                $sheet->setCellValue('D'.($num), $stat['totalAssigned']?number_format($stat['count']/$stat['totalAssigned']*100, 2).'%':0);
                $sheet->setCellValue('E'.($num), $stat['count']);
                $num++;
            }
            $sheet->getStyle("A$num:E$num")->applyFromArray($styleArray);
            $num++;
        }

        $sheet->getStyle('A1:E'.$num)->getAlignment()->setHorizontal('center');

        $streamedResponse = new StreamedResponse();
        $streamedResponse->setCallback(function() use ($spreadsheet){
            $writter = new Xlsx($spreadsheet);
            $writter->save('php://output');
        });

        $streamedResponse->setStatusCode(200);
        $streamedResponse->headers->set('Content-Type', 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        $streamedResponse->headers->set('Content-Disposition', 'attachment; filename="statistic.xlsx"');
        return $streamedResponse->send();
    }


    public function delete_image(Request $request){
        $findImage = Fobos_rune_images::find($request->input('id_image'));
        $file = ltrim($findImage->url,'/');

        if(file_exists($file)){
            unlink($file);
        }

        if($findImage->delete()){
            return back()->with('success', __("Image successfully deleted"));
        }
        else {
            return back()->with('errors', __("Error"));
        }
    }

}
