<?php

namespace App\Http\Controllers;

use App\Models\Ger_works;
use App\Models\Units;
use Illuminate\Http\Request;

class GerWorksController extends Controller
{
    public function index()
    {
        $works = Ger_works::paginate(50);
        return view('gerWorks.index', ['works' => $works]);
    }

    public function create()
    {
        $units = Units::all();
        return view('gerWorks.create', ['units' => $units]);
    }

    public function store(Request $request)
    {
        $request->validate([
            'code' => 'required',
            'work' => 'required',
            'price' => 'nullable|numeric'
        ]);
        $create = Ger_works::create([
            'code' => trim($request->input('code')),
            'work' => trim($request->input('work')),
            'unit_id' => $request->input('unit'),
            'fixed' => $request->input('fixed'),
            'price' => $request->input('price')
        ]);

        if ($create){
            return redirect()->route('ger_works.show', $create->id)->with('success', __("Data successfully added"));
        }
    }

    public function show(Ger_works $ger_work)
    {
        $wMod = new Ger_works();
        $work = $wMod->work_data($ger_work->id);
        return view('gerWorks.show', ['work' => $work]);
    }

    public function edit(Ger_works $ger_work)
    {
        $units = Units::all();
        return view('gerWorks.edit', ['work' => $ger_work, 'units' => $units]);
    }

    public function update(Request $request, Ger_works $ger_work)
    {
        $request->validate([
            'code' => 'required',
            'work' => 'required',
            'price' => 'nullable|numeric'
        ]);
        $workUpdate = Ger_works::where('id', $ger_work->id)->update([
            'code' => trim($request->input('code')),
            'work' => trim($request->input('work')),
            'unit_id' => $request->input('unit'),
            'fixed' => $request->input('fixed'),
            'price' => $request->input('price')
        ]);

        if ($workUpdate){
            return redirect()->route('ger_works.show', $ger_work->id)->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    public function destroy(Request $request)
    {
        $findWork = Ger_works::find($request->input('id_work'));

        try{
            $findWork->delete();
            return back()->withInput()->with('success', __("Work successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
