<?php

namespace App\Http\Controllers;

use App\Models\Companies;
use App\Models\Equipment;
use App\Models\Folders;
use App\Models\Hw_access_works;
use App\Models\Hw_documentation;
use App\Models\Hw_final_statuses;
use App\Models\Storage_equipment;
use App\Models\Worker_equipment;
use App\Models\Hw_vertical_works;
use App\Change_history;
use App\Models\Hw_predicted_works;
use App\Models\Areas;
use App\Models\Cities;
use App\Models\Doc_works;
use App\Models\Equipment_categories;
use App\Models\Files;
use App\Models\Huawei_access_statuses;
use App\Models\Huawei_comments;
use App\Models\Huawei_vertical_statuses;
use App\Models\Hw_images;
use App\Models\Hw_site_equipment;
use App\Models\Hw_site_work;
use App\Models\Hw_work_categories;
use App\Models\Image_types;
use App\States;
use App\Traits\Util;
use App\Models\Huawei;
use App\Models\Required_equipment;
use Illuminate\Http\Request;
use Intervention\Image\ImageManager as Img;
use Illuminate\Support\Arr;

class HuaweiController extends Controller
{

    private function setQuantity($siteId, $workId, $quantity, $column){
        if(Hw_predicted_works::where('site_id', $siteId)->where($column, $workId)->get()->isEmpty()){
            Hw_predicted_works::create([
                'site_id' => $siteId,
                $column => $workId,
                'quantity' => $quantity
            ]);
        }
        else {
            Hw_predicted_works::where('site_id', $siteId)->where($column, $workId)->update([
                'quantity' => $quantity
            ]);
        }
    }

    public function index()
    {
        $isConstructionManager = Util::isAdmin() || Util::isConstructionManager();
        $isSuperAdmin = Util::isSuperAdmin();
        $isHuaweiAdmin = Util::isHuaweiAdmin();
        $isProjectManager = Util::isProjectManager();
        $isProjectAdmin = Util::isProjectAdmin();
        $isSubcontractor = Util::isSubcontractorHw();
        $hwModel = new Huawei();
        if ($isSuperAdmin)
            $constructionSites = $hwModel->index();
        elseif ($isHuaweiAdmin){
            //ovo je specifican slucaj kad treba da se zabrani nekom neka area
            if(Util::userId() == 65)
                $constructionSites = $hwModel->index(null, null, null, null, null, Util::userPlace(),[5]);
            else
                $constructionSites = $hwModel->index(null, null, null, null, null, Util::userPlace());
        }
        elseif ($isConstructionManager)
            $constructionSites = $hwModel->index(null, Util::userId());
        elseIf($isProjectManager)
            $constructionSites = $hwModel->index(null, null, Util::userId());
        elseif($isProjectAdmin)
            $constructionSites = $hwModel->index(null, null, null, true);
        elseif($isSubcontractor)
            $constructionSites = $hwModel->index(null, null, null, null, null, Util::userId());
        else
            $constructionSites = $hwModel->index(Util::userId());
        


        session(['search_route' => false]);

        return view('huawei.index', [
            'constructionSites' => $constructionSites,
            'search'=>false,
            'isSuperAdmin'=>$isSuperAdmin,
            'isHuaweiAdmin' => $isHuaweiAdmin
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $states = States::all();
        $cities = Cities::all();
        $areas = Areas::all();
        $statusesAccess = Huawei_access_statuses::all();
        $statusesVertical = Huawei_vertical_statuses::all();
        $builders = Util::builders();
        $monters = Util::monteri();
        $workers = $builders->merge($monters);
        $admins = Util::admini();
        $projectManagers = Util::projectManagers();
        $constructionManagers = Util::constructionManagers();
        $constructionManagers = $constructionManagers->merge($admins);
        $subcontractors = Util::subcontractors();
        return view('huawei.create', [
            'states' => $states,
            'cities' => $cities,
            'areas' => $areas,
            'statusesAccess' => $statusesAccess,
            'statusesVertical' => $statusesVertical,
            'workers' => $workers,
            'projectManagers' => $projectManagers,
            'constructionManagers' => $constructionManagers,
            'subcontractors' => $subcontractors
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $name = $request->input('name');
        $seller = $request->input('seller');
        $contactSeller = $request->input('contact_seller');
        $hId = $request->input('h_id');
        $tel1 = $request->input('tel1');
        $tel2 = $request->input('tel2');
        $tel3 = $request->input('tel3');
        $manager = $request->input('manager');
        $mTel1 = $request->input('m_tel1');
        $mTel2 = $request->input('m_tel2');
        $mTel3 = $request->input('m_tel3');
        $state = $request->input('state');
        $city = $request->input('city');
        $municipality = $request->input('municipality');
        $address = $request->input('address');
        $numberOfFloors = $request->input('number_of_floors');
        $numberOfFlats = $request->input('number_of_flats');
        $area = $request->input('area');
        $statusAccess = $request->input('status_access');
        $statusVertical = $request->input('status_vertical');
        $statusSplicing = $request->input('status_splicing');
        $projectManager = $request->input("project_manager");
        $workerAccess = $request->input('worker_access');
        $workerVertical = $request->input('worker_vertical');
        $workerSplicing = $request->input('worker_splicing');
        $comment = $request->input('comment');
        $appointmentDateAccess = $request->input('appointment_date_access');
        $appointmentDateVertical = $request->input('appointment_date_vertical');
        $appointmentDateSplicing = $request->input('appointment_date_splicing');
        $appointmentTimeAccess = $request->input('appointment_time_access');
        $appointmentTimeVertical = $request->input('appointment_time_vertical');
        $appointmentTimeSplicing = $request->input('appointment_time_splicing');
        $delayDate = database_date($request->input('delay_date'));
        $delayTime = $request->input('delay_time');
        $realizationDateAccess = database_date($request->input('realization_date_access'));
        $realizationDateVertical = database_date($request->input('realization_date_vertical'));
        $withdrawalDate = database_date($request->input('withdrawal_date'));
        $sendingDateHuawei = database_date($request->input('sending_date_huawei'));
        $cluster = $request->input('cluster');
        $odo = $request->input('odo');
        $izvod = $request->input('izvod');
        $connector = $request->input('connector');
        $technicalSolutionDate = database_date($request->input('technical_solution_date'));
        $atcMsanOlt = $request->input('atc_msan_olt');
        $odfModul = $request->input('odf_modul');
        $connectorNumber = $request->input('connector_number');
        $connectionPoint = $request->input('connection_point');
        $fiber = $request->input('fiber');
        $numerationOdo = $request->input('numeration_odo');
        $tisEntryDate = database_date($request->input('tis_entry_date'));
        $createdBy = Util::userId();
        $subcontractor = $request->input('subcontractor');

        // $price = Hw_prices::orderBy('id', 'DESC')->first();
        // if($price)
        //     $price = $price->price;

        if(Util::isProjectManager())
            $projectManager = Util::userId();
        if(Util::isConstructionManager())
            $constructionManager = Util::userId();
        else
            $constructionManager = $request->input('construction_manager');

        $appointmentDateAccess = database_date_time($appointmentDateAccess, $appointmentTimeAccess);
        $appointmentDateVertical = database_date_time($appointmentDateVertical, $appointmentTimeVertical);
        $appointmentDateSplicing = database_date_time($appointmentDateSplicing, $appointmentTimeSplicing);
        $delayDate = database_date_time($delayDate, $delayTime);

        $request->validate([
            'name' => 'required',
            'address' => 'required',
            'state' => 'required',
            'city' => 'required',
            'area' => 'required'
        ]);

        $create = false;
        if(Util::isAdmin() || Util::isSuperAdmin() || Util::isProjectAdmin() || Util::isProjectManager() || Util::isConstructionManager() || Util::isHuaweiAdmin()){
            $create = Huawei::create([
                'name' => $name,
                'h_id' => $hId,
                'seller' => $seller,
                'contact_seller' => $contactSeller,
                'tel1' => $tel1,
                'tel2' => $tel2,
                'tel3' => $tel3,
                'manager' => $manager,
                'm_tel1' => $mTel1,
                'm_tel2' => $mTel2,
                'm_tel3' => $mTel3,
                'id_state' => $state,
                'id_city' => $city,
                'municipality' => $municipality,
                'id_area' => $area,
                'address' => $address,
                'number_of_floors' => $numberOfFloors,
                'number_of_flats' => $numberOfFlats,
                'id_status_vertical' => $statusVertical,
                'id_status_access' => $statusAccess,
                'id_status_splicing' => $statusSplicing,
                'project_manager' => $projectManager,
                'construction_manager' => $constructionManager,
                'id_user_vertical' => $workerVertical,
                'id_user_access' => $workerAccess,
                'id_user_splicing' => $workerSplicing,
                'appointment_date_vertical' => $appointmentDateVertical,
                'appointment_date_access' => $appointmentDateAccess,
                'appointment_date_splicing' => $appointmentDateSplicing,
                'delay_date' => $delayDate,
                'realization_date_vertical' => $realizationDateVertical,
                'realization_date_access' => $realizationDateAccess,
                'withdrawal_date' => $withdrawalDate,
                'sending_date_huawei' => $sendingDateHuawei,
                'cluster' => $cluster,
                'odo' => $odo,
                'izvod' => $izvod,
                'connector' => $connector,
                'technical_solution_date' => $technicalSolutionDate,
                'atc_msan_olt' => $atcMsanOlt,
                'odf_modul' => $odfModul,
                'connector_number' => $connectorNumber,
                'connection_point' => $connectionPoint,
                'fiber' => $fiber,
                'numeration_odo' => $numerationOdo,
                'created_by' => $createdBy,
                'tis_entry_date' => $tisEntryDate,
                'subcontractor' => $subcontractor
            ]);
        }

        if($create && $comment){
            Huawei_comments::create([
                'comment' => $comment,
                'id_site' => $create->id,
                'id_user' => $createdBy
            ]);
        }

        if($create)
            return redirect()->route('huawei.show', ['huawei' => $create->id]);
        else
            return back()->with('error', __("Data successfully added"));
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Huawei  $huawei
     * @return \Illuminate\Http\Response
     */
    public function show(Huawei $huawei)
    {
        $hModel = new Huawei();
        $site = $hModel->huawei_data($huawei->id);
        $comMod = new Huawei_comments();
        $comments = $comMod->comments($huawei->id);
        $imgModel = new Hw_images();
        $images = $imgModel->images($huawei->id);
        $equipmentModal = new Hw_site_equipment();
        $workModal = new Hw_site_work();
        $equipment = $equipmentModal->equipment($huawei->id);
        $works = $workModal->accessWorks($huawei->id);
        $verticalWorks = $workModal->verticalWorks($huawei->id);
        $docWorks = $workModal->docWorks($huawei->id);
        $allowedUsers = [$huawei->id_user_access, $huawei->id_user_vertical, $huawei->id_user_splicing, $huawei->construction_manager, $huawei->project_manager, $huawei->subcontractor];

        $totalAccess = 0;
        $totalVertical = 0;
        $totalDoc = 0;

        $totalAccess = 0;
        $totalVertical = 0;
        $totalDoc = 0;

        $predictMod = new Hw_predicted_works();

        $accessWorks = $workModal->accessWorks($huawei->id);
        foreach($accessWorks as $work){
            $totalAccess += $workModal->accessWorkQuantity($huawei->id, $work->id)*$work->price;
        }
        $verticalWorks = $workModal->verticalWorks($huawei->id);
        foreach($verticalWorks as $work){
            $totalVertical += $workModal->verticalWorkQuantity($huawei->id, $work->id)*$work->price;
        }
        $docWorks = $workModal->docWorks($huawei->id);
        foreach($docWorks as $work){
            $totalDoc += $workModal->docWorkQuantity($huawei->id, $work->id)*$work->price;
        }

        $isHuaweiAdmin = Util::isHuaweiAdmin();
        $excludedAdmins = explode(',',env('EXCLUDED_ADMINS'));
        $isSuperAdmin = Util::isSuperAdmin();
        $projectAdmin = Util::isProjectAdmin();
        if (!in_array(Util::userId(), $allowedUsers) && !$isHuaweiAdmin && !$isSuperAdmin && !$projectAdmin)
        {
            return view('missing_page');
        }
        if($isHuaweiAdmin && Util::userPlace() && Util::userPlace() != $huawei->id_area){
            return view('missing_page');
        }

        $chModel = new Change_history();
        $history = $chModel->historyHuawei($huawei->id);

        $files = Files::where('id_huawei', $huawei->id)->get();

        $reModel = new Required_equipment();
        $requiredEquipment = $reModel->required_equipment($huawei->id);

        session(['accessWorks' => json_encode($works), 'verticalWorks' => json_encode($verticalWorks)]);

        return view('huawei.show', [
            'site' => $site,
            'comments' => $comments,
            'images' => $images,
            'equipment' => $equipment,
            'works' => $works,
            'history' => $history,
            'files' => $files,
            'verticalWorks' => $verticalWorks,
            'docWorks' => $docWorks,
            'requiredEquipment' => $requiredEquipment,
            'isHuaweiAdmin' => $isHuaweiAdmin,
            'isSuperAdmin' => $isSuperAdmin,
            'totalAccess' => $totalAccess,
            'totalVertical' => $totalVertical,
            'totalDoc' => $totalDoc,
            'notExcluded' => !in_array(Util::userId(), $excludedAdmins),
            'predictMod' => $predictMod
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Huawei  $huawei
     * @return \Illuminate\Http\Response
     */
    public function edit(Huawei $huawei)
    {
        $states = States::all();
        $cities = Cities::all();
        $areas = Areas::all();
        $statusesAccess = Huawei_access_statuses::all();
        $statusesVertical = Huawei_vertical_statuses::all();
        $finalStatuses = Hw_final_statuses::all();
        $builders = Util::builders();
        $fitters = Util::monteri();
        $workers = $builders->merge($fitters);
        $imageTypes = Image_types::all();
        $equipmentCategories = Equipment_categories::all();
        $workCategories = Hw_work_categories::all();
        $comModel = new Huawei_comments();
        $comments = $comModel->comments($huawei->id);
        $comModel = new Hw_images();
        $images = $comModel->images($huawei->id);
        $files = Files::where('id_huawei', $huawei->id)->get();
        $equipmentModal = new Hw_site_equipment();
        $workModal = new Hw_site_work();
        $predictModal = new Hw_predicted_works();
        $equipment = $equipmentModal->equipment($huawei->id);
        $accessWorks = $workModal->accessWorks($huawei->id);
        $admins = Util::admini();
        $projectManagers = Util::projectManagers();
        $constructionManagers = Util::constructionManagers();
        $constructionManagers = $constructionManagers->merge($admins);
        $vModel = new Hw_vertical_works();
        $workIds = $vModel->workIds();
        $workIds = Arr::pluck($workIds, 'id');
        $verticalWorks = array();
        foreach($workIds as $key=>$id){
            $work = $vModel->workData($id);
            $quantity = $workModal->workQuantity($huawei->id, $id);
            $predicted = $predictModal->predictedWorks($huawei->id, $id, 'vertical');
            $verticalWorks[$key]['id'] = $id;
            $verticalWorks[$key]['code'] = $work->code;
            $verticalWorks[$key]['work'] = $work->work;
            $verticalWorks[$key]['unit'] = $work->unit_short;
            $verticalWorks[$key]['quantity'] = $quantity;
            $verticalWorks[$key]['predicted'] = $predicted;
        }

        $aMod = new Hw_access_works();
        $accessIds = $aMod->workIds();
        $accessIds = Arr::pluck($accessIds, 'id');
        $accessWorksFixed = array();
        foreach($accessIds as $key=>$id){
            $work = $aMod->workData($id);
            $quantity = $workModal->accessWorkQuantity($huawei->id, $id);
            $predicted = $predictModal->predictedWorks($huawei->id, $id, 'access');
            $accessWorksFixed[$key]['id'] = $id;
            $accessWorksFixed[$key]['code'] = $work->code;
            $accessWorksFixed[$key]['work'] = $work->work;
            $accessWorksFixed[$key]['unit'] = $work->unit_short;
            $accessWorksFixed[$key]['quantity'] = $quantity;
            $accessWorksFixed[$key]['predicted'] = $predicted;
        }

        $docMod = new Doc_works();
        $docIds = $docMod->workIds();
        $docIds = Arr::pluck($docIds, 'id');
        $docWorksFixed = array();
        foreach($docIds as $key=>$id){
            $work = $docMod->workData($id);
            $quantity = $workModal->docWorkQuantity($huawei->id, $id);
            $predicted = $predictModal->predictedWorks($huawei->id, $id, 'doc');
            $docWorksFixed[$key]['id'] = $id;
            $docWorksFixed[$key]['code'] = $work->code;
            $docWorksFixed[$key]['work'] = $work->work;
            $docWorksFixed[$key]['unit'] = $work->unit_short;
            $docWorksFixed[$key]['quantity'] = $quantity;
            $docWorksFixed[$key]['predicted'] = $predicted;
        }

        $allowedUsers = [$huawei->id_user_access, $huawei->id_user_vertical, $huawei->id_user_splicing, $huawei->construction_manager, $huawei->project_manager, $huawei->subcontractor];

        $isSuperAdmin = Util::isSuperAdmin();
        $isHuaweiAdmin = Util::isHuaweiAdmin();
        $isProjectAdmin = Util::isProjectAdmin();
        if (!in_array(Util::userId(), $allowedUsers) && !$isHuaweiAdmin && !$isSuperAdmin && !$isProjectAdmin)
        {
            return view('missing_page');
        }

        if($isHuaweiAdmin && Util::userPlace() && Util::userPlace() != $huawei->id_area){
            return view('missing_page');
        }

        if(Util::isConstructionManager()){
            $seMod = new Storage_equipment();
            $workerEquipment = $seMod->constructionManagerRequireEquipment();
        }
        else{
            $storageModel = new Worker_equipment();
            $workerEquipment = $storageModel->equipment_for_user(Util::userId());
        }

        $reModel = new Required_equipment();
        $requiredEquipment = $reModel->required_equipment($huawei->id);
        $excludedAdmins = explode(',',env('EXCLUDED_ADMINS'));

        return view('huawei.edit', [
            'states' => $states,
            'cities' => $cities,
            'areas' => $areas,
            'statusesAccess' => $statusesAccess,
            'statusesVertical' => $statusesVertical,
            'finalStatuses' => $finalStatuses,
            'workers' => $workers,
            'site' => $huawei,
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isAdmin' => Util::isAdmin(),
            'imageTypes' => $imageTypes,
            'equipmentCategories' => $equipmentCategories,
            'workCategories' => $workCategories,
            'comments' => $comments,
            'images' => $images,
            'files' => $files,
            'equipment' => $equipment,
            'accessWorks' => $accessWorks,
            'verticalWorks' => $verticalWorks,
            'workerEquipment' => $workerEquipment,
            'isHuaweiAdmin' => $isHuaweiAdmin,
            'requiredEquipment' => $requiredEquipment,
            'projectManagers' => $projectManagers,
            'constructionManagers' => $constructionManagers,
            'isConstructionManager' => Util::isConstructionManager(),
            'isProjectManager' => Util::isProjectManager(),
            'isFitter' => Util::isMonter(),
            'isConstructionWorker' => Util::isConstructionWorker(),
            'isProjectAdmin' => $isProjectAdmin,
            'accessWorksFixed' => $accessWorksFixed,
            'docWorksFixed' => $docWorksFixed,
            'subcontractors' => Util::subcontractors(),
            'notExcluded' => !in_array(Util::userId(), $excludedAdmins)
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Huawei  $huawei
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Huawei $huawei)
    {
        $name = $request->input('name');
        $seller = $request->input('seller');
        $contactSeller = $request->input('contact_seller');
        $hId = $request->input('h_id');
        $tel1 = $request->input('tel1');
        $tel2 = $request->input('tel2');
        $tel3 = $request->input('tel3');
        $manager = $request->input('manager');
        $mTel1 = $request->input('m_tel1');
        $mTel2 = $request->input('m_tel2');
        $mTel3 = $request->input('m_tel3');
        $state = $request->input('state');
        $city = $request->input('city');
        $municipality = $request->input('municipality');
        $address = $request->input('address');
        $numberOfFloors = $request->input('number_of_floors');
        $numberOfFlats = $request->input('number_of_flats');
        $area = $request->input('area');
        $statusAccess = $request->input('status_access');
        $statusVertical = $request->input('status_vertical');
        $statusSplicing = $request->input('status_splicing');
        $finalStatus = $request->input('final_status');
        $projectManager = $request->input("project_manager");
        $constructionManager = $request->input('construction_manager');
        $workerAccess = $request->input('worker_access');
        $workerVertical = $request->input('worker_vertical');
        $workerSplicing = $request->input('worker_splicing');
        $comment = $request->input('comment');
        $appointmentDateAccess = $request->input('appointment_date_access');
        $appointmentDateVertical = $request->input('appointment_date_vertical');
        $appointmentDateSplicing = $request->input('appointment_date_splicing');
        $appointmentTimeAccess = $request->input('appointment_time_access');
        $appointmentTimeVertical = $request->input('appointment_time_vertical');
        $appointmentTimeSplicing = $request->input('appointment_time_splicing');
        $delayDate = database_date($request->input('delay_date'));
        $delayTime = $request->input('delay_time');
        $realizationDateAccess = database_date($request->input('realization_date_access'));
        $realizationDateVertical = database_date($request->input('realization_date_vertical'));
        $withdrawalDate = database_date($request->input('withdrawal_date'));
        $sendingDateHuawei = database_date($request->input('sending_date_huawei'));
        $cluster = $request->input('cluster');
        $odo = $request->input('odo');
        $izvod = $request->input('izvod');
        $connector = $request->input('connector');
        $technicalSolutionDate = database_date($request->input('technical_solution_date'));
        $atcMsanOlt = $request->input('atc_msan_olt');
        $odfModul = $request->input('odf_modul');
        $connectorNumber = $request->input('connector_number');
        $connectionPoint = $request->input('connection_point');
        $fiber = $request->input('fiber');
        $numerationOdo = $request->input('numeration_odo');
        $disStartDate = database_date($request->input('dis_start_date'));
        $disEndDate = database_date($request->input('dis_end_date'));
        $orderNumber = $request->input('order_number');
        $setDis = $request->input('set_dis');
        $tisEntryDate = database_date($request->input('tis_entry_date'));
        $invoice = $request->input('invoice');
        $subcontractor = $request->input('subcontractor');
        $lght = $request->input('lght');

        $sentBoQ = $request->input('sent_boq');
        $approvedBoQ = $request->input('approved_boq');
        $boqSendDate = database_date($request->input('boq_send_date'));
        $boqApproveDate = database_date($request->input('boq_approve_date'));
        $correctionDateStart = database_date($request->input('correction_date_start'));
        $correctionDateEnd = database_date($request->input('correction_date_end'));
        $realizationDateSplicing = database_date($request->input('realization_date_splicing'));
        $price = $request->input('price');

        if($finalStatus == 1 && !$huawei->dis_start_date){
            $disStartDate = date('Y-m-d');
        }
        if(in_array($finalStatus, [2,7,8]) && !$huawei->dis_end_date){
            $disEndDate = date('Y-m-d');
        }

        $appointmentDateAccess = database_date_time($appointmentDateAccess, $appointmentTimeAccess);
        $appointmentDateVertical = database_date_time($appointmentDateVertical, $appointmentTimeVertical);
        $appointmentDateSplicing = database_date_time($appointmentDateSplicing, $appointmentTimeSplicing);
        $delayDate = database_date_time($delayDate, $delayTime);

        $files = $request->file('files');
        if($files){
            $request->validate([
                'files.*' => 'mimes:xlsx,xls,pdf,dwg,zip,sor,doc,docx'
            ]);
            $num = 0;
            foreach($files as $file){
                $originalFile = $file->getClientOriginalName();
                $filename = pathinfo($originalFile, PATHINFO_FILENAME);
                $extension = pathinfo($originalFile, PATHINFO_EXTENSION);
                $filename = $filename.'-'.time().'-'.$num.'.'.$extension;
                $folder = 'uploads/documents/'.quartal();
                create_folder($folder);
                $file->move($folder, $filename);
                Files::create([
                    'file_url' => '/'.$folder.'/'.$filename,
                    'id_huawei' => $huawei->id,
                    'filename' => $originalFile
                ]);
                $num++;
             }
        }

        if(Util::isAdmin() || Util::isHuaweiAdmin() || Util::isConstructionManager()){
            $request->validate([
                'name' => 'required',
                'address' => 'required',
                'state' => 'required',
                'city' => 'required',
                'area' => 'required',
                'sent_boq' => 'nullable|numeric',
                'approved_boq' => 'nullable|numeric',
                'price' => 'nullable|numeric'
            ]);
            if($orderNumber){
                $request->validate([
                    'order_number' => 'nullable|numeric|min:1|max:30'
                ]);
            }
            $update = Huawei::where('id', $huawei->id)->update([
                'name' => $name,
                'h_id' => $hId,
                'seller' => $seller,
                'contact_seller' => $contactSeller,
                'tel1' => $tel1,
                'tel2' => $tel2,
                'tel3' => $tel3,
                'manager' => $manager,
                'm_tel1' => $mTel1,
                'm_tel2' => $mTel2,
                'm_tel3' => $mTel3,
                'id_state' => $state,
                'id_city' => $city,
                'municipality' => $municipality,
                'id_area' => $area,
                'address' => $address,
                'number_of_floors' => $numberOfFloors,
                'number_of_flats' => $numberOfFlats,
                'id_status_vertical' => $statusVertical,
                'id_status_access' => $statusAccess,
                'id_status_splicing' => $statusSplicing,
                'id_status_final' => $finalStatus,
                'project_manager' => $projectManager,
                'construction_manager' => $constructionManager,
                'id_user_vertical' => $workerVertical,
                'id_user_access' => $workerAccess,
                'id_user_splicing' => $workerSplicing,
                'appointment_date_vertical' => $appointmentDateVertical,
                'appointment_date_access' => $appointmentDateAccess,
                'appointment_date_splicing' => $appointmentDateSplicing,
                'delay_date' => $delayDate,
                'realization_date_vertical' => $realizationDateVertical,
                'realization_date_access' => $realizationDateAccess,
                'realization_date_splicing' => $realizationDateSplicing,
                'withdrawal_date' => $withdrawalDate,
                'sending_date_huawei' => $sendingDateHuawei,
                'cluster' => $cluster,
                'odo' => $odo,
                'izvod' => $izvod,
                'connector' => $connector,
                'technical_solution_date' => $technicalSolutionDate,
                'atc_msan_olt' => $atcMsanOlt,
                'odf_modul' => $odfModul,
                'connector_number' => $connectorNumber,
                'connection_point' => $connectionPoint,
                'fiber' => $fiber,
                'numeration_odo' => $numerationOdo,
                'dis_start_date' => $disStartDate,
                'tis_entry_date' => $tisEntryDate,
                'subcontractor' => $subcontractor,
                'lght' => $lght
            ]);
            if(Util::isSuperAdmin() || Util::isHuaweiAdmin()){
                Huawei::where('id', $huawei->id)->update([
                    'sent_boq' => $sentBoQ,
                    'approved_boq' => $approvedBoQ,
                    'boq_send_date' => $boqSendDate,
                    'boq_approve_date' => $boqApproveDate,
                    'order_number' => $orderNumber,
                    'set_dis' => $setDis,
                ]);
            }
            if(Util::isSuperAdmin()){
                Huawei::where('id', $huawei->id)->update([
                    'correction_date_start' => $correctionDateStart,
                    'correction_date_end' => $correctionDateEnd,
                    'dis_end_date' => $disEndDate,
                    'invoice' => $invoice
                ]);
            }
            if(Util::isSuperAdmin() && $update && $price){
                Huawei::where('id', $huawei->id)->update([
                    'price' => $price
                ]);
            }
        }
        else {
            $update = null;
            if(Util::userId() == $huawei->id_user_access) {
                Huawei::where('id', $huawei->id)->update([
                    'id_status_access' => $statusAccess
                ]);
                $update = true;
                if($statusAccess == 6 && !$huawei->realization_date_access){
                    Huawei::where('id', $huawei->id)->update([
                        'realization_date_access' => date('Y-m-d')
                    ]);
                }
            }
            if(Util::userId() == $huawei->id_user_vertical) {
                Huawei::where('id', $huawei->id)->update([
                    'id_status_vertical' => $statusVertical
                ]);
                $update = true;
                if($statusVertical == 6  && !$huawei->realization_date_vertical){
                    Huawei::where('id', $huawei->id)->update([
                        'realization_date_vertical' => date('Y-m-d')
                    ]);
                }
            }
            if(Util::userId() == $huawei->id_user_splicing) {
                Huawei::where('id', $huawei->id)->update([
                    'id_status_splicing' => $statusSplicing
                ]);
                $update = true;
                if($statusSplicing == 6 && !$huawei->realization_date_splicing){
                    Huawei::where('id', $huawei->id)->update([
                        'realization_date_splicing' => date('Y-m-d')
                    ]);
                }
            }
            if(Util::isProjectManager()){
                Huawei::where('id', $huawei->id)->update([
                    'id_status_access' => $statusAccess,
                    'id_status_vertical' => $statusVertical,
                    'id_status_splicing' => $statusSplicing,
                    'id_status_final' => $finalStatus,
                    'cluster' => $cluster,
                    'odo' => $odo,
                    'izvod' => $izvod,
                    'connector' => $connector,
                    'technical_solution_date' => $technicalSolutionDate,
                    'atc_msan_olt' => $atcMsanOlt,
                    'odf_modul' => $odfModul,
                    'connector_number' => $connectorNumber,
                    'connection_point' => $connectionPoint,
                    'fiber' => $fiber,
                    'numeration_odo' => $numerationOdo,
                    'dis_start_date' => $disStartDate,
                    'dis_end_date' => $disEndDate
                ]);
                $update = true;
            }
            if(Util::isProjectAdmin()) {
                Huawei::where('id', $huawei->id)->update([
                    'id_status_access' => $statusAccess,
                    'id_status_vertical' => $statusVertical,
                    'id_status_splicing' => $statusSplicing,
                    'id_status_final' => $finalStatus,
                    'project_manager' => $projectManager,
                    'cluster' => $cluster,
                    'odo' => $odo,
                    'izvod' => $izvod,
                    'connector' => $connector,
                    'technical_solution_date' => $technicalSolutionDate,
                    'atc_msan_olt' => $atcMsanOlt,
                    'odf_modul' => $odfModul,
                    'connector_number' => $connectorNumber,
                    'connection_point' => $connectionPoint,
                    'fiber' => $fiber,
                    'numeration_odo' => $numerationOdo,
                    'dis_start_date' => $disStartDate,
                    'dis_end_date' => $disEndDate
                ]);
                $update = true;
            }
        }
        if($update){
            Change_history::create([
                'id_user' => Util::userId(),
                'id_huawei' => $huawei->id
            ]);
            if ($request->input('comment')) {
                Huawei_comments::create([
                    'comment' => $comment,
                    'id_site' => $huawei->id,
                    'id_user' => Util::userId()
                ]);
            }

            $imageType = $request->input("image_type");
            $pictures = $request->file('pictures');
            $img = new Img();
            $folder = 'uploads/construction_images/'.quartal();
            if (!file_exists($folder)){
                mkdir($folder, 0755, true);
            }

            if($pictures){
                $this->validate($request, [
                    'pictures.*' => 'image|mimes:jpeg,png,jpg,gif',
                    'image_type' => 'required'
                ]);
                $num = 0;
                foreach($pictures as $file){
                    $extension = $file->getClientOriginalExtension();
                    $filename = time().'-'.$num.'-huawei'.'.'.$extension;
                    $num++;
                    $fileInt = $img->make($file->getRealPath());
                    $fileInt->save($folder.'/'.$filename, 50);
                    $description = Image_types::find($imageType);
                    Hw_images::create([
                        'url' => '/'.$folder.'/'.$filename,
                        'id_site' => $huawei->id,
                        'image_type' => $imageType,
                        'description' => $description->type
                    ]);
                }
            }
            return redirect()->route('huawei.show', ['huawei' => $huawei->id])->with('success', __("Data successfully changed"));
        }
        //project manager can only change file
        if(Util::isProjectManager()){
            return redirect()->route('huawei.show', ['huawei' => $huawei->id])->with('success', __("File successfully added"));
        }
        else{
            return back()->with('error', __("Error"));
        }
    }

    /**
     * @param Request $request
     * @return $this
     */
    public function destroy(Request $request)
    {
        $findSite = Huawei::find($request->input('id_site'));

        try{
            $images = Hw_images::where('id_site', $request->input('id_site'))->get();
            $files = Files::where('id_huawei', $request->input('id_site'))->get();
            if($findSite->delete()){
                foreach ($images as $img){
                    $file = ltrim($img->url,'/');
                    if (file_exists($file)){
                        unlink($file);
                    }
                }
                foreach ($files as $fl){
                    $file = ltrim($fl->file_url,'/');
                    if (file_exists($file)){
                        unlink($file);
                    }
                }
            }
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Item can't be deleted because it's in use"));
        }


        return back()->withInput()->with('error', __("Data cannot be deleted"));
    }

    public function delete_comment(Request $request){
        $findComment = Huawei_comments::find($request->input('id_comment'));
        if($findComment->delete()){
            return back()->with('success', __("Comment successfully deleted"));
        }
        else {
            return back()->with('errors', __("Error"));
        }
    }

    public function delete_image(Request $request){
        $findImage = Hw_images::find($request->input('id_image'));
        $file = ltrim($findImage->url,'/');

        if(file_exists($file)){
            unlink($file);
        }

        if($findImage->delete()){
            return back()->with('success', __("Image successfully deleted"));
        }
        else {
            return back()->with('errors', __("Error"));
        }
    }

    public function huawei_search(){
        $statusesAccess = Huawei_access_statuses::all();
        $statusesVertical = Huawei_vertical_statuses::all();
        $finalStatuses = Hw_final_statuses::all();
        $builders = Util::builders();
        $monters = Util::monteri();
        $projectManagers = Util::projectManagers();
        $workers = $builders->merge($monters);
        return view('huawei.search', [
            'statusesAccess' => $statusesAccess,
            'statusesVertical' => $statusesVertical,
            'finalStatuses' => $finalStatuses,
            'workers' => $workers,
            'projectManagers' => $projectManagers
        ]);
    }

    public function huawei_advanced_search(){
        $states = States::all();
        $cities = Cities::all();
        $areas = Areas::all();
        $statusesAccess = Huawei_access_statuses::all();
        $statusesVertical = Huawei_vertical_statuses::all();
        $finalStatuses = Hw_final_statuses::all();
        $builders = Util::builders();
        $fitters = Util::monteri();
        $workers = $builders->merge($fitters);
        $admins = Util::admini();
        $projectManagers = Util::projectManagers();
        $constructionManagers = Util::constructionManagers();
        $constructionManagers = $constructionManagers->merge($admins);
        $equipment = Equipment::all();
        return view('huawei.advanced_search', [
            'states' => $states,
            'cities' => $cities,
            'areas' => $areas,
            'statusesAccess' => $statusesAccess,
            'statusesVertical' => $statusesVertical,
            'finalStatuses' => $finalStatuses,
            'workers' => $workers,
            'constructionManagers' => $constructionManagers,
            'projectManagers' => $projectManagers,
            'equipment' => $equipment,
            'isSuperAdmin' => Util::isSuperAdmin(),
            'isHuaweiAdmin' => Util::isHuaweiAdmin()
        ]);
    }

    public function huawei_search_result(Request $request){
        $param = $request->input('param');
        $projectManager = $request->input("project_manager");
        $constructionManager = $request->input('construction_manager');
        $hwModel = new Huawei();
        $userId = Util::userId();
        if(Util::isProjectManager()){
            $projectManager = $userId;
            $userId = null;
        }
        if(Util::isConstructionManager()){
            $constructionManager = $userId;
            $userId = null;
        }
        if($param == 'basic'){
            $name = $request->input('name');
            $seller = $request->input('seller');
            $hId = $request->input('h_id');
            $statusAccess = $request->input('status_access');
            $statusVertical = $request->input('status_vertical');
            $statusSplicing = $request->input('status_splicing');
            $finalStatus = $request->input('final_status');
            $appointmentDateAccess = database_date($request->input('appointment_date_access'));
            $appointmentDateVertical = database_date($request->input('appointment_date_vertical'));
            $appointmentDateSplicing = database_date($request->input('appointment_date_splicing'));
            $noAccessStatus = $request->input('no_access_status');
            $noVerticalStatus = $request->input('no_vertical_status');
            $noSplicingStatus = $request->input('no_splicing_status');
            $noFinalStatus = $request->input('no_final_status');

            if(Util::isSuperAdmin() || Util::isProjectAdmin()){
                $result = $hwModel->search($name,$seller,$hId,$statusAccess,$statusVertical,$statusSplicing,$finalStatus,$appointmentDateAccess,$appointmentDateVertical,
                    $appointmentDateSplicing,$noAccessStatus,$noVerticalStatus,$noSplicingStatus,$noFinalStatus,$projectManager,null, null, true);
                $noPagination = $hwModel->search($name,$seller,$hId,$statusAccess,$statusVertical,$statusSplicing,$finalStatus,$appointmentDateAccess,$appointmentDateVertical,
                    $appointmentDateSplicing,$noAccessStatus,$noVerticalStatus,$noSplicingStatus,$noFinalStatus,$projectManager);
            }
            elseif(Util::isHuaweiAdmin()){
                if(Util::userId() == 65 && Util::firmaId() == 1){
                    $result = $hwModel->search($name,$seller,$hId,$statusAccess,$statusVertical,$statusSplicing,$finalStatus,$appointmentDateAccess,$appointmentDateVertical,
                        $appointmentDateSplicing,$noAccessStatus,$noVerticalStatus,$noSplicingStatus,$noFinalStatus,$projectManager,null, Util::userPlace(), true, [5]);
                    $noPagination = $hwModel->search($name,$seller,$hId,$statusAccess,$statusVertical,$statusSplicing,$finalStatus,$appointmentDateAccess,$appointmentDateVertical,
                        $appointmentDateSplicing,$noAccessStatus,$noVerticalStatus,$noSplicingStatus,$noFinalStatus,$projectManager,null,Util::userPlace(), false, [5]);
                }
                else{
                    $result = $hwModel->search($name,$seller,$hId,$statusAccess,$statusVertical,$statusSplicing,$finalStatus,$appointmentDateAccess,$appointmentDateVertical,
                        $appointmentDateSplicing,$noAccessStatus,$noVerticalStatus,$noSplicingStatus,$noFinalStatus,$projectManager,null, Util::userPlace(), true);
                    $noPagination = $hwModel->search($name,$seller,$hId,$statusAccess,$statusVertical,$statusSplicing,$finalStatus,$appointmentDateAccess,$appointmentDateVertical,
                        $appointmentDateSplicing,$noAccessStatus,$noVerticalStatus,$noSplicingStatus,$noFinalStatus,$projectManager,null,Util::userPlace());
                }
            }
            else{
                $result = $hwModel->search($name,$seller,$hId,$statusAccess,$statusVertical,$statusSplicing,$finalStatus,$appointmentDateAccess,$appointmentDateVertical,
                    $appointmentDateSplicing,$noAccessStatus,$noVerticalStatus,$noSplicingStatus,$noFinalStatus,$projectManager,$constructionManager,null,true);
                $noPagination = $hwModel->search($name,$seller,$hId,$statusAccess,$statusVertical,$statusSplicing,$finalStatus,$appointmentDateAccess,$appointmentDateVertical,
                    $appointmentDateSplicing,$noAccessStatus,$noVerticalStatus,$noSplicingStatus,$noFinalStatus,$projectManager,$constructionManager);
            }
            

            $ids = Arr::pluck($noPagination, 'id');
            $count = count($ids);
            $ids = json_encode($ids);
            session(['ids_export' => $ids]);
            
        }
        else {
            $name = $request->input('name');
            $seller = $request->input('seller');
            $contactSeller = $request->input('contact_seller');
            $hId = $request->input('h_id');
            $tel1 = $request->input('tel1');
            $tel2 = $request->input('tel2');
            $tel3 = $request->input('tel3');
            $manager = $request->input('manager');
            $mTel1 = $request->input('m_tel1');
            $mTel2 = $request->input('m_tel2');
            $mTel3 = $request->input('m_tel3');
            $state = $request->input('state');
            $city = $request->input('city');
            $municipality = $request->input('municipality');
            $address = $request->input('address');
            $numberOfFloors = $request->input('number_of_floors');
            $numberOfFlats = $request->input('number_of_flats');
            $area = $request->input('area');
            $statusAccess = $request->input('status_access');
            $statusVertical = $request->input('status_vertical');
            $statusSplicing = $request->input('status_splicing');
            $finalStatus = $request->input('final_status');
            $workerAccess = $request->input('worker_access');
            $workerVertical = $request->input('worker_vertical');
            $workerSplicing = $request->input('worker_splicing');
            $appointmentDateAccess = database_date($request->input('appointment_date_access'));
            $appointmentDateVertical =  database_date($request->input('appointment_date_vertical'));
            $appointmentDateSplicing =  database_date($request->input('appointment_date_splicing'));
            $delayDate = database_date($request->input('delay_date'));
            $realizationDateAccess = database_date($request->input('realization_date_access'));
            $realizationDateVertical = database_date($request->input('realization_date_vertical'));
            $withdrawalDate = database_date($request->input('withdrawal_date'));
            $sendingDateHuawei = database_date($request->input('sending_date_huawei'));
            $cluster = $request->input('cluster');
            $odo = $request->input('odo');
            $izvod = $request->input('izvod');
            $connector = $request->input('connector');
            $noAccessStatus = $request->input('no_access_status');
            $noVerticalStatus = $request->input('no_vertical_status');
            $noSplicingStatus = $request->input('no_splicing_status');
            $noFinalStatus = $request->input('no_final_status');
            $realizationAccessStart = database_date($request->input('realization_access_start'));
            $realizationAccessEnd = database_date($request->input('realization_access_end'));
            $realizationVerticalStart = database_date($request->input('realization_vertical_start'));
            $realizationVerticalEnd = database_date($request->input('realization_vertical_end'));
            $realizationSplicingStart = database_date($request->input('realization_splicing_start'));
            $realizationSplicingEnd = database_date($request->input('realization_splicing_end'));
            $appointmentAccessStart = database_date($request->input('appointment_access_start'));
            $appointmentAccessEnd = database_date($request->input('appointment_access_end'));
            $appointmentVerticalStart = database_date($request->input('appointment_vertical_start'));
            $appointmentVerticalEnd = database_date($request->input('appointment_vertical_end'));
            $appointmentSplicingStart = database_date($request->input('appointment_splicing_start'));
            $appointmentSplicingEnd = database_date($request->input('appointment_splicing_end'));
            $technicalSolutionDate = database_date($request->input('technical_solution_date'));
            $atcMsanOlt = $request->input('atc_msan_olt');
            $odfModul = $request->input('odf_modul');
            $connectorNumber = $request->input('connector_number');
            $connectionPoint = $request->input('connection_point');
            $fiber = $request->input('fiber');
            $numerationOdo = $request->input('numeration_odo');
            $flats = $request->input('flats');
            $operation = $request->input('operation');
            $equipment = $request->input('equipment');
            $disStartDate = database_date($request->input('dis_start_date'));
            $disEndDate = database_date($request->input('dis_end_date'));
            $disEndDateStart = database_date($request->input('dis_end_date_start'));
            $disEndDateEnd = database_date($request->input('dis_end_date_end'));
            $boqSendDateStart = database_date($request->input('boq_send_date_start'));
            $boqSendDateEnd = database_date($request->input('boq_send_date_end'));
            $boqApprovalDateStart = database_date($request->input('boq_approval_date_start'));
            $boqApprovalDateEnd = database_date($request->input('boq_approval_date_end'));
            $tisEntryDate = database_date($request->input('tis_entry_date'));
            $lght = $request->input('lght');

            if(Util::isHuaweiAdmin() && Util::userPlace())
                $area = Util::userPlace();
                

            if(Util::isHuaweiAdmin() || Util::isSuperAdmin() || Util::isProjectAdmin()) {
                $result = $hwModel->advanced_search($name, $seller, $contactSeller, $hId, $tel1, $tel2, $tel3, $manager, $mTel1, $mTel2, $mTel3, $state, $city, $municipality, $address, $numberOfFloors, $numberOfFlats,
                    $area, $statusAccess, $statusVertical, $statusSplicing, $finalStatus, $projectManager, $constructionManager, $workerAccess, $workerVertical, $workerSplicing, $appointmentDateAccess, $appointmentDateVertical,
                    $appointmentDateSplicing, $delayDate, $realizationDateAccess, $realizationDateVertical, $withdrawalDate, $sendingDateHuawei, $cluster, $odo, $izvod, $connector, $realizationAccessStart,
                    $realizationAccessEnd, $realizationVerticalStart, $realizationVerticalEnd, $realizationSplicingStart, $realizationSplicingEnd, $appointmentAccessStart, $appointmentAccessEnd, $appointmentVerticalStart, $appointmentVerticalEnd,
                    $appointmentSplicingStart, $appointmentSplicingEnd, $noAccessStatus, $noVerticalStatus, $noSplicingStatus, $noFinalStatus, $technicalSolutionDate, $atcMsanOlt, $odfModul, $connectorNumber, $connectionPoint,$fiber, $numerationOdo, $disStartDate, $disEndDate, $flats,
                    $disEndDateStart, $disEndDateEnd, $boqSendDateStart, $boqSendDateEnd, $boqApprovalDateStart, $boqApprovalDateEnd, $operation, $tisEntryDate, $lght, null, true);
                $noPagination = $hwModel->advanced_search($name, $seller, $contactSeller, $hId, $tel1, $tel2, $tel3, $manager, $mTel1, $mTel2, $mTel3, $state, $city, $municipality, $address, $numberOfFloors, $numberOfFlats,
                    $area, $statusAccess, $statusVertical, $statusSplicing, $finalStatus, $projectManager, $constructionManager, $workerAccess, $workerVertical, $workerSplicing, $appointmentDateAccess, $appointmentDateVertical,
                    $appointmentDateSplicing, $delayDate, $realizationDateAccess, $realizationDateVertical, $withdrawalDate, $sendingDateHuawei, $cluster, $odo, $izvod, $connector, $realizationAccessStart,
                    $realizationAccessEnd, $realizationVerticalStart, $realizationVerticalEnd, $realizationSplicingStart, $realizationSplicingEnd, $appointmentAccessStart, $appointmentAccessEnd, $appointmentVerticalStart, $appointmentVerticalEnd,
                    $appointmentSplicingStart, $appointmentSplicingEnd, $noAccessStatus, $noVerticalStatus, $noSplicingStatus, $noFinalStatus, $technicalSolutionDate, $atcMsanOlt, $odfModul, $connectorNumber, $connectionPoint,$fiber, $numerationOdo, $disStartDate, $disEndDate, $flats,
                    $disEndDateStart, $disEndDateEnd, $boqSendDateStart, $boqSendDateEnd, $boqApprovalDateStart, $boqApprovalDateEnd, $operation, $tisEntryDate, $lght);
            }
            else{
                $result = $hwModel->advanced_search($name, $seller, $contactSeller, $hId, $tel1, $tel2, $tel3, $manager, $mTel1, $mTel2, $mTel3, $state, $city, $municipality, $address, $numberOfFloors, $numberOfFlats,
                    $area, $statusAccess, $statusVertical, $statusSplicing, $finalStatus, $projectManager, $constructionManager, $workerAccess, $workerVertical, $workerSplicing, $appointmentDateAccess, $appointmentDateVertical,
                    $appointmentDateSplicing, $delayDate, $realizationDateAccess, $realizationDateVertical, $withdrawalDate, $sendingDateHuawei, $cluster, $odo, $izvod, $connector, $realizationAccessStart,
                    $realizationAccessEnd, $realizationVerticalStart, $realizationVerticalEnd, $realizationSplicingStart, $realizationSplicingEnd, $appointmentAccessStart, $appointmentAccessEnd, $appointmentVerticalStart, $appointmentVerticalEnd,
                    $appointmentSplicingStart, $appointmentSplicingEnd, $noAccessStatus, $noVerticalStatus, $noSplicingStatus, $noFinalStatus, $technicalSolutionDate, $atcMsanOlt, $odfModul, $connectorNumber, $connectionPoint,$fiber, $numerationOdo, $disStartDate, $disEndDate, $flats,
                    $disEndDateStart, $disEndDateEnd, $boqSendDateStart, $boqSendDateEnd, $boqApprovalDateStart, $boqApprovalDateEnd, $operation, $tisEntryDate, $lght, $userId, true);
                $noPagination = $hwModel->advanced_search($name, $seller, $contactSeller, $hId, $tel1, $tel2, $tel3, $manager, $mTel1, $mTel2, $mTel3, $state, $city, $municipality, $address, $numberOfFloors, $numberOfFlats,
                    $area, $statusAccess, $statusVertical, $statusSplicing, $finalStatus, $projectManager, $constructionManager, $workerAccess, $workerVertical, $workerSplicing, $appointmentDateAccess, $appointmentDateVertical,
                    $appointmentDateSplicing, $delayDate, $realizationDateAccess, $realizationDateVertical, $withdrawalDate, $sendingDateHuawei, $cluster, $odo, $izvod, $connector, $realizationAccessStart,
                    $realizationAccessEnd, $realizationVerticalStart, $realizationVerticalEnd, $realizationSplicingStart, $realizationSplicingEnd, $appointmentAccessStart, $appointmentAccessEnd, $appointmentVerticalStart, $appointmentVerticalEnd,
                    $appointmentSplicingStart, $appointmentSplicingEnd, $noAccessStatus, $noVerticalStatus, $noSplicingStatus, $noFinalStatus, $technicalSolutionDate, $atcMsanOlt, $odfModul, $connectorNumber, $connectionPoint,$fiber, $numerationOdo, $disStartDate, $disEndDate, $flats,
                    $disEndDateStart, $disEndDateEnd, $boqSendDateStart, $boqSendDateEnd, $boqApprovalDateStart, $boqApprovalDateEnd, $operation, $tisEntryDate, $lght, $userId);
            }
            
            $ids = Arr::pluck($noPagination, 'id');
            $count = count($ids);
            $ids = json_encode($ids);
            session(['ids_export' => $ids]);
            session(['hw_equipment_id' => $equipment]);
        }
        session(['search_route' => url()->full()]);
        return view('huawei.search_result', [
            'constructionSites' => $result,
            'count' => $count,
            'isHuaweiAdmin' => Util::isHuaweiAdmin(),
            'isAdmin' => Util::isAdmin(),
            'isSuperAdmin' => Util::isSuperAdmin()
        ]);
    }

    public function delete_equipment_works(Request $request){
        $idEquipment = $request->input('id_equipment');
        $idAccessWork = $request->input('id_access_work');
        $idSite = $request->input('id_site');
        $text = '';
        if($idEquipment){
            Hw_site_equipment::where('id_site', $idSite)->where('id_equipment', $idEquipment)->delete();
            $text = __("Equipment successfully deleted");
        }
        elseif($idAccessWork){
            Hw_site_work::where('site_id', $idSite)->where('access_work_id', $idAccessWork)->delete();
            $text = __("Work successfully deleted");
        }
        return back()->with('success', $text);
    }

    public function huawei_import_index(){
        $companies = Companies::all();
        return view('huawei.import', ['companies' => $companies]);
    }

    public function documentation(){
        $files = Hw_documentation::orderBy('filename')->get();
        $folders = Folders::orderBy('folder')->get();
        $docMod = new Hw_documentation();
        return view('huawei.documentation_index', ['files' => $files, 'folders' => $folders, 'docMod' => $docMod]);
    }

    public function documentation_create(){
        $folders = Folders::orderBy('folder')->get();
        return view('huawei.documentation_create', ['folders' => $folders]);
    }

    public function documentation_store(Request $request){
        $files = $request->file('files');
        $folderId = $request->input('folder');
        $request->validate(['folder' => 'required']);
        $folderName = Folders::find($folderId);
        $folderName = $folderName->folder;
        if($files){
            $request->validate([
                'files.*' => 'mimes:xlsx,xls,pdf,dwg,zip,sor,doc,docx'
            ]);
            $num = 0;
            foreach($files as $file){
                $extension = $file->getClientOriginalExtension();
                $originalFile = $file->getClientOriginalName();
                $filename = $originalFile.'-'.$num.'-'.time().'.'.$extension;
                $folder = 'uploads/documentation/'.$folderName;
                create_folder($folder);
                $file->move($folder, $filename);
                Hw_documentation::create([
                    'file_url' => '/'.$folder.'/'.$filename,
                    'filename' => $originalFile,
                    'folder_id' => $folderId
                ]);
                $num++;
            }
        }
        return redirect()->route('hw_documentation')->with('success', __("Files successfully uploaded"));
    }

    public function add_fixed_access_work(Request $request){
        $siteId = $request->get('site_id');
        $workId = $request->get('access_work_id');
        $operation = $request->get('access_operation');
        $quantity = $request->get('fixed_access_quantity');
        $request->validate([
            'fixed_access_quantity' => 'required|numeric'
        ]);
        if($operation == 'minus')
            $quantity = -$quantity;
        if($workId) {
            $specWork = Hw_access_works::where('id', $workId)->first();
            $price = $specWork->price;
            //update price on site
            if($price > 0){
                $hMod = new Huawei();
                $hMod->updatePrice($price*$quantity, $siteId);
            }
            Hw_site_work::create([
                'site_id' => $siteId,
                'access_work_id' => $workId,
                'quantity' => $quantity
            ]);
        }
        return redirect(url()->previous().'#aWorks');
    }

    public function predict_work(Request $request){
        $siteId = $request->get('site_id');
        $workId = $request->get('p_work_id');
        $quantity = $request->get('p_quantity');
        $type = $request->get('p_type');
        $request->validate([
            'p_quantity' => 'required|numeric'
        ]);
        if($workId) {
            switch($type) {
                case 'access' : 
                    $this->setQuantity($siteId, $workId, $quantity, 'access_work_id');
                break;
                case 'vertical' : 
                    $this->setQuantity($siteId, $workId, $quantity, 'vertical_work_id');
                break;
                case 'doc' : 
                    $this->setQuantity($siteId, $workId, $quantity, 'doc_work');
                break;
            }
            
        }
        return redirect(url()->previous().'#aWorks');
    }

    public function add_doc_work(Request $request){
        $siteId = $request->get('site_id');
        $workId = $request->get('doc_work_id');
        $operation = $request->get('doc_operation');
        $quantity = $request->get('fixed_doc_quantity');
        $request->validate([
            'fixed_doc_quantity' => 'required|numeric'
        ]);
        if($operation == 'minus')
            $quantity = -$quantity;
        if($workId) {
            Hw_site_work::create([
                'site_id' => $siteId,
                'doc_work' => $workId,
                'quantity' => $quantity
            ]);
        }
        return redirect(url()->previous().'#dWorks');
    }
}
