<?php

namespace App\Http\Controllers;

use App\Models\Hw_site_work;
use App\Models\Hw_site_equipment;
use App\Models\Huawei;
use PhpOffice\PhpSpreadsheet\IOFactory as IOFactory;
use PhpOffice\PhpSpreadsheet\Writer\IWriter as IWriter;
use PhpOffice\PhpSpreadsheet\Reader\IReader;
use Illuminate\Http\Request;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use Symfony\Component\HttpFoundation\StreamedResponse;


class HwExportController extends Controller
{
    public function export_works(){
        require '../vendor/autoload.php';
        $accessWorks = json_decode(session('accessWorks'));
        $verticalWorks = json_decode(session('verticalWorks'));

        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();

        $sheet->getColumnDimension('A')->setAutoSize(true);
        $sheet->getColumnDimension('B')->setAutoSize(true);
        $sheet->getColumnDimension('C')->setAutoSize(true);
        $sheet->getColumnDimension('D')->setAutoSize(true);
        $sheet->getColumnDimension('E')->setAutoSize(true);

        $sheet->setCellValue('A1', __('Code'));
        $sheet->setCellValue('B1', __('Equipment'));
        $sheet->setCellValue('C1', __('Unit'));
        $sheet->setCellValue('D1', __('Quantity'));

        $sheet->getStyle('A1:D1')->getAlignment()->setHorizontal('center');

        $sheet->getStyle('A1:D1')->getFill()->setFillType(\PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID)->getStartColor()->setARGB('8c8c8c');

        $br = 2;
        if(!empty($accessWorks)) {
            $sheet->setCellValue('A' . $br, __('Access works'));
            $br ++;
        }
        foreach ($accessWorks as $access){
            $sheet->getStyle('A'.$br.':D'.$br)->getAlignment()->setHorizontal('left');
            $sheet->setCellValue('A'.$br, $access->code);
            $sheet->setCellValue('B'.$br, $access->work);
            $sheet->setCellValue('C'.$br, $access->unit_short);
            $sheet->setCellValue('D'.$br, $access->quantity);
            $br++;
        }

        if(!empty($verticalWorks)) {
            $br++;
            $sheet->setCellValue('A' . $br, __('Vertical works'));
            $br++;
        }

        foreach ($verticalWorks as $vertical){
            $sheet->getStyle('A'.$br.':D'.$br)->getAlignment()->setHorizontal('left');
            $sheet->setCellValue('A'.$br, $vertical->code);
            $sheet->setCellValue('B'.$br, $vertical->work);
            $sheet->setCellValue('C'.$br, $vertical->unit_short);
            $sheet->setCellValue('D'.$br, $vertical->quantity);
            $sheet->setCellValue('D'.$br, $vertical->quantity);
            $br++;
        }

        $streamedResponse = new StreamedResponse();
        $streamedResponse->setCallback(function() use ($spreadsheet){
            $writter = new Xlsx($spreadsheet);
            $writter->save('php://output');
        });

        $streamedResponse->setStatusCode(200);
        $streamedResponse->headers->set('Content-Type', 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        $streamedResponse->headers->set('Content-Disposition', 'attachment; filename="works_export.xlsx"');
        return $streamedResponse->send();
    }

    public function situations(Request $request){
        $siteId = $request->input('site_id');
        $filelUrl = public_path().'/templates/situations.xlsx';

        $hwMod = new Huawei();
        $eMod = new Hw_site_equipment();
        $wMod = new Hw_site_work();
        $huawei = $hwMod->huawei_data($siteId);

        $reader = IOFactory::createReaderForFile($filelUrl);
        $spreadsheet = $reader->load($filelUrl);

        $sheet = $spreadsheet->getSheet(0);
        $sheet->setCellValue('D10', $huawei->address);
        $sheet->setCellValue('D11', $huawei->city);
        $sheet->setCellValue('D12', $huawei->area);
        $sheet->setCellValue('D13', $huawei->cluster);
        $sheet->setCellValue('E16', $huawei->project_manager_name.' '.$huawei->project_manager_surname);


        $sheet = $spreadsheet->getSheet(1);
        $equipmentData = $sheet->rangeToArray('C5:C226');
        foreach($equipmentData as $no=>$code){
            $quantity = $eMod->specificEquipment($siteId,$code);
            if($quantity)
                $sheet->setCellValue('I'.($no+5), $quantity);
        }

        $sheet = $spreadsheet->getSheet(2);
        $equipmentData = $sheet->rangeToArray('C5:C39');
        foreach($equipmentData as $no=>$code){
            $quantity = $eMod->specificEquipment($siteId,$code);
            if($quantity)
                $sheet->setCellValue('I'.($no+5), $quantity);
        }

        $sheet = $spreadsheet->getSheet(5);
        $codes = $sheet->rangeToArray('B7:B347');
        foreach($codes as $no=>$code){
            $quantityAccess = $wMod->specificWork($siteId,$code,'access');
            $quantityVertical = $wMod->specificWork($siteId,$code,'vertical');
            if($quantityAccess)
                $sheet->setCellValue('J'.($no+7), $quantityAccess);
            if($quantityVertical)
                $sheet->setCellValue('J'.($no+7), $quantityVertical);
        }

        $streamedResponse = new StreamedResponse();
        $streamedResponse->setCallback(function() use ($spreadsheet){
            $writer = new Xlsx($spreadsheet);
            $writer->save('php://output');
        });

        $streamedResponse->setStatusCode(200);
        $streamedResponse->headers->set('Content-Type', 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        $streamedResponse->headers->set('Content-Disposition', 'attachment; filename="situations.xlsx"');
        return $streamedResponse->send();

        $writer = IOFactory::createWriter($spreadsheet, "Xlsx");
        $writer->save("05featuredemo.xlsx");

    }
}
