<?php

namespace App\Http\Controllers;

use App\Models\Hw_work_categories;
use Illuminate\Http\Request;

class HwWorkCategoryController extends Controller
{

    private function allCategories(){
        $categories = Hw_work_categories::all();
        return $categories;
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $categories = $this->allCategories();
        return view('hwWorkCategories.index', ['categories' => $categories]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('hwWorkCategories.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'work_type' => 'required'
        ]);
        $typeCreate = Hw_work_categories::create([
            'category' => trim($request->input('work_type'))
        ]);

        if ($typeCreate){
            return redirect()->route('hw_work_category.index')->with('success', __("Data successfully added"));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Hw_work_categories  $hw_work_category
     * @return \Illuminate\Http\Response
     */
    public function show(Hw_work_categories $hw_work_category)
    {
        $category = Hw_work_categories::find($hw_work_category->id);
        return view('hwWorkCategories.show', ['category' => $category]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Hw_work_categories  $hw_work_categories
     * @return \Illuminate\Http\Response
     */
    public function edit(Hw_work_categories $hw_work_category)
    {
        $category = Hw_work_categories::find($hw_work_category->id);
        return view('hwWorkCategories.edit', ['category' => $category]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Hw_work_categories  $hw_work_category
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Hw_work_categories $hw_work_category)
    {
        $request->validate([
            'category' => 'required'
        ]);
        $categoryUpdate = Hw_work_categories::where('id', $hw_work_category->id)->update([
            'category'=>trim($request->input('category'))
        ]);

        if ($categoryUpdate){
            return redirect()->route('hw_work_category.show', ['hw_work_category' => $hw_work_category->id])->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findCategory = Hw_work_categories::find($request->input('id_category'));

        try{
            $findCategory->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }

        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
