<?php

namespace App\Http\Controllers;

use App\Models\Cities;
use App\Models\Huawei;
use App\Models\Huawei_comments;
use App\Models\Origin;
use App\Napomene;
use App\Models\Construction_works;
use App\Models\Equipment;
use App\Models\Construction_prices;
use App\Models\Areas;
use App\Models\Currency;
use App\Klijent;
use App\Klijenti_bakar;
use App\Klijenti_optika;
use App\Klijenti_supernova;
use App\Traits\Util;
use Illuminate\Http\Request;

class ImportController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view('import.index');
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function optika()
    {
        $firmId = Util::firmaId();
        return view('import.optika', ['firmId' => $firmId]);
    }

    public function supernova()
    {
        return view('import.supernova');
    }

    public function bakar(){
        return view ('import.bakar');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        require '../vendor/autoload.php';
        $file = $request->file('import');
        $reclamation = $request->input('reclamation');
        $user = auth()->user();
        if($reclamation){
            $reclamation = 20;
        }
        else {
            $reclamation = null;
        }

        $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();

        if ($file){
            $allowedExtensions = array('xls', 'xlsx');
            $extension = $file->getClientOriginalExtension();
            if (in_array($extension, $allowedExtensions)){

                $spreadsheet = $reader->load($file);
                $sheetData = $spreadsheet->getActiveSheet()->toArray();

                $allowedCharacters = ['.', '/', '-'];

                $errorMessages = array();
                if($reclamation){
                    foreach ($sheetData as $br=>$data){
                        if ($br == 0)
                            continue;
                        if (!$data[0])
                            $errorMessages[] = __("Name and surname are not entered").' '.($br+1).'.  - ('. $sheetData[0][0].')';
                        if (!in_array(substr($data[5], 5, 1), $allowedCharacters) && $data[5])
                            $errorMessages[] = __("Invalid date format: cell number ").' '.($br+1).'.  - ('. $sheetData[0][5].')';
                        if (strlen(trim($data[3])) != 3 && $data[3])
                            $errorMessages[] = __("The network group must have 3 digits: cell number").' '.($br+1);
                        if (!in_array(substr($data[9], 5, 1), $allowedCharacters) && $data[9])
                            $errorMessages[] = __("Invalid date format: cell number ").' '.($br+1).'.  - ('. $sheetData[0][9].')';
                    }
                    if (!empty($errorMessages))
                        return view('import.index', ['errorMessages'=>$errorMessages]);

                    foreach($sheetData as $br=>$data){
                        if ($br == 0 || !$data[0])
                            continue;
                        $deloviImena = explode(" ",preg_replace('/\s+/', ' ', $data[0]));
                        $create = Klijent::create([
                            'ime' => $deloviImena[0],
                            'prezime' => $deloviImena[1],
                            'tis_id' => $data[1],
                            'adresa_instalacije' => $data[2],
                            'mrezna_grupa' => $data[3],
                            'tel2' => $data[4],
                            'datum_reklamacije' => $data[5] ? date('Y-m-d', strtotime(str_replace('/','.', $data[5]))): null,
                            'izvodjac' => $data[8],
                            'datum_montaze' => $data[9] ? date('Y-m-d', strtotime(str_replace('/','.', $data[9]))): null,
                            'id_status' => 20,
                            'created_by' => Util::userId(),
                            'imported' => 1,
                            'id_status_intervencije' => 1
                        ]);
                        if($data[6]){
                            Napomene::create([
                                'napomena' => $data[6],
                                'id_klijent' => $create->id,
                                'complaint' => 1
                            ]);
                        }
                        if($data[7]){
                            Napomene::create([
                                'napomena' => $data[7],
                                'id_klijent' => $create->id,
                                'complaint' => 1
                            ]);
                        }
                    }
                    return redirect()->route('import.index')->with('success', __("Data successfully imported to database"));
                }
                else {
                    foreach ($sheetData as $br=>$data){
                        if ($br == 0 || (!$data[0] && !$data[2] && !$data[3]))
                            continue;

                        if (!is_float(floatval($data[17])) && $data[17] != null)
                            $errorMessages[] = __("Point number has to be real number: cell number").' '.($br+1);

                        if (!in_array(substr($data[1], 5, 1), $allowedCharacters) && $data[1])
                            $errorMessages[] = __("Invalid date format: cell number ").' '.($br+1).'.  - ('. $sheetData[0][1].')';
                        if (!in_array(substr($data[8], 5, 1), $allowedCharacters) && $data[8])
                            $errorMessages[] = __("Invalid date format: cell number ").' '.($br+1).'.  - ('. $sheetData[0][8].')';
                        if (!in_array(substr($data[21], 5, 1), $allowedCharacters) && $data[21])
                            $errorMessages[] = __("Invalid date format: cell number ").' '.($br+1).'.  - ('. $sheetData[0][21].')';
                        if (isset($data[29])){
                            if (!in_array(substr($data[29], 5, 1), $allowedCharacters) && $data[29])
                                $errorMessages[] = __("Invalid date format: cell number ").' '.($br+1).'.  - ('. $sheetData[0][29].')';
                        }
                        if ((strlen(trim($data[3])) != 13) && $data[3])
                            $errorMessages[] = __("JMBG has to have 13 digits: cell number").' '.($br+1);
                        if (strlen(trim($data[4])) != 3 && $data[4])
                            $errorMessages[] = __("The network group must have 3 digits: cell number").' '.($br+1);
                        $deloviImena = explode(" ",preg_replace('/\s+/', ' ', $data[2]));
                        if (count($deloviImena) < 2)
                            $errorMessages[] = __("Name and surname have to be separated by space: cell number").' '.($br+1);

                    }

                    if (!empty($errorMessages))
                        return view('import.index', ['errorMessages'=>$errorMessages]);


                    foreach ($sheetData as $key=>$data){
                        if ($key == 0 || (!$data[0] && !$data[1] && !$data[2] && !$data[3]))
                            continue;

                        $deloviImena = explode(" ",preg_replace('/\s+/', ' ', $data[2]));

                        Klijent::create([
                            'br_ugovora' => $data[0],
                            'datum_dodavanja' => $data[1] ? date('Y-m-d', strtotime(str_replace('/','.', $data[1]))).' '.date('H:i:s') : null,
                            'datum_zahteva' => $data[1] ? date('Y-m-d', strtotime(str_replace('/','.', $data[1]))): null,
                            'ime' => trim($deloviImena[0]),
                            'prezime' => trim($deloviImena[1]),
                            'jmbg' => trim($data[3]),
                            'mrezna_grupa' => trim($data[4]),
                            'tel1' => $data[5],
                            'tis_id' => $data[6],
                            'broj_lk' => $data[7],
                            'datum_izdavanja_lk' => $data[8] ? date('Y-m-d', strtotime(str_replace('/','.', $data[8]))).' '.date('H:i:s') : null,
                            'mesto_izdavanja_lk' => $data[9],
                            'adresa_prebivalista' => $data[10],
                            'adresa_instalacije' => $data[11],
                            'tel2' => $data[12],
                            'paket' => $data[13],
                            'vrsta_paketa' => $data[14],
                            'nov_servis' => $data[15],
                            'dodatni_stb' => $data[16],
                            'broj_bodova' => floatval($data[17]),
                            'izvodjac_prodavac' => $data[18],
                            'prodavac' => $data[19],
                            'izvodjac' => $data[20],
                            'datum_montaze' => $data[21] ? date('Y-m-d', strtotime(str_replace('/','.', $data[21]))): null,
                            'lnb' => trim($data[22]),
                            'stb1' => trim($data[23]),
                            'stb2' => trim($data[24]),
                            'adsl' => trim($data[25]),
                            'vdsl' => trim($data[26]),
                            'mifi_imei' => trim($data[27]),
                            'mifi_iccd' => trim($data[28]),
                            'datum_odustajanja' => $data[29] ? date('Y-m-d', strtotime(str_replace('/','.', $data[29]))): null,
                            'razlog_odustajanja' => $data[30],
                            'created_by' => $user->id,
                            'imported' => 1,
                            'id_status' => $reclamation
                        ]);
                    }
                    return redirect()->route('import.index')->with('success', __("Data successfully imported to database"));
                }
            }
            else {
                return redirect()->route('import.index')->with('errors', __("Valid file extension is xls or xslx"));
            }

        }
        else {
            return redirect()->route('import.index')->with('errors', __("Import excel file"));
        }
    }

    public function import_optika(Request $request){
        require '../vendor/autoload.php';
        $file = $request->file('import');
        $user = auth()->user();

        $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();

        if ($file){
            $allowedExtensions = array('xls', 'xlsx');
            $extension = $file->getClientOriginalExtension();
            if (in_array($extension, $allowedExtensions)){

                $spreadsheet = $reader->load($file);
                $sheet = $spreadsheet->getActiveSheet();

                $allowedCharacters = ['.', '/', '-'];

                $errorMessages = array();
                if(Util::firmaId() == 2){
                    $highestRow = $sheet->getHighestRow();
                    $sheetData = $sheet->rangeToArray('A1:K'.$highestRow);
                    foreach ($sheetData as $br=>$data){
                        if ($br == 0)
                            continue;

                        if (!in_array(substr($data[1], 5, 1), $allowedCharacters) && $data[1])
                            $errorMessages[] = __("Invalid date format: cell number ").' '.($br+1).'.  - ('. $sheetData[0][1].')';

                        if(!$data[5])
                            $errorMessages[] = __("Name and surname are not entered").($br+1);

                        $nameParts = explode(" ",preg_replace('/\s+/', ' ', $data[5]));
                        if (count($nameParts) < 2)
                            $errorMessages[] = __("Name and surname have to be separated by space: cell number").' '.($br+1);
                    }
                    if (!empty($errorMessages))
                        return view('import.optika', ['errorMessages'=>$errorMessages, 'firmId' => Util::firmaId()]);

                    foreach ($sheetData as $key=>$data){
                        if ($key == 0)
                            continue;

                        $nameParts = explode(" ",preg_replace('/\s+/', ' ', $data[5]));
                        if($data[0] && is_int($data[0]) && in_array($data[0], Util::userIds())){
                            $userId = $data[0];
                        }
                        else{
                            $userId = null;
                        }
                        if($data[2])
                            $time = $data[2].':00';
                        else
                            $time = '00:00:00';
                        if($data[1])
                            $appointmentDate = date('Y-m-d H:i:s', strtotime(str_replace('/','.', $data[1].' '.$time)));
                        else
                            $appointmentDate = null;

                        $origin = $data[10];
                        $findOrigin = Origin::find($origin);
                        if($findOrigin)
                            $origin = $data[10];
                        else
                            $origin = null;

                        $client = Klijenti_optika::create([
                            'ime' => trim($nameParts[0]),
                            'prezime' => trim($nameParts[1]),
                            'tis_id' => $data[3],
                            'adresa' => $data[4],
                            'tel1' => $data[6],
                            'tel2' => $data[8],
                            'zahtev' => $data[7],
                            'datum_zakazivanja' => $appointmentDate,
                            'id_user' => $userId,
                            'created_by' => $user->id,
                            'origin_id' => $origin,
                            'imported' => 1
                        ]);

                        if($client && $data[9]){
                            Napomene::create([
                                'napomena' => $data[9],
                                'id_opticki_klijent' => $client->id
                            ]);
                        }
                    }
                }
                else{
                    $highestRow = $sheet->getHighestRow();
                    $sheetData = $sheet->rangeToArray('A1:I'.$highestRow);
                    foreach ($sheetData as $br=>$data){
                        if ($br == 0)
                            continue;

                        if (!in_array(substr($data[0], 5, 1), $allowedCharacters) && $data[0])
                            $errorMessages[] = __("Invalid date format: cell number").' '.($br+1).'.  - ('. $sheetData[0][0].')';

                        $nameParts = explode(" ",preg_replace('/\s+/', ' ', $data[3]));
                        if (count($nameParts) < 2)
                            $errorMessages[] = __("Name and surname are not separated by space: cell number").' '.($br+1);
                    }

                    if (!empty($errorMessages))
                        return view('import.optika', ['errorMessages'=>$errorMessages, 'firmId' => Util::firmaId()]);


                    foreach ($sheetData as $key=>$data){
                        if ($key == 0 || !$data[3])
                            continue;

                        if($data[0]){
                            $status = 1;
                            if($data[7])
                                $time = $data[7];
                            else
                                $time = date('H:i');
                            $datumZakazivanja = database_date_time($data[0], $time);
                        }
                        else {
                            $status = null;
                            $datumZakazivanja = null;
                        }

                        $nameParts = explode(" ",preg_replace('/\s+/', ' ', $data[3]));

                        Klijenti_optika::create([
                            'ime' => trim($nameParts[0]),
                            'prezime' => trim($nameParts[1]),
                            'datum_zakazivanja' => $datumZakazivanja,
                            'id_status' => $status,
                            'tis_id' => $data[1],
                            'adresa' => $data[2],
                            'zahtev' => $data[4],
                            'tel1' => $data[5],
                            'tel2' => $data[6],
                            'imported' => 1,
                            'created_by' => $user->id
                        ]);
                    }
                }

                return redirect()->route('optika')->with('success', __("Data successfully imported to database"));

            }
            else {
                return redirect()->route('optika')->with('errors', __("Valid file extension is xls or xslx"));
            }

        }
        else {
            return redirect()->route('optika')->with('errors', __("Import excel file"));
        }
    }
    public function import_supernova(Request $request){
        require '../vendor/autoload.php';
        $file = $request->file('import');
        $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();

        if ($file){
            $allowedExtensions = array('xls', 'xlsx');
            $extension = $file->getClientOriginalExtension();
            if (in_array($extension, $allowedExtensions)){

                $spreadsheet = $reader->load($file);
                $sheetData = $spreadsheet->getActiveSheet()->toArray();

                $allowedCharacters = ['.', '/', '-'];

                $errorMessages = array();

                foreach ($sheetData as $br=>$data){
                    if ($br == 0)
                        continue;

                    if (!in_array(substr($data[6], 5, 1), $allowedCharacters) && $data[6])
                        $errorMessages[] = __("Invalid date format: cell number ").' '.($br+1).'.  - ('. $sheetData[0][6].')';

                    $deloviImenaAgent = explode(" ",preg_replace('/\s+/', ' ', $data[1]));
                    if (count($deloviImenaAgent) < 2)
                        $errorMessages[] = __("Name and surname are not separated by space: cell number").' '.($br+1);
                    $deloviImena = explode(" ",preg_replace('/\s+/', ' ', $data[7]));
                    if (count($deloviImena) < 2)
                        $errorMessages[] = __("Name and surname have to be separated by space: cell number").' '.($br+1);

                }

                if (!empty($errorMessages))
                    return view('import.supernova', ['errorMessages'=>$errorMessages]);

                foreach ($sheetData as $key=>$data){
                    if ($key == 0)
                        continue;

                    $deloviImena = explode(" ",preg_replace('/\s+/', ' ', $data[7]));
                    $deloviImenaAgent = explode(" ",preg_replace('/\s+/', ' ', $data[1]));

                    Klijenti_supernova::create([
                        'regionalni_centar' => $data[0],
                        'klijent_ime' => trim($deloviImena[1]),
                        'klijent_prezime' => trim($deloviImena[0]),
                        'agent_ime' => trim($deloviImenaAgent[0]),
                        'agent_prezime' => trim($deloviImenaAgent[1]),
                        'br_bodova' => $data[2],
                        'provajder' => $data[3],
                        'agencija' => $data[4],
                        'mesec' => $data[5],
                        'datum_obilaska' => date('Y-m-d', strtotime(str_replace('/','.', $data[6]))),
                        'ulica' => $data[8],
                        'kucni_broj' => $data[9],
                        'mesto' => $data[10],
                        'email' => $data[11],
                        'tel2' => $data[12],
                        'tel1' => $data[13],
                        'tip_ugovora' => $data[14],
                        'paket' => $data[15],
                        'broj_ugovora' => $data[16],
                        'created_by' => Util::userId()
                    ]);
                }

                return redirect()->route('supernova')->with('success', __("Data successfully imported to database"));

            }
            else {
                return redirect()->route('supernova')->with('errors', __("Valid file extension is xls or xslx"));
            }

        }
        else {
            return redirect()->route('supernova')->with('errors', __("Import excel file"));
        }
    }

    public function import_bakar(Request $request){
        require '../vendor/autoload.php';
        $file = $request->file('import');
        $user = auth()->user();

        $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();

        if ($file){
            $allowedExtensions = array('xls', 'xlsx');
            $extension = $file->getClientOriginalExtension();
            if (in_array($extension, $allowedExtensions)){

                $spreadsheet = $reader->load($file);
                $sheetData = $spreadsheet->getActiveSheet()->toArray();

                $errorMessages = array();
                foreach ($sheetData as $br=>$data){
                    if ($br == 0)
                        continue;

                    $klijent = explode(" ",preg_replace('/\s+/', ' ', $data[2]));
                    if (count($klijent) < 2)
                        $errorMessages[] = __("Name and surname have to be separated by space: cell number").' '.($br+1);

                }

                if (!empty($errorMessages))
                    return view('import.bakar', ['errorMessages'=>$errorMessages]);


                foreach ($sheetData as $key=>$data){
                    if ($key == 0)
                        continue;

                    if ($data[15] && $data[14] && $data[13])
                        $datumZahteva = $data[15].'-'.$data[14].'-'.$data[13];
                    else
                        $datumZahteva = null;

                    $klijent = explode(" ",preg_replace('/\s+/', ' ', $data[2]));

                    Klijenti_bakar::create([
                        'podrucje' => $data[0],
                        'prodavac' => $data[1],
                        'ime' => trim($klijent[0]),
                        'prezime' => trim($klijent[1]),
                        'tel1' => $data[3].'/'.$data[4],
                        'tel2' => $data[7].'/'.$data[8],
                        'tel3' => $data[9],
                        'zahtev' => $data[10],
                        'adresa' => $data[5].' '.$data[6],
                        'br_bodova' => $data[11],
                        'datum_zahteva' => $datumZahteva,
                        'tis_id' => $data[12],
                        'oprema_ugovor' => $data[16],
                        'created_by' => $user->id
                    ]);
                }

                return redirect()->route('bakar')->with('success', __("Data successfully imported to database"));

            }
            else {
                return redirect()->route('bakar')->with('errors', __("Valid file extension is xls or xslx"));
            }

        }
        else {
            return redirect()->route('bakar')->with('errors', __("Import excel file"));
        }
    }

    public function mustra(Request $request){
        switch ($request->input('param')){
            case 'dth' :
                $file_url = public_path().'/templates/dth_template.xlsx';
                break;
            case 'optika' :
                $file_url = public_path().'/templates/biz_optika_template.xlsx';
                break;
            case 'supernova' :
                $file_url = public_path().'/templates/supernova_template.xlsx';
                break;
            case 'bakar' :
                $file_url = public_path().'/templates/bakar_template.xlsx';
                break;
            case 'construction_prices' :
                $file_url = public_path().'/templates/construction_template.xlsx';
                break;
            case 'fobos' :
                $file_url = public_path().'/templates/fobos_template.xlsx';
                break;
            case 'fobos_rune' :
                $file_url = public_path().'/templates/fobos_rune_template.xlsx';
                break;
            case 'fobos_copper' :
                $file_url = public_path().'/templates/fobos_copper_template.xlsx';
                break;
            case 'optika_despotes' :
                $file_url = public_path().'/templates/optika_despotes_template.xlsx';
                break;
            case 'dth_reklamacija' :
                $file_url = public_path().'/templates/reklamacije_template.xlsx';
                break;
            case 'kir' :
                $file_url = public_path().'/templates/kir.xlsx';
                break;
            case 'huawei' :
                $file_url = public_path().'/templates/huawei.xlsx';
                break;
        }
        header('Content-Type: application/octet-stream');
        header("Content-Transfer-Encoding: Binary");
        header("Content-disposition: attachment; filename=\"" . basename($file_url) . "\"");
        readfile($file_url);
    }

    public function import_construction(Request $request){
        $param = $request->input('param');
        require '../vendor/autoload.php';
        $file = $request->file('import');
        $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();
        $area = $request->input('area');
        $currency = $request->input('currency');
        $priceDate = $request->input('price_date');

        if($priceDate == null)
            $priceDate = date('Y-m-d');
        else
            $priceDate = date('Y-m-d', strtotime($priceDate));

        $request->validate([
            'area' => 'required',
            'currency' => 'required'
        ]);

        if($file){
            $allowedExtensions = array('xls', 'xlsx');
            $extension = $file->getClientOriginalExtension();
            $equipmentModel = new Equipment();
            $worksModel  = new Construction_works();
            if (in_array($extension, $allowedExtensions)){
                $spreadsheet = $reader->load($file);
                $sheetData = $spreadsheet->getActiveSheet()->toArray();

                $errorMessages = array();
                foreach ($sheetData as $br=>$data){
                    if ($br == 0)
                        continue;
                    if($data[0] == null)
                        $errorMessages[] = __("There is no code: cell number").' '.($br+1);
                    if($data[2] === 0)
                        continue;
                    if(!is_numeric((float)str_replace(',','', $data[2])))
                        $errorMessages[] = __("Price is not number: cell number").' '.($br+1);
                    
                }

                if (!empty($errorMessages)){
                    $areas = Areas::all();
                    $currencies = Currency::all();
                    return view('construction.import_equipment', [
                        'errorMessages'=>$errorMessages,
                        'areas' => $areas,
                        'currencies' => $currencies
                    ]);
                }
                foreach ($sheetData as $key=>$data){
                    if ($key == 0)
                        continue;
                    if(!$data[2])
                        continue;

                    $eqId = $equipmentModel->equipmentId($data[0], $data[1]);
                    $wrId = $worksModel->workId($data[0], $data[1]);

                    if($param == 'equipment' && is_object($eqId)){
                        Construction_prices::create([
                            'price' => (float)str_replace(',','', $data[2]),
                            'id_area' => $area,
                            'id_currency' => $currency,
                            'id_equipment' => $eqId->id,
                            'price_date' => $priceDate
                        ]);
                    }
                    elseif($param == 'works' && is_object($wrId)){
                        Construction_prices::create([
                            'price' => (float)str_replace(',','', $data[2]),
                            'id_area' => $area,
                            'id_currency' => $currency,
                            'id_construction_work' => $wrId->id,
                            'price_date' => $priceDate
                        ]);
                    }
                    
                }

                if ($param == 'equipment')
                    return redirect()->route('import_equipment')->with('success', __("Data successfully imported to database"));
                if ($param == 'works')
                    return redirect()->route('import_construction_works')->with('success', __("Data successfully imported to database"));

            }
                
        }
        else {
            return back()->with('errors', __("Import excel file"));
        }
    }

    public function huawei_import(Request $request){
        require '../vendor/autoload.php';
        $file = $request->file('import');
        $company = $request->input('company');
        $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();

        if($file){
            $allowedExtensions = array('xls', 'xlsx');
            $extension = $file->getClientOriginalExtension();
            if (in_array($extension, $allowedExtensions)){
                $spreadsheet = $reader->load($file);
                $sheetData = $spreadsheet->getActiveSheet()->toArray();
                $errorMessages = array();
                foreach($sheetData as $br=>$data){
                    if ($br == 0)
                        continue;
                    if(!$data[2])
                        $errorMessages[] = __("Address is required field").' '.($br+1);
                }
                if (!empty($errorMessages))
                    return view('huawei.import', ['errorMessages'=>$errorMessages]);

                foreach ($sheetData as $key=>$data){
                    if ($key == 0)
                        continue;

                    $nameSeller = null;
                    $nameManager = null;
                    $namePartsSeller = explode(" ",preg_replace('/\s+/', ' ', $data[0]));
                    if($namePartsSeller){
                        $nameSeller = $namePartsSeller[0];
                        if(isset($namePartsSeller[1]))
                            $nameSeller .= ' '.$namePartsSeller[1];
                    }
                    $namePartsManager = explode(" ",preg_replace('/\s+/', ' ', $data[7]));
                    if($namePartsManager){
                        $nameManager = $namePartsManager[0];
                        if(isset($namePartsManager[1]))
                            $nameManager .= ' '.$namePartsManager[1];
                    }

                    $address = $data[2];

                    $ctMod = new Cities();
                    $cityId = $ctMod->getCityIdByName(trim($data[4]));

                    $create = Huawei::create([
                        'name' => $address,
                        'seller' => $nameSeller,
                        'contact_seller' => $data[1],
                        'address' => $address,
                        'id_city' => $cityId,
                        'municipality' => $data[3],
                        'id_state' => 1,
                        'number_of_floors' => $data[5],
                        'number_of_flats' => $data[6],
                        'manager' => $nameManager,
                        'm_tel2' => $data[8],
                        'company_id' => $company
                    ]);

                    if($data[9]){
                        Huawei_comments::create([
                           'comment' => $data[9],
                            'id_site' => $create->id,
                            'id_user' => Util::userId()
                        ]);
                    }

                }
                return back()->with('success', __("Data successfully imported to database"));
            }
        }
        else {
            return back()->with('errors', __("Import excel file"));
        }
    }

}
