<?php

namespace App\Http\Controllers;

use App\Models\Installation_image_types;
use App\Models\Files;
use App\Models\Montage_prices;
use App\Models\Worker_equipment;
use App\Device_history;
use App\Change_history;
use App\Klijenti_bakar;
use App\Klijenti_optika;
use App\Klijenti_supernova;
use App\Images_documents;
use App\Montirani_uredjaji;
use App\Napomene;
use App\Images;
use App\Oprema;
use App\Oprema_klijent;
use App\Pomocnici;
use App\Razlozi_intervencije;
use App\Razlozi_vracanja;
use App\Traits\Util;
use App\Uredjaji;
use App\Videos;
use App\Klijent;
use App\Klijenti_prodaja;
use App\Statusi;
use App\Statusi_intervencije;
use App\Vraceni_uredjaji;
use Illuminate\Http\Request;
use Intervention\Image\ImageManager as Img;

class KlijentController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */

    public function index()
    {
        $isAdmin = Util::isAdmin();
        $klijentModel = new Klijent();
        if (!$isAdmin)
            $klijenti = $klijentModel->klijentiPregled(Util::userId());
        else
            $klijenti = $klijentModel->klijentiAdmin();

        session(['search_route' => false]);

        return view('klijenti.index', [
            'klijenti' => $klijenti,
            'search'=>false,
            'isAdmin' => $isAdmin,
            'isSuperAdmin'=>Util::isSuperAdmin()
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
        $statusi = Statusi::all();
        $statusiIntervencije = Statusi_intervencije::all();
        $monteri = Util::monteri();
        return view('klijenti.create', [
            'statusi' => $statusi,
            'statusiIntervencije' => $statusiIntervencije,
            'monteri' => $monteri,
            'isMonter' => Util::isMonter(),
            'isAdmin' => Util::isAdmin()
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'ime' => 'required',
            'prezime' => 'required',
            'jmbg' => 'nullable|digits:13'
        ]);

        // if(Util::hasTisDuplicates(1, $request->input('tis_id')))
        //     return back()->withInput()->with('error', 'TIS ID mora da bude jedinstven. Ovaj se već nalazi kod klijenta.');

        $complaint = $request->input('complaint');

        $datumOdustajanja = null;
        $datumMontaze = null;
        $datumIzdavanjaLk = null;
        $datumZakazivanja = null;
        $datumOdlaganja = null;
        $datumIntervencije = null;
        $datumReklamacije = null;
        if ($request->input('datum_montaze'))
            $datumMontaze = date('Y-m-d', strtotime($request->input('datum_montaze')));
        if ($request->input('datum_izdavanja_lk'))
            $datumIzdavanjaLk = date('Y-m-d', strtotime($request->input('datum_izdavanja_lk')));
        if ($request->input('datum_odustajanja'))
            $datumOdustajanja = date('Y-m-d', strtotime($request->input('datum_odustajanja')));
        if ($request->input('datum_zakazivanja'))
            $datumZakazivanja = date('Y-m-d', strtotime($request->input('datum_zakazivanja')));
        if ($request->input('datum_odlaganja'))
            $datumOdlaganja = date('Y-m-d', strtotime($request->input('datum_odlaganja')));
        if ($request->input('datum_intervencije'))
            $datumIntervencije = date('Y-m-d', strtotime($request->input('datum_intervencije')));
        if ($request->input('datum_reklamacije'))
            $datumReklamacije = date('Y-m-d', strtotime($request->input('datum_reklamacije')));


        if ($datumZakazivanja && $request->input('vreme'))
            $datumZakazivanja = date('Y-m-d', strtotime($datumZakazivanja)).' '.$request->input('vreme').':'.date('s');
        if ($datumOdlaganja && $request->input('vreme2'))
            $datumOdlaganja = date('Y-m-d', strtotime($datumOdlaganja)).' '.$request->input('vreme2').':'.date('s');

        $points = (float)str_replace(',','.',$request->input('broj_bodova'));
        if($points == 0)
            $points = null;

        $klijent = Klijent::create([
            'br_ugovora' => $request->input('br_ugovora'),
            'ime' => $request->input('ime'),
            'prezime' => $request->input('prezime'),
            'jmbg' => $request->input('jmbg'),
            'mrezna_grupa' => $request->input('mrezna_grupa'),
            'tel1' => $request->input('tel1'),
            'tel2' => $request->input('tel2'),
            'tel3' => $request->input('tel3'),
            'tis_id' => $request->input('tis_id'),
            'broj_lk' => $request->input('broj_lk'),
            'datum_izdavanja_lk' => $datumIzdavanjaLk,
            'mesto_izdavanja_lk' => $request->input('mesto_izdavanja_lk'),
            'adresa_prebivalista' => $request->input('adresa_prebivalista'),
            'adresa_instalacije' => $request->input('adresa_instalacije'),
            'paket' => $request->input('paket'),
            'vrsta_paketa' => $request->input('vrsta_paketa'),
            'nov_servis' => $request->input('nov_servis'),
            'dodatni_stb' => $request->input('dodatni_stb'),
            'broj_bodova' => $points,
            'izvodjac_prodavac' => $request->input('izvodjac_prodavac'),
            'prodavac' => $request->input('prodavac'),
            'izvodjac' => $request->input('izvodjac'),
            'datum_montaze' => $datumMontaze,
            'lnb' => $request->input('lnb'),
            'stb1' => $request->input('stb1'),
            'stb2' => $request->input('stb2'),
            'adsl' => $request->input('adsl'),
            'vdsl' => $request->input('vdsl'),
            'mifi_imei' => $request->input('mifi_imei'),
            'mifi_iccd' => $request->input('mifi_iccd'),
            'datum_odustajanja' => $datumOdustajanja,
            'razlog_odustajanja' => $request->input('razlog_odustajanja'),
            'id_status' => $request->input('status')[0],
            'id_status_intervencije' => $request->input('status_intervencije')[0],
            'datum_intervencije' => $datumIntervencije,
            'datum_zakazivanja' => $datumZakazivanja,
            'datum_odlaganja' => $datumOdlaganja,
            'datum_dodavanja' => date('Y-m-d H:i:s'),
            'id_user' => $request->input('user')[0],
            'id_user_reklamacije' => $request->input('monter_reklamacije')[0],
            'datum_reklamacije' => $datumReklamacije,
            'created_by'=>Util::userId()
        ]);

        if ($request->input('napomena')) {
            Napomene::create([
                'napomena' => $request->input('napomena'),
                'id_user' => Util::userId(),
                'id_klijent' => $klijent->id,
                'complaint' => $complaint?1:null
            ]);
        }

        $klijentModel = new Klijent();
        if (!Util::isAdmin()) {
            $klijenti = $klijentModel->klijentiPregled(Util::userId());
        }
        else
            $klijenti = $klijentModel->klijentiAdmin();

        if ($klijent){
            Change_history::create([
              'id_user' => Util::userId(),
              'id_klijent' => $klijent->id
            ]);
            return redirect()->route('klijent.index', [
                'klijenti' => $klijenti,
                'isAdmin' => Util::isAdmin(),
                'isSuperAdmin' => Util::isSuperAdmin()
            ])->with('success', __("Data successfully added"));
        }

    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Klijent  $klijent
     * @return \Illuminate\Http\Response
     */
    public function show(Klijent $klijent)
    {
        $clientId = $klijent->id;
        $klijentModel = new Klijent();
        $klijentData = $klijentModel->klijentPodaci($klijent->id);
        $imageModel = new Images();
        $images = $imageModel->slikeZaKlijenta($klijent->id);
        $imgDocModel = new Images_documents();
        $imgDocs = $imgDocModel->dokumentiZaKlijenta($klijent->id);
        $napModel = new Napomene();
        $napomene = $napModel->napomene($klijent->id);
        $chModel = new Change_history();
        $history = $chModel->history($klijent->id);
        $montiraniModel = new Montirani_uredjaji();
        $montirani = $montiraniModel->montiraniList($klijent->id);
        $vraceniModel = new Vraceni_uredjaji();
        $vraceni = $vraceniModel->vraceniList('id_klijent', $klijent->id);
        $equipModel = new Oprema_klijent();
        $equipment = $equipModel->equipment($klijent->id);
        $devLogModel = new Device_history();
        $deviceLog = $devLogModel->deviceLog($klijent->id, 'id_klijent');

        $dismantled = false;
        if(Util::firmaId() == 1){
            if($klijent->id_status == 19)
                $dismantled = true;
        }

        $date = new \DateTime();
        $date->modify("-2 years");
        $substractedDate = $date->format('Y-m-d');
        if ($klijent->datum_montaze < $substractedDate && $klijent->datum_montaze != null)
            $oldMontage = true;
        else
            $oldMontage = false;

        $files = Files::where('msat_client_id', $clientId)->get();

        return view('klijenti.show', [
            'klijent' => $klijentData,
            'id_user' => Util::userId(),
            'isAdmin' => Util::isAdmin(),
            'images' => $images,
            'imgDocs' => $imgDocs,
            'napomene'=>$napomene,
            'history' => $history,
            'montirani' => $montirani,
            'equipment' => $equipment,
            'vraceni' => $vraceni,
            'deviceLog' => $deviceLog,
            'oldMontage' => $oldMontage,
            'files' => $files,
            'dismantled' => $dismantled,
            'isSuperAdmin' => Util::isSuperAdmin()
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Klijent  $klijent
     * @return \Illuminate\Http\Response
     */
    public function edit(Klijent $klijent)
    {
        //caching disabled for this page
        $ts = gmdate("D, d M Y H:i:s") . " GMT";
        header("Expires: $ts");
        header("Last-Modified: $ts");
        header("Pragma: no-cache");
        header("Cache-Control: no-cache, must-revalidate");

        if (Util::isAdmin())
            $statusi = Statusi::all();
        else
            $statusi = Statusi::all()->whereIn('id', [2,4,5,21]);

        $statusiIntervencije = Statusi_intervencije::all();
        $klijent = Klijent::find($klijent->id);
        $monteri = Util::monteri();
        $helpers = Pomocnici::all();

        $imageModel = new Images();
        $images = $imageModel->slikeZaKlijenta($klijent->id);
        $imgDocModel = new Images_documents();
        $imgDoc = $imgDocModel->dokumentiZaKlijenta($klijent->id);
        $napModel = new Napomene();
        $napomene = $napModel->napomene($klijent->id);
        $razlogModel = new Razlozi_intervencije();
        $razlozi = $razlogModel->razlozi();
        $montiraniModel = new Montirani_uredjaji();
        $montirani = $montiraniModel->montiraniList($klijent->id);
        $vraceniModel = new Vraceni_uredjaji();
        $vraceni = $vraceniModel->vraceniList('id_klijent', $klijent->id);
        $equipModel = new Oprema_klijent();
        $equipment = $equipModel->equipment($klijent->id);
        if(Util::isAdmin()){
            $oprema = Oprema::all();
        }
        else {
            $storageModel = new Worker_equipment();
            $oprema = $storageModel->mont_client_equipment(Util::userId());
        }
        $uredjaji = Uredjaji::devicesByType(config('app.dev_type_msat'));

        $reasonModel = new Razlozi_vracanja();
        $returnReasons = $reasonModel->return_reasons();

        $files = Files::where('msat_client_id', $klijent->id)->get();
        $imageTypes = Installation_image_types::all();

        return view('klijenti.edit', [
            'klijent' => $klijent,
            'statusi'=>$statusi,
            'statusiIntervencije'=>$statusiIntervencije,
            'isAdmin'=>Util::isAdmin(),
            'images'=>$images,
            'imgDocs'=> $imgDoc,
            'napomene'=>$napomene,
            'userId'=>Util::userId(),
            'isSuperAdmin'=>Util::isSuperAdmin(),
            'monteri'=>$monteri,
            'razlozi_intervencije'=>$razlozi,
            'montirani' => $montirani,
            'equipment' => $equipment,
            'uredjaji' => $uredjaji,
            'oprema' => $oprema,
            'razlozi' => $returnReasons,
            'vraceni' => $vraceni,
            'files' => $files,
            'imageTypes' => $imageTypes,
            'helpers' => $helpers
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Klijent  $klijent
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Klijent $klijent)
    {
        //save data
        require '../vendor/autoload.php';
        $this->validate($request, [
            'ime' => 'required',
            'prezime' => 'required',
            'jmbg' => 'nullable|digits:13',
            'document' => 'mimes:xlsx,xls,pdf'
        ]);

        $document = $request->file('document');
        if($document){
            $originalFile = $document->getClientOriginalName();
            $filename = strtotime(date('d.m.Y. H:i:s')).'_'.$originalFile;
            $folder = 'uploads/documents/'.quartal();
            create_folder($folder);
            $document->move($folder, $filename);
            Files::create([
                'file_url' => '/'.$folder.'/'.$filename,
                'msat_client_id' => $klijent->id,
                'filename' => $originalFile
            ]);
        }

        // if(Util::hasTisDuplicates(1, $request->input("tis_id")))
        //     return back()->withInput()->with('error', 'TIS ID mora da bude jedinstven. Ovaj se već nalazi kod klijenta.');

        $complaint = $request->input('complaint');

        $datumOdustajanja = null;
        $datumMontaze = null;
        $datumIzdavanjaLk = null;
        $datumZakazivanja = null;
        $datumOdlaganja = null;
        $datumIntervencije = null;
        $datumReklamacije = null;
        if ($request->input('datum_montaze'))
            $datumMontaze = date('Y-m-d', strtotime($request->input('datum_montaze')));
        if ($request->input('datum_izdavanja_lk'))
            $datumIzdavanjaLk = date('Y-m-d', strtotime($request->input('datum_izdavanja_lk')));
        if ($request->input('datum_odustajanja'))
            $datumOdustajanja = date('Y-m-d', strtotime($request->input('datum_odustajanja')));
        if ($request->input('datum_zakazivanja'))
            $datumZakazivanja = date('Y-m-d', strtotime($request->input('datum_zakazivanja')));
        if ($request->input('datum_odlaganja'))
            $datumOdlaganja = date('Y-m-d', strtotime($request->input('datum_odlaganja')));
        if ($request->input('datum_intervencije'))
            $datumIntervencije = date('Y-m-d', strtotime($request->input('datum_intervencije')));
        if ($request->input('datum_reklamacije'))
            $datumReklamacije = date('Y-m-d', strtotime($request->input('datum_reklamacije')));

        if ($datumZakazivanja && $request->input('vreme'))
            $datumZakazivanja = date('Y-m-d', strtotime($datumZakazivanja)).' '.$request->input('vreme').':'.date('s');
        if ($datumOdlaganja && $request->input('vreme2'))
            $datumOdlaganja = date('Y-m-d', strtotime($datumOdlaganja)).' '.$request->input('vreme2').':'.date('s');

        $status = $request->input('status');

        /*---------------images*---------------*/
        $pictures = $request->file('pictures');
        $img = new Img();
        $folder = 'uploads/images/'.quartal();
        if (!file_exists($folder)){
            mkdir($folder, 0755, true);
        }

        if($pictures){
            $imageType = $request->input("image_type");
            $this->validate($request, [
                'pictures.*' => 'image|mimes:jpeg,png,jpg,gif',
            ]);
            foreach($pictures as $file){
                $extension = $file->getClientOriginalExtension();
                $filename = date('Y-m-d').'-'.rand(1,100).'montaza'.rand(1,100000).'.'.$extension;
                $fileInt = $img->make($file->getRealPath());
                $fileInt->save($folder.'/'.$filename, 50);
                if(in_array($imageType, [5,6])){
                    Images_documents::create([
                        'image_url' => '/'.$folder.'/'.$filename,
                        'id_klijent' => $klijent->id,
                        'type_id' => $imageType
                    ]);
                }
                else {
                    Images::create([
                        'image_url' => '/'.$folder.'/'.$filename,
                        'id_klijent' => $klijent->id,
                        'type_id' => $imageType
                    ]);
                }
            }
        }

        $points = (float)str_replace(',','.',$request->input('broj_bodova'));
        if($points == 0)
            $points = null;

        if($request->input('terrain'))
            $onTerrain = 1;
        else
            $onTerrain = null;

        $helper = $request->input('helper');

        if($request->input('filed'))
            $filed = 1;
        else
            $filed = 0;

        if (Util::isAdmin()) {
            $klijentUpdate = Klijent::where('id', $klijent->id)->update([
                'br_ugovora' => $request->input('br_ugovora'),
                'ime' => $request->input('ime'),
                'prezime' => $request->input('prezime'),
                'jmbg' => $request->input('jmbg'),
                'mrezna_grupa' => $request->input('mrezna_grupa'),
                'tel1' => $request->input('tel1'),
                'tel2' => $request->input('tel2'),
                'tel3' => $request->input('tel3'),
                'tis_id' => $request->input('tis_id'),
                'broj_lk' => $request->input('broj_lk'),
                'datum_izdavanja_lk' => $datumIzdavanjaLk,
                'mesto_izdavanja_lk' => $request->input('mesto_izdavanja_lk'),
                'adresa_prebivalista' => $request->input('adresa_prebivalista'),
                'adresa_instalacije' => $request->input('adresa_instalacije'),
                'paket' => $request->input('paket'),
                'vrsta_paketa' => $request->input('vrsta_paketa'),
                'nov_servis' => $request->input('nov_servis'),
                'dodatni_stb' => $request->input('dodatni_stb'),
                'broj_bodova' => $points,
                'izvodjac_prodavac' => $request->input('izvodjac_prodavac'),
                'prodavac' => $request->input('prodavac'),
                'izvodjac' => $request->input('izvodjac'),
                'datum_montaze' => $datumMontaze,
                'for_payment' => $request->input('for_payment')?1:0,
                'datum_odustajanja' => $datumOdustajanja,
                'razlog_odustajanja' => $request->input('razlog_odustajanja'),
                'id_status' => $status,
                'id_status_intervencije' => $request->input('status_intervencije'),
                'datum_intervencije' => $datumIntervencije,
                'id_user' => $request->input('user')[0],
                'id_user_reklamacije' => $request->input('monter_reklamacije')[0],
                'id_razlog_reklamacije' => $request->input('razlog_reklamacije')[0],
                'datum_reklamacije' => $datumReklamacije,
                'created_by' => Util::userId(),
                'helper' => $helper,
                'on_terrain' => $onTerrain,
                'filed' => $filed
            ]);

            if ($klijentUpdate){
                if($klijent->id_klijent_prodaja && $datumMontaze){
                    Klijenti_prodaja::where('id', $klijent->id_klijent_prodaja)->update([
                        'montage_date' => $datumMontaze
                    ]);
                }
                if ($status == 1)
                    Klijent::where('id', $klijent->id)->update(['datum_zakazivanja' => $datumZakazivanja]);
                if ($status == 2)
                    Klijent::where('id', $klijent->id)->update(['datum_odlaganja' => $datumOdlaganja]);
            }
        }
        //fitter part
        else {
            $request->validate([
                'dodatni_stb' => 'required|numeric'
            ]);
            //intervention comment is required if intervention status is closed
            if(Util::userId() == $klijent->id_user_reklamacije && $request->input('status_intervencije') == 2){
                $request->validate([
                    'napomena' => 'required'
                ]);
            }
//            $request->validate(['helper' => 'required']);
            if($helper == 0)
                $helper = null;
            $reklamator = $klijent->id_user_reklamacije;
            if ($status == 5 && !$reklamator){
                $datumMontaze = date('Y-m-d');
                $datumOdustajanja = null;
            }

            if ($status == 4 && !$reklamator){
                $datumOdustajanja = date('Y-m-d');
                $datumMontaze = null;
            }
            $izmeniStatus=false;
            //monter nema sve statuse, tako da ukoliko ne unese jedan od 4 moguca, ne menja se status u bazi
            if (in_array($status, [2,4,5,21]))
                $izmeniStatus = true;
                
            if ($izmeniStatus){
                $klijentUpdate = Klijent::where('id', $klijent->id)->update([
                    'datum_montaze' => $datumMontaze,
                    'datum_odustajanja' => $datumOdustajanja,
                    'razlog_odustajanja' => $request->input('razlog_odustajanja'),
                    'id_status' => $status,
                    'id_status_intervencije' => $request->input('status_intervencije'),
                    'datum_intervencije' => $datumIntervencije,
                    'datum_reklamacije' => $datumReklamacije,
                    'created_by' => Util::userId(),
                    'helper' => $helper,
                    'on_terrain' => $onTerrain,
                    'dodatni_stb' => $request->input('dodatni_stb')
                ]);
                if ($klijentUpdate){
                    if($klijent->id_klijent_prodaja && $datumMontaze){
                        Klijenti_prodaja::where('id', $klijent->id_klijent_prodaja)->update([
                            'montage_date' => $datumMontaze
                        ]);
                    }
                    if ($status == 1)
                        Klijent::where('id', $klijent->id)->update(['datum_zakazivanja' => $datumZakazivanja]);
                    if ($status == 2)
                        Klijent::where('id', $klijent->id)->update(['datum_odlaganja' => $datumOdlaganja]);
                }
            }
            else {
                $klijentUpdate = Klijent::where('id', $klijent->id)->update([
                    'datum_montaze' => $datumMontaze,
                    'datum_odustajanja' => $datumOdustajanja,
                    'razlog_odustajanja' => $request->input('razlog_odustajanja'),
                    'id_status_intervencije' => $request->input('status_intervencije'),
                    'datum_intervencije' => $datumIntervencije,
                    'id_razlog_reklamacije' => $request->input('razlog_reklamacije')[0],
                    'datum_reklamacije' => $datumReklamacije,
                    'created_by' => Util::userId(),
                    'helper' => $helper,
                    'on_terrain' => $onTerrain,
                    'dodatni_stb' => $request->input('dodatni_stb')
                ]);
                if ($klijentUpdate){
                    if($klijent->id_klijent_prodaja && $datumMontaze){
                        Klijenti_prodaja::where('id', $klijent->id_klijent_prodaja)->update([
                            'montage_date' => $datumMontaze
                        ]);
                    }
                    if ($status == 1)
                        Klijent::where('id', $klijent->id)->update(['datum_zakazivanja' => $datumZakazivanja]);
                    if ($status == 2)
                        Klijent::where('id', $klijent->id)->update(['datum_odlaganja' => $datumOdlaganja]);
                }
            }

        }

        if ($klijentUpdate){
            Change_history::create([
                'id_user' => Util::userId(),
                'id_klijent' => $klijent->id
            ]);
            if ($request->input('napomena')) {
                Napomene::create([
                    'napomena' => $request->input('napomena'),
                    'id_user' => Util::userId(),
                    'id_klijent' => $klijent->id,
                    'complaint' => $complaint?1:null
                ]);
            }
            return redirect()->route('klijent.show', ['klijent' => $klijent->id])->with('success', __("Data successfully changed"));
        }
        //redirect
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Klijent  $klijent
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findKlijent = Klijent::find($request->input('id_klijent'));

        $imagesModel = new Images();
        $dokumentModel = new Images_documents();
        $images = $imagesModel->slikeZaKlijenta($request->input('id_klijent'));
        $dokumenti = $dokumentModel->dokumentiZaKlijenta($request->input('id_klijent'));

        if ($findKlijent->delete()){
            foreach ($images as $img){
                $file = ltrim($img->image_url,'/');
                if (file_exists($file)){
                    unlink($file);
                }
            }
            foreach ($dokumenti as $doc){
                $file = ltrim($doc->image_url,'/');
                if (file_exists($file)){
                    unlink($file);
                }
            }
            return redirect()->route('klijent.index')->with('success', __("Data successfully deleted"));
        }

        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }

    public function deleteImage(Request $request){
        $findImage = Images::find($request->input('id_image'));
        $idKlijent = $request->input('id_klijent');

        $file = ltrim($findImage->image_url,'/');


        if(file_exists($file)){
            unlink($file);
        }


        if ($findImage->delete()){
            if (array_key_exists('optika', $request->input()))
                return redirect()->route('klijentiOptika.edit', $idKlijent)->with('success', __("Image successfully deleted"));
            elseif (array_key_exists('copper', $request->input()))
                return redirect()->route('klijentiBakar.edit', $idKlijent)->with('success', __("Image successfully deleted"));
            else
                return redirect()->route('klijent.edit', $idKlijent)->with('success', __("Image successfully deleted"));
        }

        return back()->withInput()->with('error', __("Error"));

    }

    public function deleteDoc(Request $request){
        $findImage = Images_documents::find($request->input('id_doc'));
        $idKlijent = $request->input('id_klijent');

        $file = ltrim($findImage->image_url,'/');

        if(file_exists($file)){
            unlink($file);
        }


        if ($findImage->delete()){
            if (array_key_exists('optika', $request->input()))
                return redirect()->route('klijentiOptika.edit', $idKlijent)->with('success', __("Image successfully deleted"));
            elseif (array_key_exists('supernova', $request->input()))
                return redirect()->route('klijentiSupernova.edit', $idKlijent)->with('success', __("Image successfully deleted"));
            elseif (array_key_exists('copper', $request->input()))
                return redirect()->route('klijentiBakar.edit', $idKlijent)->with('success', __("Image successfully deleted"));
            else
                return redirect()->route('klijent.edit', $idKlijent)->with('success', __("Image successfully deleted"));
        }

        return back()->withInput()->with('error', __("Error"));

    }

    public function deleteVideo(Request $request){
        $findVideo = Videos::find($request->input('id_video'));
        $idKlijent = $request->input('id_klijent');

        $file = ltrim($findVideo->video_url,'/');

        if(file_exists($file)){
            unlink($file);
        }


        if ($findVideo->delete()){
            if (array_key_exists('optika', $request->input()))
                return redirect()->route('klijentiOptika.edit', $idKlijent)->with('success', __("Video successfully deleted"));
            elseif (array_key_exists('copper', $request->input()))
                return redirect()->route('klijentiBakar.edit', $idKlijent)->with('success', __("Video successfully deleted"));
            else
                return redirect()->route('klijent.edit', $idKlijent)->with('success', __("Video successfully deleted"));
        }

        return back()->withInput()->with('error', 'Video ne može biti izbrisan');

    }

    public function deleteNapomena(Request $request){
        $findNapomena = Napomene::find($request->input('id_napomena'));
        $idKlijent = $request->input('id_klijent');

        if ($findNapomena->delete()){
            if (array_key_exists('optika', $request->input()))
                return redirect()->route('klijentiOptika.edit', $idKlijent)->with('success', __("Comment successfully deleted"));
            elseif (array_key_exists('prodaja', $request->input()))
                return redirect()->route('klijentiProdaja.edit', $idKlijent)->with('success', __("Comment successfully deleted"));
            elseif (array_key_exists('supernova', $request->input()))
                return redirect()->route('klijentiSupernova.edit', $idKlijent)->with('success', __("Comment successfully deleted"));
            elseif (array_key_exists('copper', $request->input()))
                return redirect()->route('klijentiBakar.edit', $idKlijent)->with('success', __("Comment successfully deleted"));
            else
                return redirect()->route('klijent.edit', $idKlijent)->with('success', __("Comment successfully deleted"));
        }
    }

    public function odlozeni(){
        $klijentModel = new Klijent();
        $klijenti = $klijentModel->odlozeniDth(date('Y-m-d'));
        $klijentiOptika = $klijentModel->odlozeniOptika(date('Y-m-d'));
        $klijentiSupernova = $klijentModel->odlozeniSupernova(date('Y-m-d'));
        $klijentiBakar = $klijentModel->odlozeniBakar(date('Y-m-d'));
        $runeOptics = $klijentModel->odlozeniRune(date('Y-m-d'));

        session(['odlozen' => false]);


        return view('klijenti.odlozeni', [
            'klijenti' => $klijenti,
            'klijentiOptika' => $klijentiOptika,
            'klijentiSupernova' => $klijentiSupernova,
            'klijentiBakar' => $klijentiBakar,
            'runeOptics' => $runeOptics
        ]);
    }

    public function odlozen_destroy(Request $request){
        $tip = $request->input('tip_klijenta');
        $id = $request->input('id_klijent');
        $imagesModel = new Images();
        $dokumentModel = new Images_documents();
        $image = true;
        switch ($tip) {
            case 0:
                $find = Klijent::find($id);
                $images = $imagesModel->slikeZaKlijenta($id);
                $dokumenti = $dokumentModel->dokumentiZaKlijenta($id);
                break;
            case 1:
                $find = Klijenti_optika::find($id);
                $images = $imagesModel->slikeZaOptickogKlijenta($id);
                $dokumenti = $dokumentModel->dokumentiZaOptickogKlijenta($id);
                $videoModel = new Videos();
                $videos = $videoModel->videoZaOptickogKlijenta($request->input('id_klijent'));
                foreach ($videos as $vid){
                    $file = ltrim($vid->video_url,'/');
                    if (file_exists($file)){
                        unlink($file);
                    }
                }
                break;
            case 2:
                $find = Klijenti_supernova::find($id);
                $image = false;
                $dokumenti = $dokumentModel->dokumentiZaSupernovaKlijenta($id);
                break;
            case 3:
                $find = Klijenti_bakar::find($id);
                $images = $imagesModel->slikeZaBakarnogKlijenta($id);
                $dokumenti = $dokumentModel->dokumentiZaBakarnogKlijenta($id);
                break;
        }




        if ($find->delete()){
            if ($image){
                foreach ($images as $img){
                    $file = ltrim($img->image_url,'/');
                    if (file_exists($file)){
                        unlink($file);
                    }
                }
            }
            foreach ($dokumenti as $doc){
                $file = ltrim($doc->image_url,'/');
                if (file_exists($file)){
                    unlink($file);
                }
            }
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }

        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }

    public function old_montages(){
        $klijentModel = new Klijent();
        $klijenti = $klijentModel->old_montages(2);
        $count = $klijentModel->old_montages(2, true);

        return view('klijenti.old_montages', [
            'klijenti' => $klijenti,
            'isSuperAdmin'=>Util::isSuperAdmin(),
            'count' => $count
        ]);
    }

    public function price_recalculation(){
        return view('klijenti.recalculation');
    }

    public function recalculate(Request $request){
        $from = database_date($request->input('from'));
        $to = database_date($request->input('to'));
        $request->validate([
            'from' => 'required',
            'to' => 'required'
        ]);

        $muMod = new Montirani_uredjaji();

        $uredjaji = Uredjaji::all()->where('category_id', '=', 1);
        $klijenti = Klijent::all()->where('datum_montaze', '>=', $from)->where('datum_montaze', '<=', $to);
        $kMod = new Klijent;
        foreach($klijenti as $klijent) {
            foreach ($uredjaji as $uredjaj) {
                $price = Montage_prices::where('device_id', $uredjaj->id)->where('type', 1)->orderBy('id', 'DESC')->first();
                if (isset($price->price)) {
                    $price = $price->price;
                } else {
                    $price = 0;
                }
                $count = $muMod->mountedDevices($uredjaj->id, $klijent->id, 'id_klijent');
                if($uredjaj->id == 2){
                    if($count > 1){
                        $kMod->priceUpdate($klijent->id, ($count-1)*$price);
                    }
                }
                else{
                    $kMod->priceUpdate($klijent->id, ($count)*$price);
                }
            }
        }
        return back()->with('success', __("Prices successfully recalculated"));
    }

}
