<?php

namespace App\Http\Controllers;

use App\Models\Installation_image_types;
use App\Models\Files;
use App\Models\Worker_equipment;
use App\Device_history;
use App\Change_history;
use App\Images;
use App\Images_documents;
use App\Klijenti_bakar;
use App\Klijenti_prodaja;
use App\Montirani_uredjaji;
use App\Napomene;
use App\Oprema;
use App\Oprema_klijent;
use App\Razlozi_vracanja;
use App\Statusi;
use App\Statusi_intervencije;
use App\Tip_montaze;
use App\Traits\Util;
use App\Uredjaji;
use App\Videos;
use App\Vraceni_uredjaji;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Intervention\Image\ImageManager as Img;

class KlijentiBakarController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $isAdmin = Util::isAdmin();
        $cliMod = new Klijenti_bakar();
        if (!$isAdmin)
            $klijenti = $cliMod->klijentiPregled(Util::userId());
        else
            $klijenti = $cliMod->klijentiAdmin();

        session(['search_route' => false]);

        return view('klijentiBakar.index', [
            'klijenti' => $klijenti,
            'isAdmin' => $isAdmin,
            'isSuperAdmin'=>Util::isSuperAdmin()
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $statusi = Statusi::all();
        $statusiIntervencije = Statusi_intervencije::all();
        $monteri = Util::monteri();
        $tipovi_montaze = Tip_montaze::all();
        return view('klijentiBakar.create', [
            'statusi' => $statusi,
            'statusiIntervencije' => $statusiIntervencije,
            'monteri' => $monteri,
            'isAdmin' => Util::isAdmin(),
            'isMonter' => Util::isMonter(),
            'tipoviMontaze' => $tipovi_montaze
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'ime' => 'required',
            'prezime' => 'required'
        ]);

        // if(Util::hasTisDuplicates(1, $request->input("tis_id")))
        //     return back()->withInput()->with('error', 'TIS ID mora da bude jedinstven. Ovaj se već nalazi kod klijenta.');

        $datumOdustajanja = null;
        $datumMontaze = null;
        $datumZakazivanja = null;
        $datumOdlaganja = null;
        $datumIntervencije = null;
        $datumReklamacije = null;
        $datumZahteva = null;
        if ($request->input('datum_montaze'))
            $datumMontaze = date('Y-m-d', strtotime($request->input('datum_montaze')));
        if ($request->input('datum_odustajanja'))
            $datumOdustajanja = date('Y-m-d', strtotime($request->input('datum_odustajanja')));
        if ($request->input('datum_zakazivanja'))
            $datumZakazivanja = date('Y-m-d', strtotime($request->input('datum_zakazivanja')));
        if ($request->input('datum_odlaganja'))
            $datumOdlaganja = date('Y-m-d', strtotime($request->input('datum_odlaganja')));
        if ($request->input('datum_intervencije'))
            $datumIntervencije = date('Y-m-d', strtotime($request->input('datum_intervencije')));
        if ($request->input('datum_reklamacije'))
            $datumReklamacije = date('Y-m-d', strtotime($request->input('datum_reklamacije')));
        if ($request->input('datum_zahteva'))
            $datumZahteva = date('Y-m-d', strtotime($request->input('datum_zahteva')));


        if ($datumZakazivanja && $request->input('vreme'))
            $datumZakazivanja = date('Y-m-d', strtotime($datumZakazivanja)).' '.$request->input('vreme').':'.date('s');
        if ($datumOdlaganja && $request->input('vreme2'))
            $datumOdlaganja = date('Y-m-d', strtotime($datumOdlaganja)).' '.$request->input('vreme2').':'.date('s');

        $points = (float)str_replace(',','.',$request->input('broj_bodova'));
        if($points == 0)
            $points = null;

        $klijent = Klijenti_bakar::create([
            'broj_ugovora' => $request->input('broj_ugovora'),
            'ime' => $request->input('ime'),
            'prezime' => $request->input('prezime'),
            'tel1' => $request->input('tel1'),
            'tel2' => $request->input('tel2'),
            'tel3' => $request->input('tel3'),
            'tis_id' => $request->input('tis_id'),
            'adresa' => $request->input('adresa'),
            'zahtev' => $request->input('zahtev'),
            'zahtev_uneo' => $request->input('zahtev_uneo'),
            'podrucje' => $request->input('podrucje'),
            'br_bodova' => $points,
            'prodavac' => $request->input('prodavac'),
            'datum_montaze' => $datumMontaze,
            'id_tip_montaze' => $request->input('tip_montaze')[0],
            'datum_odustajanja' => $datumOdustajanja,
            'razlog_odustajanja' => $request->input('razlog_odustajanja'),
            'oprema_ugovor' => $request->input('oprema_ugovor'),
            'id_status' => $request->input('status')[0],
            'id_status_intervencije' => $request->input('status_intervencije')[0],
            'datum_intervencije' => $datumIntervencije,
            'datum_zakazivanja' => $datumZakazivanja,
            'datum_odlaganja' => $datumOdlaganja,
            'datum_zahteva' => $datumZahteva,
            'id_user' => $request->input('user')[0],
            'id_user_reklamacije' => $request->input('monter_reklamacije')[0],
            'datum_reklamacije' => $datumReklamacije,
            'created_by'=>Util::userId()
        ]);

        if ($request->input('napomena')) {
            Napomene::create([
                'napomena' => $request->input('napomena'),
                'id_user' => Util::userId(),
                'id_bakar_klijent' => $klijent->id
            ]);
        }

        $klijentModel = new Klijenti_bakar();
        if (!Util::isAdmin()) {
            $klijenti = $klijentModel->klijentiPregled(Util::userId());
        }
        else
            $klijenti = $klijentModel->klijentiAdmin();

        if ($klijent){
            Change_history::create([
                'id_user' => Util::userId(),
                'id_bakar_klijent' => $klijent->id
            ]);
            return redirect()->route('klijentiBakar.index', [
                'klijenti' => $klijenti,
                'isAdmin' => Util::isAdmin(),
                'isSuperAdmin' => Util::isSuperAdmin()
            ])->with('success', __("Data successfully added"));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\klijenti_bakar  $klijenti_bakar
     * @return \Illuminate\Http\Response
     */
    public function show(klijenti_bakar $klijenti_bakar)
    {
        $user = auth()->user();
        $klijentModel = new Klijenti_bakar();
        $klijent = $klijentModel->klijentPodaci($klijenti_bakar->id);
        $imageModel = new Images();
        $images = $imageModel->slikeZaBakarnogKlijenta($klijent->id);
        $imgDocModel = new Images_documents();
        $imgDocs = $imgDocModel->dokumentiZaBakarnogKlijenta($klijent->id);
        $videoModel = new Videos();
        $videos = $videoModel->videoZaBakarnogKlijenta($klijent->id);
        $napModel = new Napomene();
        $napomene = $napModel->napomeneBakar($klijent->id);
        $chModel = new Change_history();
        $history = $chModel->historyBakar($klijent->id);
        $montiraniModel = new Montirani_uredjaji();
        $montirani = $montiraniModel->montiraniBakarList($klijent->id);
        $equipModel = new Oprema_klijent();
        $equipment = $equipModel->equipmentBakar($klijent->id);
        $vraceniModel = new Vraceni_uredjaji();
        $vraceni = $vraceniModel->vraceniList('id_bakar_klijent', $klijent->id);
        $devLogModel = new Device_history();
        $deviceLog = $devLogModel->deviceLog($klijent->id, 'id_bakar_klijent');
        $files = Files::where('copper_client_id', $klijenti_bakar->id)->get();

        return view('klijentiBakar.show', [
            'klijent' => $klijent,
            'id_user' => $user->id,
            'role_id' => $user->role_id,
            'images' => $images,
            'imgDocs' => $imgDocs,
            'napomene'=>$napomene,
            'videos' => $videos,
            'history' => $history,
            'montirani' => $montirani,
            'equipment' => $equipment,
            'vraceni' => $vraceni,
            'deviceLog' => $deviceLog,
            'files' => $files
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\klijenti_bakar  $klijenti_bakar
     * @return \Illuminate\Http\Response
     */
    public function edit(klijenti_bakar $klijenti_bakar)
    {
        if (Util::isAdmin())
            $statusi = Statusi::all();
        else {
            $statusi = DB::table('statusi')->whereIn('id', [4,5])->get();
        }
        $statusiIntervencije = Statusi_intervencije::all();
        $klijent = Klijenti_bakar::find($klijenti_bakar->id);
        $monteri = Util::monteri();

        $imageModel = new Images();
        $images = $imageModel->slikeZaBakarnogKlijenta($klijent->id);
        $imgDocModel = new Images_documents();
        $imgDoc = $imgDocModel->dokumentiZaBakarnogKlijenta($klijent->id);
        $videoModel = new Videos();
        $videos = $videoModel->videoZaBakarnogKlijenta($klijent->id);
        $napModel = new Napomene();
        $napomene = $napModel->napomeneBakar($klijent->id);
        $tipovi_montaze = Tip_montaze::all();
        $uredjaji = Uredjaji::devicesByType(config('app.dev_type_bakar'));
        $montiraniModel = new Montirani_uredjaji();
        $montirani = $montiraniModel->montiraniBakarList($klijent->id);
        $vraceniModel = new Vraceni_uredjaji();
        $vraceni = $vraceniModel->vraceniList('id_bakar_klijent', $klijent->id);
        $equipModel = new Oprema_klijent();
        $equipment = $equipModel->equipmentBakar($klijent->id);
        if(Util::isAdmin()){
            $oprema = Oprema::all();
        }
        else {
            $storageModel = new Worker_equipment();
            $oprema = $storageModel->mont_client_equipment(Util::userId());
        }

        $files = Files::where('copper_client_id', $klijenti_bakar->id)->get();
        $reasonModel = new Razlozi_vracanja();
        $returnReasons = $reasonModel->return_reasons();

        $imageTypes = Installation_image_types::all();

        return view('klijentiBakar.edit', [
            'klijent' => $klijent,
            'statusi'=>$statusi,
            'statusiIntervencije'=>$statusiIntervencije,
            'isAdmin'=>Util::isAdmin(),
            'images'=>$images,
            'imgDocs'=> $imgDoc,
            'napomene'=>$napomene,
            'userId'=>Util::userId(),
            'isSuperAdmin'=>Util::isSuperAdmin(),
            'monteri'=>$monteri,
            'videos'=>$videos,
            'tipovi_montaze' => $tipovi_montaze,
            'oprema' => $oprema,
            'uredjaji' => $uredjaji,
            'montirani' => $montirani,
            'equipment' => $equipment,
            'razlozi' => $returnReasons,
            'vraceni' => $vraceni,
            'files' => $files,
            'imageTypes' => $imageTypes
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\klijenti_bakar  $klijenti_bakar
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, klijenti_bakar $klijenti_bakar)
    {
        require '../vendor/autoload.php';
        $this->validate($request, [
            'ime' => 'required',
            'prezime' => 'required',
            'document' => 'mimes:xlsx,xls,pdf'
        ]);

        // if(Util::hasTisDuplicates(1, $request->input("tis_id")))
        //     return back()->withInput()->with('error', 'TIS ID mora da bude jedinstven. Ovaj se već nalazi kod klijenta.');

        $document = $request->file('document');
        if($document){
            $originalFile = $document->getClientOriginalName();
            $filename = strtotime(date('d.m.Y. H:i:s')).'_'.$originalFile;
            $folder = 'uploads/documents/'.quartal();
            create_folder($folder);
            $document->move($folder, $filename);
            Files::create([
                'file_url' => '/'.$folder.'/'.$filename,
                'copper_client_id' => $klijenti_bakar->id,
                'filename' => $originalFile
            ]);
        }

        $datumOdustajanja = null;
        $datumMontaze = null;
        $datumZakazivanja = null;
        $datumOdlaganja = null;
        $datumIntervencije = null;
        $datumReklamacije = null;
        $datumZahteva = null;
        if ($request->input('datum_montaze'))
            $datumMontaze = date('Y-m-d', strtotime($request->input('datum_montaze')));
        if ($request->input('datum_odustajanja'))
            $datumOdustajanja = date('Y-m-d', strtotime($request->input('datum_odustajanja')));
        if ($request->input('datum_zakazivanja'))
            $datumZakazivanja = date('Y-m-d', strtotime($request->input('datum_zakazivanja')));
        if ($request->input('datum_odlaganja'))
            $datumOdlaganja = date('Y-m-d', strtotime($request->input('datum_odlaganja')));
        if ($request->input('datum_intervencije'))
            $datumIntervencije = date('Y-m-d', strtotime($request->input('datum_intervencije')));
        if ($request->input('datum_reklamacije'))
            $datumReklamacije = date('Y-m-d', strtotime($request->input('datum_reklamacije')));
        if ($request->input('datum_zahteva'))
            $datumZahteva = date('Y-m-d', strtotime($request->input('datum_zahteva')));

        if ($datumZakazivanja && $request->input('vreme'))
            $datumZakazivanja = date('Y-m-d', strtotime($datumZakazivanja)).' '.$request->input('vreme').':'.date('s');
        if ($datumOdlaganja && $request->input('vreme2'))
            $datumOdlaganja = date('Y-m-d', strtotime($datumOdlaganja)).' '.$request->input('vreme2').':'.date('s');


        /*---------------images*---------------*/
        $pictures = $request->file('pictures');
        $img = new Img();
        $folder = 'uploads/images/'.quartal();
        if (!file_exists($folder)){
            mkdir($folder, 0755, true);
        }

        if($pictures){
            $imageType = $request->input('image_type');
            $this->validate($request, [
                'pictures.*' => 'image|mimes:jpeg,png,jpg,gif',
            ]);
            foreach($pictures as $file){
                $extension = $file->getClientOriginalExtension();
                $filename = date('Y-m-d').'-'.rand(1,100).'montaza'.rand(1,100000).'.'.$extension;
                $fileInt = $img->make($file->getRealPath());
                $fileInt->save($folder.'/'.$filename, 50);
                if(in_array($imageType, [5,6])){
                    Images_documents::create([
                        'image_url' => '/'.$folder.'/'.$filename,
                        'id_bakar_klijent' => $klijenti_bakar->id,
                        'type_id' => $imageType
                    ]);
                }
                else {
                    Images::create([
                        'image_url' => '/'.$folder.'/'.$filename,
                        'id_bakar_klijent' => $klijenti_bakar->id,
                        'type_id' => $imageType
                    ]);
                }
            }
        }

        $points = (float)str_replace(',','.',$request->input('broj_bodova'));
        if($points == 0)
            $points = null;

        //protiv zloupotrebe readonly polja
        if (Util::isAdmin()) {
            $klijentUpdate = Klijenti_bakar::where('id', $klijenti_bakar->id)->update([
                'broj_ugovora' => $request->input('broj_ugovora'),
                'ime' => $request->input('ime'),
                'prezime' => $request->input('prezime'),
                'tel1' => $request->input('tel1'),
                'tel2' => $request->input('tel2'),
                'tel3' => $request->input('tel3'),
                'tis_id' => $request->input('tis_id'),
                'adresa' => $request->input('adresa'),
                'zahtev' => $request->input('zahtev'),
                'zahtev_uneo' => $request->input('zahtev_uneo'),
                'podrucje' => $request->input('podrucje'),
                'br_bodova' => $points,
                'prodavac' => $request->input('prodavac'),
                'oprema_ugovor' => $request->input('oprema_ugovor'),
                'datum_montaze' => $datumMontaze,
                'id_tip_montaze' => $request->input('tip_montaze')[0],
                'datum_odustajanja' => $datumOdustajanja,
                'razlog_odustajanja' => $request->input('razlog_odustajanja'),
                'id_status' => $request->input('status')[0],
                'id_status_intervencije' => $request->input('status_intervencije')[0],
                'datum_intervencije' => $datumIntervencije,
                'datum_zahteva' => $datumZahteva,
                'id_user' => $request->input('user')[0],
                'id_user_reklamacije' => $request->input('monter_reklamacije')[0],
                'datum_reklamacije' => $datumReklamacije,
                'updated_by'=>Util::userId()
            ]);
            if ($klijentUpdate){
                if($klijenti_bakar->id_klijent_prodaja && $datumMontaze){
                    Klijenti_prodaja::where('id', $klijenti_bakar->id_klijent_prodaja)->update([
                        'montage_date' => $datumMontaze
                    ]);
                }
                if ($request->input('status')[0] == 1)
                    Klijenti_bakar::where('id', $klijenti_bakar->id)->update(['datum_zakazivanja' => $datumZakazivanja]);
                if ($request->input('status')[0] == 2)
                    Klijenti_bakar::where('id', $klijenti_bakar->id)->update(['datum_odlaganja' => $datumOdlaganja]);
            }
        }
        else {
            $reklamator = $klijenti_bakar->id_user_reklamacije;
            if ($request->input('status')[0] == 5 && !$reklamator){
                $datumMontaze = date('Y-m-d');
                $datumOdustajanja = null;
            }

            if ($request->input('status')[0] == 4 && !$reklamator){
                $datumOdustajanja = date('Y-m-d');
                $datumMontaze = null;
            }
            $izmeniStatus=false;
            if (in_array($request->input('status')[0], [4,5]))
                $izmeniStatus = true;
            //monter nema sve statuse, tako da ukoliko ne unese jedan od dva moguca, ne menja se status u bazi
            if ($izmeniStatus){
                $klijentUpdate = Klijenti_bakar::where('id', $klijenti_bakar->id)->update([
                    'datum_montaze' => $datumMontaze,
                    'id_tip_montaze' => $request->input('tip_montaze')[0],
                    'datum_odustajanja' => $datumOdustajanja,
                    'razlog_odustajanja' => $request->input('razlog_odustajanja'),
                    'id_status' => $request->input('status')[0],
                    'id_status_intervencije' => $request->input('status_intervencije')[0],
                    'datum_intervencije' => $datumIntervencije,
                    'datum_zahteva' => $datumZahteva,
                    'datum_reklamacije' => $datumReklamacije,
                    'updated_by'=>Util::userId()
                ]);
                if ($klijentUpdate){
                    if($klijenti_bakar->id_klijent_prodaja && $datumMontaze){
                        Klijenti_prodaja::where('id', $klijenti_bakar->id_klijent_prodaja)->update([
                            'montage_date' => $datumMontaze
                        ]);
                    }
                    if ($request->input('status')[0] == 1)
                        Klijenti_bakar::where('id', $klijenti_bakar->id)->update(['datum_zakazivanja' => $datumZakazivanja]);
                    if ($request->input('status')[0] == 2)
                        Klijenti_bakar::where('id', $klijenti_bakar->id)->update(['datum_odlaganja' => $datumOdlaganja]);
                }
            }
            else {
                $klijentUpdate = Klijenti_bakar::where('id', $klijenti_bakar->id)->update([
                    'datum_montaze' => $datumMontaze,
                    'id_tip_montaze' => $request->input('tip_montaze')[0],
                    'datum_odustajanja' => $datumOdustajanja,
                    'razlog_odustajanja' => $request->input('razlog_odustajanja'),
                    'id_status_intervencije' => $request->input('status_intervencije')[0],
                    'datum_intervencije' => $datumIntervencije,
                    'datum_zahteva' => $datumZahteva,
                    'datum_reklamacije' => $datumReklamacije,
                    'updated_by'=>Util::userId()
                ]);
                if ($klijentUpdate){
                    if($klijenti_bakar->id_klijent_prodaja && $datumMontaze){
                        Klijenti_prodaja::where('id', $klijenti_bakar->id_klijent_prodaja)->update([
                            'montage_date' => $datumMontaze
                        ]);
                    }
                    if ($request->input('status')[0] == 1)
                        Klijenti_bakar::where('id', $klijenti_bakar->id)->update(['datum_zakazivanja' => $datumZakazivanja]);
                    if ($request->input('status')[0] == 2)
                        Klijenti_bakar::where('id', $klijenti_bakar->id)->update(['datum_odlaganja' => $datumOdlaganja]);
                }
            }

        }
        if ($klijentUpdate){
            Change_history::create([
                'id_user' => Util::userId(),
                'id_bakar_klijent' => $klijenti_bakar->id
            ]);
            if ($request->input('napomena')) {
                Napomene::create([
                    'napomena' => $request->input('napomena'),
                    'id_user' => Util::userId(),
                    'id_bakar_klijent' => $klijenti_bakar->id
                ]);
            }

            return redirect()->route('klijentiBakar.show', ['klijenti_bakar' => $klijenti_bakar->id])->with('success', __("Data successfully changed"));
        }
        //redirect
        return back()->withInput();
    }

    /**
     * @param Request $request
     * @return $this
     */
    public function destroy(Request $request)
    {
        $findKlijent = Klijenti_bakar::find($request->input('id_klijent'));

        $imagesModel = new Images();
        $dokumentModel = new Images_documents();
        $videoModel = new Videos();
        $images = $imagesModel->slikeZaBakarnogKlijenta($request->input('id_klijent'));
        $dokumenti = $dokumentModel->dokumentiZaBakarnogKlijenta($request->input('id_klijent'));
        $videos = $videoModel->videoZaBakarnogKlijenta($request->input('id_klijent'));

        if ($findKlijent->delete()){
            foreach ($images as $img){
                $file = ltrim($img->image_url,'/');
                if (file_exists($file)){
                    unlink($file);
                }
            }
            foreach ($dokumenti as $doc){
                $file = ltrim($doc->image_url,'/');
                if (file_exists($file)){
                    unlink($file);
                }
            }
            foreach ($videos as $vid){
                $file = ltrim($vid->video_url,'/');
                if (file_exists($file)){
                    unlink($file);
                }
            }
            return redirect()->route('klijentiBakar.index')->with('success', __("Data successfully deleted"));
        }

        return back()->withInput()->with('klijentiBakar', __("Data cannot be deleted"));
    }

}
