<?php

namespace App\Http\Controllers;

use App\Models\Files;
use App\Models\Worker_equipment;
use App\Device_history;
use App\Montirani_uredjaji;
use App\Oprema;
use App\Oprema_klijent;
use App\Razlozi_vracanja;
use App\Uredjaji;
use App\Vraceni_uredjaji;
use Illuminate\Support\Facades\DB;
use Intervention\Image\ImageManager as Img;
use App\Change_history;
use App\Images_documents;
use App\Klijenti_prodaja;
use App\Klijenti_supernova;
use App\Napomene;
use App\Statusi;
use App\Traits\Util;
use Illuminate\Http\Request;

class KlijentiSupernovaController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $isAdmin = Util::isAdmin();
        $cliMod = new Klijenti_supernova();
        if (!$isAdmin)
            $klijenti = $cliMod->klijentiPregled(Util::userId());
        else
            $klijenti = $cliMod->klijentiAdmin();

        session(['search_route' => false]);
        return view('klijentiSupernova.index', [
            'klijenti' => $klijenti,
            'search'=>false,
            'isAdmin' => $isAdmin,
            'isSuperAdmin'=>Util::isSuperAdmin()
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $statusi = Statusi::all();
        $monteri = Util::monteri();
        return view('klijentiSupernova.create', [
            'statusi' => $statusi,
            'monteri' => $monteri,
            'isAdmin' => Util::isAdmin(),
            'isMonter' => Util::isMonter(),
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'ime' => 'required',
            'prezime' => 'required'
        ]);

        $datumOdustajanja = null;
        $datumMontaze = null;
        $datumZakazivanja = null;
        $datumOdlaganja = null;
        $datumObilaska = null;
        if ($request->input('datum_montaze'))
            $datumMontaze = date('Y-m-d', strtotime($request->input('datum_montaze')));
        if ($request->input('datum_odustajanja'))
            $datumOdustajanja = date('Y-m-d', strtotime($request->input('datum_odustajanja')));
        if ($request->input('datum_zakazivanja'))
            $datumZakazivanja = date('Y-m-d', strtotime($request->input('datum_zakazivanja')));
        if ($request->input('datum_odlaganja'))
            $datumOdlaganja = date('Y-m-d', strtotime($request->input('datum_odlaganja')));
        if ($request->input('datum_obilaska'))
            $datumObilaska = date('Y-m-d', strtotime($request->input('datum_obilaska')));

        if ($datumZakazivanja && $request->input('vreme'))
            $datumZakazivanja = date('Y-m-d', strtotime($datumZakazivanja)).' '.$request->input('vreme').':'.date('s');
        if ($datumOdlaganja && $request->input('vreme2'))
            $datumOdlaganja = date('Y-m-d', strtotime($datumOdlaganja)).' '.$request->input('vreme2').':'.date('s');

        $points = (float)str_replace(',','.',$request->input('broj_bodova'));
        if($points == 0)
            $points = null;

        $klijentCreate = Klijenti_supernova::create([
            'broj_ugovora' => $request->input('broj_ugovora'),
            'klijent_ime' => $request->input('ime'),
            'klijent_prezime' => $request->input('prezime'),
            'regionalni_centar' => $request->input('regionalni_centar'),
            'ulica' => $request->input('ulica'),
            'kucni_broj' => $request->input('kucni_broj'),
            'tel1' => $request->input('tel1'),
            'tel2' => $request->input('tel2'),
            'br_bodova' => $points,
            'mesec' => $request->input('mesec'),
            'provajder' => $request->input('provajder'),
            'datum_obilaska' => $datumObilaska,
            'email' => $request->input('email'),
            'tip_ugovora' => $request->input('tip_ugovora'),
            'paket' => $request->input('paket'),
            'mesto' => $request->input('mesto'),
            'agent_ime' => $request->input('agent_ime'),
            'agent_prezime' => $request->input('agent_prezime'),
            'agencija' => $request->input('agencija'),
            'datum_montaze' => $datumMontaze,
            'datum_odustajanja' => $datumOdustajanja,
            'id_status' => $request->input('status')[0],
            'datum_zakazivanja' => $datumZakazivanja,
            'datum_odlaganja' => $datumOdlaganja,
            'id_user' => $request->input('user')[0],
            'updated_by'=>Util::userId()
        ]);

        if ($request->input('napomena')) {
            Napomene::create([
                'napomena' => $request->input('napomena'),
                'id_user' => Util::userId(),
                'id_supernova_klijent' => $klijentCreate->id
            ]);
        }

        if ($klijentCreate){
            return redirect()->route('klijentiSupernova.show', [
                'klijenti_supernova' => $klijentCreate
            ])->with('success', __("Data successfully added"));
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Klijenti_supernova  $klijenti_supernova
     * @return \Illuminate\Http\Response
     */
    public function show(Klijenti_supernova $klijenti_supernova)
    {
        $klijentModel = new Klijenti_supernova();
        $klijent = $klijentModel->klijentPodaci($klijenti_supernova->id);
        $imgDocModel = new Images_documents();
        $imgDocs = $imgDocModel->dokumentiZaSupernovaKlijenta($klijenti_supernova->id);
        $napModel = new Napomene();
        $napomene = $napModel->napomeneSupernova($klijenti_supernova->id);
        $chModel = new Change_history();
        $history = $chModel->historySupernova($klijenti_supernova->id);
        $montiraniModel = new Montirani_uredjaji();
        $montirani = $montiraniModel->montiraniSupernovaList($klijent->id);
        $equipModel = new Oprema_klijent();
        $equipment = $equipModel->equipmentSupernova($klijent->id);
        $vraceniModel = new Vraceni_uredjaji();
        $vraceni = $vraceniModel->vraceniList('id_supernova_klijent', $klijent->id);
        $devLogModel = new Device_history();
        $deviceLog = $devLogModel->deviceLog($klijent->id, 'id_supernova_klijent');
        $files = Files::where('supernova_client_id', $klijenti_supernova->id)->get();
        return view('klijentiSupernova.show', [
            'klijent' => $klijent,
            'id_user' => Util::userId(),
            'isAdmin' => Util::isAdmin(),
            'imgDocs' => $imgDocs,
            'napomene'=>$napomene,
            'history' => $history,
            'montirani' => $montirani,
            'equipment' => $equipment,
            'vraceni' => $vraceni,
            'deviceLog' => $deviceLog,
            'files' => $files
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Klijenti_supernova  $klijenti_supernova
     * @return \Illuminate\Http\Response
     */
    public function edit(Klijenti_supernova $klijenti_supernova)
    {
        if (Util::isAdmin())
            $statusi = Statusi::all();
        else {
            $statusi = DB::table('statusi')->whereIn('id', [4,5])->get();
        }
        $monteri = Util::monteri();

        $imgDocModel = new Images_documents();
        $imgDocs = $imgDocModel->dokumentiZaSupernovaKlijenta($klijenti_supernova->id);
        $napModel = new Napomene();
        $napomene = $napModel->napomeneSupernova($klijenti_supernova->id);
        $uredjaji = Uredjaji::devicesByType(config('app.dev_type_supernova'));
        $montiraniModel = new Montirani_uredjaji();
        $montirani = $montiraniModel->montiraniSupernovaList($klijenti_supernova->id);
        $vraceniModel = new Vraceni_uredjaji();
        $vraceni = $vraceniModel->vraceniList('id_supernova_klijent', $klijenti_supernova->id);
        $equipModel = new Oprema_klijent();
        $equipment = $equipModel->equipmentSupernova($klijenti_supernova->id);
        if(Util::isAdmin()){
            $oprema = Oprema::all();
        }
        else {
            $storageModel = new Worker_equipment();
            $oprema = $storageModel->mont_client_equipment(Util::userId());
        }

        $reasonModel = new Razlozi_vracanja();
        $returnReasons = $reasonModel->return_reasons();
        $files = Files::where('supernova_client_id', $klijenti_supernova->id)->get();

        return view('klijentiSupernova.edit', [
            'klijent' => $klijenti_supernova,
            'statusi'=>$statusi,
            'isAdmin'=>Util::isAdmin(),
            'imgDocs'=> $imgDocs,
            'napomene'=>$napomene,
            'userId'=>Util::userId(),
            'isSuperAdmin'=>Util::isSuperAdmin(),
            'monteri'=>$monteri,
            'oprema' => $oprema,
            'uredjaji' => $uredjaji,
            'montirani' => $montirani,
            'equipment' => $equipment,
            'razlozi' => $returnReasons,
            'vraceni' => $vraceni,
            'files' => $files
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Klijenti_supernova  $klijenti_supernova
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Klijenti_supernova $klijenti_supernova)
    {
        require '../vendor/autoload.php';
        $this->validate($request, [
            'ime' => 'required',
            'prezime' => 'required',
            'document' => 'mimes:xlsx,xls,pdf'
        ]);
        $document = $request->file('document');
        if($document){
            $originalFile = $document->getClientOriginalName();
            $filename = strtotime(date('d.m.Y. H:i:s')).'_'.$originalFile;
            $folder = 'uploads/documents/'.quartal();
            create_folder($folder);
            $document->move($folder, $filename);
            Files::create([
                'file_url' => '/'.$folder.'/'.$filename,
                'supernova_client_id' => $klijenti_supernova->id,
                'filename' => $originalFile
            ]);
        }

        $datumOdustajanja = null;
        $datumMontaze = null;
        $datumZakazivanja = null;
        $datumOdlaganja = null;
        $datumObilaska = null;
        if ($request->input('datum_montaze'))
            $datumMontaze = date('Y-m-d', strtotime($request->input('datum_montaze')));
        if ($request->input('datum_odustajanja'))
            $datumOdustajanja = date('Y-m-d', strtotime($request->input('datum_odustajanja')));
        if ($request->input('datum_zakazivanja'))
            $datumZakazivanja = date('Y-m-d', strtotime($request->input('datum_zakazivanja')));
        if ($request->input('datum_odlaganja'))
            $datumOdlaganja = date('Y-m-d', strtotime($request->input('datum_odlaganja')));
        if ($request->input('datum_obilaska'))
            $datumObilaska = date('Y-m-d', strtotime($request->input('datum_obilaska')));

        if ($datumZakazivanja && $request->input('vreme'))
            $datumZakazivanja = date('Y-m-d', strtotime($datumZakazivanja)).' '.$request->input('vreme').':'.date('s');
        if ($datumOdlaganja && $request->input('vreme2'))
            $datumOdlaganja = date('Y-m-d', strtotime($datumOdlaganja)).' '.$request->input('vreme2').':'.date('s');


        /*---------------images*---------------*/
        $pictures = $request->file('pictures');
        $img = new Img();
        $folder = 'uploads/images/'.quartal();
        if (!file_exists($folder)){
            mkdir($folder, 0755, true);
        }

        if($pictures){
            $this->validate($request, [
                'pictures.*' => 'image|mimes:jpeg,png,jpg,gif',
            ]);
            foreach($pictures as $file){
                $extension = $file->getClientOriginalExtension();
                $filename = date('Y-m-d').'-'.rand(1,100).'montaza'.rand(1,100000).'.'.$extension;
                $fileInt = $img->make($file->getRealPath());
                $fileInt->save($folder.'/'.$filename, 50);
                Images_documents::create([
                    'image_url' => '/'.$folder.'/'.$filename,
                    'id_supernova_klijent' => $klijenti_supernova->id
                ]);
            }
        }

        $points = (float)str_replace(',','.',$request->input('broj_bodova'));
        if($points == 0)
            $points = null;
        //protiv zloupotrebe readonly polja
        if (Util::isAdmin()) {
            $klijentUpdate = Klijenti_supernova::where('id', $klijenti_supernova->id)->update([
                'broj_ugovora' => $request->input('broj_ugovora'),
                'klijent_ime' => $request->input('ime'),
                'klijent_prezime' => $request->input('prezime'),
                'regionalni_centar' => $request->input('regionalni_centar'),
                'provajder' => $request->input('provajder'),
                'datum_obilaska' => $datumObilaska,
                'email' => $request->input('email'),
                'tip_ugovora' => $request->input('tip_ugovora'),
                'paket' => $request->input('paket'),
                'mesto' => $request->input('mesto'),
                'ulica' => $request->input('ulica'),
                'kucni_broj' => $request->input('kucni_broj'),
                'tel1' => $request->input('tel1'),
                'tel2' => $request->input('tel2'),
                'br_bodova' => $points,
                'mesec' => $request->input('mesec'),
                'agent_ime' => $request->input('agent_ime'),
                'agent_prezime' => $request->input('agent_prezime'),
                'agencija' => $request->input('agencija'),
                'datum_montaze' => $datumMontaze,
                'datum_odustajanja' => $datumOdustajanja,
                'id_status' => $request->input('status')[0],
                'id_user' => $request->input('user')[0],
                'updated_by'=>Util::userId()
            ]);
            if ($klijentUpdate){
                if($klijenti_supernova->id_klijent_prodaja && $datumMontaze){
                    Klijenti_prodaja::where('id', $klijenti_supernova->id_klijent_prodaja)->update([
                        'montage_date' => $datumMontaze
                    ]);
                }
                if ($request->input('status')[0] == 1)
                    Klijenti_supernova::where('id', $klijenti_supernova->id)->update(['datum_zakazivanja' => $datumZakazivanja]);
                if ($request->input('status')[0] == 2)
                    Klijenti_supernova::where('id', $klijenti_supernova->id)->update(['datum_odlaganja' => $datumOdlaganja]);
            }
        }
        else {
            if ($request->input('status')[0] == 5){
                $datumMontaze = date('Y-m-d');
                $datumOdustajanja = null;
            }

            if ($request->input('status')[0] == 4){
                $datumOdustajanja = date('Y-m-d');
                $datumMontaze = null;
            }
            $izmeniStatus=false;
            if (in_array($request->input('status')[0], [4,5]))
                $izmeniStatus = true;
            //monter nema sve statuse, tako da ukoliko ne unese jedan od dva moguca, ne menja se status u bazi
            if ($izmeniStatus){
                $klijentUpdate = Klijenti_supernova::where('id', $klijenti_supernova->id)->update([
                    'datum_montaze' => $datumMontaze,
                    'datum_odustajanja' => $datumOdustajanja,
                    'id_status' => $request->input('status')[0],
                    'updated_by'=>Util::userId()
                ]);
                if ($klijentUpdate){
                    if($klijenti_supernova->id_klijent_prodaja && $datumMontaze){
                        Klijenti_prodaja::where('id', $klijenti_supernova->id_klijent_prodaja)->update([
                            'montage_date' => $datumMontaze
                        ]);
                    }
                    if ($request->input('status')[0] == 1)
                        Klijenti_supernova::where('id', $klijenti_supernova->id)->update(['datum_zakazivanja' => $datumZakazivanja]);
                    if ($request->input('status')[0] == 2)
                        Klijenti_supernova::where('id', $klijenti_supernova->id)->update(['datum_odlaganja' => $datumOdlaganja]);
                }
            }
            else {
                $klijentUpdate = Klijenti_supernova::where('id', $klijenti_supernova->id)->update([
                    'datum_montaze' => $datumMontaze,
                    'datum_odustajanja' => $datumOdustajanja,
                    'updated_by'=>Util::userId()
                ]);
                if ($klijentUpdate){
                    if($klijenti_supernova->id_klijent_prodaja && $datumMontaze){
                        Klijenti_prodaja::where('id', $klijenti_supernova->id_klijent_prodaja)->update([
                            'montage_date' => $datumMontaze
                        ]);
                    }
                    if ($request->input('status')[0] == 1)
                        Klijenti_supernova::where('id', $klijenti_supernova->id)->update(['datum_zakazivanja' => $datumZakazivanja]);
                    if ($request->input('status')[0] == 2)
                        Klijenti_supernova::where('id', $klijenti_supernova->id)->update(['datum_odlaganja' => $datumOdlaganja]);
                }
            }

        }
        if ($klijentUpdate){
            Change_history::create([
                'id_user' => Util::userId(),
                'id_supernova_klijent' => $klijenti_supernova->id
            ]);
            if ($request->input('napomena')) {
                Napomene::create([
                    'napomena' => $request->input('napomena'),
                    'id_user' => Util::userId(),
                    'id_supernova_klijent' => $klijenti_supernova->id
                ]);
            }
            return redirect()->route('klijentiSupernova.show', ['klijenti_supernova' => $klijenti_supernova->id])->with('success', __("Data successfully changed"));
        }
        //redirect
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Klijenti_supernova  $klijenti_supernova
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findKlijent = Klijenti_supernova::find($request->input('id_klijent'));

        $dokumentModel = new Images_documents();
        $dokumenti = $dokumentModel->dokumentiZaSupernovaKlijenta($request->input('id_klijent'));

        if ($findKlijent->delete()){
            foreach ($dokumenti as $doc){
                $file = ltrim($doc->image_url,'/');
                if (file_exists($file)){
                    unlink($file);
                }
            }
            return redirect()->route('klijentiSupernova.index')->with('success', __("Data successfully deleted"));
        }

        return back()->withInput()->with('klijentiSupernova', __("Data cannot be deleted"));
    }
}
