<?php

namespace App\Http\Controllers;

use App\Models\Storage_logs;
use App\Models\Worker_equipment;
use App\Models\Storage_equipment;
use App\Device_history;
use App\Oprema_otpremnica;
use App\Razlozi_vracanja;
use App\Tip_opreme;
use App\Vraceni_uredjaji;
use Illuminate\Support\Facades\DB;
use App\Magacin;
use App\Magacin_history;
use App\Magz;
use App\Models\Mont_equipment_categories;
use App\Models\Worker_storage_logs;
use App\Montirani_uredjaji;
use App\Oprema;
use App\Oprema_povratnica;
use App\Oprema_revers;
use App\Otpremljena_roba;
use App\Otpremnice;
use App\Povratna_roba;
use App\Povratnice;
use App\Revers_roba;
use App\Stanje_uredjaja;
use App\Statusi_uredjaja;
use App\Traits\Util;
use App\User;
use App\Revers;
use App\Uredjaji;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use Illuminate\Support\Facades\Session;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use Symfony\Component\HttpFoundation\StreamedResponse;

class MagacinController extends Controller
{

    private function magz(){
        $magModel = new Magz();
        if(Util::isSuperAdmin())
            $magz = Magz::all();
        else
            $magz = $magModel->magzForUser(Util::userId());
        return $magz;
    }

    private function linkForgeryCheck($magId){
        $magModel = new Magz();
        $forgery = $magModel->linkForgeryCheck($magId, Util::userId());
        return $forgery;
    }

    private function updateChangeLog($equipmentId, $storageId, $quantity, $packageNumber, $fitterId=null){
        if($quantity != 0){
            Storage_logs::create([
                'mont_equipment_id' => $equipmentId,
                'user_id' => Util::userId(),
                'storage_id' => $storageId,
                'quantity' => $quantity,
                'package_number' => $packageNumber,
                'fitter_id' => $fitterId
            ]);
        }
    }

    /* ----------------------------------------magacin--------------------------------------------*/
    public function index()
    {
        $magacinMod = new Magacin();
        $vrModel = new Vraceni_uredjaji();
        $devicesArray = Uredjaji::all()->where('category_id', '=', 1);
        $devices = array();
        $returned = array();
        $devicesInStorage = array();
        foreach ($devicesArray as $dev){
            $devices[$dev->uredjaj] = $magacinMod->deviceCount(null, $dev->id);
            $returned[$dev->uredjaj] = $vrModel->vraceniCount($dev->id);

            $specDeviceStorage = $magacinMod->specificDeviceAmountInStorage($dev->id);
            $deviceRevers = $magacinMod->reversCount($dev->id);
            $amount = $specDeviceStorage - $deviceRevers;
            if($amount < 0)
                $amount = 0;
            $devicesInStorage[$dev->uredjaj] = $amount;
        }
        if(Util::firmaId() != 1)
            $magacini = Magz::all();
        else
            $magacini = Magz::where('id', '<', 10)->get();

        $magz = array();
        $magzRev = array();
        foreach ($magacini as $mag){
            foreach ($devicesArray as $dev){
                $magz[$mag->naziv][$dev->uredjaj] = $magacinMod->deviceCount($mag->id, $dev->id);
                $count = $magacinMod->deviceCount($mag->id, $dev->id)->count - $magacinMod->reversCount($dev->id, $mag->id);
                $magzRev[$mag->naziv][$dev->uredjaj] = $count;
            }
        }

        return view('magacin.index', [
            'devices' => $devices,
            'magz' => $magz,
            'returned' => $returned,
            'devicesInStorage' => $devicesInStorage,
            'magzRev' => $magzRev
        ]);
    }

    public function magacin_dodavanje(){
        $magMod = new Magacin();
        $robaMagacin = $magMod->robaMagacin(1);
        $devices = Uredjaji::all()->where('category_id', 1);
        return view('magacin.magacin_dodavanje', [
            'roba_magacin' => $robaMagacin,
            'devices' => $devices
        ]);
    }

    public function dodavanje_uredjaja(Request $request){
        $magMod = new Magacin();
        $robaMagacin = $magMod->robaMagacin(1);
        $tip = $request->input('tip');
        $urMod = new Uredjaji();
        $uredjaj = $urMod->uredjajIme($tip);
        $magz = Magz::all();
        return view('magacin.skeniranje', [
            'tip' => $tip,
            'magz' => $magz,
            'uredjaj' => $uredjaj->uredjaj,
            'roba_magacin' => $robaMagacin
        ]);
    }

    public function skeniranje(Request $request){
        $mag = $request->input('mag')[0];
        $srBr = $request->input('serijski_broj');
        $serijskiBroj = serialTrim($srBr);
        $tip = $request->input('tip');
        $qrCode = $request->input('qr_code');
        $magMod = new Magacin();
        $mountMod = new Montirani_uredjaji();
        if($qrCode){
            $QRcodes = explode(' ', $qrCode);
        }

        session(['mag' => $mag]);
        //required mac address for specific devices
        if($tip == 10){
            $request->validate([
                'mak1' => 'required',
                'mak2' => 'required'
            ]);
        }
        //if qr code is scanned it has priority over single serial scan
        if($qrCode){
            foreach($QRcodes as $code){
                $serialMatch = $magMod->serialMatch($code);
                $isMounted = $mountMod->checkIfMounted($code);
                if (!$serialMatch && !$isMounted) {
                    $magacin = Magacin::create([
                        'serijski_broj' => trim($code),
                        'mac1' => $request->input('mak1'),
                        'mac2' => $request->input('mak2'),
                        'id_uredjaj' => $request->input('tip'),
                        'id_mag' => $mag,
                        'id_magacioner' => Util::userId()
                    ]);
                    if ($magacin) {
                        Magacin_history::create([
                            'id_user' => Util::userId(),
                            'serijski_broj' => $code,
                            'device_id' => $request->input('tip')
                        ]);
                    }
                }
            }
            return back()->with('success', __("Goods successfully added to the warehouse"));
        }
        //if there is no qr code, then scan single device
        else {
            $request->validate([
                'serijski_broj' => 'required|string|max:25',
            ]);
            $serialMatch = $magMod->serialMatch($serijskiBroj);
            $isMounted = $mountMod->checkIfMounted($serijskiBroj);
            if (!$serialMatch && !$isMounted) {
                $magacin = Magacin::create([
                    'serijski_broj' => $serijskiBroj,
                    'mac1' => $request->input('mak1'),
                    'mac2' => $request->input('mak2'),
                    'id_uredjaj' => $request->input('tip'),
                    'id_mag' => $mag,
                    'id_magacioner' => Util::userId()
                ]);
                if ($magacin) {
                    Magacin_history::create([
                        'id_user' => Util::userId(),
                        'serijski_broj' => $serijskiBroj,
                        'device_id' => $request->input('tip')
                    ]);
                    return back()->with('success', __("Goods successfully added to the warehouse"));
                }
            } else {
                if($serialMatch)
                    return back()->with('errors', __("This product already exists in the warehouse"));
                elseif($isMounted)
                    return back()->with('errors', __("This product is mounted"));
            }
        }
    }

    public function magacin_history(Request $request){
        $historyModel = new Magacin_history();
        $history = $historyModel->get_magacin_history($request->input('serijski_broj'), database_date($request->input('history_date')));

        return view('magacin.history', [
            'history' => $history,
        ]);
    }

    /* --------------------------------------otpremnice--------------------------------------------*/
    public function otpremnice(){
        $otMod = new Otpremnice();
        $otpremnice = $otMod->otpremnice();
        $monteri = Util::allActiveUsers();

        return view('magacin.otpremnice', [
            'otpremnice' => $otpremnice,
            'magacioner' => Util::username(),
            'monteri' => $monteri
        ]);
    }

    public function otpremnica_dodavanje(Request $request){
        $nazivFirme = $request->input('naziv_firme');
        $robuPreuzeo = $request->input('robu_preuzeo');
        $brLk = $request->input('br_lk');
        $regBr = $request->input('reg_br');
        $idMonter = $request->input('id_monter');
        $jmbg = $request->input('jmbg');
        $tel = $request->input('tel');
        $request->validate([
            'robu_preuzeo' => 'required',
        ]);
        $otprCreate = Otpremnice::create([
            'id_magacioner' => Util::userId(),
            'robu_preuzeo' => $robuPreuzeo,
            'naziv_firme' => $nazivFirme,
            'br_lk' => $brLk,
            'reg_br' => $regBr,
            'id_monter' => $idMonter,
            'jmbg' => $jmbg,
            'tel' => $tel
        ]);

        if ($otprCreate)
            return back()->with('success', __("Delivery note created"));

    }

    public function otpremnica_uredjaj(Request $request){
        $idOtp = $request->input('id_otpremnica');
        $robuPreuzeo = $request->input('robu_preuzeo');
        $otpMod = new Otpremljena_roba();
        $otpremljenaRoba = $otpMod->otpRoba($idOtp);
        $oprema = Oprema::all()->where('is_active', 1);
        $ooModel = new Oprema_otpremnica();
        $opremaOtpremnica = $ooModel->oprema($idOtp);
        $magzModel = new Magz();
        if(Util::isSuperAdmin() || Util::isStorekeeper())
            $magz = Magz::all();
        else
            $magz = $magzModel->magzForUser(Util::userId());
        return view('magacin.otpremnica_skeniranje', [
            'id_otpremnice' => $idOtp,
            'otpremljena_roba' => $otpremljenaRoba,
            'robu_preuzeo' => $robuPreuzeo,
            'oprema' => $oprema,
            'opremaOtpremnica' => $opremaOtpremnica,
            'magz' => $magz
        ]);
    }
    //delivery note reduces products from storage
    public function otpremnica_skeniranje(Request $request){
        $srBr = $request->input('serijski_broj');
        $serijskiBroj = serialTrim($srBr);
        $idOtpremnice = $request->input('id_otpremnice');
        $QRcode = $request->input('qr_code');
        $QRcodes = array();
        if(!$QRcode) {
            $request->validate([
                'serijski_broj' => 'required',
            ]);
        }
        else {
            $QRcodes = explode(' ', $QRcode);
        }
        $magMod = new Magacin();
        $errorMessage = '';
        if($QRcode){
            foreach ($QRcodes as $code){
                $magacin = $magMod->checkSerial($code);
                if($magacin->isEmpty()){
                    $errorMessage .= $code.' '.__("does not exist in stock").'. ';
                }
            }
            if($errorMessage != ''){
                return back()->with('error', $errorMessage);
            }
            foreach($QRcodes as $code){
                $magacin = $magMod->checkSerial($code);
                $findMag = Magacin::find($magacin[0]->id);
                $findMag->delete();
                $tip = $magacin[0]->id_uredjaj;
                $idMag = $magacin[0]->id_mag;
                $otp = Otpremljena_roba::create([
                    'serijski_broj' => $code,
                    'id_uredjaj' => $tip,
                    'id_otpremnice' => $idOtpremnice,
                    'id_mag' => $idMag
                ]);

                Revers_roba::where('serijski_broj', $code)->update(['obsolete' => 1]);
            }
            return back()->with('success', __("Products successfully shipped"));
        }
        else {
            $magacin = $magMod->checkSerial($serijskiBroj);
            if (!$magacin->isEmpty()) {
                $findMag = Magacin::find($magacin[0]->id);
                $findMag->delete();
                $tip = $magacin[0]->id_uredjaj;
                $idMag = $magacin[0]->id_mag;
                $otp = Otpremljena_roba::create([
                    'serijski_broj' => $serijskiBroj,
                    'id_uredjaj' => $tip,
                    'id_otpremnice' => $idOtpremnice,
                    'id_mag' => $idMag
                ]);
                if ($otp) {
                    Revers_roba::where('serijski_broj', $serijskiBroj)->update(['obsolete' => 1]);
                    return back()->with('success', __("Product has been shipped"));
                }
            } else {
                return back()->with('errors', __("Device").' '.__("does not exist in stock"));
            }
        }
    }

    public function otpremnica_search(){
        return view('magacin.otpremnica_search', [
            'monteri' => Util::allWorkers(),
            'magacioneri' => Util::magacioneri()
        ]);
    }

    public function otpremnica_search_result(Request $request){
        $otMod = new Otpremnice();
        $monter = $request->input('monter')[0];
        $magacioner = $request->input('magacioner')[0];
        $serijskiBroj = Util::serialTrim($request->input('serijski_broj'));
        $brojOtpremnice = $request->input('broj_otpremnice');
        $od = $request->input('start');
        $do = $request->input('end');
        if ($od && $do){
            $start = date('Y-m-d', strtotime($od));
            $end = date('Y-m-d', strtotime($do));
        }
        else {
            $start = null;
            $end = null;
        }

        $otpremnice = $otMod->otpremniceSearch($monter, $magacioner, $serijskiBroj, $start, $end, $brojOtpremnice);

        return view('magacin.otpremnica_search_result', [
            'otpremnice' => $otpremnice
        ]);
    }

    /* ---------------------------------------revers--------------------------------------------*/
    public function revers(){
        $monteri = Util::allWorkers();
        $revMod = new Revers();
        $reversi = $revMod->reversi();
        $magz = $this->magz();

        return view('magacin.revers', [
            'monteri' => $monteri,
            'reversi' => $reversi,
            'magacioner' => Util::username(),
            'magz' => $magz
        ]);
    }

    public function revers_dodavanje(Request $request){
        $monter = $request->input('monter')[0];
        $text = $request->input('text');
        $warehouse = $request->input('warehouse');
        $revCreate = Revers::create([
            'id_monter' => $monter,
            'id_magacioner' => Util::userId(),
            'text' => $text,
            'storage_id' => $warehouse
        ]);

        if ($revCreate)
            return back()->with('success', __("Reverse created"));
    }

    public function revers_uredjaj(Request $request){
        $reversId = $request->input('id_revers');
        $monterId = $request->input('id_monter');
        $text = $request->input('text');
        $revMod = new Revers_roba();
        $reversRoba = $revMod->revRoba($reversId);
        if($text){
            $monter = $text;
        }
        else {
            $monter = User::find($monterId);
            if($monter)
                $monter = $monter->ime.' '.$monter->prezime;
        }
        $oprema = Oprema::all()->where('is_active', 1);
        $revOpremaModel = new Oprema_revers();
        $opremaRevers = $revOpremaModel->oprema($reversId);
        return view('magacin.revers_skeniranje', [
            'id_revers' => $reversId,
            'monter' => $monter,
            'revers_roba' => $reversRoba,
            'oprema' => $oprema,
            'opremaRevers' => $opremaRevers,
            'warehouses' => $this->magz()
        ]);
    }

    public function revers_skeniranje(Request $request){
        $srBr = $request->input('serijski_broj');
        $serijskiBroj = serialTrim($srBr);
        $idRevers = $request->input('id_revers');
        $QRcode = $request->input('qr_code');
        $QRcodes = array();
        if(!$QRcode){
            $request->validate([
                'serijski_broj' => 'required',
            ]);
        }
        else {
            $QRcodes = explode(' ', $QRcode);
        }
        $magMod = new Magacin();
        $reversMod = new Revers();
        $error = false;
        $errorMessage = '';
        //errors
        if($QRcode){
            foreach($QRcodes as $code){
                if($code == '') continue;
                //check if it's in storage
                $magacin = $magMod->checkSerial($code);
                //check if it's in revers
                $duplikat = $reversMod->checkSerial($code, $idRevers);
                //check if it's mounted
                $mounted = $reversMod->checkIfMounted($code);
                if($magacin->isEmpty()){
                    $error = true;
                    $errorMessage .= __("Product").' '.__("does not exist in stock");
                    break;
                }
                if($duplikat){
                    $error = true;
                    $errorMessage .= __("This product is already on reverse");
                    break;
                }
                if($mounted){
                    $error = true;
                    $errorMessage .= __("This product is mounted");
                    break;
                }
            }
        }

        if($error)
            return back()->with('error', $errorMessage);

        if($QRcode){
            foreach($QRcodes as $code){
                if($code == '') continue;
                $magacin = $magMod->checkSerial($code);
                $tip = $magacin[0]->id_uredjaj;
                $storageId = $magacin[0]->id_mag;
                $revers = Revers_roba::create([
                    'serijski_broj' => $code,
                    'id_uredjaj' => $tip,
                    'id_revers' => $idRevers,
                    'storage_id' => $storageId
                ]);
                if($revers){
                    Revers_roba::where('id', '!=', $revers->id)->where('serijski_broj', '=', $serijskiBroj)->update(['obsolete' => 1]);
                }
            }
            return back()->with('success', __("Product has been shipped"));
        }
        else {
            //da li se nalazi u magacin
            $magacin = $magMod->checkSerial($serijskiBroj);
            //da li se vec nalazi na revers
            $duplikat = $reversMod->checkSerial($serijskiBroj, $idRevers);
            //check if it's mounted
            $mounted = $reversMod->checkIfMounted($serijskiBroj);
            if(Util::firmaId() == 2){
                $reversNumbers = '';
                $possibleRevers = $reversMod->checkIfOnRevers($serijskiBroj);
                foreach($possibleRevers as $num=>$revers){
                    $reversNumbers .= $revers->id;
                    if(count($possibleRevers) > $num+1){
                        $reversNumbers .= ', ';
                    }
                    else{
                        $reversNumbers .= '.';
                    }
                }

                if (!$possibleRevers->isEmpty())
                    return back()->with('error', __("This product is already on reverse").' '.__("No.").$reversNumbers);
            }
            if ($duplikat)
                return back()->with('error', __("Product is already scanned"));
            if ($mounted)
                return back()->with('error', __("This product is mounted"));
            if (isset($magacin[0])){
                $tip = $magacin[0]->id_uredjaj;
                $storageId = $magacin[0]->id_mag;
                $revers = Revers_roba::create([
                    'serijski_broj' => $serijskiBroj,
                    'id_uredjaj' => $tip,
                    'id_revers' => $idRevers,
                    'storage_id' => $storageId
                ]);
                if ($revers){
                    Revers_roba::where('id', '!=', $revers->id)->where('serijski_broj', '=', $serijskiBroj)->update(['obsolete' => 1]);
                    return back()->with('success', __("Product has been shipped"));
                }
            }
            else {
                return back()->with('error', __("Device").' '.__("does not exist in stock"));
            }
        }
    }

    public function revers_pretraga(){
        return view('magacin.revers_pretraga', [
            'monteri' => Util::allWorkers(),
            'magacioneri' => Util::allWorkers()
        ]);
    }

    public function revers_pretraga_result(Request $request){
        $monter = $request->input('monter')[0];
        $magacioner = $request->input('magacioner')[0];
        $serijskiBroj = serialTrim($request->input('serijski_broj'));
        $brojReversa = $request->input('broj_reversa');
        $od = $request->input('start');
        $do = $request->input('end');
        if ($od && $do){
            $start = date('Y-m-d', strtotime($od));
            $end = date('Y-m-d', strtotime($do));
        }
        else {
            $start = null;
            $end = null;
        }

        $reversModel = new Revers();
        $reversi = $reversModel->reversi_pretraga($monter, $magacioner, $serijskiBroj, $start, $end, $brojReversa);
        return view('magacin.revers_pretraga_result', [
            'reversi' => $reversi
        ]);
    }

    /* ---------------------------------------------- search ------------------------------------------------------ */

    public function magacin_pretraga(){
        $magacioneri = Util::allWorkers();
        $magacini = Magz::all();
        $uredjaji = Uredjaji::all()->where('category_id', '=', 1);
        return view('magacin.magacin_pretraga', [
            'magacioneri' => $magacioneri,
            'uredjaji' => $uredjaji,
            'magacini' => $magacini
        ]);
    }

    public function magacin_pretraga_result(Request $request){
        $magMod = new Magacin();
        $serijskiBroj = Util::serialTrim($request->input('serijski_broj'));
        $uredjaj = $request->input('uredjaj')[0];
        $magacin = $request->input('magacin')[0];
        $magacioner = $request->input('magacioner')[0];
        $start = $request->input('start');
        $end = $request->input('end');
        $notOnReverse = $request->input('not_on_reverse');

        if ($start)
            $start = date('Y-m-d', strtotime($start));
        if ($end)
            $end = date('Y-m-d', strtotime($end));


        $robaMagacin = $magMod->magacinSearch($serijskiBroj, $uredjaj, $magacin, $magacioner, $start, $end, $notOnReverse);
        $serials = Arr::pluck($robaMagacin, 'serijski_broj');
        $serials = json_encode($serials);
        return view('magacin.magacin_pretraga_result', [
            'roba_magacin' => $robaMagacin,
            'serials' => $serials
        ]);
    }

    /* ---------------------------------------------- revers montaza ------------------------------------------------------ */

    public function revers_montaza(){
        return view('magacin.revers_montaza');
    }

    public function revers_montaza_result(Request $request){
        $datum = $request->input('datum_montaze');
        if ($datum)
            $datumMontaze = date('Y-m-d', strtotime($datum));
        else
            $datumMontaze = date('Y-m-d');

        $brojReversa = $request->input('broj_reversa');

        $reversModel = new Revers_roba();
        $montiraniModel = new Montirani_uredjaji();
        $zaRazduzenje = array();
        $reversSerials = $reversModel->reversSerials($brojReversa);
        $montiraniSerials = Arr::pluck($montiraniModel->montiraniSerials($datumMontaze), 'serijski_broj');

        foreach ($reversSerials as $br=>$serial){
            if (!in_array($serial->serijski_broj, $montiraniSerials)){
                $zaRazduzenje[$br]['serijski_broj'] = $serial->serijski_broj;
                $zaRazduzenje[$br]['broj_reversa'] = $serial->broj_reversa;
            }
        }

        return view('magacin.revers_montaza_result', [
            'zaRazduzenje' => $zaRazduzenje
        ]);


    }

    /* ---------------------------------------------- povratnice ------------------------------------------------------ */

    public function povratnice(){
        $povModel = new Povratnice();
        $povratnice = $povModel->povratnice();
        $magz = $this->magz();
        $workers = User::all();

        return view('magacin.povratnice',[
            'povratnice' => $povratnice,
            'magacioner' => Util::username(),
            'magz' => $magz,
            'workers' => $workers
        ]);
    }

    public function povratnica_dodavanje(Request $request){
        $worker = $request->input('worker');
        $robuPreuzeo = $request->input('robu_preuzeo');
        $brLk = $request->input('br_lk');
        $regBr = $request->input('reg_br');
        $storage = $request->input('storage');

        $request->validate([
            'robu_preuzeo' => 'required',
        ]);
        $povCreate = Povratnice::create([
            'id_magacioner' => Util::userId(),
            'robu_preuzeo' => $robuPreuzeo,
            'id_monter' => $worker,
            'br_lk' => $brLk,
            'reg_br' => $regBr,
            'storage_id' => $storage
        ]);

        if ($povCreate)
            return back()->with('success', __("Return note created"));
    }

    public function povratnica_uredjaj(Povratnice $povratnica){
        $povMod = new Povratna_roba();
        $povratnaRoba = $povMod->povRoba($povratnica->id);
        $statusi = Statusi_uredjaja::all();
        $stanja = Stanje_uredjaja::all();
        $uredjaji = Uredjaji::all()->where('category_id', '=', 1);
        if(!$povratnica->id_monter){
            $oprema = Oprema::all()->where('is_active', 1);
        }
        else {
            $storageModel = new Worker_equipment();
            $oprema = $storageModel->mont_client_equipment($povratnica->id_monter);
        }
        $opModel = new Oprema_povratnica();
        $logModel = new Device_history();
        $opremaPov = $opModel->oprema($povratnica->id);

        return view('magacin.povratnica_skeniranje', [
            'id_povratnice' => $povratnica->id,
            'fitterId' => $povratnica->id_monter,
            'povratna_roba' => $povratnaRoba,
            'robu_preuzeo' => $povratnica->robu_preuzeo,
            'statusi' => $statusi,
            'stanja' => $stanja,
            'uredjaji' => $uredjaji,
            'oprema' => $oprema,
            'opremaPov' => $opremaPov,
            'logModel' => $logModel,
            'magz' => Magz::all()
        ]);
    }

    public function povratnica_skeniranje(Request $request){
        $srBr = $request->input('serijski_broj');
        $serijskiBroj = serialTrim($srBr);

        $id_povratnica = $request->input('id_povratnice');
        $idUredjaj = $request->input('uredjaj');
        $statusUredjaja = $request->input('status_uredjaja');
        $stanjeUredjaja = $request->input('stanje_uredjaja');
        $zamena = $request->input('zamena');
        $jmbg = $request->input('jmbg');
        $tisId = $request->input('tis_id');
        if ($zamena)
            $zamena = 1;

        $request->validate(['serijski_broj' => 'required']);
        $montModel = new Montirani_uredjaji();
        $montiran = $montModel->montiran($serijskiBroj);
        $povracaj = false;

        $povModel = new Povratna_roba();
        $povracen = $povModel->checkSerial($serijskiBroj);

        if ($povracen)
            return back()->with('errors', __("This device has already been added to a return note"));
        if ($idUredjaj == 0)
            return back()->with('errors', __("Device field is required"));
        if ($statusUredjaja == 0)
            return back()->with('errors', __("Device state is required"));
        if ($stanjeUredjaja == 0)
            $stanjeUredjaja = null;

        //povratnica brise iz vracenih uredjaja
        if (!$montiran){
            $povracaj = Povratna_roba::create([
                'serijski_broj' => $serijskiBroj,
                'id_povratnica' =>  $id_povratnica,
                'id_uredjaj' => $idUredjaj,
                'id_status_uredjaja' => $statusUredjaja,
                'id_stanje_uredjaja' => $stanjeUredjaja,
                'zamena' => $zamena,
                'jmbg' => $jmbg,
                'tis_id' => $tisId
            ]);

            Revers_roba::where('serijski_broj', $serijskiBroj)->update(['obsolete' => 1]);

            Vraceni_uredjaji::where('serijski_broj', $serijskiBroj)->delete();

            Magacin::where('serijski_broj', $serijskiBroj)->delete();
        }
        if ($povracaj){
            return back()->with('success', __("Device added"));
        }
        else{
            if ($montiran)
                return back()->with('errors', __("Device is mounted"));
            else
                return back()->with('errors', __("Device is in stock"));
        }

    }

    public function dodaj_opremu(Request $request){
        $kol = $request->input('kol');
        $idOprema = $request->input('oprema');
        $param = $request->input('param');
        $storageId = $request->input('storage');
        $packageNumber = $request->input('package_number');
        //oprema za revers
        if ($param == 'revers'){
            $idRevers = $request->input('id_revers');
            if (!$idOprema)
                return back()->with('errors', __("Equipment field is required"));

            Oprema_revers::create([
                'id_oprema' => $idOprema,
                'id_revers' => $idRevers,
                'kol' => $kol
            ]);
        }
        //otpremnica skida stanje sa magacina
        elseif ($param == 'otpremnica'){
            $idOtpremnica = $request->input('id_otpremnica');
            if (!$idOprema)
                return back()->with('errors', __("Equipment field is required"));

            $monter = Otpremnice::find($idOtpremnica)->id_monter;

            $sModel = new Storage_equipment();
            $storageEquipment = $sModel->specific_equipment_mont($storageId, $idOprema, $packageNumber);

            if($storageEquipment)
                $storageAmmount = $storageEquipment->quantity;
            else 
                $storageAmmount = 0;

            if($storageAmmount >= $kol){
                Oprema_otpremnica::create([
                    'id_oprema' => $idOprema,
                    'id_otpremnica' => $idOtpremnica,
                    'kol' => $kol
                ]);
                $wModel = new Worker_equipment();
                $workerEquipment = $wModel->specific_equipment_mont($monter, $idOprema);

                if($workerEquipment){
                    $wModel->equipment_update_mont($monter, $idOprema, $kol, $storageId);
                    Worker_storage_logs::create([
                        'mont_equipment_id' => $idOprema,
                        'worker_id' => $monter,
                        'storage_id' => $storageId,
                        'quantity' => $kol,
                        'package_number' => $packageNumber
                    ]);
                }
                else{
                    Worker_equipment::create([
                        'user_id' => $monter,
                        'equipment_id' => null,
                        'mont_equipment_id' => $idOprema,
                        'quantity' => $kol
                    ]);
                    Worker_storage_logs::create([
                        'mont_equipment_id' => $idOprema,
                        'worker_id' => $monter,
                        'storage_id' => $storageId,
                        'quantity' => $kol,
                        'package_number' => $packageNumber
                    ]);
                }

                $sModel->storage_update_mont($storageId, $idOprema, -$kol, $packageNumber);
                $this->updateChangeLog($idOprema, $storageId, -$kol, $packageNumber, $monter);
            } 
            else {
                return back()->with('error', __("Equipment is out of stock"));
            }   
        }
        //oprema za povratnice
        else {
            $idPovratnica = $request->input('id_povratnice');
            $fitterId = $request->input('fitter_id');
            $idStanjeOpreme = $request->input('stanje_opreme')[0];

            $request->validate([
                'oprema' =>'required',
                'stanje_opreme' =>'required',
                'storage' =>'required',
                'kol' => 'required'
            ]);

            $sModel = new Storage_equipment();
            $specificEquipment = Oprema::where('id', $idOprema)->first();
            if($specificEquipment->package == 1){
                $packageNumber = $sModel->lastNumber();
            }
            else {
                $packageNumber = null;
            }
            $create = Oprema_povratnica::create([
                'id_oprema' => $idOprema,
                'id_povratnica' => $idPovratnica,
                'kol' => $kol,
                'id_stanje_opreme' => $idStanjeOpreme,
                'package_number' => $packageNumber
            ]);

            if($create){
                /* check if specific equipment needs number of packages */
                
                $wModel = new Worker_equipment();
                $wModel->equipment_update_mont($fitterId, $idOprema, -$kol, $storageId);
                Worker_storage_logs::create([
                    'mont_equipment_id' => $idOprema,
                    'worker_id' => $fitterId,
                    'storage_id' => $storageId,
                    'quantity' => -$kol
                ]);
                if($packageNumber){
                    $packageNumber = $sModel->lastNumber();
                    Storage_equipment::create([
                        'mag_id' => $storageId,
                        'mont_equipment_id' => $idOprema,
                        'quantity' => $kol,
                        'package_number' => $packageNumber
                    ]);
                }
                else {
                    $sModel->storage_update_mont($storageId, $idOprema, $kol);
                }
                $this->updateChangeLog($idOprema, $storageId, $kol, $packageNumber, $fitterId);
            }
        }

        return back()->with('success', __("Equipment successfully added"));
    }

    public function povratnica_search(){
        return view('magacin.povratnica_search', [
            'monteri' => Util::allWorkers(),
            'magacioneri' => Util::magacioneri()
        ]);
    }

    public function povratnica_search_result(Request $request){
        $povMod = new Povratnice();
        $monter = $request->input('monter')[0];
        $magacioner = $request->input('magacioner')[0];
        $serijskiBroj = Util::serialTrim($request->input('serijski_broj'));
        $brojPovratnice = $request->input('broj_povratnice');
        $od = $request->input('start');
        $do = $request->input('end');
        if ($od && $do){
            $start = date('Y-m-d', strtotime($od));
            $end = date('Y-m-d', strtotime($do));
        }
        else {
            $start = null;
            $end = null;
        }

        $povratnice = $povMod->povratniceSearch($monter, $magacioner, $serijskiBroj, $start, $end, $brojPovratnice);

        return view('magacin.povratnica_search_result', [
            'povratnice' => $povratnice
        ]);
    }

    /* ---------------------------------------------- destroy ------------------------------------------------------ */

    public function delete_otpremnica(Request $request){
        $findOtpremnica = Otpremnice::find($request->input('id_otpremnica'));
        $robaMod = new Otpremljena_roba();
        $otprRoba = $robaMod->otpRoba($request->input('id_otpremnica'));

        $magMod = new Magacin();
        foreach ($otprRoba as $roba){
            $serialMatch = $magMod->serialMatch($roba->serijski_broj);
            if (!$serialMatch)
            Magacin::create([
                'serijski_broj' => $roba->serijski_broj,
                'id_uredjaj' => $roba->id_uredjaj,
                'id_mag' => $roba->id_mag,
                'id_magacioner' => Util::userId()
            ]);
        }

        if ($findOtpremnica->delete()){
            return back()->with('success', __("Data successfully deleted"));
        }
    }

    public function delete_revers(Request $request){
        $findRevers = Revers::find($request->input('id_revers'));

        if ($findRevers->delete()){
            return back()->with('success', __("Data successfully deleted"));
        }

    }

    public function delete_roba_revers(Request $request){
        $findRoba = Revers_roba::find($request->input('id_roba_revers'));
        if ($findRoba->delete()){
            return back()->with('success', __("Data successfully deleted"));
        }
    }

    public function delete_artikl(Request $request){
        $findArtikl = Magacin::find($request->input('id_artikl'));
        $findRevers = Revers_roba::where('serijski_broj', '=', $findArtikl->serijski_broj)->where('mounted', '=', 0)->get();
        if(!$findRevers->isEmpty())
            return back()->with('error', __("This device is on reverse. For erasure to be possible, the device must be deleted from the reverse."));
        if ($findArtikl->delete()){
            return back()->with('success', __("Data successfully deleted"));
        }
    }

    public function delete_povratnica(Request $request){
        $findPovratnica = Povratnice::find($request->input('id_povratnica'));

        if ($findPovratnica->delete()){
            return back()->with('success', __("Data successfully deleted"));
        }
    }

    public function delete_roba_povratnica(Request $request){
        $findRoba = Povratna_roba::find($request->input('id_roba_povratnica'));
        if ($findRoba->delete()){
            return back()->with('success', __("Data successfully deleted"));
        }
    }

    public function delete_oprema_povratnica(Request $request){
        $idOprema = $request->input('id_oprema');
        $idPovratnica = $request->input('id_oprema_povratnica');
        $idStanjeOpreme = $request->input('id_stanje_opreme');
        $findOprema = Oprema_povratnica::where('id_oprema', $idOprema)->where('id_povratnica', $idPovratnica)->where('id_stanje_opreme', $idStanjeOpreme)->delete();
        if ($findOprema)
            return back()->withInput()->with('success', __("Equipment successfully deleted"));
        else
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }

    public function delete_oprema_revers(Request $request){
        $idOprema = $request->input('id_oprema');
        $idRevers = $request->input('id_oprema_revers');
        $findOprema = Oprema_revers::where('id_oprema', $idOprema)->where('id_revers', $idRevers)->delete();
        if ($findOprema)
            return back()->withInput()->with('success', __("Equipment successfully deleted"));
        else
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }

    public function delete_oprema_otpremnica(Request $request){
        $idOprema = $request->input('id_oprema');
        $idOtpremnica = $request->input('id_oprema_otpremnica');
        $findOprema = Oprema_otpremnica::where('id_oprema', $idOprema)->where('id_otpremnica', $idOtpremnica)->delete();
        if ($findOprema)
            return back()->withInput()->with('success', __("Equipment successfully deleted"));
        else
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }

    public function warehouse_edit(Request $request){
        $param = $request->input('param');
        $firma = $request->input('e_firma');
        $worker = $request->input('e_worker');
        $robuPreuzeo = $request->input('e_robu_preuzeo');
        $brLk = $request->input('e_br_lk');
        $regBr = $request->input('e_reg_br');
        $jmbg = $request->input('e_jmbg');
        $tel = $request->input('e_tel');
        $monter = $request->input('e_monter');

        $request->validate([
            'e_robu_preuzeo' => 'required',
        ]);

        if ($param == 'otpremnica') {
            $id = $request->input('e_otpremnica_id');
            $otpUpdate = Otpremnice::where('id', $id)->update([
                'naziv_firme' => $firma,
                'robu_preuzeo' => $robuPreuzeo,
                'br_lk' => $brLk,
                'reg_br' => $regBr,
                'tel' => $tel,
                'jmbg' => $jmbg,
                'id_monter' => $monter
            ]);

            if ($otpUpdate)
                return back()->withInput()->with('success', __("Data successfully changed"));
            else
                return back()->withInput()->with('errors', __("Error"));
        }
        if ($param == 'povratnica'){
            $id = $request->input('e_povratnica_id');
            $warehouse = $request->input('warehouse');
            $sentToWarehouse = $request->input('ware_sent')?1:null;
            $sendDate = database_date($request->input('ware_send_date'));
            $printed = $request->input('ware_printed');
            $povUpdate = Povratnice::where('id', $id)->update([
                'id_monter' => $worker,
                'robu_preuzeo' => $robuPreuzeo,
                'br_lk' => $brLk,
                'reg_br' => $regBr,
                'storage_id' => $warehouse,
                'sent_to_warehouse' => $sentToWarehouse,
                'send_date' => $sendDate,
                'printed' => $printed
            ]);

            if ($povUpdate)
                return back()->withInput()->with('success', __("Data successfully changed"));
            else
                return back()->withInput()->with('errors', __("Error"));
        }
    }

    public function oprema_razduzenje(){
        $tipOpreme = Tip_opreme::all();
        return view ('equipment.razduzenje', [
            'monteri' => Util::allWorkers(),
            'tipOpreme' => $tipOpreme
        ]);
    }

    /**
     * @param Request $request
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     *
     */
    public function equipment_result(Request $request){
        $od = $request->input('start');
        $do = $request->input('end');
        $monterId = $request->input('monter')[0];
        $tipOpreme = $request->input('tip_opreme');
        if (!$monterId)
            return back()->withInput()->with('errors', __("Choose fitter"));
        $monter = DB::table('users')->select('ime', 'prezime')->where('id', '=', $monterId)->get();
        $monter = $monter[0]->ime.' '.$monter[0]->prezime;
        $request->validate([
            'start' => 'required',
            'end' => 'required'
        ]);
        if ($od && $do){
            $start = date('Y-m-d', strtotime($od));
            $end = date('Y-m-d', strtotime($do));
        }
        else {
            $start = null;
            $end = null;
        }

        $equipModel = new Oprema();
        $mounted = $equipModel->mountedEquipment($monterId, $start, $end);
        $otpremnica = $equipModel->otpremnicaEquipment($monterId, $start, $end);
        $oprema = $equipModel->oprema($tipOpreme);

        $merged = array_merge($mounted, $otpremnica);
        $equipmentFinal = array();
        foreach ($oprema as $br=>$opr){
            foreach($merged as $mrg){
                if ($opr->id == $mrg->id_oprema){
                    $equipmentFinal[$br]['oprema'] = $mrg->oprema;
                    if (isset($mrg->kol_montirano))
                        $equipmentFinal[$br]['kol_montirano'] = $mrg->kol_montirano;
                    if (isset($mrg->kol_otpremnica))
                        $equipmentFinal[$br]['kol_otpremnica'] = $mrg->kol_otpremnica;
                }
            }
        }

        foreach ($equipmentFinal as $key=>&$equip){
            if (!isset($equip['kol_otpremnica']))
                $equip['kol_otpremnica'] = 0;
            if (!isset($equip['kol_montirano']))
                $equip['kol_montirano'] = 0;
        }

        return view('equipment.razduzenje_result', [
            'equipment' => $equipmentFinal,
            'monter' => $monter,
            'date' => $od.' - '.$do
        ]);
    }

    public function vraceni(Request $request){
        $serial = serialTrim($request->input('serijski_broj'));
        $idMonter = $request->input('id_monter');
        $field = $request->input('field');
        $od = $request->input('start');
        $do = $request->input('end');
        $razlog = $request->input('razlog');
        $razlozi = Razlozi_vracanja::all();
        if ($od && $do){
            $start = date('Y-m-d', strtotime($od));
            $end = date('Y-m-d', strtotime($do));
        }
        else {
            $start = null;
            $end = null;
        }
        $monteri = Util::allWorkers();
        $vraceniModel = new Vraceni_uredjaji();
        $vraceni = $vraceniModel->vraceni($serial, $idMonter, $field, $start, $end, $razlog, true);
        $ids = $vraceniModel->vraceni($serial, $idMonter, $field, $start, $end, $razlog, false);
        return view('magacin.vraceni', [
            'vraceni' => $vraceni,
            'monteri' => $monteri,
            'razlozi' => $razlozi,
            'ids' => json_encode(Arr::pluck($ids, 'id'))
        ]);
    }

    public function delete_vraceni(Request $request){
        $id = $request->input('id_vraceni');
        $find = Vraceni_uredjaji::find($id);
        if ($find->delete()){
            return back()->with('success', __("Data successfully deleted"));
        }
        else {
            return back()->with('errors', __("Error"));
        }
    }

    public function return_devices_search(){
        return view ('magacin.return_devices_search');
    }

    public function return_devices_result(Request $request){
        $start = (int)$request->input('start');
        $end = (int)$request->input('end');
        $request->validate([
            'start' => 'required|integer',
            'end' => 'required|integer'
        ]);

        $ids = array();
        for($i=$start; $i<=$end; $i++){
            $ids[] = $i;
        }

        $povMod = new Povratna_roba();
        $returnDevices = $povMod->returnDevices($ids, true);
        return view ('magacin.return_devices_result', ['returnDevices' => $returnDevices, 'ids' => $ids]);
    }

    /*--------------------------------------------equipment storage-------------------------------------------------*/

    public function stockpile(){
        $equipModel = new Storage_equipment();
        $stockpile = array();
        $equipment = $equipModel->available_goods();
        foreach ($equipment as $num=>$eq){
            $stockpile[$num]['equipment'] = $eq->equipment;
            $stockpile[$num]['quantity'] = $eq->sumasumarum;
            $stockpile[$num]['id_category'] = $eq->id_category;
            $stockpile[$num]['category'] = $eq->category;
            $stockpile[$num]['code'] = $eq->code;
            $stockpile[$num]['price'] = $eq->price;
        }

        return view('magacin.stockpile', ['stockpile' => $stockpile]);

    }

    public function package_storage(){
        $packMod = new Storage_equipment();
        $magz = Magz::all();
        $packages = array();
        foreach($magz as $mag){
            $dataCollection = $packMod->packageSum($mag->id);
            if($dataCollection)
                $packages[$mag->naziv] = $dataCollection;
        }
        return view('magacin.package_storage', ['packages' => $packages]);
    }

    public function package_search(){
        $equipmentCategories = Mont_equipment_categories::all();
        return view('magacin.package_search', ['equipmentCategories' => $equipmentCategories]);
    }
    
    public function package_result(Request $request){
        $id = $request->input('equipment');
        $packMod = new Storage_equipment();
        $equipment = Oprema::find($id);
        return view('magacin.package_result', [
            'equipment' => $equipment->naziv, 
            'code' => $equipment->code, 
            'total' => $packMod->montEqupmentSum($id), 
            'packageData' => $packMod->packageList($id)]);
    }

    public function storage(){
        $monters = Util::allActiveUsers();
        $equipModel = new Worker_equipment();
        return view('magacin.storage', ['monters' => $monters, 'equipModel' => $equipModel]);
    }

    public function storages(){
        $magz = $this->magz();
        return view('magacin.storages', ['magz' => $magz]);
    }

    public function equipment_storage(Request $request){
        $id = $request->input('id');
        if($this->linkForgeryCheck($id) && !Util::isAdmin())
            return back()->withInput();
        $equipModel = new Storage_equipment();
        $equipment = $equipModel->equipment_for_storage_mont($id);
        $equipmentCategories = Mont_equipment_categories::all();
        $storage = Magz::find($id);
        $fitters = Util::allWorkers();
        return view('magacin.storage_equipment', [
            'equipment' => $equipment, 
            'storage' => $storage,
            'equipmentCategories' => $equipmentCategories,
            'fitters' => $fitters,
            'lastNumber' => $equipModel->lastNumber(),
            'total' => 0
        ]);
    }

    public function storage_logs(Request $request){
        $storageId = $request->input('storage_id');
        $logsModel = new Storage_logs();
        $logs = $logsModel->logs_mont($storageId);
        return view('magacin.logs', [
            'logs' => $logs
        ]);
    }

    public function storage_logs_search(Request $request){
        $storageId = $request->input('storage_id');
        $receiveNumber = $request->input('s_receive_number');
        $createdAt = database_date($request->input('created_at'));
        $fitter = $request->input('fitter');
        $from = $request->input('s_from');
        $logsModel = new Storage_logs();
        $logs = $logsModel->logs_search_mont($storageId, $receiveNumber, $from, $fitter, $createdAt);
        session(['equipment_logs' => json_encode($logs)]);
        return view('constructionStorage.logs', ['logs' => $logs]);
    }

    public function worker_storage(Request $request){
        $id = $request->input('id');
        $equipModel = new Worker_equipment();
        $equipment = $equipModel->equipment_for_user_mont($id);
        $storages = $this->magz();
        $equipmentList = Oprema::all()->where('is_active', 1);
        $user = User::find($id);
        return view('magacin.worker', [
            'equipment' => $equipment, 
            'user' => $user, 
            'storages' => $storages,
            'equipmentList' => $equipmentList,
            'total' => 0, 
            'isSuperAdmin' => Util::isSuperAdmin()
            
        ]);
    }


    public function return_device_update(Request $request){
        $id = $request->input('ware_id');
        $tisId = $request->input('ware_tis');
        $status = $request->input('ware_status_uredjaja');
        $stanje = $request->input('ware_stanje_uredjaja');
        $uredjaj = $request->input('ware_uredjaj');
        $jmbg = $request->input('ware_jmbg');
        $serial = $request->input('ware_serijski_broj');
        $sentToWarehouse = $request->input('ware_sent');
        $sendDate = $request->input('ware_send_date');
        $printed = $request->input('ware_printed');

        Povratna_roba::find($id)->update([
            'id_uredjaj' => $uredjaj,
            'id_status_uredjaja' => $status,
            'id_stanje_uredjaja' => $stanje,
            'serijski_broj' => $serial,
            'jmbg' => $jmbg,
            'tis_id' => $tisId,
            'sent_to_warehouse' => $sentToWarehouse,
            'send_date' => $sendDate,
            'printed' => $printed
        ]);
        $povModel = new Povratna_roba();
        $povracen = $povModel->checkSerial($serial);
        if($povracen)
            Vraceni_uredjaji::where('serijski_broj', $serial)->delete();

        return back()->withInput()->with('success', __("Data successfully changed"));

    }

    public function delete_device(Request $request)
    {
        $deviceId = $request->input('device_id');
        $delete = Otpremljena_roba::where('id', $deviceId)->delete();
        if ($delete)
            return back()->withInput()->with('success', __("Device successfully deleted"));
        else
            return back()->withInput()->with('error', __("Error"));
    }

    public function device_serials_session(Request $request){
        $serials = $request->input('serials');
        session(['device_serials' => $serials]);
        return back()->with('success', __("Devices successfully added to session"));
    }

    public function add_devices_to_document(Request $request){
        $document = $request->input('m_document');
        $number = $request->input('m_number');
        $serials = json_decode(session('device_serials'));

        if($serials){
            switch($document){
                case 'otpremnica' :
                    $hasDeliveryNote = Otpremnice::find($number);
                    if (!$hasDeliveryNote)
                        return back()->with('error', __('This delivery note number does not exist'));
                    foreach($serials as $serial){
                        $device = Magacin::where('serijski_broj', $serial)->get();
                        if($device->isEmpty())
                            continue;
                        else
                            $device = $device[0];
                        $create = Otpremljena_roba::create([
                            'serijski_broj' => $device->serijski_broj,
                            'id_otpremnice' => $number,
                            'id_uredjaj' => $device->id_uredjaj,
                            'id_mag' => $device->id_mag
                        ]);
                        if($create)
                            Magacin::where('serijski_broj', $serial)->delete();
                    }
                    Session::forget('device_serials');
                    return back()->with('success', __("Devices successfully added to delivery note")." $number.");
                break;
                case 'povratnica' :
                    $hasReturnNote = Povratnice::find($number);
                    if (!$hasReturnNote)
                        return back()->with('error', __("This return note number does not exist"));
                    foreach($serials as $serial){
                        $device = Magacin::where('serijski_broj', $serial)->get();
                        if($device->isEmpty())
                            continue;
                        else
                            $device = $device[0];
                        $create = Povratna_roba::create([
                            'serijski_broj' => $device->serijski_broj,
                            'id_povratnica' => $number,
                            'id_uredjaj' => $device->id_uredjaj
                        ]);
                        if($create) {
                            Vraceni_uredjaji::where('serijski_broj', $serial)->delete();
                            Magacin::where('serijski_broj', $serial)->delete();
                        }
                    }
                    Session::forget('device_serials');
                    return back()->with('success', __("Devices successfully added to return note")." $number.");
                    break;
                case 'revers' :
                    $revers = Revers::find($number);
                    if (!$revers)
                        return back()->with('error', __("This reverse number does not exist"));
                    foreach($serials as $serial){
                        $device = Magacin::where('serijski_broj', $serial)->get();
                        if($device->isEmpty())
                            continue;
                        else
                            $device = $device[0];
                        Revers_roba::create([
                            'serijski_broj' => $device->serijski_broj,
                            'id_revers' => $number,
                            'id_uredjaj' => $device->id_uredjaj,
                            'storage_id' => $revers->storage_id
                        ]);
                    }
                    Session::forget('device_serials');
                    return back()->with('success', __("Devices successfully added to reverse")." $number.");
                    break;
            }
        }
        else {
            return back()->withInput()->with('error', __("Session is empty"));
        }
    }

    public function magacin_group_entry(){
        $serials = json_decode(session('device_serials'));
        $documents = ['otpremnica', 'povratnica', 'revers'];
        return view('magacin.group_entry', ['serials' => $serials, 'documents' => $documents]);
    }

    public function clear_device_session(){
        Session::forget('device_serials');
        return back()->with('success', __("Session is empty"));
    }

    public function fitter_stock(){
        $fitters = Util::allWorkers();
        $storageModel = new Magacin();
        $deviceTypes = Uredjaji::all()->where('category_id', '=', 1);
        $deviceTypes = Arr::pluck($deviceTypes, 'id');
        return view('magacin.fitter_stock', ['fitters' => $fitters, 'storageModel' => $storageModel, 'deviceTypes' => $deviceTypes]);
    }

    public function revers_change_status(Request $request){
        $id = $request->input('ro_id');
        $serial = $request->input('ro_serial');
        $obsolete = $request->input('status');
        $storageId = $request->input('storage');
        Revers_roba::where('id', $id)->update([
            'obsolete' => $obsolete
        ]);
        if($storageId){
            Revers_roba::where('id', $id)->update([
                'storage_id' => $storageId
            ]);
            Magacin::where('serijski_broj', $serial)->update([
                'id_mag' => $storageId
            ]);
        }
        return back()->with('success', __("Data successfully changed"));
    }

    public function worker_device_search(){
        $fitters = Util::allWorkers();
        return view('magacin.worker_device_search', ['fitters' => $fitters]);
    }

    public function worker_devices(Request $request){
        $fitterId = $request->input("fitter");
        $fitter = User::find($fitterId);
        $rMod = new Revers_roba();
        $workerDevices = $rMod->workerDevices($fitterId);
        return view('magacin.worker_devices', ['workerDevices' => $workerDevices, 'fitter' => $fitter->ime.' '.$fitter->prezime]);
    }

    public function irregularities(){
         return view('magacin.irregularities');
    }

    public function find_irregularities(){
        $revers = Revers_roba::all()->where('obsolete', '=', 0)->where('mounted', '=', 0);
        $irregularities = array();
        foreach($revers as $rev){
            $findSerials = Magacin::where('serijski_broj', $rev->serijski_broj)->get();
            if($findSerials->isEmpty())
                $irregularities[] = $rev->serijski_broj;
        }
        return view('magacin.irregularities', ['irregularities' => $irregularities]);
    }

    public function serial_checker(){
        return view('magacin.check');
    }

    public function check_serials(Request $request){
        $file = $request->file('serials');
        $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();
        require '../vendor/autoload.php';

        if ($file){
            $allowedExtensions = array('xls', 'xlsx');
            $extension = $file->getClientOriginalExtension();
            $result = array();
            if (in_array($extension, $allowedExtensions)){
                $spreadsheet = $reader->load($file);
                $sheetData = $spreadsheet->getActiveSheet()->toArray();
                $mMod = new Montirani_uredjaji();
                foreach($sheetData as $key=>$data){
                    $serial = $data[0];
                    $onRevers = Revers_roba::where('serijski_broj', $serial)->get();
                    if($onRevers->isEmpty())
                        $revers = false;
                    else
                        $revers = true;
                    $onOtpr = Otpremljena_roba::where('serijski_broj', $serial)->get();
                    if($onOtpr->isEmpty())
                        $otpremnica = false;
                    else
                        $otpremnica = true;

                    $onReturnNote = Povratna_roba::where('serijski_broj', $serial)->get();
                    if($onReturnNote->isEmpty())
                        $povratnica = false;
                    else
                        $povratnica = true;
                    
                    $result[$key]['serial'] = $serial;
                    $result[$key]['mounted'] = $mMod->montiran($serial);
                    $result[$key]['revers'] = $revers;
                    $result[$key]['otpremnica'] = $otpremnica;
                    $result[$key]['povratnica'] = $povratnica;
                }
            }
        }

        
        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();

        $sheet->getColumnDimension('A')->setAutoSize(true);
        $sheet->getColumnDimension('B')->setAutoSize(true);
        $sheet->getColumnDimension('C')->setAutoSize(true);
        $sheet->getColumnDimension('D')->setAutoSize(true);
        $sheet->getColumnDimension('E')->setAutoSize(true);

        $sheet->setCellValue('A1', __("Serial number"));
        $sheet->setCellValue('B1', __("Mounted"));
        $sheet->setCellValue('C1', __("Reverse"));
        $sheet->setCellValue('D1', __("Delivery note"));
        $sheet->setCellValue('E1', __("Return note"));

        foreach($result as $num=>$data){
            $sheet->setCellValue('A'.($num+2), $data["serial"]);
            $sheet->setCellValue('B'.($num+2), $data["mounted"]);
            $sheet->setCellValue('C'.($num+2), $data["revers"]);
            $sheet->setCellValue('D'.($num+2), $data["otpremnica"]);
            $sheet->setCellValue('E'.($num+2), $data["povratnica"]);
        }

        $streamedResponse = new StreamedResponse();
        $streamedResponse->setCallback(function() use ($spreadsheet){
            $writter = new Xlsx($spreadsheet);
            $writter->save('php://output');
        });

        $streamedResponse->setStatusCode(200);
        $streamedResponse->headers->set('Content-Type', 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        $streamedResponse->headers->set('Content-Disposition', 'attachment; filename="serials.xlsx"');
        return $streamedResponse->send();

    }
}
