<?php

namespace App\Http\Controllers;

use App\Models\Equipment_packages;
use App\Models\Mont_equipment_categories;
use App\Oprema;
use App\Tip_opreme;
use App\Traits\Util;
use Illuminate\Http\Request;

class OpremaController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $oprModel = new Oprema();
        $oprema = $oprModel->opremaIndex();
        return view('oprema.index', [
            'oprema' => $oprema,
            'admin' => Util::isAdmin()
            ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $tipOpreme = Tip_opreme::all();
        $categories = Mont_equipment_categories::all();
        $packages = Equipment_packages::all();
        return view('oprema.create', ['tipOpreme' => $tipOpreme, 'categories' => $categories, 'packages' => $packages]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $naziv = $request->input('oprema');
        $tipOpreme = $request->input('tip_opreme');
        $request->merge([
            'price' => str_replace(',', '.', $request->input('price'))
        ]);
        $request->validate(['oprema' => 'required', 'price' => 'numeric']);
        $category = $request->input('category');
        $code = $request->input('code');
        $package = $request->input('package');
        $price = $request->input('price');
        Oprema::create([
            'naziv' => $naziv,
            'id_tip_opreme' => $tipOpreme,
            'id_category' => $category,
            'code' => $code,
            'package' => $package,
            'price' => $price
        ]);
        $oprModel = new Oprema();
        $oprema = $oprModel->opremaIndex();
        return view('oprema.index', ['oprema' => $oprema, 'admin' => Util::isAdmin()]);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Oprema  $oprema
     * @return \Illuminate\Http\Response
     */
    public function show(Oprema $oprema)
    {
        $oprModel = new Oprema();
        $oprema = $oprModel->opremaShow($oprema->id);
        return view('oprema.show', ['oprema' => $oprema]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Oprema  $oprema
     * @return \Illuminate\Http\Response
     */
    public function edit(Oprema $oprema)
    {
        $opremaArr = Oprema::find($oprema->id);
        $tipOpreme = Tip_opreme::all();
        $categories = Mont_equipment_categories::all();
        $packages = Equipment_packages::all();

        return view('oprema.edit', ['oprema' => $opremaArr, 'tipOpreme' => $tipOpreme, 'categories' => $categories, 'packages' => $packages]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Oprema  $oprema
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Oprema $oprema)
    {
        $request->merge([
            'price' => str_replace(',', '.', $request->input('price'))
        ]);
        $request->validate([
            'oprema' => 'required',
            'price' => 'numeric'
        ]);
        $tipOpreme = $request->input('tip_opreme');
        $opremaUpdate = Oprema::where('id', $oprema->id)->update([
            'naziv' => trim($request->input('oprema')),
            'id_tip_opreme' => $tipOpreme,
            'is_active' => $request->input('is_active'),
            'id_category' => $request->input('category'),
            'code' => $request->input('code'),
            'package' => $request->input('package'),
            'price' => $request->input('price')
        ]);

        if ($opremaUpdate){
            return redirect()->route('oprema.show', ['oprema' => $oprema->id])->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Oprema  $oprema
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findOprema = Oprema::find($request->input('id_oprema'));

        try{
            $findOprema->delete();
            return back()->withInput()->with('success', __("Equipment successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }

    public function filter(){
        $equipment = Oprema::all()->where('is_active', '=', 1);
        return view('oprema.filter', ['equipment' => $equipment]);
    }

    public function filter_result(Request $request){
        $id = $request->input('equipment');
        $data = Oprema::find($id);
        return view('oprema.filterResult', ['data' => $data]);
    }
}
