<?php

namespace App\Http\Controllers;

use App\Razlozi_intervencije;
use App\Traits\Util;
use Illuminate\Http\Request;

class RazlogIntervencijeController extends Controller
{

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $razlogModel = new Razlozi_intervencije();
        $razlozi = $razlogModel->razlozi();

        return view('razlog_intervencije.index', ['razlozi' => $razlozi, 'admin' => Util::isSuperAdmin()]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('razlog_intervencije.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
           'razlog' => 'required'
        ]);

        $razlog = Razlozi_intervencije::create([
           'razlog' => trim($request->input('razlog')),
            'default' => 0
        ]);

        $razlogModel = new Razlozi_intervencije();
        $razlozi = $razlogModel->razlozi();
        if ($razlog){
            return view('razlog_intervencije.index', ['razlozi' => $razlozi, 'admin' => Util::isSuperAdmin()]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Razlozi_intervencije  $razlog_intervencije
     * @return \Illuminate\Http\Response
     */
    public function show(Razlozi_intervencije $razlog_intervencije)
    {
        $razlog = Razlozi_intervencije::find($razlog_intervencije->id);
        return view('razlog_intervencije.show', ['razlog'=>$razlog]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Razlozi_intervencije  $razlog_intervencije
     * @return \Illuminate\Http\Response
     */
    public function edit(Razlozi_intervencije $razlog_intervencije)
    {
        $razlog = Razlozi_intervencije::find($razlog_intervencije->id);
        return view('razlog_intervencije.edit', ['razlog' => $razlog]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Razlozi_intervencije  $razlozi_intervencije
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Razlozi_intervencije $razlog_intervencije)
    {
        $request->validate([
            'razlog' => 'required'
        ]);

        $razlogUpdate = Razlozi_intervencije::where('id', $razlog_intervencije->id)->update([
            'razlog' => trim($request->input('razlog')),
            'default' => 0
        ]);

        if ($razlogUpdate){
            return redirect()->route('razlog_intervencije.show', ['razlog_intervencije' => $razlog_intervencije->id])->with('success', __("Data successfully changed"));
        }

        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Razlozi_intervencije  $razlozi_intervencije
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findRazlog = Razlozi_intervencije::find($request->input('id_razlog'));

        try{
            $findRazlog->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
