<?php

namespace App\Http\Controllers;

use App\Device_history;
use App\Models\Areas;
use App\Models\Clusters;
use App\Models\Fobos_rune;
use App\Models\Material_rune;
use App\Models\Materials;
use App\Models\Origin;
use App\Models\Providers;
use App\Models\Rune_comments;
use App\Models\Rune_images;
use App\Models\Rune_logs;
use App\Models\Rune_optics;
use App\Models\User_cluster;
use App\Models\Worker_equipment;
use App\Models\Worker_materials;
use App\Montirani_uredjaji;
use App\Oprema;
use App\Oprema_klijent;
use App\Pomocnici;
use App\Razlozi_vracanja;
use App\Rune_files;
use App\Statusi;
use App\Statusi_intervencije;
use App\Tip_montaze;
use App\Traits\Util;
use App\Uredjaji;
use App\Vraceni_uredjaji;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use Intervention\Image\ImageManager as Img;
use PhpOffice\PhpSpreadsheet\Spreadsheet;
use PhpOffice\PhpSpreadsheet\Writer\Xlsx;
use Symfony\Component\HttpFoundation\StreamedResponse;

class RuneOpticsController extends Controller
{
    private function linkCheck($id){
        $rMod = new Rune_optics();
        if(Util::isMonter()){
            return $rMod->linkCheck($id,Util::userId(),false, false,Util::userPlace(),Util::providers());
        }
        elseif(Util::isProjectManager()){
            return $rMod->linkCheck($id,false,Util::userId(),false,Util::userPlace(),Util::providers());
        }
        elseif(Util::isConstructionManager()){
            return $rMod->linkCheck($id,false,false,Util::userId(),null,null);
        }
        else{
            return true;
        }
    }

    public function index()
    {
        $cliMod = new Rune_optics();
        if (Util::isSuperAdmin()){
            $clients = $cliMod->indexAdmin();
        }
        elseif(Util::isAdmin()){
            $clients = $cliMod->index(null, null, null, Util::userPlace(), Util::providers());
        }
        elseif(Util::isProjectAdmin() || Util::isProjectManager()){
            $clients = $cliMod->index(null, Util::userId(), null, Util::userPlace(), Util::providers());
        }
        elseif(Util::isConstructionManager()){
            $clients = $cliMod->index(null, null, Util::userId());
        }
        elseif(Util::isProdavac()){
            $clients = $cliMod->index(null, null, null, null, null, Util::userId());
        }
        else{
            $clients = $cliMod->index(Util::userId(), null, Util::userPlace(), Util::providers());
        }

        session(['search_route' => false]);
        return view('runeOptics.index', [
            'clients' => $clients,
            'search'=>false,
            'isAdmin' => Util::isSuperAdmin(),
            'isSuperAdmin'=>Util::isSuperAdmin()
        ]);
    }

    public function create()
    {
        $statusi = Statusi::all();
        $statusiIntervencije = Statusi_intervencije::all();
        $monteri = Util::monteri();
        $tipovi_montaze = Tip_montaze::all();
        $origin = Origin::all();
        $projectManagers = Util::projectManagers();
        $teamLeaders = Util::teamLeaders();
        $providers = Providers::all();
        $areas = Areas::all();
        return view('runeOptics.create', [
            'statusi' => $statusi,
            'statusiIntervencije' => $statusiIntervencije,
            'monteri' => $monteri,
            'isAdmin' => Util::isAdmin(),
            'isMonter' => Util::isMonter(),
            'tipoviMontaze' => $tipovi_montaze,
            'origin' => $origin,
            'projectManagers' => $projectManagers,
            'teamLeaders' => $teamLeaders,
            'providers' => $providers,
            'areas' => $areas,
            'constructionManagers' => Util::constructionManagers(),
            'clusters' => Clusters::all()
        ]);
    }

    public function store(Request $request)
    {
        if(Util::isSalesManager()){
            return back()->with('error', __('Changing data is not allowed for your role'));
        }
        $request->validate([
            'cluster' => 'required',
            'x_coordinate' => 'nullable|numeric',
            'y_coordinate' => 'nullable|numeric',
            'extra_stb' => 'nullable|numeric',
            'pan' => 'required'
        ]);

        $datumZakazivanja = null;
        $datumOdlaganja = null;
        if ($request->input('datum_zakazivanja'))
            $datumZakazivanja = date('Y-m-d', strtotime($request->input('datum_zakazivanja')));
        if ($request->input('datum_odlaganja'))
            $datumOdlaganja = date('Y-m-d', strtotime($request->input('datum_odlaganja')));

        if ($datumZakazivanja && $request->input('vreme'))
            $datumZakazivanja = date('Y-m-d', strtotime($datumZakazivanja)).' '.$request->input('vreme').':'.date('s');
        if ($datumOdlaganja && $request->input('vreme2'))
            $datumOdlaganja = date('Y-m-d', strtotime($datumOdlaganja)).' '.$request->input('vreme2').':'.date('s');

        $points = (float)str_replace(',','.',$request->input('points'));
        if($points == 0)
            $points = null;

        if(Util::isProjectManager()){
            $projectManager = Util::userId();
        }
        else{
            $projectManager = $request->input('project_manager');
        }
        if(Util::isConstructionManager()){
            $constructionManager = Util::userId();
        }
        else{
            $constructionManager = $request->input('construction_manager');
        }

        //construction manager automatization for cluster
        if(env('SERVER_ID') == 3 && !$constructionManager){
            $ucMod = new User_cluster();
            $cm = $ucMod->defaultUser($request->input('cluster'));
            $constructionManager = $cm;
        }


        $client = Rune_optics::create([
            'cluster' => $request->input('cluster'),
            'street' => $request->input('street'),
            'pan' => $request->input('pan'),
            'home_no' => $request->input('home_no'),
            'enterance' => $request->input('enterance'),
            'floor' => $request->input('floor'),
            'apartment' => $request->input('apartment'),
            'tel1' => $request->input('tel1'),
            'tel2' => $request->input('tel2'),
            'tel3' => $request->input('tel3'),
            'network_group' => $request->input('network_group'),
            'eta' => $request->input('eta'),
            'fobos_id' => $request->input('fobos_id'),
            'county' => $request->input('county'),
            'city' => $request->input('city'),
            'settlement' => $request->input('settlement'),
            'household' => $request->input('household'),
            'households' => $request->input('households'),
            'state' => $request->input('state'),
            'state_services' => $request->input('state_services'),
            'email' => $request->input('email'),
            'packet' => $request->input('packet'),
            'recomended_tariff' => $request->input('recomended_tariff'),
            'first_offer' => $request->input('first_offer'),
            'operator' => $request->input('operator'),
            'month' => $request->input('month'),
            'year' => $request->input('year'),
            'status' => $request->input('status'),
            'team_leader' => $request->input('team_leader'),
            'withdrawal_date' => database_date($request->input('withdrawal_date')),
            'delay_date' => database_date($request->input('delay_date')),
            'contract_expire_date' => database_date($request->input('contract_expire_date')),
            'withdrawal_reason' => $request->input('withdrawal_reason'),
            'created_by' => Util::userId(),
            'updated_by' => Util::userId(),
            'project_manager' => $projectManager,
            'construction_manager' => $constructionManager,
            'points' => $points,
            'cable' => $request->input('cable'),
            'thread' => $request->input('thread'),
            'tube' => $request->input('tube'),
            'case' => $request->input('case'),
            'x_coordinate' => $request->input('x_coordinate'),
            'y_coordinate' => $request->input('y_coordinate'),
            'name' => $request->input('name'),
            'surname' => $request->input('surname'),
            'tis_id' => $request->input('tis_id'),
            'address' => $request->input('address'),
            'claim' => $request->input('claim'),
            'claim_created_by' => $request->input('claim_created_by'),
            'seller' => $request->input('seller'),
            'area' => $request->input('area'),
            'montage_date' => database_date($request->input('montage_date')),
            'montage_type' => $request->input('montage_type'),
            'intervention_status' => $request->input('intervention_status'),
            'intervention_date' => database_date($request->input('intervention_date')),
            'origin' => $request->input('origin'),
            'appointment_date' => $datumZakazivanja,
            'date_of_disposal' => $datumOdlaganja,
            'claim_date' => database_date($request->input('claim_date')),
            'user' => $request->input('user'),
            'reclamation_user' => $request->input('reclamation_user'),
            'reclamation_date' => database_date($request->input('reclamation_date')),
            'extra_stb' => $request->input('extra_stb'),
            'provider' => $request->input('provider')
        ]);

        if ($request->input('comment')) {
            Rune_comments::create([
                'comment' => $request->input('comment'),
                'user_id' => Util::userId(),
                'client_id' => $client->id
            ]);
        }

        if ($client){
            Rune_logs::create([
              'user_id' => Util::userId(),
              'client_id' => $client->id
            ]);
            return redirect()->route('runeOptics.index')->with('success', __("Data successfully added"));
        }
    }

    public function show(Rune_optics $runeOptic)
    {
        if(!$this->linkCheck($runeOptic->id)){
            return back()->with('error', 'What are you doing here???');
        }
        $user = auth()->user();
        $clientMod = new Rune_optics();
        $client = $clientMod->data($runeOptic->id);
        $imageModel = new Rune_images();
        $images = $imageModel->images($runeOptic->id);
        $comMod = new Rune_comments();
        $comments = $comMod->comments($runeOptic->id);
        $logMod = new Rune_logs();
        $history = $logMod->logs($runeOptic->id);
        $montiraniModel = new Montirani_uredjaji();
        $montirani = $montiraniModel->montiraniRune($runeOptic->id);
        $equipModel = new Oprema_klijent();
        $equipment = $equipModel->equipmentRune($runeOptic->id);
        $returnMod = new Vraceni_uredjaji();
        $vraceni = $returnMod->vraceniList('id_rune', $runeOptic->id);
        $devLogModel = new Device_history();
        $deviceLog = $devLogModel->deviceLog($runeOptic->id, 'id_rune');
        $maMod = new Material_rune();
        $spentMaterial = $maMod->spentMaterial($runeOptic->id);

        $files = Rune_files::where('client_id', $runeOptic->id)->get();

        return view('runeOptics.show', [
            'client' => $client,
            'id_user' => $user->id,
            'role_id' => $user->role_id,
            'images' => $images,
            'comments'=>$comments,
            'history' => $history,
            'montirani' => $montirani,
            'equipment' => $equipment,
            'vraceni' => $vraceni,
            'deviceLog' => $deviceLog,
            'isAdmin' => Util::isAdmin(),
            'files' => $files,
            'isSuperAdmin' => Util::isSuperAdmin(),
            'spentMaterial' => $spentMaterial
        ]);
    }

    public function edit(Rune_optics $runeOptic)
    {
        if(!$this->linkCheck($runeOptic->id)){
            return back()->with('error', 'What are you doing here???');
        }
        if (Util::isAdmin())
            $statusi = Statusi::all();
        else
            $statusi = Statusi::all()->whereIn('id', [2,4,5,21,31,32]);
            
        $statusiIntervencije = Statusi_intervencije::all();
        $client = Rune_optics::find($runeOptic->id);
        $monteri = Util::monteri();

        $imageModel = new Rune_images();
        $images = $imageModel->images($runeOptic->id);
        $comMod = new Rune_comments();
        $comments = $comMod->comments($runeOptic->id);
        $montageTypes = Tip_montaze::all();
        $uredjaji = Uredjaji::devicesByType(config('app.dev_type_optika'));
        $montiraniModel = new Montirani_uredjaji();
        $montirani = $montiraniModel->montiraniOptikaList($runeOptic->id);
        $vraceniModel = new Vraceni_uredjaji();
        $vraceni = $vraceniModel->vraceniList('id_rune', $runeOptic->id);
        $equipModel = new Oprema_klijent();
        $equipment = $equipModel->equipmentRune($runeOptic->id);
        $devices = Uredjaji::devicesByType(config('app.dev_type_optika'));
        $maMod = new Material_rune();
        $spentMaterial = $maMod->spentMaterial($runeOptic->id);
        if(Util::isAdmin()){
            $oprema = Oprema::all()->where('is_active', 1);
        }
        else {
            $storageModel = new Worker_equipment();
            $oprema = $storageModel->mont_client_equipment(Util::userId());
        }

        $files = Rune_files::where('client_id', $runeOptic->id)->get();

        $origin = Origin::all();
        $helpers = Pomocnici::all();

        $montiraniModel = new Montirani_uredjaji();
        $mounted = $montiraniModel->montiraniRuneList($runeOptic->id);
        $vraceniModel = new Vraceni_uredjaji();
        $returned = $vraceniModel->vraceniList('id_rune', $runeOptic->id);
        $equipModel = new Oprema_klijent();
        $equipment = $equipModel->equipmentRune($runeOptic->id);
        $reasonModel = new Razlozi_vracanja();
        $returnReasons = $reasonModel->return_reasons();
        $providers = Providers::all();
        $areas = Areas::all();

        if(Util::isAdmin()){
            $materials = Materials::all();
        }
        else {
            $maMod = new Worker_materials();
            $materials = $maMod->materials_for_user(Util::userId());
        }

        return view('runeOptics.edit', [
            'client' => $client,
            'statusi'=>$statusi,
            'statusiIntervencije'=>$statusiIntervencije,
            'isAdmin'=>Util::isAdmin(),
            'images'=>$images,
            'comments'=>$comments,
            'userId'=>Util::userId(),
            'isSuperAdmin'=>Util::isSuperAdmin(),
            'monteri'=>$monteri,
            'tipoviMontaze' => $montageTypes,
            'oprema' => $oprema,
            'uredjaji' => $uredjaji,
            'montirani' => $montirani,
            'equipment' => $equipment,
            'materials' => $materials,
            'vraceni' => $vraceni,
            'files' => $files,
            'origin' => $origin,
            'helpers' => $helpers,
            'projectManagers' => Util::allProjectManagers(),
            'teamLeaders' => Util::teamLeaders(),
            'sellers' => Util::allSellers(),
            'devices' => $devices,
            'mounted' => $mounted,
            'returned' => $returned,
            'returnReasons' => $returnReasons,
            'providers' => $providers,
            'areas' => $areas,
            'constructionManagers' => Util::constructionManagers(),
            'clusters' => Clusters::all(),
            'spentMaterial' => $spentMaterial
        ]);
    }

    public function update(Request $request, Rune_optics $runeOptic)
    {
        if(Util::isSalesManager()){
            return back()->with('error', __('Changing data is not allowed for your role'));
        }
        require '../vendor/autoload.php';
        $request->validate([
            'cluster' => 'required',
            'x_coordinate' => 'nullable|numeric',
            'y_coordinate' => 'nullable|numeric',
            'document' => 'mimetypes:application/vnd.openxmlformats-officedocument.spreadsheetml.sheet,application/vnd.ms-excel,application/pdf,audio/mpeg,audio/wav,audio/ogg,audio/x-wav,audio/mp4', // allow documents and audio files by MIME type
            'extra_stb' => 'nullable|numeric',
            'additional_splicing' => 'nullable|numeric',
            'pan' => 'required'
        ]);

        $status = $request->input('status');
        $withdrawalDate = database_date($request->input('withdrawal_date'));
        $confirmedInRuneApp = $request->input('confirmed_in_rune_app');
        $drawnIntoQgis = $request->input('drawn_into_qgis');
        $contacted = $request->input('contacted')?1:0;
        $contactDate = database_date($request->input('contact_date'));

        if($contacted == 1 && !$contactDate){
            $contactDate = date('Y-m-d');
        }
        if($contacted == 0){
            $contactDate = null;
        }

        $datumZakazivanja = null;
        $datumOdlaganja = null;

        $runeAppDate = $runeOptic->rune_app_date;
        if($confirmedInRuneApp && $runeOptic->confirmed_in_rune_app != 1){
            $runeAppDate = date('Y-m-d');
        }
        if(!$confirmedInRuneApp){
            $runeAppDate = null;
        }
        $qgisDate = $runeOptic->qgis_date;
        if($drawnIntoQgis && $runeOptic->drawn_into_qgis != 1){
            $qgisDate = date('Y-m-d');
        }
        if(!$drawnIntoQgis){
            $qgisDate = null;
        }
        if ($request->input('datum_zakazivanja'))
            $datumZakazivanja = date('Y-m-d', strtotime($request->input('datum_zakazivanja')));
        if ($request->input('datum_odlaganja'))
            $datumOdlaganja = date('Y-m-d', strtotime($request->input('datum_odlaganja')));

        if ($datumZakazivanja && $request->input('vreme'))
            $datumZakazivanja = date('Y-m-d', strtotime($datumZakazivanja)).' '.$request->input('vreme').':'.date('s');
        if ($datumOdlaganja && $request->input('vreme2'))
            $datumOdlaganja = date('Y-m-d', strtotime($datumOdlaganja)).' '.$request->input('vreme2').':'.date('s');

        if($status == 5 && !$request->input('montage_type')){
            return back()->with('error', __("You must select montage type"));
        }

        if($status == 3 && $runeOptic->status != 3 && !$withdrawalDate){
            $withdrawalDate = date('Y-m-d');
        }
        elseif($status == 4 && $runeOptic->status != 4 && !$withdrawalDate){
            $withdrawalDate = date('Y-m-d');
        }

        

        $points = (float)str_replace(',','.',$request->input('points'));
        if($points == 0)
            $points = null;

        if(Util::isConstructionManager()){
            $constructionManager = Util::userId();
        }
        else{
            $constructionManager = $request->input('construction_manager');
        }

        if (Util::isAdmin() || Util::isConstructionManager()) {
            $update = Rune_optics::where('id', $runeOptic->id)->update([
                'cluster' => $request->input('cluster'),
                'street' => $request->input('street'),
                'pan' => $request->input('pan'),
                'home_no' => $request->input('home_no'),
                'enterance' => $request->input('enterance'),
                'floor' => $request->input('floor'),
                'apartment' => $request->input('apartment'),
                'tel1' => $request->input('tel1'),
                'tel2' => $request->input('tel2'),
                'tel3' => $request->input('tel3'),
                'network_group' => $request->input('network_group'),
                'eta' => $request->input('eta'),
                'fobos_id' => $request->input('fobos_id'),
                'county' => $request->input('county'),
                'city' => $request->input('city'),
                'settlement' => $request->input('settlement'),
                'household' => $request->input('household'),
                'households' => $request->input('households'),
                'state' => $request->input('state'),
                'state_services' => $request->input('state_services'),
                'email' => $request->input('email'),
                'packet' => $request->input('packet'),
                'recomended_tariff' => $request->input('recomended_tariff'),
                'first_offer' => $request->input('first_offer'),
                'operator' => $request->input('operator'),
                'month' => $request->input('month'),
                'year' => $request->input('year'),
                'status' => $request->input('status'),
                'team_leader' => $request->input('team_leader'),
                'withdrawal_date' => $withdrawalDate,
                'delay_date' => database_date($request->input('delay_date')),
                'contract_expire_date' => database_date($request->input('contract_expire_date')),
                'withdrawal_reason' => $request->input('withdrawal_reason'),
                'created_by' => Util::userId(),
                'updated_by' => Util::userId(),
                'project_manager' => $request->input('project_manager'),
                'construction_manager' => $constructionManager,
                'points' => $points,
                'cable' => $request->input('cable'),
                'thread' => $request->input('thread'),
                'tube' => $request->input('tube'),
                'case' => $request->input('case'),
                'x_coordinate' => $request->input('x_coordinate'),
                'y_coordinate' => $request->input('y_coordinate'),  
                'name' => $request->input('name'),
                'surname' => $request->input('surname'),
                'address' => $request->input('address'),
                'claim' => $request->input('claim'),
                'claim_created_by' => $request->input('claim_created_by'),
                'seller_id' => $request->input('seller'),
                'area' => $request->input('area'),
                'montage_date' => database_date($request->input('montage_date')),
                'montage_type' => $request->input('montage_type'),
                'intervention_status' => $request->input('intervention_status'),
                'intervention_date' => database_date($request->input('intervention_date')),
                'origin' => $request->input('origin'),
                'appointment_date' => $datumZakazivanja,
                'date_of_disposal' => $datumOdlaganja,
                'claim_date' => database_date($request->input('claim_date')),
                'user' => $request->input('user'),
                'reclamation_user' => $request->input('reclamation_user'),
                'reclamation_date' => database_date($request->input('reclamation_date')),
                'extra_stb' => $request->input('extra_stb'),
                'confirmed_in_rune_app' => $confirmedInRuneApp?1:0,
                'rune_app_date' => $runeAppDate,
                'drawn_into_qgis' => $drawnIntoQgis?1:0,
                'qgis_date' => $qgisDate,
                'additional_work' => $request->input('additional_work'),
                'additional_splicing' => $request->input('additional_splicing'),
                'contacted' => $contacted,
                'contact_date' => $contactDate
            ]);

            if(Util::isAdmin()){
                Rune_optics::where('id', $runeOptic->id)->update([
                    'provider' => $request->input('provider')
                ]);
            }

            if ($update){
                if ($status == 1)
                    Rune_optics::where('id', $runeOptic->id)->update(['appointment_date' => $datumZakazivanja]);
                if ($status == 2)
                    Rune_optics::where('id', $runeOptic->id)->update(['delay_date' => $datumOdlaganja]);

            }
        }
        elseif(Util::isProjectManager() || Util::isProjectAdmin()){
            $update = Rune_optics::where('id', $runeOptic->id)->update([
                'cable' => $request->input('cable'),
                'thread' => $request->input('thread'),
                'tube' => $request->input('tube'),
                'case' => $request->input('case'),
                'status' => $request->input('status'),
                'additional_work' => $request->input('additional_work'),
                'additional_splicing' => $request->input('additional_splicing')
            ]);
        }
        else {
            $montageDate = null;
            $withdrawalDate = null;

            $reklamator = $runeOptic->reclamation_user;
            $changeStatus = false;
            if($status != $runeOptic->status){
                $changeStatus = true;
            }

            if ($status == 4 && !$reklamator){
                $withdrawalDate = date('Y-m-d');
                $montageDate = null;
            };
            $validChange = false;
            if(in_array($status, [2,4,5,21,31,32]))
                $validChange = true;
            $changeApproved = $validChange && $changeStatus;
            if ($changeApproved){
                if(env('SERVER_ID') != 3){
                    if(!$montageDate && $status == 5)
                        $montageDate = date('Y-m-d');
                }
                else {
                    if(!$montageDate && in_array($status, [5,21,31,32])){
                        $montageDate = date('Y-m-d');
                    }
                }
                if(!$withdrawalDate && $status == 4)
                    $withdrawalDate = date('Y-m-d');
                $update = Rune_optics::where('id', $runeOptic->id)->update([
                    'montage_date' => $montageDate,
                    'montage_type' => $request->input('montage_type'),
                    'withdrawal_date' => $withdrawalDate,
                    'withdrawal_reason' => $request->input('withdrawal_reason'),
                    'status' => $status,
                    'intervention_status' => $request->input('intervention_status'),
                    'intervention_date' => database_date($request->input('intervention_date')),
                    'claim_date' => database_date($request->input('claim_date')),
                    'reclamation_date' => database_date($request->input('reclamation_date')),
                    'updated_by'=>Util::userId(),
                    'extra_stb' => $request->input('extra_stb'),
                    'additional_work' => $request->input('additional_work'),
                    'additional_splicing' => $request->input('additional_splicing')
                ]);
                if ($update){
                    if ($status == 1)
                        Rune_optics::where('id', $runeOptic->id)->update(['appointment_date' => $datumZakazivanja]);
                    if ($status == 2)
                        Rune_optics::where('id', $runeOptic->id)->update(['delay_date' => $datumOdlaganja]);
                }
            }
            else {
                $update = Rune_optics::where('id', $runeOptic->id)->update([
                    'montage_type' => $request->input('montage_type'),
                    'withdrawal_date' => $withdrawalDate,
                    'withdrawal_reason' => $request->input('withdrawal_reason'),
                    'intervention_status' => $request->input('intervention_status'),
                    'intervention_date' => database_date($request->input('intervention_date')),
                    'claim_date' => database_date($request->input('claim_date')),
                    'reclamation_date' => database_date($request->input('reclamation_date')),
                    'updated_by'=>Util::userId(),
                    'extra_stb' => $request->input('extra_stb'),
                    'additional_work' => $request->input('additional_work'),
                    'additional_splicing' => $request->input('additional_splicing')
                ]);
                if ($update){
                    if ($status == 1)
                        Rune_optics::where('id', $runeOptic->id)->update(['appointment_date' => $datumZakazivanja]);
                    if ($status == 2)
                        Rune_optics::where('id', $runeOptic->id)->update(['delay_date' => $datumOdlaganja]);
                }
            }

        }
        if ($update){
            Rune_logs::create([
                'user_id' => Util::userId(),
                'client_id' => $runeOptic->id
            ]);
            if ($request->input('comment')) {
                Rune_comments::create([
                    'comment' => $request->input('comment'),
                    'user_id' => Util::userId(),
                    'client_id' => $runeOptic->id
                ]);
            }
        }

        /*------------ Fobos rune update ---------------*/
        if($update && $status == 3){
            Fobos_rune::where('fobos_id', $runeOptic->fobos_id)->update(['penetration' => null, 'status_id' => 9, 'accepted' => 0, 'withdrawal_date' => $withdrawalDate, 
                        'withdrawal_reason' => $request->input('withdrawal_reason')]);
        }
        elseif($update && $status == 4){
            Fobos_rune::where('fobos_id', $runeOptic->fobos_id)->update(['penetration' => null, 'status_id' => 8, 'accepted' => 0, 'withdrawal_date' => $withdrawalDate, 
                        'withdrawal_reason' => $request->input('withdrawal_reason')]);
        }
        elseif($update && !in_array($status, [3,4])) {
            $fMod = new Fobos_rune();
            $penetration = $fMod->totalByStatus($runeOptic->pan_id,1)/($fMod->totalByStatus($runeOptic->pan_id)-$fMod->totalByStatus($runeOptic->pan_id,5))*100;
            Fobos_rune::where('fobos_id', $runeOptic->fobos_id)->update(['penetration' => $penetration, 'status_id' => 1, 'accepted' => 1]);
        }

        /*---------------files---------------*/
        $pictures = $request->file('pictures');
        $img = new Img();
        $folder = 'uploads/images/'.quartal();
        if (!file_exists($folder)){
            mkdir($folder, 0755, true);
        }

        if($pictures){
            $this->validate($request, [
                'pictures.*' => 'image|mimes:jpeg,png,jpg,gif'
            ]);
            foreach($pictures as $key=>$file){
                $extension = $file->getClientOriginalExtension();
                $filename = $key.'-'.time().'-rune.'.$extension;
                $fileInt = $img->make($file->getRealPath());
                $fileInt->save($folder.'/'.$filename, 50);
                Rune_images::create([
                    'image_url' => '/'.$folder.'/'.$filename,
                    'client_id' => $runeOptic->id
                ]);
            }
        }

        $document = $request->file('document');
        $folder = 'uploads/documents/'.quartal();
        if (!file_exists($folder)){
            mkdir($folder, 0755, true);
        }
        if($document){
            $originalFile = $document->getClientOriginalName();
            $filename = strtotime(date('d.m.Y. H:i:s')).'_'.$originalFile;
            $folder = 'uploads/documents/'.quartal();
            create_folder($folder);
            $document->move($folder, $filename);
            Rune_files::create([
                'file_url' => '/'.$folder.'/'.$filename,
                'client_id' => $runeOptic->id,
                'filename' => $originalFile
            ]);
        }

        return redirect()->route('runeOptics.show', ['runeOptic' => $runeOptic->id])->with('success', __("Data successfully added"));
        //redirect
        return back()->withInput();
    }

    public function delete_image(Request $request){
        $findImage = Rune_images::find($request->input('id_image'));
        $client = $request->input('id_client');

        $file = ltrim($findImage->image_url,'/');


        if(file_exists($file)){
            unlink($file);
        }


        if ($findImage->delete()){
            return redirect()->route('runeOptics.edit', $client)->with('success', __("Image successfully deleted"));
        }

        return back()->withInput()->with('error', __("Error"));
    }

    public function delete_comment(Request $request){
        $findComment = Rune_comments::find($request->input('id_comment'));
        if($findComment->delete()){
            return back()->with('success', __("Data successfully deleted"));
        }
    }

    public function destroy(Request $request)
    {
        $findClient = Rune_optics::find($request->input('id_rune'));

        $imagesModel = new Rune_images();
        $images = $imagesModel->images($request->input('id_rune'));

        if ($findClient->delete()){
            foreach ($images as $img){
                $file = ltrim($img->image_url,'/');
                if (file_exists($file)){
                    unlink($file);
                }
            }
            Fobos_rune::where('fobos_id', $findClient->fobos_id)->update(['accepted' => 0]);
            return redirect()->route('runeOptics.index')->with('success', __("Data successfully deleted"));
        }

        return back()->withInput()->with('runeOptics', __("Data cannot be deleted"));
    }

    public function search(){
        $status = Statusi::all();
        $fitters = Util::monteri();
        return view('runeOptics.search', [
            'statusi' => $status,
            'users' => $fitters
        ]);
    }

    public function advanced_search(){
        $status = Statusi::all();
        $fitters = Util::monteri();
        return view('runeOptics.advanced_search', [
            'statusi' => $status,
            'teamLeaders' => Util::teamLeaders(),
            'monteri' => $fitters,
            'projectManagers' => Util::projectManagers(),
            'constructionManagers' => Util::constructionManagers(),
            'sellers' => Util::allSellers(),
            'tipoviMontaze' => Tip_montaze::all(),
            'origin' => Origin::all(),
            'statusiIntervencije' => Statusi_intervencije::all(),
            'clusters' => Clusters::all()
        ]);
    }

    public function search_result(Request $request){

        if(Util::isProjectAdmin() || Util::isProjectManager())
            $projectManager = Util::userId();
        else
            $projectManager = $request->input('project_manager');

        if(Util::isConstructionManager())
            $constructionManager = Util::userId();
        else
            $constructionManager = $request->input('construction_manager');

        if(Util::isProdavac())
            $seller = Util::userId();
        else
            $seller = $request->input('seller');

        $clientMod = new Rune_optics();
        if($request->input('param') == 'basic'){
            $name = $request->input('name');
            $surname = $request->input('surname');
            $fitter = $request->input('fitter');
            $statusIds = $request->input('status');
            $created_at = $request->input('created_at');
            $withdrawalDate = $request->input('withdrawal_date');
            $montageDate = $request->input('montage_date');
            $appointmentDate = $request->input('appointment_date');
            $delayDate =$request->input('delay_date');
            $withoutStatus = $request->input('without_status');
            $append = $request->input('append');
            $fobosId = $request->input('fobos_id');
    
            if ($created_at)
                $created_at = date('Y-m-d', strtotime($created_at));
            if ($withdrawalDate)
                $withdrawalDate = date('Y-m-d', strtotime($withdrawalDate));
            if ($montageDate)
                $montageDate = date('Y-m-d', strtotime($montageDate));
            if ($appointmentDate)
                $appointmentDate = date('Y-m-d', strtotime($appointmentDate));
            if ($delayDate)
                $delayDate = date('Y-m-d', strtotime($delayDate));

            if(Util::isSuperAdmin()){
                $result = $clientMod->search($name, $surname, $fobosId, $fitter, $statusIds, $created_at, $montageDate, $withdrawalDate, $appointmentDate, $delayDate, $projectManager, $constructionManager, $seller, $withoutStatus, $append, true);
                $noPagination = $clientMod->search($name, $surname, $fobosId, $fitter, $statusIds, $created_at, $montageDate, $withdrawalDate, $appointmentDate, $delayDate, $projectManager, $constructionManager, $seller, $withoutStatus, $append);
            }
            else {
                $result = $clientMod->search($name, $surname, $fobosId, $fitter, $statusIds, $created_at, $montageDate, $withdrawalDate, $appointmentDate, $delayDate, $projectManager, $constructionManager, $seller, $withoutStatus, $append, true);
                $noPagination = $clientMod->search($name, $surname, $fobosId, $fitter, $statusIds, $created_at, $montageDate, $withdrawalDate, $appointmentDate, $delayDate, $projectManager, $constructionManager, $seller, $withoutStatus, $append, false);
            }
            $ids = Arr::pluck($noPagination, 'id');
            $count = count($ids);
            $ids = json_encode($ids);
            session(['ids_export'=>$ids]);
    
            session(['search_route' => url()->full()]);
            return view('runeOptics.search_result', [
                'clients' => $result,
                'isSuperAdmin' => Util::isSuperAdmin(),
                'isAdmin' => Util::isAdmin(),
                'count' => $count
            ]);
        }
        else {
            $cluster = $request->input('cluster');
            $street = $request->input('street');
            $pan = $request->input('pan');
            $homeNo = $request->input('home_no');
            $enterance = $request->input('enterance');
            $floor = $request->input('floor');
            $apartment = $request->input('apartment');
            $tel1 = $request->input('tel1');
            $tel2 = $request->input('tel2');
            $tel3 = $request->input('tel3');
            $eta = $request->input('eta');
            $fobosId = $request->input('fobos_id');
            $networkGroup = $request->input('network_group');
            $county = $request->input('county');
            $city = $request->input('city');
            $settlement = $request->input('settlement');
            $household = $request->input('household');
            $households = $request->input('households');
            $state = $request->input('state');
            $stateServices = $request->input('state_services');
            $email = $request->input('email');
            $packet = $request->input('packet');
            $status = $request->input('status');
            $points = $request->input('points');
            $recommendedTariff = $request->input('recomended_tariff');
            $firstOffer = $request->input('first_offer');
            $cable = $request->input('cable');
            $thread = $request->input('thread');
            $tube = $request->input('tube');
            $case = $request->input('case');
            $operator = $request->input('operator');
            $month = $request->input('month');
            $year = $request->input('year');
            $withdrawalDate = database_date($request->input('withdrawal_date'));
            $contractExpireDate = database_date($request->input('contract_expire_date'));
            $withdrawalReason = $request->input('withdrawal_reason');
            $xCoordinate = $request->input('x_coordinate');
            $yCoordinate = $request->input('y_coordinate');
            $name = $request->input('name');
            $surname = $request->input('surname');
            $claimCreatedby = $request->input('claim_created_by');
            $tisId = $request->input('tis_id');
            $address = $request->input('address');
            $claim = $request->input('claim');
            $user = $request->input('user');
            $projectManager = $request->input('project_manager');
            $area = $request->input('area');
            $montageType = $request->input('montage_type');
            $appointmentDate = database_date($request->input('datum_zakazivanja'));
            $delayDate = database_date($request->input('datum_odlaganja'));
            $montageDate = database_date($request->input('montage_date'));
            $interventionStatus = $request->input('intervention_status');
            $interventionDate = database_date($request->input('intervention_date'));
            $reclamationUser = $request->input('reclamation_user');
            $reclamationDate = database_date($request->input('reclamation_date'));
            $montageStart = database_date($request->input('start'));
            $montageEnd = database_date($request->input('end'));
            $extraStb = $request->input('extra_stb');
            $withoutStatus = $request->input('bez_statusa');
            $teamLeader = $request->input('teamLeader');
            $serial = $request->input('serial');
            $withoutProjectManager = $request->input('without_project_manager');
            $withoutConstructionManager = $request->input('without_construction_manager');
            $notConfirmedInRune = $request->input('not_confirmed_in_rune');
            $runeAppDate = database_date($request->input('rune_app_date'));
            $qgisDate = database_date($request->input('qgis_date'));
            $additionalWork = $request->input('additional_work');
            $additionalSplicing = $request->input('additional_splicing');
            $contacted = $request->input('contacted');
            $contactDate = $request->input('contact_date');

            $result = $clientMod->advancedSearch($cluster,$street,$pan,$homeNo,$enterance,$floor,$apartment,$tel1,$tel2,$tel3,$eta,$fobosId,$networkGroup,$county,$city,$settlement,
            $household,$households,$state,$stateServices,$email,$packet,$seller,$status,$points,$recommendedTariff,$firstOffer,$cable,$thread,$tube,$case,$operator,$month,$year,
            $withdrawalDate,$contractExpireDate,$withdrawalReason,$xCoordinate,$yCoordinate,$teamLeader,$name,$surname,$claimCreatedby,$tisId,$address,$claim,$user,$projectManager,
            $constructionManager,$area,$montageType,$appointmentDate,$delayDate,$montageDate,$interventionStatus,$interventionDate,$reclamationUser,$reclamationDate,$montageStart,$montageEnd,
            $extraStb,$withoutStatus,$serial,$withoutProjectManager,$withoutConstructionManager,$notConfirmedInRune,$runeAppDate,$qgisDate,$additionalWork,$additionalSplicing,$contacted,$contactDate,true);
            $noPagination = $clientMod->advancedSearch($cluster,$street,$pan,$homeNo,$enterance,$floor,$apartment,$tel1,$tel2,$tel3,$eta,$fobosId,$networkGroup,$county,$city,$settlement,
            $household,$households,$state,$stateServices,$email,$packet,$seller,$status,$points,$recommendedTariff,$firstOffer,$cable,$thread,$tube,$case,$operator,$month,$year,
            $withdrawalDate,$contractExpireDate,$withdrawalReason,$xCoordinate,$yCoordinate,$teamLeader,$name,$surname,$claimCreatedby,$tisId,$address,$claim,$user,$projectManager,
            $constructionManager,$area,$montageType,$appointmentDate,$delayDate,$montageDate,$interventionStatus,$interventionDate,$reclamationUser,$reclamationDate,$montageStart,$montageEnd,
            $extraStb,$withoutStatus,$serial,$withoutProjectManager,$withoutConstructionManager,$notConfirmedInRune,$runeAppDate,$qgisDate,$additionalWork,$additionalSplicing,$contacted,$contactDate);

            $ids = Arr::pluck($noPagination, 'id');
            $count = count($ids);
            $ids = json_encode($ids);
            session(['ids_export'=>$ids]);
    
            session(['search_route' => url()->full()]);
            return view('runeOptics.search_result', [
                'clients' => $result,
                'isSuperAdmin' => Util::isSuperAdmin(),
                'isAdmin' => Util::isAdmin(),
                'count' => $count
            ]);
        }
    }

    public function export(Request $request){
        require '../vendor/autoload.php';
        $ids = session('ids_export');
        $ids = json_decode($ids);

        $withComments = $request->input('comments');

        $cMod = new Rune_optics();
        $clients = $cMod->export($ids);

        $spreadsheet = new Spreadsheet();
        $sheet = $spreadsheet->getActiveSheet();

        $sheet->getColumnDimension('A')->setAutoSize(true);
        $sheet->getColumnDimension('B')->setAutoSize(true);
        $sheet->getColumnDimension('C')->setAutoSize(true);
        $sheet->getColumnDimension('D')->setAutoSize(true);
        $sheet->getColumnDimension('E')->setAutoSize(true);
        $sheet->getColumnDimension('F')->setAutoSize(true);
        $sheet->getColumnDimension('G')->setAutoSize(true);
        $sheet->getColumnDimension('H')->setAutoSize(true);
        $sheet->getColumnDimension('I')->setAutoSize(true);
        $sheet->getColumnDimension('J')->setAutoSize(true);
        $sheet->getColumnDimension('K')->setAutoSize(true);
        $sheet->getColumnDimension('L')->setAutoSize(true);
        $sheet->getColumnDimension('M')->setAutoSize(true);
        $sheet->getColumnDimension('N')->setAutoSize(true);
        $sheet->getColumnDimension('O')->setAutoSize(true);
        $sheet->getColumnDimension('P')->setAutoSize(true);
        $sheet->getColumnDimension('Q')->setAutoSize(true);
        $sheet->getColumnDimension('R')->setAutoSize(true);
        $sheet->getColumnDimension('S')->setAutoSize(true);
        $sheet->getColumnDimension('T')->setAutoSize(true);
        $sheet->getColumnDimension('U')->setAutoSize(true);
        $sheet->getColumnDimension('V')->setAutoSize(true);
        $sheet->getColumnDimension('W')->setAutoSize(true);
        $sheet->getColumnDimension('X')->setAutoSize(true);
        $sheet->getColumnDimension('Y')->setAutoSize(true);
        $sheet->getColumnDimension('Z')->setAutoSize(true);
        $sheet->getColumnDimension('AA')->setAutoSize(true);
        $sheet->getColumnDimension('AB')->setAutoSize(true);
        $sheet->getColumnDimension('AC')->setAutoSize(true);
        $sheet->getColumnDimension('AD')->setAutoSize(true);
        $sheet->getColumnDimension('AE')->setAutoSize(true);
        $sheet->getColumnDimension('AF')->setAutoSize(true);
        $sheet->getColumnDimension('AG')->setAutoSize(true);
        $sheet->getColumnDimension('AH')->setAutoSize(true);
        $sheet->getColumnDimension('AI')->setAutoSize(true);
        $sheet->getColumnDimension('AJ')->setAutoSize(true);
        $sheet->getColumnDimension('AK')->setAutoSize(true);
        $sheet->getColumnDimension('AL')->setAutoSize(true);
        $sheet->getColumnDimension('AM')->setAutoSize(true);
        $sheet->getColumnDimension('AN')->setAutoSize(true);
        $sheet->getColumnDimension('AO')->setAutoSize(true);
        $sheet->getColumnDimension('AP')->setAutoSize(true);
        $sheet->getColumnDimension('AQ')->setAutoSize(true);
        $sheet->getColumnDimension('AR')->setAutoSize(true);
        $sheet->getColumnDimension('AS')->setAutoSize(true);
        $sheet->getColumnDimension('AT')->setAutoSize(true);
        $sheet->getColumnDimension('AU')->setAutoSize(true);
        $sheet->getColumnDimension('AV')->setAutoSize(true);
        $sheet->getColumnDimension('AW')->setAutoSize(true);
        $sheet->getColumnDimension('AX')->setAutoSize(true);
        $sheet->getColumnDimension('AY')->setAutoSize(true);
        $sheet->getColumnDimension('AZ')->setAutoSize(true);
        $sheet->getColumnDimension('BA')->setAutoSize(true);
        $sheet->getColumnDimension('BB')->setAutoSize(true);
        $sheet->getColumnDimension('BC')->setAutoSize(true);
        $sheet->getColumnDimension('BD')->setAutoSize(true);
        $sheet->getColumnDimension('BE')->setAutoSize(true);
        $sheet->getColumnDimension('BF')->setAutoSize(true);
        $sheet->getColumnDimension('BG')->setAutoSize(true);
        $sheet->getColumnDimension('BH')->setAutoSize(true);
        $sheet->getColumnDimension('BI')->setAutoSize(true);
        $sheet->getColumnDimension('BJ')->setAutoSize(true);
        $sheet->getColumnDimension('BK')->setAutoSize(true);
        $sheet->getColumnDimension('BL')->setAutoSize(true);
        $sheet->getColumnDimension('BM')->setAutoSize(true);
        $sheet->getColumnDimension('BN')->setAutoSize(true);
        $sheet->getColumnDimension('BO')->setAutoSize(true);
        $sheet->getColumnDimension('BP')->setAutoSize(true);
        $sheet->getColumnDimension('BQ')->setAutoSize(true);
        $sheet->getColumnDimension('BR')->setAutoSize(true);
        
        

        $sheet->setCellValue('A1', __("Cluster"));
        $sheet->setCellValue('B1', __("County"));
        $sheet->setCellValue('C1', __("City"));
        $sheet->setCellValue('D1', __("Settlement"));
        $sheet->setCellValue('E1', __("Street"));
        $sheet->setCellValue('F1', __("Home number"));
        $sheet->setCellValue('G1', __("PAN"));
        $sheet->setCellValue('H1', __("Status"));
        $sheet->setCellValue('I1', __("Construction manager"));
        $sheet->setCellValue('J1', __("Project manager"));
        $sheet->setCellValue('K1', __("Network group"));
        $sheet->setCellValue('L1', __("Phone").' 1');
        $sheet->setCellValue('M1', __("Phone").' 2');
        $sheet->setCellValue('N1', __("Phone").' 3');
        $sheet->setCellValue('O1', __("Packet"));
        $sheet->setCellValue('P1', __("BL"));
        $sheet->setCellValue('Q1', __("Enterance"));
        $sheet->setCellValue('R1', __("Apartment"));
        $sheet->setCellValue('S1', __("Floor"));
        $sheet->setCellValue('T1', __("Household"));
        $sheet->setCellValue('U1', __("Households"));
        $sheet->setCellValue('V1', __("Country"));
        $sheet->setCellValue('W1', __("State services"));
        $sheet->setCellValue('X1', __("Country"));
        $sheet->setCellValue('Y1', __("Recommended tariff"));
        $sheet->setCellValue('Z1', __("First offer"));
        $sheet->setCellValue('AA1', __("Operater"));
        $sheet->setCellValue('AB1', __("Month"));
        $sheet->setCellValue('AC1', __("Year"));
        $sheet->setCellValue('AD1', __("Email"));
        $sheet->setCellValue('AE1', __("Statement type"));
        $sheet->setCellValue('AF1', __("Date of withdrawal"));
        $sheet->setCellValue('AG1', __("Reason of withdrawal"));
        $sheet->setCellValue('AH1', __("Expiration date"));
        $sheet->setCellValue('AI1', __("Points"));
        $sheet->setCellValue('AJ1', __("ID"));
        $sheet->setCellValue('AK1', __("Cable"));
        $sheet->setCellValue('AL1', __("Thread"));
        $sheet->setCellValue('AM1', __("Tube"));
        $sheet->setCellValue('AN1', __("Case"));
        $sheet->setCellValue('AO1', __("X-coordinate"));
        $sheet->setCellValue('AP1', __("Y-coordinate"));
        $sheet->setCellValue('AQ1', __("Name"));
        $sheet->setCellValue('AR1', __("Surname"));
        $sheet->setCellValue('AS1', __("Request created by"));
        $sheet->setCellValue('AT1', __("Address"));
        $sheet->setCellValue('AU1', __("Request"));
        $sheet->setCellValue('AV1', __("Seller"));
        $sheet->setCellValue('AW1', __("Request date"));
        $sheet->setCellValue('AX1', __("Points"));
        $sheet->setCellValue('AY1', __("Montage date"));
        $sheet->setCellValue('AZ1', __("Withdrawal date"));
        $sheet->setCellValue('BA1', __("Delay date"));
        $sheet->setCellValue('BB1', __("Assigned to fitter"));
        $sheet->setCellValue('BC1', __("Appointment date"));
        $sheet->setCellValue('BD1', __("Withdrawal reason"));
        $sheet->setCellValue('BE1', __("Intervention status"));
        $sheet->setCellValue('BF1', __("Intervention date"));
        $sheet->setCellValue('BG1', __("Reclamation fitter"));
        $sheet->setCellValue('BH1', __("Reclamation date"));
        $sheet->setCellValue('BI1', __("Montage type"));
        $sheet->setCellValue('BJ1', __("Origin"));
        $sheet->setCellValue('BK1', __("Helper"));
        $sheet->setCellValue('BL1', __("Terrain"));
        $sheet->setCellValue('BM1', __("Extra STB"));
        $sheet->setCellValue('BN1', __("Note"));
        $sheet->setCellValue('BO1', __("Additional work"));
        $sheet->setCellValue('BP1', __("Additional splicing"));
        $sheet->setCellValue('BQ1', __("Client contacted"));
        $sheet->setCellValue('BR1', __("Contact date"));

        $sheet->getStyle('A1:BN1')->getAlignment()->setHorizontal('center');

        $sheet->getStyle('A1:BN1')->getFill()->setFillType(\PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID)->getStartColor()->setARGB('8c8c8c');

        $commentText = '';
        $comMod = new Rune_comments();
        foreach ($clients as $br=>$client){
            if($withComments) {
                $comments = $comMod->comments($client->id);
                foreach ($comments as $comment)
                    $commentText .= $comment->comment . " (" . $comment->ime . ' ' . $comment->prezime . ' ' . date('d.m.Y H:i:s', strtotime($comment->created_at)) . ') ';
            }
            if (in_array($client->status_id, [3,4]))
                $sheet->getStyle('A'.($br+2).':BN'.($br+2))->getFill()->setFillType(\PhpOffice\PhpSpreadsheet\Style\Fill::FILL_SOLID)->getStartColor()->setARGB('ebe134');

            $sheet->getStyle('A'.($br+2).':BN'.($br+2))->getAlignment()->setHorizontal('left');
            $sheet->setCellValue('A'.($br+2), $client->cluster);
            $sheet->setCellValue('B'.($br+2), $client->county);
            $sheet->setCellValue('C'.($br+2), $client->city);
            $sheet->setCellValue('D'.($br+2), $client->settlement);
            $sheet->setCellValue('E'.($br+2), $client->street);
            $sheet->setCellValue('F'.($br+2), $client->home_no);
            $sheet->setCellValue('G'.($br+2), $client->pan);
            $sheet->setCellValue('H'.($br+2), $client->status);
            $sheet->setCellValue('I'.($br+2), $client->cm_name." ".$client->cm_surname);
            $sheet->setCellValue('J'.($br+2), $client->pm_name." ".$client->pm_surname);
            $sheet->setCellValue('K'.($br+2), $client->network_group);
            $sheet->setCellValue('L'.($br+2), $client->tel1);
            $sheet->setCellValue('M'.($br+2), $client->tel2);
            $sheet->setCellValue('N'.($br+2), $client->tel3);
            $sheet->setCellValue('O'.($br+2), $client->packet);
            $sheet->setCellValue('P'.($br+2), $client->black_list);
            $sheet->setCellValue('Q'.($br+2), $client->enterance);
            $sheet->setCellValue('R'.($br+2), $client->apartment);
            $sheet->setCellValue('S'.($br+2), $client->floor);
            $sheet->setCellValue('T'.($br+2), $client->household);
            $sheet->setCellValue('U'.($br+2), $client->households);
            $sheet->setCellValue('V'.($br+2), $client->household);
            $sheet->setCellValue('W'.($br+2), $client->state_services);
            $sheet->setCellValue('X'.($br+2), $client->state);
            $sheet->setCellValue('Y'.($br+2), $client->recomended_tariff);
            $sheet->setCellValue('Z'.($br+2), $client->first_offer);
            $sheet->setCellValue('AA'.($br+2), $client->operator);
            $sheet->setCellValue('AB'.($br+2), $client->month);
            $sheet->setCellValue('AC'.($br+2), $client->year);
            $sheet->setCellValue('AD'.($br+2), $client->email);
            $sheet->setCellValue('AE'.($br+2), $client->eta);
            $sheet->setCellValue('AF'.($br+2), $client->withdrawal_date ? date('d.m.Y.', strtotime($client->withdrawal_date)) : null);
            $sheet->setCellValue('AG'.($br+2), $client->withdrawal_reason);
            $sheet->setCellValue('AH'.($br+2), $client->contract_expire_date ? date('d.m.Y.', strtotime($client->contract_expire_date)) : null);
            $sheet->setCellValue('AI'.($br+2), $client->points);
            $sheet->setCellValue('AJ'.($br+2), $client->fobos_id);
            $sheet->setCellValue('AK'.($br+2), $client->cable);
            $sheet->setCellValue('AL'.($br+2), $client->thread);
            $sheet->setCellValue('AM'.($br+2), $client->tube);
            $sheet->setCellValue('AN'.($br+2), $client->case);
            $sheet->setCellValue('AO'.($br+2), $client->x_coordinate);
            $sheet->setCellValue('AP'.($br+2), $client->y_coordinate);
            $sheet->setCellValue('AQ'.($br+2), $client->name);
            $sheet->setCellValue('AR'.($br+2), $client->surname);
            $sheet->setCellValue('AS'.($br+2), $client->claim_created_by);
            $sheet->setCellValue('AT'.($br+2), $client->address);
            $sheet->setCellValue('AU'.($br+2), $client->claim);
            $sheet->setCellValue('AV'.($br+2), $client->seller_name.' '.$client->seller_surname);
            $sheet->setCellValue('AW'.($br+2), $client->claim ? date('d.m.Y.', strtotime($client->claim_date)) : null);
            $sheet->setCellValue('AX'.($br+2), $client->points);
            $sheet->setCellValue('AY'.($br+2), $client->montage_date ? date('d.m.Y.', strtotime($client->montage_date)) : null);
            $sheet->setCellValue('AZ'.($br+2), $client->withdrawal_date ? date('d.m.Y.', strtotime($client->withdrawal_date)) : null);
            $sheet->setCellValue('BA'.($br+2), $client->delay_date ? date('d.m.Y.', strtotime($client->delay_date)) : null);
            $sheet->setCellValue('BB'.($br+2), $client->fitter_name.' '.$client->fitter_surname);
            $sheet->setCellValue('BC'.($br+2), $client->appointment_date ? date('d.m.Y.', strtotime($client->appointment_date)) : null);
            $sheet->setCellValue('BD'.($br+2), $client->withdrawal_reason);
            $sheet->setCellValue('BE'.($br+2), $client->intervention_status);
            $sheet->setCellValue('BF'.($br+2), $client->intervention_date ? date('d.m.Y.', strtotime($client->intervention_date)) : null);
            $sheet->setCellValue('BG'.($br+2), $client->reclamation_name.' '.$client->reclamation_surname);
            $sheet->setCellValue('BH'.($br+2), $client->reclamation_date ? date('d.m.Y.', strtotime($client->reclamation_date)) : null);
            $sheet->setCellValue('BI'.($br+2), $client->montage_type);
            $sheet->setCellValue('BJ'.($br+2), $client->origin);
            $sheet->setCellValue('BK'.($br+2), $client->helper_name.' '.$client->helper_surname);
            $sheet->setCellValue('BL'.($br+2), $client->on_terrain);
            $sheet->setCellValue('BM'.($br+2), $client->extra_stb);
            $sheet->setCellValue('BN'.($br+2), $commentText);
            $sheet->setCellValue('BO'.($br+2), $client->additional_work==1?__('YES'):__('NO'));
            $sheet->setCellValue('BP'.($br+2), $client->additional_splicing);
            $sheet->setCellValue('BQ'.($br+2), $client->contacted == 1?__('YES'):__('NO'));
            $sheet->setCellValue('BR'.($br+2), $client->contact_date) ? date('d.m.Y.', strtotime($client->contact_date)) : null;

            $commentText = '';

            // $montMod = new Montirani_uredjaji();
            // $montirani = $montMod->montiraniOptikaList($klijent->id);
            // $vraceniMod = new Vraceni_uredjaji();
            // $vraceni = $vraceniMod->vraceniList('id_opticki_klijent', $klijent->id);
            // $letter = 'B';
            // foreach($montirani as $mont){
            //     $sheet->getColumnDimension('A'.$letter)->setAutoSize(true);
            //     $sheet->setCellValue('A'.$letter.($br+2), '('.$mont->uredjaj.') '.$mont->serijski_broj);
            //     $letterAscii = ord($letter);
            //     $letterAscii++;
            //     $letter = chr($letterAscii);
            // }
            // if (!$vraceni->isEmpty()){
            //     $sheet->getColumnDimension('A'.$letter)->setAutoSize(true);
            //     $sheet->setCellValue('A'.$letter.($br+2), 'vraćeno: ');
            //     $letterAscii = ord($letter);
            //     $letterAscii++;
            //     $letter = chr($letterAscii);
            //     foreach ($vraceni as $vra){
            //         $sheet->getColumnDimension('A'.$letter)->setAutoSize(true);
            //         $sheet->setCellValue('A'.$letter.($br+2), '('.$vra->uredjaj.') '.$vra->serijski_broj);
            //         $letterAscii = ord($letter);
            //         $letterAscii++;
            //         $letter = chr($letterAscii);
            //     }
            // }
        }

        $streamedResponse = new StreamedResponse();
        $streamedResponse->setCallback(function() use ($spreadsheet){
            $writter = new Xlsx($spreadsheet);
            $writter->save('php://output');
        });

        $streamedResponse->setStatusCode(200);
        $streamedResponse->headers->set('Content-Type', 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
        $streamedResponse->headers->set('Content-Disposition', 'attachment; filename="rune_optics.xlsx"');
        return $streamedResponse->send();
    }

    public function export_equipment(){
        $ids = json_decode(session('ids_export'));
        $filename = 'troskovnik';
        $file = public_path()."/templates/$filename.xlsx";
        $reader = new \PhpOffice\PhpSpreadsheet\Reader\Xlsx();
        $spreadsheet = $reader->load($file);
        $sheet = $spreadsheet->getActiveSheet();
        $sheetData = $spreadsheet->getActiveSheet()->rangeToArray('A9:A80');
        $columntIndex = 8;
        // dd($sheetData);
        foreach($ids as $id){
            $num = 9;
            if($id){
                $site = Rune_optics::find($id);
                $letter = $this->getExcelColumnName($columntIndex);
                $sheet->setCellValue($letter.'5', $site->fobos_id);
                $sheet->setCellValue($letter.'6', $site->street);
                foreach($sheetData as $code){
                    $equipModel = new Oprema_klijent();
                    $equipment = $equipModel->specificEquipment($code[0],$id);
                    if(isset($equipment->quantity)){
                        $sheet->setCellValue($letter.$num, $equipment->quantity);
                    }
                    $num++;
                }
                //move to the next
                $columntIndex++;
            }
        }
        $streamedResponse = new StreamedResponse();
        $streamedResponse->setCallback(function() use ($spreadsheet) {
            $writer = new Xlsx($spreadsheet);

            // Set headers for the download response
            header('Content-Type: application/vnd.openxmlformats-officedocument.spreadsheetml.sheet');
            header('Content-Disposition: attachment;filename="troskovnik-updated.xlsx"');
            header('Cache-Control: max-age=0');

            // Save the file to the output stream
            $writer->save('php://output');
        });

        // Ensure no other output has been sent before this
        if (ob_get_length()) {
            ob_end_clean();
        }

        $streamedResponse->send();
        exit();
    }

    // Helper function to get Excel column name based on index
    private function getExcelColumnName($index) {
        $letters = '';
        while ($index > 0) {
            $index--;
            $letters = chr(65 + ($index % 26)) . $letters;
            $index = floor($index / 26);
        }
        return $letters;
    }
    

    public function kir_import(){
        echo 'stranica je u izradi'; exit;
    }

}
