<?php

namespace App\Http\Controllers;

use App\Nov_servis;
use App\Oprema;
use App\Oprema_klijent;
use App\Paketi;
use App\Razlozi_intervencije;
use App\Statusi;
use App\Teams;
use App\Traits\Statistika;
use App\Traits\Util;
use App\User;
use App\Vrste_paketa;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;

class StatistikaController extends Controller
{
    public function montaza_sintetika(Request $request){
        $od = $request->input('start');
        $do = $request->input('end');
        if ($od && $do){
            $start = date('Y-m-d', strtotime($od));
            $end = date('Y-m-d', strtotime($do));
        }
        else {
            $start = null;
            $end = null;
        }

        $statistic = array();

        $statusi = Statusi::all();
        $clientTypes = ['rune_optics'=>'RUNE'];

//        $divider = Statistika::clientStat('klijenti_supernova', null, $start, $end);
//        var_dump($divider); exit;
        foreach ($clientTypes as $field=>$cli){
            $divider = Statistika::clientStat($field, null, $start, $end);
            if ($divider == 0)
                continue;
            foreach($statusi as $stat){
                switch ($stat->id) {
                    case 1 : $color = '#0088cc'; break;
                    case 2 : $color = '#cc0b4e'; break;
                    case 3 : $color = '#2baab1'; break;
                    case 4 : $color = '#734ba9'; break;
                    case 5 : $color = '#E36159'; break;
                    case 6 : $color = '#00cc2b'; break;
                    default: $color = random_color();
                }
                $statistic[$cli][$stat->status] = [
                    'br' => Statistika::clientStat($field, $stat->id, $start, $end),
                    'procenat' =>  number_format(Statistika::clientStat($field, $stat->id, $start, $end)*100/$divider, 1),
                    'color' => $color
                ];
            }
            $statistic[$cli]['bez statusa'] = [
                'br'=>Statistika::clientStat($field, null, $start, $end, true),
                'procenat'=>number_format(Statistika::clientStat($field, null, $start, $end, true)*100/$divider, 1),
                'color'=>'#a3a3a3'
            ];
        }

        return view('statistika.montaza_sintetika', [
            'statistic' => $statistic,
            'from' => $od?$od:date('01.m.Y.'),
            'to' => $do?$do:date('t.m.Y.')
        ]);
    }

    public function montaza_analitika(Request $request){
        $monteri = Util::monteri();
        $statusi = Statusi::all();
        $idMonter = $request->input('monter');
        $monterData = User::find($idMonter);
        if ($monterData)
            $monter = $monterData->ime.' '.$monterData->prezime;
        else
            $monter = __("all workers");
        $od = $request->input('start');
        $do = $request->input('end');
        if ($od && $do){
            $start = date('Y-m-d', strtotime($od));
            $end = date('Y-m-d', strtotime($do));
        }
        else {
            $start = null;
            $end = null;
        }
        $statisticOptika = array();
        foreach ($statusi as $status){
            $statisticOptika[$status->status] = Statistika::statistikaMonter('rune_optics', $idMonter, $status->id, $start, $end);
        }

        return view ('statistika.montaza_analitika', [
            'statisticOptika' => $statisticOptika,
            'monteri' => $monteri,
            'monter' => $monter,
            'from' => $od?$od:date('01.m.Y.'),
            'to' => $do?$do:date('t.m.Y.')
        ]);
    }

    public function zakazan_montiran(Request $request){
        $monteri = Util::monteri();
        $idMonter = $request->input('monter');
        $monterData = User::find($idMonter);
        if ($monterData)
            $monter = $monterData->ime.' '.$monterData->prezime;
        else
            $monter = 'svi monteri';
        $od = $request->input('start');
        $do = $request->input('end');
        if ($od && $do){
            $start = date('Y-m-d', strtotime($od));
            $end = date('Y-m-d', strtotime($do));
        }
        else {
            $start = null;
            $end = null;
        }

        $statisticDth = array();
        $statisticOptika = array();
        $statisticSupernova = array();
        $statisticBakar = array();
        $statusi = ['zakazani'=>1, 'montirani' => 5];

        foreach ($statusi as $status=>$id){
            $statisticDth[$status] = Statistika::zakazanMontiran('klijent', $idMonter, $id, $start, $end);
            $statisticOptika[$status] = Statistika::zakazanMontiran('klijenti_optika', $idMonter, $id, $start, $end);
            $statisticSupernova[$status] = Statistika::zakazanMontiran('klijenti_supernova', $idMonter, $id, $start, $end);
            $statisticBakar[$status] = Statistika::zakazanMontiran('klijenti_bakar', $idMonter, $id, $start, $end);
        }

        return view('statistika.zakazan_montiran', [
            'statisticDth' => $statisticDth,
            'statisticOptika' => $statisticOptika,
            'statisticSupernova' => $statisticSupernova,
            'statisticBakar' => $statisticBakar,
            'monteri' => $monteri,
            'monter' => $monter,
            'from' => $od?$od:date('01.m.Y.'),
            'to' => $do?$do:date('t.m.Y.')
        ]);
    }

    public function prodaja_sintetika(Request $request){
        $od = $request->input('start');
        $do = $request->input('end');
        if ($od && $do){
            $start = date('Y-m-d', strtotime($od));
            $end = date('Y-m-d', strtotime($do));
        }
        else {
            $start = null;
            $end = null;
        }

        $novServis = $request->input('nov_servis');
        $vrstaPaketa = $request->input('vrste_paketa');
        $paket = $request->input('paketi');

        $statistic = array();

        $statusi = Statusi::all();
        $clientTypes = ['klijent'=>'M:SAT DTH', 'klijenti_optika'=>'OPTIKA', 'klijenti_supernova'=>'SUPERNOVA', 'klijenti_bakar'=>'BAKAR'];

        if ($novServis){
            $novServisi = Nov_servis::all();
            foreach ($clientTypes as $field=>$cli){
                $divider = Statistika::sellAll($field, $start, $end);
                if ($divider == 0)
                    continue;
                foreach($novServisi as $br=>$nov){
                    switch ($nov->id) {
                        case 1 : $color = '#0088cc'; break;
                        case 2 : $color = '#cc0b4e'; break;
                        case 3 : $color = '#2baab1'; break;
                        case 4 : $color = '#734ba9'; break;
                        case 5 : $color = '#E36159'; break;
                        case 6 : $color = '#ff9900'; break;
                        default: $color = random_color();
                    }
                    $statistic[$cli][$nov->naziv] = [
                        'br' => Statistika::saleStat($field, false, $start, $end, false, false, false, $nov->id),
                        'procenat' =>  number_format(Statistika::saleStat($field, false, $start, $end, false, false, false, $nov->id)*100/$divider, 1),
                        'color' => $color
                    ];
                    $statistic[$cli]['ostalo'] = [
                        'br'=>Statistika::saleStat($field, false, $start, $end, false, false,
                            false, false, false, false, false, true),
                        'procenat'=> number_format(Statistika::saleStat($field, null, $start, $end, false,
                                false, false, false, false, false, false, true)*100/$divider, 1),
                        'color'=>'#a3a3a3'
                    ];

                }
            }
        }
        elseif($vrstaPaketa){
            $vrstePaketa = Vrste_paketa::all();
            foreach ($clientTypes as $field=>$cli){
                $divider = Statistika::sellAll($field, $start, $end);
                if ($divider == 0)
                    continue;
                foreach($vrstePaketa as $pak){
                    switch ($pak->id) {
                        case 1 : $color = '#0088cc'; break;
                        case 2 : $color = '#cc0b4e'; break;
                        case 3 : $color = '#2baab1'; break;
                        case 4 : $color = '#734ba9'; break;
                        case 5 : $color = '#E36159'; break;
                        case 6 : $color = '#ff9900'; break;
                        default: $color = random_color();
                    }
                    $statistic[$cli][$pak->vrsta] = [
                        'br' => Statistika::saleStat($field, false, $start, $end, false, false, false, false, $pak->id),
                        'procenat' =>  number_format(Statistika::saleStat($field, false, $start, $end, false, false, false, false, $pak->id)*100/$divider, 1),
                        'color' => $color
                    ];
                }
                $statistic[$cli]['ostalo'] = [
                    'br'=>Statistika::saleStat($field, false, $start, $end, false, false,
                        false, false, false, false, true),
                    'procenat'=> number_format(Statistika::saleStat($field, null, $start, $end, false,
                            false, false, false, false, false, true)*100/$divider, 1),
                    'color'=>'#a3a3a3'
                ];
            }
        }
        elseif($paket){
            $paketi = Paketi::all();
            foreach ($clientTypes as $field=>$cli){
                $divider = Statistika::sellAll($field, $start, $end);
                if ($divider == 0)
                    continue;
                foreach($paketi as $pak){
                    switch ($pak->id) {
                        case 1 : $color = '#0088cc'; break;
                        case 2 : $color = '#cc0b4e'; break;
                        case 3 : $color = '#2baab1'; break;
                        case 4 : $color = '#734ba9'; break;
                        case 5 : $color = '#E36159'; break;
                        case 6 : $color = '#ff9900'; break;
                        default: $color = random_color();
                    }
                    $statistic[$cli][$pak->naziv] = [
                        'br' => Statistika::saleStat($field, false, $start, $end, false, false, false, false,
                            false, false, false, false, $pak->id),
                        'procenat' =>  number_format(Statistika::saleStat($field, false, $start, $end, false, false, false, false,
                                false, false, false, false, $pak->id)*100/$divider, 1),
                        'color' => $color
                    ];
                }
                $statistic[$cli]['ostalo'] = [
                    'br'=>Statistika::saleStat($field, false, $start, $end, false, false,
                        false, false, false, false, false, false, false, true),
                    'procenat'=> number_format(Statistika::saleStat($field, null, $start, $end, false,
                            false, false, false, false, false, false,
                            false, false, true)*100/$divider, 1),
                    'color'=>'#a3a3a3'
                ];
            }
        }
        else {
            foreach ($clientTypes as $field=>$cli){
                $divider = Statistika::sellAll($field, $start, $end);
                if ($divider == 0)
                    continue;
                foreach($statusi as $br=>$stat){
                    switch ($stat->id) {
                        case 1 : $color = '#0088cc'; break;
                        case 2 : $color = '#cc0b4e'; break;
                        case 3 : $color = '#2baab1'; break;
                        case 4 : $color = '#734ba9'; break;
                        case 5 : $color = '#E36159'; break;
                        case 6 : $color = '#ff9900'; break;
                        default: $color = random_color();
                    }
                    $statistic[$cli][$stat->status] = [
                        'br' => Statistika::saleStat($field, $stat->id, $start, $end),
                        'procenat' =>  number_format(Statistika::saleStat($field, $stat->id, $start, $end)*100/$divider, 1),
                        'color' => $color
                    ];
                }
                $statistic[$cli]['prihvaceno'] = [
                    'br'=>Statistika::saleStat($field, null, $start, $end, true),
                    'procenat' =>  number_format(Statistika::saleStat($field, null, $start, $end, true)*100/$divider, 1),
                    'color' => '#21cc60'
                ];
                $statistic[$cli]['vraceno'] = [
                    'br'=>Statistika::saleStat($field, null, $start, $end, false, true),
                    'procenat'=> number_format(Statistika::saleStat($field, null, $start, $end, false, true)*100/$divider, 1),
                    'color'=>'#f5ce42'
                ];
                $statistic[$cli]['ostalo'] = [
                    'br'=>Statistika::saleStat($field, null, $start, $end, false, false, false, false, false, true),
                    'procenat'=> number_format(Statistika::saleStat($field, null, $start, $end, false, false, false, false, false, true)*100/$divider, 1),
                    'color'=>'#a3a3a3'
                ];
            }
        }



        return view('statistika.prodaja_sintetika', [
            'statistic' => $statistic,
            'from' => $od?$od:date('01.m.Y.'),
            'to' => $do?$do:date('t.m.Y.')
        ]);
    }

    public function prodaja_analitika(Request $request){
        $prodavci = Util::allSellers();
        $timovi = Teams::all();
        $idSeller = $request->input('seller');
        $idTeam = $request->input('team');
        if ($idTeam){
            $teamData = Teams::find($idTeam);
            $paragraph = $teamData->naziv;
        }
        elseif ($idSeller){
            $sellerData = User::find($idSeller);
            $paragraph = $sellerData->ime.' '.$sellerData->prezime;
        }
        else {
            $paragraph = 'svi akviziteri';
        }
        $od = $request->input('start');
        $do = $request->input('end');
        if ($od && $do){
            $start = date('Y-m-d', strtotime($od));
            $end = date('Y-m-d', strtotime($do));
        }
        else {
            $start = null;
            $end = null;
        }

        $novServis = $request->input('nov_servis');
        $vrstaPaketa = $request->input('vrste_paketa');
        $paket = $request->input('paketi');
        $teamModel = new Teams();

        $sellers = $teamModel->sellers($idTeam);

        if ($idSeller)
            $seller = $idSeller;
        elseif($idTeam){
            $findTeam = Teams::find($idTeam);
            $lider = $findTeam->id_lider;
            $seller = Arr::pluck($sellers, 'id');
            $seller = array_merge($seller, [$lider]);
        }
        else
            $seller = Arr::pluck(Util::allSellers(), 'id');

        $statistic = array();

        $statusi = Statusi::all();
        $clientTypes = ['klijent'=>'M:SAT DTH', 'klijenti_optika'=>'OPTIKA', 'klijenti_supernova'=>'SUPERNOVA', 'klijenti_bakar'=>'BAKAR'];

        if ($novServis){
            $novServisi = Nov_servis::all();
            foreach ($clientTypes as $field=>$cli){
                $divider = Statistika::sellAll($field, $start, $end, $seller);
                if ($divider == 0)
                    continue;
                foreach($novServisi as $br=>$nov){
                    switch ($nov->id) {
                        case 1 : $color = '#0088cc'; break;
                        case 2 : $color = '#cc0b4e'; break;
                        case 3 : $color = '#2baab1'; break;
                        case 4 : $color = '#734ba9'; break;
                        case 5 : $color = '#E36159'; break;
                        case 6 : $color = '#ff9900'; break;
                        default: $color = random_color();
                    }
                    $statistic[$cli][$nov->naziv] = [
                        'br' => Statistika::saleStat($field, false, $start, $end, false, false, $seller, $nov->id),
                        'procenat' =>  number_format(Statistika::saleStat($field, false, $start, $end, false, false, $seller, $nov->id)*100/$divider, 1),
                        'color' => $color
                    ];
                }
                $statistic[$cli]['ostalo'] = [
                    'br'=>Statistika::saleStat($field, false, $start, $end, false, false,
                        $seller, false, false, false, false, true),
                    'procenat'=> number_format(Statistika::saleStat($field, null, $start, $end, false,
                            false, $seller, false, false, false, false, true)*100/$divider, 1),
                    'color'=>'#a3a3a3'
                ];
            }
        }
        elseif($vrstaPaketa){
            $vrstePaketa = Vrste_paketa::all();
            foreach ($clientTypes as $field=>$cli){
                $divider = Statistika::sellAll($field, $start, $end, $seller);
                if ($divider == 0)
                    continue;
                foreach($vrstePaketa as $pak){
                    switch ($pak->id) {
                        case 1 : $color = '#0088cc'; break;
                        case 2 : $color = '#cc0b4e'; break;
                        case 3 : $color = '#2baab1'; break;
                        case 4 : $color = '#734ba9'; break;
                        case 5 : $color = '#E36159'; break;
                        case 6 : $color = '#ff9900'; break;
                        default: $color = random_color();
                    }
                    $statistic[$cli][$pak->vrsta] = [
                        'br' => Statistika::saleStat($field, false, $start, $end, false, false, $seller, false, $pak->id),
                        'procenat' =>  number_format(Statistika::saleStat($field, false, $start, $end, false, false, $seller, false, $pak->id)*100/$divider, 1),
                        'color' => $color
                    ];
                }
                $statistic[$cli]['ostalo'] = [
                    'br'=>Statistika::saleStat($field, false, $start, $end, false, false,
                        $seller, false, false, false, true),
                    'procenat'=> number_format(Statistika::saleStat($field, null, $start, $end, false,
                            false, $seller, false, false, false, true)*100/$divider, 1),
                    'color'=>'#a3a3a3'
                ];
            }
        }
        elseif($paket){
            $paketi = Paketi::all();
            foreach ($clientTypes as $field=>$cli){
                $divider = Statistika::sellAll($field, $start, $end, $seller);
                if ($divider == 0)
                    continue;
                foreach($paketi as $pak){
                    switch ($pak->id) {
                        case 1 : $color = '#0088cc'; break;
                        case 2 : $color = '#cc0b4e'; break;
                        case 3 : $color = '#2baab1'; break;
                        case 4 : $color = '#734ba9'; break;
                        case 5 : $color = '#E36159'; break;
                        case 6 : $color = '#ff9900'; break;
                        default: $color = random_color();
                    }
                    $statistic[$cli][$pak->naziv] = [
                        'br' => Statistika::saleStat($field, false, $start, $end, false, false, $seller, false,
                            false, false, false, false, $pak->id),
                        'procenat' =>  number_format(Statistika::saleStat($field, false, $start, $end, false, false, $seller, false,
                                false, false, false, false, $pak->id)*100/$divider, 1),
                        'color' => $color
                    ];
                }
                $statistic[$cli]['ostalo'] = [
                    'br'=>Statistika::saleStat($field, false, $start, $end, false, false,
                        $seller, false, false, false, false, false, false, true),
                    'procenat'=> number_format(Statistika::saleStat($field, null, $start, $end, false,
                            false, $seller, false, false, false, false,
                            false, false, true)*100/$divider, 1),
                    'color'=>'#a3a3a3'
                ];
            }
        }
        else{
            foreach ($clientTypes as $field=>$cli){
                $divider = Statistika::sellAll($field, $start, $end, $seller);
                if ($divider == 0)
                    continue;
                foreach($statusi as $stat){
                    switch ($stat->id) {
                        case 1 : $color = '#0088cc'; break;
                        case 2 : $color = '#cc0b4e'; break;
                        case 3 : $color = '#2baab1'; break;
                        case 4 : $color = '#734ba9'; break;
                        case 5 : $color = '#E36159'; break;
                        case 6 : $color = '#ff9900'; break;
                        default: $color = random_color();
                    }
                    $statistic[$cli][$stat->status] = [
                        'br' => Statistika::saleStat($field, $stat->id, $start, $end, false, false, $seller),
                        'procenat' =>  number_format(Statistika::saleStat($field, $stat->id, $start, $end, false, false, $seller)*100/$divider, 1),
                        'color' => $color
                    ];
                }
                $statistic[$cli]['prihvaceno'] = [
                    'br'=>Statistika::saleStat($field, null, $start, $end, true, false, $seller),
                    'procenat' =>  number_format(Statistika::saleStat($field, null, $start, $end, true, false, $seller)*100/$divider, 1),
                    'color' => '#21cc60'
                ];
                $statistic[$cli]['vraceno'] = [
                    'br'=>Statistika::saleStat($field, null, $start, $end, false, true, $seller),
                    'procenat' =>  number_format(Statistika::saleStat($field, null, $start, $end, false, true, $seller)*100/$divider, 1),
                    'color' => '#f5ce42'
                ];
                $statistic[$cli]['ostalo'] = [
                    'br'=>Statistika::saleStat($field, null, $start, $end, false, false, $seller, false, false, true),
                    'procenat'=> number_format(Statistika::saleStat($field, null, $start, $end, false, false, $seller, false, false, true)*100/$divider, 1),
                    'color'=>'#a3a3a3'
                ];
            }
        }

        return view('statistika.prodaja_analitika', [
            'paragraph' => $paragraph,
            'prodavci' => $prodavci,
            'timovi' => $timovi,
            'statistic' => $statistic,
            'from' => $od?$od:date('01.m.Y.'),
            'to' => $do?$do:date('t.m.Y.')
        ]);
    }

    public function intervention_sintetika(Request $request){
        $od = $request->input('start');
        $do = $request->input('end');
        if ($od && $do){
            $start = date('Y-m-d', strtotime($od));
            $end = date('Y-m-d', strtotime($do));
        }
        else {
            $start = null;
            $end = null;
        }

        $statistic = array();
        $razlogInput = $request->input('razlozi');
        $resto = true;
        if ($razlogInput){
            foreach($razlogInput as $raz){
                $findRazlog = Razlozi_intervencije::find($raz)->toArray();
                $razlozi[] = (object)['id'=>$raz, 'razlog'=>$findRazlog['razlog']];
            }
            $razloziIds = Arr::pluck($razlozi, 'id');
            $resto = false;
        }
        else {
            $razlozi = Razlozi_intervencije::all();
            $razloziIds = Arr::pluck($razlozi, 'id');
        }
        $clientTypes = ['klijent'=>'M:SAT DTH'];
        foreach ($clientTypes as $field=>$cli){
            $divider = Statistika::interventionStat(null, $start, $end, false, false, $razloziIds);
            if($resto){
                $ostalo = Statistika::interventionStat(null, $start, $end, null, true);
                $divider += $ostalo;
            }
            if ($divider == 0)
                continue;
            foreach($razlozi as $razlog){
                switch ($razlog->id) {
                    case 1 : $color = '#0088cc'; break;
                    case 2 : $color = '#cc0b4e'; break;
                    case 3 : $color = '#2baab1'; break;
                    case 4 : $color = '#734ba9'; break;
                    case 5 : $color = '#E36159'; break;
                    case 6 : $color = '#00cc2b'; break;
                    default: $color = random_color();
                }
                $statistic[$cli][$razlog->razlog] = [
                    'br' => Statistika::interventionStat($razlog->id, $start, $end),
                    'procenat' =>  number_format(Statistika::interventionStat($razlog->id, $start, $end)*100/$divider,1),
                    'color' => $color
                ];
            }
            if ($resto){
                $statistic[$cli]['ostalo'] = [
                    'br'=>Statistika::interventionStat(null, $start, $end, null, true),
                    'procenat'=>number_format($ostalo*100/$divider, 1),
                    'color'=>'#a3a3a3'
                ];
            }
        }

        $razlozi = Razlozi_intervencije::all();
        return view('statistika.intervention_sintetika', [
            'statistic' => $statistic,
            'razlozi' => $razlozi,
            'from' => $od?$od:date('01.m.Y.'),
            'to' => $do?$do:date('t.m.Y.')
        ]);
    }

    public function intervention_analitika(Request $request){
        $od = $request->input('start');
        $do = $request->input('end');
        $monter = $request->input('monter');
        if ($od && $do){
            $start = date('Y-m-d', strtotime($od));
            $end = date('Y-m-d', strtotime($do));
        }
        else {
            $start = null;
            $end = null;
        }

        $statistic = array();
        $razlogInput = $request->input('razlozi');
        $resto = true;
        if ($razlogInput){
            foreach($razlogInput as $raz){
                $findRazlog = Razlozi_intervencije::find($raz)->toArray();
                $razlozi[] = (object)['id'=>$raz, 'razlog'=>$findRazlog['razlog']];
            }
            $razloziIds = Arr::pluck($razlozi, 'id');
            $resto = false;
        }
        else {
            $razlozi = Razlozi_intervencije::all();
            $razloziIds = Arr::pluck($razlozi, 'id');
        }

        $clientTypes = ['klijent'=>'M:SAT DTH'];

        foreach ($clientTypes as $field=>$cli){
            $divider = Statistika::interventionStat(null, $start, $end, $monter, false, $razloziIds);
            if ($resto) {
                $ostalo = Statistika::interventionStat(null, $start, $end, $monter, true);
                $divider += $ostalo;
            }
            if ($divider == 0)
                continue;
            foreach($razlozi as $razlog){
                switch ($razlog->id) {
                    case 1 : $color = '#0088cc'; break;
                    case 2 : $color = '#cc0b4e'; break;
                    case 3 : $color = '#2baab1'; break;
                    case 4 : $color = '#734ba9'; break;
                    case 5 : $color = '#E36159'; break;
                    case 6 : $color = '#00cc2b'; break;
                    default: $color = random_color();
                }
                $statistic[$cli][$razlog->razlog] = [
                    'br' => Statistika::interventionStat($razlog->id, $start, $end, $monter),
                    'procenat' =>  number_format(Statistika::interventionStat($razlog->id, $start, $end, $monter)*100/$divider,1),
                    'color' => $color
                ];
            }
            if ($resto) {
                $statistic[$cli]['ostalo'] = [
                    'br' => Statistika::interventionStat(null, $start, $end, $monter, true),
                    'procenat' => number_format($ostalo * 100 / $divider, 1),
                    'color' => '#a3a3a3'
                ];
            }
        }

        $monteri = Util::monteri();
        if ($monter){
            $mnt = User::find($monter);
            $monterData = $mnt->ime.' '.$mnt->prezime;
        }
        else {
            $monterData = 'svi monteri';
        }

        $razlozi = Razlozi_intervencije::all();
        return view('statistika.intervention_analitika', [
            'statistic' => $statistic,
            'monteri' => $monteri,
            'monter' => $monterData,
            'razlozi' => $razlozi,
            'from' => $od?$od:date('01.m.Y.'),
            'to' => $do?$do:date('t.m.Y.')
        ]);
    }

    public function upotreba_opreme(Request $request){
        $monterId = $request->input('monter');
        $od = $request->input('start');
        $do = $request->input('end');
        if ($od && $do){
            $start = date('Y-m-d', strtotime($od));
            $end = date('Y-m-d', strtotime($do));
        }
        else {
            $start = null;
            $end = null;
        }

        $fields = ['klijent' => 'id_klijent', 'klijenti_optika' => 'id_opticki_klijent', 'klijenti_bakar' => 'id_bakar_klijent'];

        $statistic = array();

        $okModel = new Oprema_klijent();
        foreach($fields as $client=>$field){
            $equipment = $okModel->equipmentStat($client, $field, $monterId, $start, $end);
            $statistic[$client] = $equipment;
        }

        $monteri = Util::monteri();
        $monter = User::find($monterId);
        if ($monterId)
            $monter = $monter->ime.' '.$monter->prezime;
        else
            $monter = '';

        return view ('statistika.upotreba_opreme', [
            'statistic' => $statistic,
            'monteri' => $monteri,
            'monter' => $monter,
            'from' => $od?$od:date('01.m.Y.'),
            'to' => $do?$do:date('t.m.Y.')
        ]);
    }

    public function monter_marks(Request $request){
        $monterId = $request->input('monter');
        $from = database_date($request->input('start'));
        $to = database_date($request->input('end'));
        $monteri = Util::monteri();
        $monter = User::find($monterId);
        if ($monterId)
            $monter = $monter->ime.' '.$monter->prezime;
        else
            $monter = '';

        if(!$from)
            $from = date('Y-m-01');
        if(!$to)
            $to = date('Y-m-t');

        $statistic = Statistika::marks($from, $to, $monterId);

        return view ('statistika.monter_marks', [
            'statistic' => $statistic,
            'monteri' => $monteri,
            'monter' => $monter,
            'from' => $from?$from:date('01.m.Y.'),
            'to' => $to?$to:date('t.m.Y.')
        ]);
    }

    public function work_days(Request $request){
        $from = database_date($request->input('start'));
        $to = database_date($request->input('end'));
        if(!$from)
            $from = date('Y-m-01');
        if(!$to)
            $to = date('Y-m-t');
        $fitter = $request->input('fitter');

        if($fitter == null)
            $fitter = ['0' => null];
        
        if ($fitter[0] == null){
            $fitterIds = Arr::pluck(Util::monteri(), 'id');
        }
        else {
            $fitterIds = $fitter;
        }
        $workDays = array();
        foreach($fitterIds as $id){
            $statistic = Statistika::work_days($id, $from, $to);
            if($statistic)
                $workDays[$statistic->fitter] = $statistic->days;
        }
        $fitters = Util::monteri();
        return view('statistika.work_days', [
            'workDays' => $workDays,
            'fitters' => $fitters,
            'from' => $from,
            'to' => $to,
            'fitters' => $fitters,
            'workDdays' => $workDays
        ]);
    }

    public function seller_points(Request $request){
        $sellerId = $request->input('seller');
        $from = database_date($request->input('start'));
        $to = database_date($request->input('end'));
        $sellers = Util::allSellers();
        $seller = User::find($sellerId);
        if ($sellerId)
            $seller = $seller->ime.' '.$seller->prezime;
        else
            $seller = '';

        if(!$from)
            $from = date('Y-m-01');
        if(!$to)
            $to = date('Y-m-t');

        $tables = ['klijent', 'klijenti_optika', 'klijenti_supernova', 'klijenti_bakar'];

        $statistic = array();
        $points = 0;
        if($sellerId){
            foreach($tables as $table){
                $points += Statistika::points($from, $to, $sellerId, $table);
            }
            $statistic[$seller] = $points;
        }
        else {
            foreach($sellers as $s){
                foreach($tables as $table){
                    $points += Statistika::points($from, $to, $s->id, $table);
                }
                $statistic[$s->ime.' '.$s->prezime] = $points;
                $points = 0;
            }
        }

        return view ('statistika.seller_points', [
            'statistic' => $statistic,
            'sellers' => $sellers,
            'seller' => $seller,
            'from' => $from?$from:date('01.m.Y.'),
            'to' => $to?$to:date('t.m.Y.')
        ]);
    }

    public function used_equipment(Request $request){
        $equipmentId = $request->input('equipment');
        $from = database_date($request->input('start'));
        $to = database_date($request->input('end'));
        $findEquipment = Oprema::find($equipmentId);
        if($findEquipment)
            $equipmentName = $findEquipment->naziv;
        else
            $equipmentName = null;
        if(!$from)
            $from = date('Y-m-01');
        if(!$to)
            $to = date('Y-m-t');
        $equipment = Oprema::all();
        $okMod = new Oprema_klijent();
        $quantity = $okMod->usedEquipmentStatistic($from, $to, $equipmentId);
        return view('statistika.used_equipment', ['equipment' => $equipment, 'quantity' => $quantity, 'equipmentName' => $equipmentName]);
    }
}
