<?php

namespace App\Http\Controllers;

use App\Statusi;
use App\Traits\Util;
use Aws\S3\Enum\Status;
use Illuminate\Http\Request;
use DB;
use Matrix\Exception;

class StatusController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
        $statusi = Statusi::all();
        return view('statusi.index', ['statusi' => $statusi, 'admin' => Util::isSuperAdmin()]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('statusi.create');

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
             'status' => 'required'
        ]);
        $status = Statusi::create([
            'status' => trim($request->input('status')),
            'default' => 0
        ]);

        $statusi = Statusi::all();
        if ($status){
            return view('statusi.index', ['statusi' => $statusi, 'admin' => Util::isSuperAdmin()]);
        }
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Statusi  $statusi
     * @return \Illuminate\Http\Response
     */
    public function show(Statusi $status)
    {
        return view('statusi.show', ['statusiArr' => $status]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Statusi  $statusi
     * @return \Illuminate\Http\Response
     */
    public function edit(Statusi $status)
    {
        $statusi = Statusi::find($status->id);

        return view('statusi.edit', ['status' => $statusi]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Statusi  $statusi
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Statusi $status)
    {
        $request->validate([
            'status' => 'required'
        ]);
        $statusUpdate = Statusi::where('id', $status->id)->update([
            'status'=>trim($request->input('status')),
            'default'=>0
        ]);

        if ($statusUpdate){
            return redirect()->route('status.show', ['status' => $status->id])->with('success', __("Data successfully changed"));
        }
        return back()->withInput();
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Statusi  $statusi
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findStatus = Statusi::find($request->input('id_status'));

        try{
            $findStatus->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("Data cannot be deleted"));
        }


        return back()->withInput()->with('error', __("Data cannot be deleted"));
    }
}
