<?php

namespace App\Http\Controllers;

use App\Magz;
use App\Models\Mat_dispatch_notes;
use App\Models\Material_dispatch_note;
use App\Models\Material_logs;
use App\Models\Materials;
use App\Models\Storage_materials;
use App\Models\Worker_materials;
use App\Traits\Util;
use App\User;
use Illuminate\Http\Request;
use setasign\Fpdi\Fpdi;

class StorageMaterialsController extends Controller
{
    private function magz(){
        $magModel = new Magz();
        $magz = $magModel->magzForUser(Util::userId());
        return $magz;
    }
    private function linkForgeryCheck($magId){
        $magModel = new Magz();
        $forgery = $magModel->linkForgeryCheck($magId, Util::userId());
        return $forgery;
    }

    private function updateChangeLog($materialId, $storageId, $quantity, $worker=null){
        if($quantity != 0){
            Material_logs::create([
                'material_id' => $materialId,
                'storekeeper' => Util::userId(),
                'worker' => $worker,
                'storage_id' => $storageId,
                'quantity' => $quantity
            ]);
        }
    }

    public function stockpile_materials(){
        $mMod = new Storage_materials();
        if(Util::isSuperAdmin()) {
            $magz = Magz::all();
        }
        else{
            $magz = $this->magz();
        }
        $stockpile = array();
        foreach($magz as $mag){
            $materials = $mMod->materials_for_storage($mag->id);
            foreach ($materials as $num=>$mat){
                if($mat->quantity<$mat->min_qnt)
                    $blinker = 'alarm-pulse-red';
                else
                    $blinker = '';
                $stockpile[$mag->naziv][$num]['material'] = $mat->material;
                $stockpile[$mag->naziv][$num]['quantity'] = $mat->quantity;
                $stockpile[$mag->naziv][$num]['blinker'] = $blinker;
            }
        }

        return view('storageMaterials.stockpile', ['stockpile' => $stockpile]);
    }

    public function storages(){
        if(Util::isSuperAdmin()){
            $magz = Magz::all();
        }
        else{
            $magz = $this->magz();
        }
        return view('storageMaterials.storages', ['magz' => $magz]);
    }

    public function storage_material(Request $request){
        $id = $request->input('id');
        if($this->linkForgeryCheck($id) && !Util::isSuperAdmin())
            return back()->withInput();
        $mMod = new Storage_materials();
        $materials = $mMod->materials_for_storage($id);
        $storage = Magz::find($id);
        $fitters = Util::allWorkers();
        $mats = Materials::all()->where('is_active', 1);
        return view('storageMaterials.storage_materials', [
            'materials' => $materials, 
            'storage' => $storage,
            'fitters' => $fitters,
            'mats' => $mats
        ]);
    }

    public function fill_material_storage(Request $request){
        $storageId = $request->input('storageId');
        $param = $request->input('param');
        $materialId = $request->input('materialId');
        $mat = Materials::find($materialId);
        if(!$materialId){
            return __("no goods are selected");
        }
        $quantity = $request->input('quantity');
        $operation = $request->input('operation');
        $stMod = new Storage_materials();
        $specificMaterial = $stMod->specific_material($storageId, $materialId);

        if($operation == 'minus'){
            $quantity = -$quantity;
        }

        if($specificMaterial)
            $storageAmmount = $specificMaterial->quantity;
        else 
            $storageAmmount = 0;

        if($param == 'storage'){
            if($storageAmmount + $quantity < 0){
                return __("value has to be a positive number");
            }
            if($specificMaterial){
                $stMod->storage_update($storageId, $materialId, $quantity);
                $this->updateChangeLog($materialId, $storageId, $quantity);
            }
            else {
                Storage_materials::create([
                    'material_id' => $materialId,
                    'storage_id' => $storageId,
                    'quantity' => $quantity
                ]);
                $this->updateChangeLog($materialId, $storageId, $quantity);
            }
        }

        /*giving stuff to worker and removing stuff from selected storage.
          worker equipment can have values, but with quantity 0.*/
        else {
            $userId = $request->input('userId');
            $wmMod = new Worker_materials();
            $specificMaterial = $wmMod->specific_material($userId, $materialId);

            if(isset($specificMaterial->quantity))
                $workerQuantity = $specificMaterial->quantity;
            else
                $workerQuantity = 0;
            if($workerQuantity + $quantity < 0)
                return __("Worker doesn't have goods in his inventory");
            if($storageAmmount >= $quantity){
                if($specificMaterial){
                    $wmMod->material_update($userId, $materialId, $quantity);
                    $stMod->storage_update($storageId, $materialId, -$quantity);
                    $this->updateChangeLog($materialId, $storageId, -$quantity, $userId);
                }
                else{
                    Worker_materials::create([
                        'user_id' => $userId,
                        'material_id' => $materialId,
                        'storage_id' => $storageId,
                        'quantity' => $quantity
                    ]);
                    $stMod->storage_update($storageId, $materialId, -$quantity);
                    $this->updateChangeLog($materialId, $storageId, -$quantity, $userId);
                }
            }
            else {
                return __("not enough goods in warehouse");
            }
        }
        /* session stuff for notification */
        if($storageId && $materialId){
            $specificMaterial = $stMod->specific_material($storageId, $materialId);
            if($specificMaterial)
                $storageAmmount = $specificMaterial->quantity;
            else 
                $storageAmmount = 0;
            $key = $mat->id.'|'.$storageId;
            if($storageAmmount<$mat->min_qnt && Util::isSuperAdmin()){
                $storageName = Magz::find($storageId)->naziv;
                $data = session()->get('material_alarm', []);
                $data[$key] = ['material_name' => $mat->material, 'material_storage' => $storageName, 'min_qnt' => $mat->min_qnt];
                session()->put('material_alarm', $data);
            }
            else {
                session()->forget("material_alarm.$key");
            }
        }
        /* end of session stuff */
        return __("goods successfully added");
    }

    public function worker_materials(){
        $workers =Util::allActiveUsers();
        $wMod = new Worker_materials();
        return view('storageMaterials.storage', ['workers' => $workers, 'wMod' => $wMod]);
    }

    public function worker_material_storage(Request $request){
        $id = $request->input('id');
        $wMod = new Worker_materials();
        $materials = $wMod->materials_for_user($id);
        if(Util::isSuperAdmin())
            $storages = Magz::all();
        else
            $storages = $this->magz();
        $user = User::find($id);
        $mats = Materials::all();
        return view('storageMaterials.worker', [
            'materials' => $materials, 
            'user' => $user, 
            'storages' => $storages,
            'mats' => $mats
        ]);
    }

    public function material_logs(Request $request){
        $storageId = $request->input('storage_id');
        $logMod = new Material_logs();
        $logs = $logMod->logs($storageId);
        return view('storageMaterials.logs', [
            'logs' => $logs
        ]);
    }

    public function worker_material_log(Request $request){
        $worker = $request->input('worker');
        $logMod = new Material_logs();
        $logs = $logMod->worker_logs($worker);
        return view('storageMaterials.worker_logs', [
            'logs' => $logs
        ]);
    }

    //dispatch notes

    public function dispatch_notes(){
        $dnModel = new Mat_dispatch_notes();
        $dispatchNotes = $dnModel->dispatch_notes();
        $currentUser = Util::username();
        $users = Util::allActiveUsers();
        return view('storageMaterials.dispatch_notes', [
            'dispatchNotes' => $dispatchNotes,
            'currentUser' => $currentUser,
            'users' => $users
        ]);
    }

    public function add_dispatch_note(Request $request){
        $currentUser = Util::userId();
        $takenBy = $request->input('taken_by');
        $worker = $request->input('id_worker');
        $request->validate(['taken_by' => 'required', 'id_worker' => 'required']);

        $create = Mat_dispatch_notes::create([
            'storekeeper_id' => $currentUser,
            'taken_by' => $takenBy,
            'user_id' => $worker
        ]);

        if($create){
            return back()->with('success', __("Data successfully added"));
        }
        else {
            return back()->with('error', __("Error"));
        }
    }

    public function edit_dispatch_note(Request $request){
        $id = $request->input('e_id');
        $currentUser = Util::userId();
        $takenBy = $request->input('e_taken_by');
        $worker = $request->input('e_worker');

        $update = Mat_dispatch_notes::where('id', $id)->update([
            'storekeeper_id' => $currentUser,
            'taken_by' => $takenBy,
            'user_id' => $worker
        ]);

        if($update){
            return back()->with('succes',  __("Data successfully changed"));
        }
        else {
            return back()->with('error',  __("Error"));
        }
    }

    public function dispatch_notes_materials(Request $request){
        $dispatchId = $request->input('dispatchId');
        $takenBy = $request->input('takenBy');
        $mMod = new Material_dispatch_note();
        $allMats = Materials::all()->where('is_active', 1);
        $mats = $mMod->material_list($dispatchId);
        $magz = Magz::all();
        $worker = Mat_dispatch_notes::find($dispatchId)->user_id;
        return view('storageMaterials.dispatch_notes_materials', [
            'dispatchId' => $dispatchId,
            'takenBy' => $takenBy,
            'mats' => $mats,
            'allMats' => $allMats,
            'magz' => $magz,
            'worker' => $worker
        ]);
    }

    public function dispatch_notes_scan(Request $request){
        $dispatchId = $request->input('dispatchId');
        $material = $request->input('material');
        $quantity = (float)$request->input('quantity');
        $warehouse = $request->input('warehouse');
        $worker = $request->input('worker');
        $request->validate([
            'quantity' => 'required|numeric',
            'material' => 'required',
            'warehouse' => 'required'
        ]);

        $sModel = new Storage_materials();
        $wmMod = new Worker_materials();
        $specificMaterialWorker = $wmMod->specific_material($worker, $material);
        $storageMaterial = $sModel->specific_material($warehouse, $material);
        if($storageMaterial)
            $storageAmmount = $storageMaterial->quantity;
        else
            $storageAmmount = 0;
        if($storageAmmount >= $quantity){
            if($specificMaterialWorker){
                $wmMod->material_update($worker, $material, $quantity);
            }
            else {
                Worker_materials::create([
                    'user_id' => $worker,
                    'material_id' => $material,
                    'storage_id' => $warehouse,
                    'quantity' => $quantity
                ]);
            }
            $sModel->storage_update($warehouse, $material, -$quantity);
            $this->updateChangeLog($material, $warehouse, -$quantity, $worker);
        }
        else {
            return back()->with('error',__("not enough goods in warehouse"));
        }

        //check if row is created in database, update it or create new
        $duplicate = Material_dispatch_note::where('dispatch_note_id', $dispatchId)->where('material_id', $material)->get();
        if($duplicate->isEmpty()){
            $hasDuplicate = false;
        }
        else{
            $hasDuplicate = true;
        }

        if($hasDuplicate){
            Material_dispatch_note::where('dispatch_note_id', $dispatchId)->where('material_id', $material)->increment('quantity', $quantity);
            return back()->with('success', __("Equipment successfully added"));
        }
        else {
            $create = Material_dispatch_note::create([
                'material_id' => $material,
                'dispatch_note_id' => $dispatchId,
                'quantity' => $quantity
            ]);
            if ($create)
                return back()->with('succes', __("Equipment successfully added"));
            else
                return back()->with('errors', __("Error"));
        }

    }

    public function delete_dispatch_note(Request $request){
        $id = $request->input('delete_id');
        $find = Material_dispatch_note::find($id);

        try{
            $find->delete();
            return back()->with('success', __("Item successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->with('error', __("Item can't be deleted because it's in use"));
        }

        return back()->with('error', __("Deletion is not possible"));
    }

    public function delete_material_from_document(Request $request){
        $id = $request->input('delete_id');
        $find = Material_dispatch_note::find($id);

        try{
            $find->delete();
            return back()->with('success', __("Item successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->with('error', __("Item can't be deleted because it's in use"));
        }

        return back()->with('error', __("Deletion is not possible"));
    }
    
    public function material_pdf(Request $request)
    {
        require_once('../vendor/setasign/fpdf/fpdf.php');
        require_once('../vendor/setasign/fpdi/src/autoload.php');

        $idOtpr = $request->input('dn_id');

        $otpMod = new Mat_dispatch_notes();
        $otp = $otpMod->dispatch_note_data($idOtpr);
        $matMod = new Material_dispatch_note();
        $materials = $matMod->material_list($idOtpr);
        $storekeeper = iconv('UTF-8', 'Windows-1250', $otp->storekeeper_name . ' ' . $otp->storekeeper_surname);
        $takenBy = iconv('UTF-8', 'Windows-1250', $otp->fitter_name.' '.$otp->fitter_surname);
        $creationDate = date('d.m.Y.', strtotime($otp->created_at));
        $creationTime = date('H:i', strtotime($otp->created_at));

        $pdf = new Fpdi();
        $pdf->addPage();
        $pdf->setSourceFile('../public/templates/memo.pdf');
        $tplIdx = $pdf->importPage(1);
        $pdf->useTemplate($tplIdx, null, null, null, null, true);

        $pdf->AddFont('DejaVu', '', 'DejaVuSans.php');
        $pdf->SetFont('DejaVu', '', 11);
        $pdf->SetTextColor(0, 0, 0);
        $pdf->SetXY(25, 70);
        $pdf->SetFont('DejaVu', '', 11);
        $pdf->Write(0, __("Delivery note").' '.__("No.").' '. $otp->id);
        $pdf->SetXY(25, 76);
        $pdf->Write(0, __("Date").' '. $creationDate);
        $pdf->SetXY(25, 82);
        $pdf->Write(0, __("Time").' ' . $creationTime);
        $pdf->SetXY(25, 88);
        $pdf->Write(0, __("Storekeeper").' ' . $storekeeper);

        if (!$materials->isEmpty()){

            $y = 90;
            $x = 10;
            $pdf->SetFont('DejaVu', '', 12);
            $pdf->SetXY($x, $y);
            $pdf->SetFont('DejaVu', '', 10);
            $y+=5;
            foreach ($materials as $mat) {
                $y += 5;
                $x = 10; // Assuming starting X position
            
                // Splitting the text into multiple lines if it exceeds the cell width
                $lines = wordwrap($mat->material, 80, "\n", true); // 20 is the maximum characters per line, adjust as needed
            
                // Writing each line separately
                $linesArray = explode("\n", $lines);
                foreach ($linesArray as $line) {
                    $pdf->SetXY($x, $y);
                    $pdf->Write(0, iconv('UTF-8', 'Windows-1250', $line));
                    $y += 5; // Adjust this value according to your font size and line spacing
                }

                $pdf->Line(10, $y, $pdf->GetPageWidth()-10, $y);
            
                // Writing the second cell
                $pdf->SetXY($x + 160, $y - 5); // Adjust the X position accordingly
                $pdf->Write(0, '('.$mat->quantity.')');
            }

        }
        

        $y+=20;
        $pdf->SetXY($x, $y);
        $pdf->SetFont('DejaVu', '', 10);
        $pdf->Write(0, __("Goods taken by").': ');
        $pdf->SetXY($x+29, $y);
        $y += 6;
        $pdf->SetXY($x, $y);
        $pdf->Write(0, __("JMBG").': ' . $otp->jmbg);
        $y += 6;
        $pdf->SetXY($x, $y);
        $pdf->Write(0, iconv('UTF-8', 'Windows-1250', __("Seal and signature").': _________________________'));
        
        
        $pdf->Output('material_' . time() . '.pdf', 'D');
    }

}
