<?php

namespace App\Http\Controllers;

use App\Magacin;
use App\Magacin_history;
use App\Uredjaji;
use App\Models\Tool_logs;
use App\User;
use App\Models\Worker_tools;
use App\Models\Tools;
use App\Models\Tool_types;
use App\Traits\Util;
use App\Models\Storage_tools;
use App\Magz;
use App\Models\Device_states;
use App\Models\Tool_delivered_goods;
use App\Models\Tool_delivery_notes;
use App\Models\Tool_origins;
use App\Models\Tool_providers;
use App\Models\Tool_reverse;
use App\Models\Tool_reverse_goods;
use Illuminate\Http\Request;
use Illuminate\Support\Arr;
use setasign\Fpdi\Fpdi;

class StorageToolsController extends Controller
{
    private function magz(){
        if(!Util::isSuperAdmin()){
            $magModel = new Magz();
            $magz = $magModel->magzForUser(Util::userId());
            return $magz;
        }
        else {
            return Magz::all()->where('type_id', 4);
        }
    }
    private function linkForgeryCheck($magId){
        $magModel = new Magz();
        $forgery = $magModel->linkForgeryCheck($magId, Util::userId());
        return $forgery;
    }
    private function updateChangeLog($toolId, $storageId, $quantity, $worker=null){
        if($quantity != 0){
            Tool_logs::create([
                'tool_id' => $toolId,
                'storekeeper' => Util::userId(),
                'worker' => $worker,
                'storage_id' => $storageId,
                'quantity' => $quantity
            ]);
        }
    }

    public function tool_devices_inventory(){
        $magacinMod = new Magacin();
        $trevMod = new Tool_reverse_goods();
        //tools are category 2
        $devicesArray = Uredjaji::all()->where('category_id', '=', 2);
        $devices = array();
        $devicesInStorage = array();
        foreach ($devicesArray as $dev){
            $devices[$dev->uredjaj] = $magacinMod->deviceCount(null, $dev->id);
            $specDeviceStorage = $magacinMod->specificDeviceAmountInStorage($dev->id);
            $deviceRevers = $trevMod->reversCount($dev->id);
            $amount = $specDeviceStorage - $deviceRevers;
            if($amount < 0)
                $amount = 0;
            $devicesInStorage[$dev->uredjaj] = $amount;
        }

        $magacini = Magz::all()->where('type_id', 4);

        $magz = array();
        $magzRev = array();
        foreach ($magacini as $mag){
            foreach ($devicesArray as $dev){
                $magz[$mag->naziv][$dev->uredjaj] = $magacinMod->deviceCount($mag->id, $dev->id);
                $count = $magacinMod->deviceCount($mag->id, $dev->id)->count - $trevMod->reversCount($dev->id, $mag->id);
                $magzRev[$mag->naziv][$dev->uredjaj] = $count;
            }
        }

        return view('storageTools.tool_devices_inventory', [
            'devices' => $devices,
            'magz' => $magz,
            'devicesInStorage' => $devicesInStorage,
            'magzRev' => $magzRev
        ]);
    }

    public function stockpile_tools(){
        $stMod = new Storage_tools();
        $wtMod = new Worker_tools();
        if(Util::isSuperAdmin()) {
            $magz = Magz::all()->where('type_id', '=', 4);
        }
        else{
            $magz = $this->magz();
        }

        $tools = Tools::all();
        $stockpile = array();
        foreach($magz as $mag){
            foreach ($tools as $num=>$tool){
                $sTool = $stMod->specific_tool($mag->id, $tool->id);
                $wTool = $wtMod->specific_equipment_for_storage($mag->id, $tool->id);
                if(!$sTool) continue;
                if($wTool)
                    $quantity = $sTool->quantity + $wTool->quantity;
                else
                    $quantity = $sTool->quantity;

                $stockpile[$mag->naziv][$num]['tool'] = $sTool->tool;
                $stockpile[$mag->naziv][$num]['quantity'] = $quantity;
                $stockpile[$mag->naziv][$num]['provider'] = $sTool->provider;
                $stockpile[$mag->naziv][$num]['invoice_number'] = $sTool->invoice_number;
                $stockpile[$mag->naziv][$num]['origin'] = $sTool->invoice_number;
                $stockpile[$mag->naziv][$num]['type'] = $sTool->type;
            }
        }

        return view('storageTools.stockpile', ['stockpile' => $stockpile]);
    }

    public function storages(){
        if(Util::isSuperAdmin()){
            $magz = Magz::all()->where('type_id', 4);
        }
        else{
            $magz = $this->magz();
        }
        return view('storageTools.storages', ['magz' => $magz]);
    }

    public function storage_tool(Request $request){
        $id = $request->input('id');
        if($this->linkForgeryCheck($id) && !Util::isSuperAdmin())
            return back()->withInput();
        $tMod = new Storage_tools();
        $toolTypes = Tool_types::all();
        $tools = $tMod->tools_for_storage($id);
        $storage = Magz::find($id);
        $fitters = Util::allWorkers();
        return view('storageTools.storage_tools', [
            'tools' => $tools, 
            'toolTypes' => $toolTypes, 
            'storage' => $storage,
            'fitters' => $fitters
        ]);
    }

    public function tool_populate(Request $request){
        $output = '';
        $id = $request->get('id');
        $tMod = new Tools();
        $tools = $tMod->toolsByType($id);
        foreach($tools as $tool){
            $output .= '<option value="'.$tool->id.'">'.$tool->tool;
            if($tool->origin)
                $output .= ' -'.$tool->origin;
            if($tool->invoice_number)
                $output .= ' - '.$tool->invoice_number;
            if($tool->provider)
                $output .= ' - '.$tool->provider;
            $output .= '</option>';
        }
        return $output;
    }

    public function fill_tool_storage(Request $request){
        $storageId = $request->input('storageId');
        $param = $request->input('param');
        $toolId = $request->input('toolId');
        if(!$toolId){
            return __("no goods are selected");
        }
        $quantity = $request->input('quantity');
        $operation = $request->input('operation');
        $stMod = new Storage_tools();
        $specificTool = $stMod->specific_tool($storageId, $toolId);

        if($operation == 'minus'){
            $quantity = -$quantity;
        }

        if($specificTool)
            $storageAmmount = $specificTool->quantity;
        else 
            $storageAmmount = 0;
        if($param == 'storage'){
            if($storageAmmount + $quantity < 0){
                return __("value has to be a positive number");
            }
            if($specificTool){
                $stMod->storage_update($storageId, $toolId, $quantity);
                $this->updateChangeLog($toolId, $storageId, $quantity);
            }
            else {
                Storage_tools::create([
                    'tool_id' => $toolId,
                    'storage_id' => $storageId,
                    'quantity' => $quantity
                ]);
                $this->updateChangeLog($toolId, $storageId, $quantity);
            }
        }
        /*giving stuff to worker and removing stuff from selected storage.
          worker equipment can have values, but with quantity 0.*/
        else {
            $userId = $request->input('userId');
            $wtMod = new Worker_tools();
            $specificTool = $wtMod->specific_equipment($userId, $toolId);
            if(isset($specificTool->quantity))
                $workerQuantity = $specificTool->quantity;
            else
                $workerQuantity = 0;
            if($workerQuantity + $quantity < 0)
                return __("Worker doesn't have goods in his inventory");
            if($storageAmmount >= $quantity){
                if($specificTool){
                    $wtMod->tool_update($userId, $toolId, $quantity);
                    $stMod->storage_update($storageId, $toolId, -$quantity);
                    $this->updateChangeLog($toolId, $storageId, -$quantity, $userId);
                }
                else{
                    Worker_tools::create([
                        'user_id' => $userId,
                        'tool_id' => $toolId,
                        'storage_id' => $storageId,
                        'quantity' => $quantity
                    ]);
                    $stMod->storage_update($storageId, $toolId, -$quantity);
                    $this->updateChangeLog($toolId, $storageId, -$quantity, $userId);
                }
            }
            else {
                return __("not enough goods in warehouse");
            }
        }
        return __("goods successfully added");
    }

    public function worker_tools(){
        $builders = Util::builders();
        $monters = Util::allWorkers();
        $workers = $builders->merge($monters);
        $wtMod = new Worker_tools();
        return view('storageTools.storage', ['workers' => $workers, 'wtMod' => $wtMod]);
    }

    public function worker_tool_storage(Request $request){
        $id = $request->input('id');
        $wtMod = new Worker_tools();
        $toolTypes = Tool_types::all();
        $tools = $wtMod->tools_for_user($id);
        if(Util::isSuperAdmin())
            $storages = Magz::all()->where('type_id', 4);
        else
            $storages = $this->magz();
        $user = User::find($id);
        return view('storageTools.worker', [
            'tools' => $tools, 
            'toolTypes' => $toolTypes, 
            'user' => $user, 
            'storages' => $storages
        ]);
    }

    public function tool_logs(Request $request){
        $storageId = $request->input('storage_id');
        $logMod = new Tool_logs();
        $logs = $logMod->logs($storageId);
        return view('storageTools.logs', [
            'logs' => $logs
        ]);
    }

    public function tools_print(Request $request){
        require_once ('../vendor/setasign/fpdf/fpdf.php');
        require_once ('../vendor/setasign/fpdi/src/autoload.php');
        $id = $request->input('id');
        $wMod = new Worker_tools();
        $tools = $wMod->tools_for_user($id);
        $user = User::find($id);
        $pdf = new Fpdi();
        $pdf->addPage();
        $x = 10;
        $y = 10;
        $pdf->AddFont('DejaVu', '', 'DejaVuSans.php');
        $pdf->SetFont('DejaVu', 'U', 15);
        $pdf->Text($x, $y, iconv('UTF-8', 'Windows-1250', $user->ime.' '.$user->prezime));
        $y+=5;
        $pdf->SetFont('DejaVu', '', 10);
        $counter = 0;
        foreach($tools as $tool){
            $pdf->Text($x, $y, iconv('UTF-8', 'Windows-1250//IGNORE', $tool->type.' '.$tool->tool.' '.__('Qty')).': ('.$tool->quantity.')');
            $y+=5;
            $counter++;
            if($counter == 56){
                $pdf->addPage();
                $x = 10;
                $y = 10;
                $counter = 0;
            }
        }

        $pdf->Output(__('Tools').'.pdf', 'D');
    }

    //devices part
    public function tool_device(){
        $magMod = new Magacin();
        $robaMagacin = $magMod->robaMagacin(2);
        $devices = Uredjaji::all()->where('category_id', 2);
        return view('storageTools.tool_device_add', [
            'roba_magacin' => $robaMagacin,
            'devices' => $devices
        ]);
    }

    public function tool_device_add(Request $request){
        $magMod = new Magacin();
        $robaMagacin = $magMod->robaMagacin(2);
        $tip = $request->input('device');
        $urMod = new Uredjaji();
        $uredjaj = $urMod->uredjajIme($tip);
        $providers = Tool_providers::all();
        $origins = Tool_origins::all();
        $magz = Magz::all()->where('type_id', 4);
        return view('storageTools.scaning', [
            'tip' => $tip,
            'magz' => $magz,
            'uredjaj' => $uredjaj->uredjaj,
            'roba_magacin' => $robaMagacin,
            'providers' => $providers,
            'origins' => $origins
        ]);
    }

    public function tool_device_scan(Request $request){
        $mag = $request->input('mag')[0];
        $srBr = $request->input('serijski_broj');
        $serijskiBroj = serialTrim($srBr);
        $qrCode = $request->input('qr_code');
        $provider = $request->input('provider');
        $origin = $request->input('origin');
        $invoiceNumber = $request->input('invoice_number');
        $magMod = new Magacin();
        if($qrCode){
            $QRcodes = explode(' ', $qrCode);
        }

        session(['mag' => $mag]);
        //if qr code is scanned it has priority over single serial scan
        if($qrCode){
            foreach($QRcodes as $code){
                $serialMatch = $magMod->serialMatch($code);
                if (!$serialMatch) {
                    $magacin = Magacin::create([
                        'serijski_broj' => trim($code),
                        'id_uredjaj' => $request->input('tip'),
                        'id_mag' => $mag,
                        'id_magacioner' => Util::userId(),
                        'provider' => $provider,
                        'origin' => $origin,
                        'invoice_number' => $invoiceNumber
                    ]);
                    if ($magacin) {
                        Magacin_history::create([
                            'id_user' => Util::userId(),
                            'serijski_broj' => $code,
                            'device_id' => $request->input('tip')
                        ]);
                    }
                }
            }
            return back()->with('success', __("Goods successfully added to the warehouse"));
        }
        //if there is no qr code, then scan single device
        else {
            $request->validate([
                'serijski_broj' => 'required|string|max:25',
            ]);
            $serialMatch = $magMod->serialMatch($serijskiBroj);
            if (!$serialMatch) {
                $magacin = Magacin::create([
                    'serijski_broj' => $serijskiBroj,
                    'id_uredjaj' => $request->input('tip'),
                    'id_mag' => $mag,
                    'id_magacioner' => Util::userId(),
                    'provider' => $provider,
                    'origin' => $origin,
                    'invoice_number' => $invoiceNumber
                ]);
                if ($magacin) {
                    Magacin_history::create([
                        'id_user' => Util::userId(),
                        'serijski_broj' => $serijskiBroj,
                        'device_id' => $request->input('tip')
                    ]);
                    return back()->with('success', __("Goods successfully added to the warehouse"));
                }
            } else {
                if($serialMatch)
                    return back()->with('errors', __("This product already exists in the warehouse"));
            }
        }
    }

        /* ---------------------------------------revers--------------------------------------------*/
        public function reverse(){
            $monteri = Util::allWorkers();
            $revMod = new Tool_reverse();
            $reversi = $revMod->reverses();
            $magz = $this->magz();
    
            return view('storageTools.reverse', [
                'monteri' => $monteri,
                'reversi' => $reversi,
                'magacioner' => Util::username(),
                'magz' => $magz
            ]);
        }
    
        public function add_reverse(Request $request){
            $monter = $request->input('monter');
            $text = $request->input('text');
            $warehouse = $request->input('warehouse');
            $revCreate = Tool_reverse::create([
                'worker_id' => $monter,
                'storekeeper_id' => Util::userId(),
                'text' => $text,
                'storage_id' => $warehouse
            ]);
    
            if ($revCreate)
                return back()->with('success', __("Reverse created"));
        }
    
        public function reverse_device(Request $request){
            $reversId = $request->input('reverse_id');
            $monterId = $request->input('worker_id');
            $text = $request->input('text');
            $revMod = new Tool_reverse_goods();
            $reversGoods = $revMod->revGoods($reversId);
            if($text){
                $monter = $text;
            }
            else {
                $monter = User::find($monterId);
                if($monter)
                    $monter = $monter->ime.' '.$monter->prezime;
            }
            return view('storageTools.reverse_scanning', [
                'id_revers' => $reversId,
                'monter' => $monter,
                'reversGoods' => $reversGoods,
                'warehouses' => $this->magz()
            ]);
        }
    
        public function reverse_scanning(Request $request){
            $srBr = $request->input('serijski_broj');
            $serijskiBroj = serialTrim($srBr);
            $idRevers = $request->input('id_revers');
            $QRcode = $request->input('qr_code');
            $QRcodes = array();
            if(!$QRcode){
                $request->validate([
                    'serijski_broj' => 'required',
                ]);
            }
            else {
                $QRcodes = explode(' ', $QRcode);
            }
            $magMod = new Magacin();
            $reversMod = new Tool_reverse();
            $error = false;
            $errorMessage = '';
            //errors
            if($QRcode){
                foreach($QRcodes as $code){
                    if($code == '') continue;
                    //check if it's in storage
                    $magacin = $magMod->checkSerial($code);
                    //check if it's in revers
                    $duplikat = $reversMod->checkIfOnRevers($code);
                    if($magacin->isEmpty()){
                        $error = true;
                        $errorMessage .= __("Product").' '.__("does not exist in stock");
                        break;
                    }
                    if($duplikat){
                        $error = true;
                        $errorMessage .= __("This product is already on reverse").' '.$duplikat;
                        break;
                    }
                }
            }
    
            if($error)
                return back()->with('error', $errorMessage);
    
            if($QRcode){
                foreach($QRcodes as $code){
                    if($code == '') continue;
                    $magacin = $magMod->checkSerial($code);
                    $deviceId = $magacin[0]->id_uredjaj;
                    $storageId = $magacin[0]->id_mag;
                    $providerId = $magacin[0]->provider;
                    $invoiceNumber = $magacin[0]->invoice_number;
                    $origin = $magacin[0]->origin;
                    $revers = Tool_reverse_goods::create([
                        'serial_number' => $code,
                        'device_id' => $deviceId,
                        'reverse_id' => $idRevers,
                        'storage_id' => $storageId,
                        'provider_id' => $providerId,
                        'invoice_number' => $invoiceNumber,
                        'origin' => $origin
                    ]);
                }
                return back()->with('success', __("Product has been shipped"));
            }
            else {
                //da li se nalazi u magacin
                $magacin = $magMod->checkSerial($serijskiBroj);
                //da li se vec nalazi na revers
                $duplikat = $reversMod->checkIfOnRevers($serijskiBroj);
                if ($duplikat){
                    $errorMessage .= __("This product is already on reverse").' '.$duplikat;
                    return back()->with('error', $errorMessage);
                }
                if (isset($magacin[0])){
                    $deviceId = $magacin[0]->id_uredjaj;
                    $storageId = $magacin[0]->id_mag;
                    $providerId = $magacin[0]->provider;
                    $invoiceNumber = $magacin[0]->invoice_number;
                    $origin = $magacin[0]->origin;
                    $revers = Tool_reverse_goods::create([
                        'serial_number' => $serijskiBroj,
                        'device_id' => $deviceId,
                        'reverse_id' => $idRevers,
                        'storage_id' => $storageId,
                        'provider_id' => $providerId,
                        'invoice_number' => $invoiceNumber,
                        'origin' => $origin
                    ]);
                    if ($revers){
                        return back()->with('success', __("Product has been shipped"));
                    }
                }
                else {
                    return back()->with('error', __("Device").' '.__("does not exist in stock"));
                }
            }
        }
    
        public function reverse_search(){
            return view('storageTools.reverse_search', [
                'monteri' => Util::allWorkers(),
                'magacioneri' => Util::magacioneri()
            ]);
        }
    
        public function reverse_search_result(Request $request){
            $monter = $request->input('monter')[0];
            $magacioner = $request->input('magacioner')[0];
            $serijskiBroj = serialTrim($request->input('serijski_broj'));
            $brojReversa = $request->input('broj_reversa');
            $od = $request->input('start');
            $do = $request->input('end');
            if ($od && $do){
                $start = date('Y-m-d', strtotime($od));
                $end = date('Y-m-d', strtotime($do));
            }
            else {
                $start = null;
                $end = null;
            }
    
            $reversModel = new Tool_reverse();
            $reversi = $reversModel->reverse_search($monter, $magacioner, $serijskiBroj, $start, $end, $brojReversa);
            return view('storageTools.reverse_search_result', [
                'reversi' => $reversi
            ]);
        }

        public function delete_reverse(Request $request){
            $id = $request->input('reverse_id');
            $find = Tool_reverse::find($id);
            if($find->delete())
                return back()->with('success', __('Data successfully deleted'));
            else
                return back()->with('error', __('Error'));
        }

        public function delete_goods_reverse(Request $request){
            $id = $request->input('good_reverse');
            $find = Tool_reverse_goods::find($id);
            if($find->delete())
                return back()->with('success', __('Data successfully deleted'));
            else
                return back()->with('error', __('Error'));
        }

            /* ---------------------------------------------- search ------------------------------------------------------ */

    public function tool_device_search(){
        $magacioneri = Util::magacioneri();
        $magacini = Magz::all()->where('type_id', 4);
        $uredjaji = Uredjaji::all()->where('category_id', '=', 2);
        $states = Device_states::all();
        return view('storageTools.device_search', [
            'magacioneri' => $magacioneri,
            'uredjaji' => $uredjaji,
            'magacini' => $magacini,
            'states' => $states
        ]);
    }

    public function tool_device_search_result(Request $request){
        $tMod = new Storage_tools();
        $serial = Util::serialTrim($request->input('serial'));
        $device = $request->input('device');
        $storage = $request->input('storage');
        $storekeeper = $request->input('storekeeper');
        $start = $request->input('start');
        $end = $request->input('end');
        $notOnReverse = $request->input('not_on_reverse');
        $deviceState = $request->input('device_state');

        if ($start)
            $start = date('Y-m-d', strtotime($start));
        if ($end)
            $end = date('Y-m-d', strtotime($end));


        $goods = $tMod->search($serial, $device, $storage, $storekeeper, $start, $end, $notOnReverse, $deviceState);
        $serials = Arr::pluck($goods, 'serial_number');
        $serials = json_encode($serials);
        return view('storageTools.device_search_result', [
            'roba_magacin' => $goods,
            'serials' => $serials,
            'states' => Device_states::all()
        ]);
    }

    public function tool_storage_history(Request $request){
        $historyModel = new Magacin_history();
        $history = $historyModel->tools_history($request->input('serijski_broj'), database_date($request->input('history_date')));

        return view('storageTools.history', [
            'history' => $history,
        ]);
    }
            /* ---------------------------------------------- export ------------------------------------------------------ */

    public function export_pdf(Request $request){
        
        require_once ('../vendor/setasign/fpdf/fpdf.php');
        require_once ('../vendor/setasign/fpdi/src/autoload.php');

        $idRev = $request->input('id_revers');

        $revMod = new Tool_reverse();
        $rev = $revMod->revers($idRev);
        $stavke = $revMod->robaStavke($idRev);
        $robaCount = $revMod->robaCount($idRev);
        $magacioner = iconv('UTF-8', 'Windows-1250', $rev->magacioner_ime.' '. $rev->magacioner_prezime);
        if($rev->text)
            $monter = iconv('UTF-8', 'Windows-1250', $rev->text);
        else
            $monter = iconv('UTF-8', 'Windows-1250', $rev->monter_ime.' '. $rev->monter_prezime);
        $datumIzrade = date('d.m.Y.', strtotime($rev->created_at));
        $vremeIzrade = date('H:i', strtotime($rev->created_at));

        $pdf = new Fpdi();
        $pdf->addPage();
        $pdf->setSourceFile('../public/templates/memo.pdf');
        $tplIdx = $pdf->importPage(1);
        $pdf->useTemplate($tplIdx, null, null, null,null, true);

        $pdf->AddFont('DejaVu','','DejaVuSans.php');
        $pdf->SetFont('DejaVu','',11);
        $pdf->SetTextColor(0,0,0);
        $pdf->SetXY(25, 70); //this
        $pdf->SetFont('DejaVu','',11);
        $pdf->Write(0, __("Reverse").' '.__("No.").' '.$rev->id);
        $pdf->SetXY(25, 76);
        $pdf->Write(0, __("Date").' '.$datumIzrade);
        $pdf->SetXY(25, 82);
        $pdf->Write(0, __("Time").' '.$vremeIzrade);
        $pdf->SetXY(25, 88);
        $pdf->Write(0, __("Storekeeper").' '.$magacioner);

        $tbWdth = 70;
        $y = 99; $x = 25;
        $pdf->SetXY($x, 94);
        $pdf->Cell($tbWdth,5,__("Goods"),1,0,'L',0);
        $pdf->Cell($tbWdth,5,iconv('UTF-8', 'Windows-1250', __("Quantity")),1,0,'L',0);

        foreach ($robaCount as $roba) {
            $pdf->SetXY($x, $y);
            $pdf->Cell($tbWdth, 5, iconv('UTF-8', 'Windows-1250',$roba->uredjaj),1,0,'L',0);
            $pdf->Cell($tbWdth, 5, $roba->count, 1, 0, 'L', 0);
            $y += 5;
        }

        $pdf->SetXY($x, 222);
        $pdf->Write(0, __("Goods taken by").': '.$monter);
        $pdf->SetXY($x, 228);
        $pdf->Write(0, iconv('UTF-8', 'Windows-1250', __("Seal and signature").': _________________________'));
        /*--------------------------------------druga strana------------------------------------------------------------------*/
        $pdf->addPage();
        $pdf->setSourceFile('../public/templates/memo.pdf');
        $pdf->useTemplate($tplIdx, null, null, null,null, true);

        $y = 65; $x = 10;
        $pageSplitter = 0;
        $changeY = true;
        foreach ($stavke as $br => $st) {
            $y+=4;
            if ($br == 0) {
                $pdf->SetFont('DejaVu', '', 12);
                $pdf->SetXY($x, $y);
                $pdf->Write(0, iconv('UTF-8', 'Windows-1250', '(' . strtoupper($st->uredjaj) . ')'));
                $y+=6;
            }
            else {
                if ($st->device_id != $stavke[$br-1]->device_id){
                    $y+=2;
                    $pdf->SetFont('DejaVu', '', 12);
                    $pdf->SetXY($x, $y);
                    $pdf->Write(0, iconv('UTF-8', 'Windows-1250', '('.strtoupper($st->uredjaj).')'));
                    $y+=6;
                }
            }

            $pdf->SetFont('DejaVu', '', 7);
            $pdf->SetXY($x, $y);
            $pdf->Write(0, iconv('UTF-8', 'Windows-1250', $st->serial_number));

            $pageSplitter++;
            if ($pageSplitter > 45){
                if ($changeY) {
                    $y = 68;
                    $changeY = false;
                }
                $x = 100;
            }
            if ($pageSplitter > 90){
                $pdf->addPage();
                $pdf->setSourceFile('../public/templates/memo.pdf');
                $pdf->useTemplate($tplIdx, null, null, null, null, true);
                $y = 65;
                $x = 10;
                $pageSplitter = 0;
                $changeY = true;
            }
        }

        $pdf->Output('memorandum_'.time().'.pdf', 'D');
    }

    public function update_device_state(Request $request){
        $deviceId = $request->input('device_id');
        $deviceState = $request->input('device_state');
        $update = Magacin::where('id', $deviceId)->update([
            'state_id' => $deviceState
        ]);
        if($update)
            return back()->with('success', __("Data successfully changed"));
        else
            return back()->with('error', __('Error'));
    }

    public function revers_change_status(Request $request){
        $id = $request->input('ro_id');
        $serial = $request->input('ro_serial');
        $obsolete = $request->input('status');
        $storageId = $request->input('storage');
        Tool_reverse_goods::where('id', $id)->update([
            'obsolete' => $obsolete
        ]);
        if($storageId){
            Tool_reverse_goods::where('id', $id)->update([
                'storage_id' => $storageId
            ]);
            Magacin::where('serijski_broj', $serial)->update([
                'id_mag' => $storageId
            ]);
        }
        return back()->with('success', __("Data successfully changed"));
    }

    public function worker_tool_devices(){
        $workers = Util::allWorkers();
        return view('storageTools.worker_tool_devices', [
            'workers' => $workers
        ]);
    }

    public function tool_devices_for_worker(Request $request){
        $worker = $request->input('worker');
        $obsolete = $request->input('obsolete');
        $revMod = new Tool_reverse_goods();
        $fitter = User::find($worker);
        $revGoods = $revMod->revGoodsForWorker($worker, $obsolete);
        return view('storageTools.tool_devices_worker', [
            'revGoods' => $revGoods,
            'fitter' => $fitter->ime.' '.$fitter->prezime
        ]);
    }

    /* --------------------------------------delivery notes--------------------------------------------*/
    public function tool_delivery_notes(){
        $otMod = new Tool_delivery_notes();
        $deliveryNotes = $otMod->deliveryNotes();
        $fitters = Util::allWorkers();

        return view('storageTools.delivery_notes', [
            'deliveryNotes' => $deliveryNotes,
            'storekeeper' => Util::username(),
            'fitters' => $fitters
        ]);
    }

    public function add_delivery_note(Request $request){
        $takenBy = $request->input('taken_by');
        $fitter = $request->input('fitter_id');
        $request->validate([
            'taken_by' => 'required',
        ]);
        $create = Tool_delivery_notes::create([
            'storekeeper_id' => Util::userId(),
            'taken_by' => $takenBy,
            'fitter_id' => $fitter
        ]);

        if ($create)
            return back()->with('success', __("Delivery note created"));

    }

    public function tool_dn_device(Request $request){
        $id = $request->input('dn_id');
        $takenBy = $request->input('taken_by');
        $tMod = new Tool_delivered_goods();
        $deliveredGoods = $tMod->deliveredGoods($id);
        $magzModel = new Magz();
        if(Util::isSuperAdmin() || Util::isStorekeeper())
            $magz = Magz::all();
        else
            $magz = $magzModel->magzForUser(Util::userId());
        return view('storageTools.delivery_notes_scanning', [
            'dnId' => $id,
            'deliveredGoods' => $deliveredGoods,
            'takenBy' => $takenBy,
            'magz' => $magz
        ]);

    }

    public function delete_tool_dn(Request $request){
        $find = Tool_delivery_notes::find($request->input('dn_id'));
        try{
            $find->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->withInput()->with('error', __("You must remove devices first"));
        }
    }

        //delivery note reduces products from storage
        public function dn_scanning(Request $request){
            $serial = serialTrim($request->input('serial'));
            $dnId = $request->input('dn_id');
            $QRcode = $request->input('qr_code');
            $QRcodes = array();
            if(!$QRcode) {
                $request->validate([
                    'serial' => 'required',
                ]);
            }
            else {
                $QRcodes = explode(' ', $QRcode);
            }
            $magMod = new Magacin();
            $errorMessage = '';
            if($QRcode){
                foreach ($QRcodes as $code){
                    $magacin = $magMod->checkSerial($code);
                    if($magacin->isEmpty()){
                        $errorMessage .= $code.' '.__("does not exist in stock").'. ';
                    }
                }
                if($errorMessage != ''){
                    return back()->with('error', $errorMessage);
                }
                foreach($QRcodes as $code){
                    $magacin = $magMod->checkSerial($code);
                    $findMag = Magacin::find($magacin[0]->id);
                    $findMag->delete();
                    $device = $magacin[0]->id_uredjaj;
                    $idMag = $magacin[0]->id_mag;
                    $otp = Tool_delivered_goods::create([
                        'serial' => $code,
                        'device_id' => $device,
                        'delivery_note' => $dnId,
                        'warehouse' => $idMag
                    ]);
                    //make reverse goods obsolete if deleted
                    Tool_reverse_goods::where('serial_number', $code)->update(['obsolete' => 1]);
                }
                return back()->with('success', __("Products successfully shipped"));
            }
            else {
                $magacin = $magMod->checkSerial($serial);
                if (!$magacin->isEmpty()) {
                    $findMag = Magacin::find($magacin[0]->id);
                    $findMag->delete();
                    $device = $magacin[0]->id_uredjaj;
                    $idMag = $magacin[0]->id_mag;
                    $otp = Tool_delivered_goods::create([
                        'serial' => $serial,
                        'device_id' => $device,
                        'delivery_note' => $dnId,
                        'warehouse' => $idMag
                    ]);
                    if ($otp) {
                        Tool_reverse_goods::where('serial_number', $serial)->update(['obsolete' => 1]);
                        return back()->with('success', __("Product has been shipped"));
                    }
                } else {
                    return back()->with('errors', __("Device").' '.__("does not exist in stock"));
                }
            }
        }

        public function delete_dn_device(Request $request){
            $device = $request->input('device_id');
            $find = Tool_delivered_goods::find($device);

            try{
                $find->delete();
                return back()->withInput()->with('success', __("Data successfully deleted"));
            }
            catch (\Illuminate\Database\QueryException $e){
                return back()->withInput()->with('error', __("Data cannot be deleted"));
            }

            return back()->withInput()->with('error', __("Data cannot be deleted"));
        }

        
}
