<?php

namespace App\Http\Controllers;

use App\Magz;
use App\Models\Storage_uniforms;
use App\Models\Uniform_logs;
use App\Traits\Util;
use App\Models\Uniform_types;
use App\Models\Uniforms;
use App\Models\Worker_uniforms;
use App\User;
use Illuminate\Http\Request;
use setasign\Fpdi\Fpdi;

class StorageUniformsController extends Controller
{
    private function magz(){
        $magModel = new Magz();
        $magz = $magModel->magzForUser(Util::userId());
        return $magz;
    }
    private function linkForgeryCheck($magId){
        $magModel = new Magz();
        $forgery = $magModel->linkForgeryCheck($magId, Util::userId());
        return $forgery;
    }
    private function updateChangeLog($uniformId, $storageId, $quantity, $worker=null){
        if($quantity != 0){
            Uniform_logs::create([
                'uniform_id' => $uniformId,
                'storekeeper' => Util::userId(),
                'worker' => $worker,
                'storage_id' => $storageId,
                'quantity' => $quantity
            ]);
        }
    }

    public function stockpile_uniforms(){
        $tMod = new Storage_uniforms();
        if(Util::isSuperAdmin()) {
            $magz = Magz::all()->where('type_id', 5);
        }
        else{
            $magz = $this->magz();
        }
        $stockpile = array();
        foreach($magz as $mag){
            $uniforms = $tMod->uniforms_for_storage($mag->id);
            foreach ($uniforms as $num=>$uni){
                $stockpile[$mag->naziv][$num]['uniform'] = $uni->uniform;
                $stockpile[$mag->naziv][$num]['color'] = $uni->color;
                $stockpile[$mag->naziv][$num]['size'] = $uni->size;
                $stockpile[$mag->naziv][$num]['quantity'] = $uni->quantity;
                $stockpile[$mag->naziv][$num]['type'] = $uni->type;
            }
        }

        return view('storageUniforms.stockpile', ['stockpile' => $stockpile]);
    }

    public function storages(){
        if(Util::isSuperAdmin()){
            $magz = Magz::all()->where('type_id', 5);
        }
        else{
            $magz = $this->magz();
        }
        return view('storageUniforms.storages', ['magz' => $magz]);
    }

    public function storage_uniform(Request $request){
        $id = $request->input('id');
        if($this->linkForgeryCheck($id) && !Util::isSuperAdmin())
            return back()->withInput();
        $tMod = new Storage_uniforms();
        $uniformTypes = Uniform_types::all();
        $uniforms = $tMod->uniforms_for_storage($id);
        $storage = Magz::find($id);
        $fitters = Util::allWorkers();
        return view('storageUniforms.storage_uniforms', [
            'uniforms' => $uniforms,
            'uniformTypes' => $uniformTypes,
            'storage' => $storage,
            'fitters' => $fitters
        ]);
    }

    public function uniform_populate(Request $request){
        $output = '';
        $id = $request->get('id');
        $uMod = new Uniforms();
        $uniforms = $uMod->uniformsByType($id);
        foreach($uniforms as $uni){
            $output .= '<option value="'.$uni->id.'">'.$uni->uniform.' '.$uni->size.' '.$uni->color.' '.'</option>';
        }
        return $output;
    }

    public function fill_uniform_storage(Request $request){
        $storageId = $request->input('storageId');
        $param = $request->input('param');
        $uniformId = $request->input('uniformId');
        if(!$uniformId){
            return __("no goods are selected");
        }
        $quantity = $request->input('quantity');
        $operation = $request->input('operation');
        $suMod = new Storage_uniforms();
        $specificUniform = $suMod->specific_uniform($storageId, $uniformId);

        if($operation == 'minus'){
            $quantity = -$quantity;
        }

        if($specificUniform)
            $storageAmmount = $specificUniform->quantity;
        else
            $storageAmmount = 0;
        if($param == 'storage'){
            if($storageAmmount + $quantity < 0){
                return __("value has to be a positive number");
            }
            if($specificUniform){
                $suMod->storage_update($storageId, $uniformId, $quantity);
                $this->updateChangeLog($uniformId, $storageId, $quantity);
            }
            else {
                Storage_uniforms::create([
                    'uniform_id' => $uniformId,
                    'storage_id' => $storageId,
                    'quantity' => $quantity
                ]);
                $this->updateChangeLog($uniformId, $storageId, $quantity);
            }
        }
        /*giving stuff to worker and removing stuff from selected storage.
          worker equipment can have values, but with quantity 0.*/
        else {
            $userId = $request->input('userId');
            $wuMod = new Worker_uniforms();
            $specificUniform = $wuMod->specific_uniform($userId, $uniformId);
            if(isset($specificUniform->quantity))
                $workerQuantity = $specificUniform->quantity;
            else
                $workerQuantity = 0;
            if($workerQuantity + $quantity < 0)
                return __("Worker doesn't have goods in his inventory");
            if($storageAmmount >= $quantity){
                if($specificUniform){
                    $wuMod->uniform_update($userId, $uniformId, $quantity);
                    $suMod->storage_update($storageId, $uniformId, -$quantity);
                    $this->updateChangeLog($uniformId, $storageId, -$quantity, $userId);
                }
                else{
                    Worker_uniforms::create([
                        'user_id' => $userId,
                        'uniform_id' => $uniformId,
                        'storage_id' => $storageId,
                        'quantity' => $quantity
                    ]);
                    $suMod->storage_update($storageId, $uniformId, -$quantity);
                    $this->updateChangeLog($uniformId, $storageId, -$quantity, $userId);
                }
            }
            else {
                return __("not enough goods in warehouse");
            }
        }
        return __("goods successfully added");
    }

    public function worker_uniforms(){
        $workers = User::all();
        $wuMod = new Worker_uniforms();
        return view('storageUniforms.storage', ['workers' => $workers, 'wuMod' => $wuMod]);
    }

    public function worker_uniform_storage(Request $request){
        $id = $request->input('id');
        $wuMod = new Worker_uniforms();
        $uniformTypes = Uniform_types::all();
        $uniforms = $wuMod->uniforms_for_user($id);
        if(Util::isSuperAdmin())
            $storages = Magz::all()->where('type_id', 5);
        else
            $storages = $this->magz();
        $user = User::find($id);
        return view('storageUniforms.worker', [
            'uniforms' => $uniforms,
            'uniformTypes' => $uniformTypes,
            'user' => $user,
            'storages' => $storages
        ]);
    }

    public function uniform_logs(Request $request){
        $storageId = $request->input('storage_id');
        $logMod = new Uniform_logs();
        $logs = $logMod->logs($storageId);
        return view('storageUniforms.logs', [
            'logs' => $logs
        ]);
    }

    public function uniforms_print(Request $request){
        require_once ('../vendor/setasign/fpdf/fpdf.php');
        require_once ('../vendor/setasign/fpdi/src/autoload.php');
        $id = $request->input('id');
        $wMod = new Worker_uniforms();
        $uniforms = $wMod->uniforms_for_user($id);
        $user = User::find($id);
        $pdf = new Fpdi();
        $pdf->addPage();
        $x = 10;
        $y = 10;
        $pdf->AddFont('DejaVu', '', 'DejaVuSans.php');
        $pdf->SetFont('DejaVu', 'U', 15);
        $pdf->Text($x, $y, iconv('UTF-8', 'Windows-1250', $user->ime.' '.$user->prezime));
        $y+=5;
        $pdf->SetFont('DejaVu', '', 10);
        $counter = 0;
        foreach($uniforms as $uniform){
            $pdf->Text($x, $y, iconv('UTF-8', 'Windows-1250//IGNORE', $uniform->type.' '.$uniform->uniform.' '.$uniform->color.' '.$uniform->size.' '.__('Qty')).': ('.$uniform->quantity.')');
            $y+=5;
            $counter++;
            if($counter == 56){
                $pdf->addPage();
                $x = 10;
                $y = 10;
                $counter = 0;
            }
        }

        $pdf->Output(__('Tools').'.pdf', 'D');
    }
}
