<?php

namespace App\Http\Controllers;

use App\Traits\Util;
use App\Magz;
use App\Models\Storage_vehicle_equipment;
use App\Models\Vehicle_equipment;
use App\Models\Vehicle_equipment_logs;
use App\Models\Worker_vehicle_equipment;
use App\User;
use Illuminate\Http\Request;

class StorageVehicleEquipmentController extends Controller
{
    private function magz(){
        $magModel = new Magz();
        if(Util::isSuperAdmin())
            $magz = Magz::all();
        else
            $magz = $magModel->magzForUser(Util::userId());
        return $magz;
    }
    private function linkForgeryCheck($magId){
        $magModel = new Magz();
        $forgery = $magModel->linkForgeryCheck($magId, Util::userId());
        return $forgery;
    }
    private function updateChangeLog($equipmentId, $storageId, $quantity, $worker=null){
        if($quantity != 0){
            Vehicle_equipment_logs::create([
                'equipment_id' => $equipmentId,
                'storekeeper' => Util::userId(),
                'worker' => $worker,
                'storage_id' => $storageId,
                'quantity' => $quantity
            ]);
        }
    }

    public function stockpile_vehicle_equipment(){
        $tMod = new Storage_vehicle_equipment();
        $magz = $this->magz();
        $stockpile = array();
        foreach($magz as $mag){
            $equipment = $tMod->equipment_for_storage($mag->id);
            foreach ($equipment as $num=>$eq){
                $stockpile[$mag->naziv][$num]['equipment'] = $eq->equipment;
                $stockpile[$mag->naziv][$num]['quantity'] = $eq->quantity;
            }
        }

        return view('storageVehicleEquipment.stockpile', ['stockpile' => $stockpile]);
    }

    public function storages(){
        $magz = $this->magz();
        return view('storageVehicleEquipment.storages', ['magz' => $magz]);
    }

    public function storage_vehicle_equipment(Request $request){
        $id = $request->input('id');
        if($this->linkForgeryCheck($id) && !Util::isSuperAdmin())
            return back()->withInput();
        $tMod = new Storage_vehicle_equipment();
        $equipment = $tMod->equipment_for_storage($id);
        $equipmentList = Vehicle_equipment::all();
        $storage = Magz::find($id);
        $fitters = Util::monteri();
        return view('storageVehicleEquipment.storage_vehicle_equipment', [
            'equipment' => $equipment,
            'storage' => $storage,
            'fitters' => $fitters,
            'equipmentList' => $equipmentList
        ]);
    }

    public function fill_vehicle_equipment(Request $request){
        $storageId = $request->input('storageId');
        $param = $request->input('param');
        $equipmentId = $request->input('equipmentId');
        if(!$equipmentId){
            return __("no goods are selected");
        }
        $quantity = $request->input('quantity');
        $operation = $request->input('operation');
        $suMod = new Storage_vehicle_equipment();
        $specificEquipment = $suMod->specific_equipment($storageId, $equipmentId);

        if($operation == 'minus'){
            $quantity = -$quantity;
        }

        if($specificEquipment)
            $storageAmmount = $specificEquipment->quantity;
        else
            $storageAmmount = 0;
        if($param == 'storage'){
            if($storageAmmount + $quantity < 0){
                return __("value has to be a positive number");
            }
            if($specificEquipment){
                $suMod->storage_update($storageId, $equipmentId, $quantity);
                $this->updateChangeLog($equipmentId, $storageId, $quantity);
            }
            else {
                Storage_vehicle_equipment::create([
                    'equipment_id' => $equipmentId,
                    'storage_id' => $storageId,
                    'quantity' => $quantity
                ]);
                $this->updateChangeLog($equipmentId, $storageId, $quantity);
            }
        }
        /*giving stuff to worker and removing stuff from selected storage.
          worker equipment can have values, but with quantity 0.*/
        else {
            $userId = $request->input('userId');
            $wuMod = new Worker_vehicle_equipment();
            $specificEquipment = $wuMod->specific_equipment($userId, $equipmentId);
            if(isset($specificEquipment->quantity))
                $workerQuantity = $specificEquipment->quantity;
            else
                $workerQuantity = 0;
            if($workerQuantity + $quantity < 0)
                return __("Worker doesn't have goods in his inventory");
            if($storageAmmount >= $quantity){
                if($specificEquipment){
                    $wuMod->equipment_update($userId, $equipmentId, $quantity);
                    $suMod->storage_update($storageId, $equipmentId, -$quantity);
                    $this->updateChangeLog($equipmentId, $storageId, -$quantity, $userId);
                }
                else{
                    Worker_vehicle_equipment::create([
                        'user_id' => $userId,
                        'equipment_id' => $equipmentId,
                        'storage_id' => $storageId,
                        'quantity' => $quantity
                    ]);
                    $suMod->storage_update($storageId, $equipmentId, -$quantity);
                    $this->updateChangeLog($equipmentId, $storageId, -$quantity, $userId);
                }
            }
            else {
                return __("not enough goods in warehouse");
            }
        }
        return __("goods successfully added");
    }

    public function worker_vehicle_equipment(){
        $builders = Util::builders();
        $fitters = Util::monteri();
        $workers = $builders->merge($fitters);
        $wuMod = new Worker_vehicle_equipment();
        return view('storageVehicleEquipment.storage', ['workers' => $workers, 'wuMod' => $wuMod]);
    }

    public function worker_vehicle_storage(Request $request){
        $id = $request->input('id');
        $wuMod = new Worker_vehicle_equipment();
        $equipment = $wuMod->equipment_for_user($id);
        $storages = $this->magz();
        $user = User::find($id);
        $equipmentList = Vehicle_equipment::all();
        return view('storageVehicleEquipment.worker', [
            'equipment' => $equipment,
            'user' => $user,
            'storages' => $storages,
            'equipmentList' => $equipmentList
        ]);
    }

    public function vehicle_equipment_log(Request $request){
        $storageId = $request->input('storage_id');
        $logMod = new Vehicle_equipment_logs();
        $logs = $logMod->logs($storageId);
        return view('storageVehicleEquipment.logs', [
            'logs' => $logs
        ]);
    }
}
