<?php

namespace App\Http\Controllers;

use App\Team_prodavac;
use App\Teams;
use App\Traits\Util;
use Illuminate\Http\Request;

class TeamController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $teamModel = new Teams();
        $teams = $teamModel->teams();
        return view('teams.index', [
            'teams' => $teams,
            'teamModel' => $teamModel
        ]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('teams.create', [
            'lideri' => Util::lideri(),
            'prodavci' => Util::prodavci()
        ]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'naziv' => 'required',
            'lider' => 'required',
            'prodavac' => 'required'
        ]);
        $naziv = $request->input('naziv');
        $lider = $request->input('lider')[0];
        $prodavci = $request->input('prodavac');

        $team = Teams::create([
           'naziv' => $naziv,
            'id_lider' => $lider
        ]);
        if ($team){
            foreach ($prodavci as $idProdavac)
            Team_prodavac::create([
                'id_team' => $team->id,
                'id_prodavac' => $idProdavac
            ]);
        }

        return redirect()->route('team.index');

    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Teams  $teams
     * @return \Illuminate\Http\Response
     */
    public function show(Teams $teams)
    {
        $tModel = new Teams();
        $team = $tModel->timPodaci($teams->id);
        $sellers = $tModel->sellers($teams->id);
        return view('teams.show', [
           'team' => $team,
            'sellers' => $sellers
        ]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Teams  $teams
     * @return \Illuminate\Http\Response
     */
    public function edit(Teams $teams)
    {
        $team = Teams::find($teams->id);
        $teamModel = new Teams();
        $sellers = $teamModel->sellers($teams->id);

        return view('teams.edit', [
            'lideri' => Util::lideri(),
            'prodavci' => Util::prodavci(),
            'team' => $team,
            'sellers' => $sellers
        ]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Teams  $teams
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Teams $teams)
    {
        $request->validate([
            'naziv' => 'required',
            'lider' => 'required'
        ]);
        $naziv = $request->input('naziv');
        $lider = $request->input('lider')[0];
        $prodavci = $request->input('prodavac');

        $teamUpdate = Teams::where('id', $teams->id)->update([
            'naziv' => $naziv,
            'id_lider' => $lider
        ]);
        if ($teamUpdate){
            if ($prodavci){
                foreach ($prodavci as $idProdavac) {
                    Team_prodavac::create([
                        'id_team' => $teams->id,
                        'id_prodavac' => $idProdavac
                    ]);
                }
            }
        }

        return redirect()->route('team.show', ['teams' => $teams->id])->with('success', __("Data successfully changed"));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $findTeam = Teams::find($request->input('id_team'));

        if ($findTeam){
            $findTeam->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }


        return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }

    public function seller_delete(Request $request){
        $idTeam = $request->input('id_team');
        $idSeller = $request->input('id_seller');
        $deleteSeller = Team_prodavac::where('id_team', $idTeam)->where('id_prodavac', $idSeller)->delete();
        if ($deleteSeller)
            return back()->withInput()->with('success', __("Data successfully deleted"));
        else
            return back()->withInput()->with('errors', __("Data cannot be deleted"));
    }
}
