<?php

namespace App\Http\Controllers;

use App\Models\Wf_statuses;
use Illuminate\Http\Request;

class WfStatusesController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $statuses = Wf_statuses::orderBy('id','DESC')->paginate(15);
        return view ('workFlow.status_index', ['statuses' => $statuses]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('workFlow.status_create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $status = $request->input('wf_status');
        $request->validate([
            'status' => 'status'
        ]);
        $create = Wf_statuses::create([
            'status' => $status
        ]);

        if($create)
            return redirect()->route('wf_status.index')->with('success', __("Data successfully added"));
        else
            return redirect()->route('wf_status.index')->with('error', __("Error"));
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Wf_statuses  $wf_status
     * @return \Illuminate\Http\Response
     */
    public function show(Wf_statuses $wf_status)
    {
        return view('workFlow.status_show', ['status' => $wf_status]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Wf_statuses  $wf_status
     * @return \Illuminate\Http\Response
     */
    public function edit(Wf_statuses $wf_status)
    {
        return view('workFlow.status_edit', ['status' => $wf_status]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Wf_statuses  $wf_status
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Wf_statuses $wf_status)
    {
        $statusName = $request->input('wf_status');
        $request->validate([
            'wf_status' => 'required'
            ]);
        $update = Wf_statuses::where('id', $wf_status->id)->update([
            'status' => $statusName
        ]);

        if($update)
            return redirect()->route('wf_status.show', ['wf_status' => $wf_status])->with('success', __("Data successfully changed"));
        else
            return redirect()->route('wf_status.index')->with('error', __("Error"));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $statusId = $request->input('id_status');
        $findStatus = Wf_statuses::where('id', $statusId);
        try{
            $findStatus->delete();
            return back()->withInput()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->with('error', __("Item can't be deleted because it's in use"));
        }
    }
}
