<?php

namespace App\Http\Controllers;

use App\Models\Wf_works;
use Illuminate\Http\Request;

class WfWorksController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $works = Wf_works::orderBy('id','DESC')->paginate(15);
        return view ('workFlow.work_index', ['works' => $works]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('workFlow.work_create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $work = $request->input('wf_work');
        $request->validate([
            'wf_work' => 'required'
        ]);
        $create = Wf_works::create([
            'work' => $work
        ]);

        if($create)
            return redirect()->route('wf_work.index')->with('success', __("Data successfully added"));
        else
            return redirect()->route('wf_work.index')->with('error', __("Error"));
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Wf_works  $wf_work
     * @return \Illuminate\Http\Response
     */
    public function show(Wf_works $wf_work)
    {
        return view('workFlow.work_show', ['work' => $wf_work]);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Wf_works  $wf_work
     * @return \Illuminate\Http\Response
     */
    public function edit(Wf_works $wf_work)
    {
        return view('workFlow.work_edit', ['work' => $wf_work]);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Wf_works  $wf_works
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Wf_works $wf_work)
    {
        $workName = $request->input('wf_work');
        $request->validate([
            'wf_work' => 'required'
            ]);
        $update = Wf_works::where('id', $wf_work->id)->update([
            'work' => $workName
        ]);

        if($update)
            return redirect()->route('wf_work.show', ['wf_work' => $wf_work])->with('success', __("Data successfully changed"));
        else
            return redirect()->route('wf_work.index')->with('error', __("Error"));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function destroy(Request $request)
    {
        $workId = $request->input('id_work');
        $findWork = Wf_works::where('id', $workId);
        try{
            $findWork->delete();
            return back()->with('success', __("Data successfully deleted"));
        }
        catch (\Illuminate\Database\QueryException $e){
            return back()->with('error', __("Item can't be deleted because it's in use"));
        }
    }
}
