<?php

namespace App;

use DB;
use Illuminate\Database\Eloquent\Model;

class Klijenti_bakar extends Model
{
    protected $table = 'klijenti_bakar';
    protected  $fillable = [
        'broj_ugovora',
        'ime',
        'prezime',
        'zahtev_uneo',
        'podrucje',
        'tis_id',
        'adresa',
        'tel1',
        'tel2',
        'tel3',
        'zahtev',
        'prodavac',
        'br_bodova',
        'id_status',
        'id_user',
        'id_user_reklamacije',
        'created_by',
        'datum_zahteva',
        'datum_zakazivanja',
        'datum_odlaganja',
        'datum_reklamacije',
        'datum_montaze',
        'datum_odustajanja',
        'datum_intervencije',
        'razlog_odustajanja',
        'oprema_ugovor',
        'id_status_intervencije',
        'updated_at',
        'created_at',
        'id_tip_montaze',
        'id_klijent_prodaja',
        'helper',
        'on_terrain'
    ];

    public function klijentiPregled($userId){
        $query = DB::table('klijenti_bakar as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'k.adresa', 'u.prezime as user_prezime', 's.status', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja', 'k.datum_odustajanja',
                'k.oprema_ugovor')
            ->where('id_user', '=', $userId)
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->paginate(15);

        return $result;
    }

    public function klijentiAdmin(){
        $query = DB::table('klijenti_bakar as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'k.adresa', 'u.prezime as user_prezime', 's.status', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja', 'k.datum_odustajanja')
            ->orderby('datum_zakazivanja', 'DESC')
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->paginate(15);

        return $result;
    }

    public function klijentPodaci($klijentId){
        $query = DB::table('klijenti_bakar as ko')
            ->leftJoin('users as u', 'ko.id_user', '=', 'u.id')
            ->leftJoin('statusi as s', 'ko.id_status', '=', 's.id')
            ->leftJoin('users as usr', 'ko.updated_by', '=', 'usr.id')
            ->leftJoin('statusi_intervencije as stsi', 'ko.id_status_intervencije', '=', 'stsi.id')
            ->leftJoin('users as rek', 'ko.id_user_reklamacije', '=', 'rek.id')
            ->leftJoin('tip_montaze as tpm', 'tpm.id', '=', 'ko.id_tip_montaze')
            ->select('ko.id', 'ko.ime', 'ko.prezime', 'ko.zahtev_uneo', 'ko.podrucje', 'ko.tis_id', 'ko.adresa', 'ko.tel1', 'ko.tel2', 'ko.tel3',
                'ko.zahtev', 'ko.prodavac', 'ko.br_bodova', 'ko.id_status', 'ko.id_user', 'ko.id_user_reklamacije', 'ko.datum_montaze', 'ko.datum_odustajanja',
                'ko.razlog_odustajanja', 'ko.datum_zahteva', 'u.ime as user_ime', 'u.prezime as user_prezime', 's.status', 'ko.datum_zakazivanja',
                'ko.datum_odustajanja', 'ko.datum_odlaganja', 'usr.ime as kreirao_ime', 'usr.prezime as kreirao_prezime', 'u.id as id_user', 'ko.updated_at',
                'stsi.status as status_intervencije', 'ko.datum_intervencije', 'rek.ime as monter_reklamacije_ime', 'rek.prezime as monter_reklamacije_prezime',
                'ko.datum_reklamacije', 'ko.id_user_reklamacije', 'tpm.tip as tip_montaze', 'ko.oprema_ugovor', 'ko.broj_ugovora')
            ->where('ko.id', '=', $klijentId)
        ;

        $result = $query->get();
        return $result[0];
    }

    public function pretraga($ime = null, $prezime = null, $id_user = null, $statusIds = null,
                                  $created_at = null, $datumMontaze=null, $datumOdustajanja = null, $datumZakazivanja = null,
                                  $datumOdlaganja = null, $bezStatusa = null, $paginate=false)
    {
        $query = DB::table('klijenti_bakar as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->leftJoin('users as mont', 'mont.id', '=', 'k.id_user_reklamacije')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'u.prezime as user_prezime', 's.status', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja',
                'k.datum_montaze', 'k.datum_odustajanja', 'mont.ime as monter_int_ime', 'mont.prezime as monter_int_prezime', 'k.adresa')
        ;
        if ($ime)
            $query->where('k.ime', 'like', $ime.'%');
        if ($prezime)
            $query->where('k.prezime', 'like', $prezime.'%');
        if ($id_user)
            $query->where('k.id_user', '=', $id_user);
        if ($statusIds)
            $query->whereIn('k.id_status', $statusIds);
        if ($created_at)
            $query->where('k.datum_zahteva', '=', $created_at);
        if ($datumMontaze)
            $query->where('k.datum_montaze', '=', $datumMontaze);
        if ($datumOdustajanja)
            $query->where('k.datum_odustajanja', '=', $datumOdustajanja);
        if ($datumZakazivanja)
            $query->whereDate('k.datum_zakazivanja', '=', $datumZakazivanja);
        if ($datumOdlaganja)
            $query->whereDate('k.datum_odlaganja', '=', $datumOdlaganja);
        if ($bezStatusa)
            $query->orWhere('k.id_status', '=', null);

        if($paginate)
            $result = $query->paginate(100);
        else
            $result = $query->get();

        return $result;
    }

    public function naprednaPretraga($ime=null, $prezime=null, $zahtevUneo=null, $podrucje=null, $adresa=null, $tel1=null, $tel2=null, $tel3=null,
                                           $tisId=null, $zahtev=null, $datumZahteva=null, $prodavac=null, $datumMontaze=null, $tipoviMontazeIds, $datumOdustajanja=null,
                                           $razlogOdustajanja=null, $napomena=null, $statusIds=null, $datumZakazivanja=null, $datumOdlaganja=null, $idUser=null, $createdAt=null, $bezStatusa = null,
                                           $statusIntIds=null, $datumIntervencije=null, $reklamacijaMonter=null, $datumReklamacije=null, $start=null, $end=null, $serial=null, $opremaUgovor=null,
                                           $seller=null, $callistoId=null, $paginate=false)
    {
        $query = DB::table('klijenti_bakar as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->leftJoin('users as mont', 'mont.id', '=', 'k.id_user_reklamacije')
            ->leftJoin('klijenti_prodaja as kp', 'kp.id', '=', 'k.id_klijent_prodaja')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'u.prezime as user_prezime', 's.status', 'k.created_at', 'k.datum_zahteva', 'k.datum_zakazivanja',
                'k.datum_montaze', 'k.datum_odustajanja', 'mont.ime as monter_int_ime', 'mont.prezime as monter_int_prezime', 'k.adresa')
        ;
        if ($ime)
            $query->where('k.ime', 'like', $ime.'%');
        if ($prezime)
            $query->where('k.prezime', 'like', $prezime.'%');
        if ($zahtevUneo)
            $query->where('k.zahtev_uneo', 'like', $zahtevUneo.'%');
        if ($podrucje)
            $query->where('k.podrucje', 'like', $podrucje.'%');
        if ($adresa)
            $query->where('k.adresa', 'like', $adresa.'%');
        if ($zahtev)
            $query->where('k.zahtev', 'like', $zahtev.'%');
        if ($datumZahteva)
            $query->where('k.datum_zahteva', '=', $datumZahteva);
        if ($tel1)
            $query->where('k.tel1', '=', $tel1);
        if ($tel2)
            $query->where('k.tel2', '=', $tel2);
        if ($tel3)
            $query->where('k.tel3', '=', $tel3);
        if ($tisId)
            $query->where('k.tis_id', '=', $tisId);
        if ($prodavac)
            $query->where('k.prodavac', 'like', '%'.$prodavac.'%');
        if ($datumMontaze)
            $query->where('k.datum_montaze', '=', $datumMontaze);
        if ($tipoviMontazeIds)
            $query->whereIn('k.id_tip_montaze', $tipoviMontazeIds);
        if ($datumOdustajanja)
            $query->where('k.datum_odustajanja', '=', $datumOdustajanja);
        if ($razlogOdustajanja)
            $query->where('k.razlog_odustajanja', 'like', '%'.$razlogOdustajanja.'%');
        if ($napomena)
            $query->where('k.napomena', 'like', '%'.$napomena.'%');
        if ($tisId)
            $query->where('k.tis_id', '=', $tisId);
        if ($statusIds)
            $query->whereIn('k.id_status', $statusIds);
        if ($datumZakazivanja)
            $query->where('k.datum_zakazivanja', '=', $datumZakazivanja);
        if ($datumOdlaganja)
            $query->whereDate('k.datum_odlaganja', '=', $datumOdlaganja);
        if ($idUser)
            $query->where('k.id_user', '=', $idUser);
        if ($createdAt)
            $query->where('k.datum_zahteva', '=', $createdAt);
        if ($opremaUgovor)
            $query->where('k.oprema_ugovor', '=', $opremaUgovor);
        if ($bezStatusa)
            $query->orWhere('k.id_status', '=', null);
        if ($statusIntIds[0])
            $query->whereIn('k.id_status_intervencije', $statusIntIds);
        if ($datumIntervencije)
            $query->where('k.datum_intervencije', '=', $datumIntervencije);
        if ($reklamacijaMonter)
            $query->where('k.id_user_reklamacije', '=', $reklamacijaMonter);
        if ($datumReklamacije)
            $query->where('k.datum_reklamacije', '=', $datumReklamacije);
        if ($start && $end){
            $query->where('k.datum_montaze', '>=', $start);
            $query->where('k.datum_montaze', '<=', $end);
        }
        if($serial){
            $query->leftJoin('montirani_uredjaji as mu', 'k.id', '=', 'mu.id_bakar_klijent')
                ->where('serijski_broj', '=', $serial)
                ->groupBy('mu.id_bakar_klijent');
        }
        if($seller){
            $query->where('kp.id_prodavac', '=', $seller);
        }
        if($callistoId){
            $query->where('k.id', '=', $callistoId);
        }

        if($paginate)
            $result = $query->paginate(100);
        else
            $result = $query->get();

        return $result;
    }


    public function export($ids){
        $query = DB::table('klijenti_bakar as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('statusi_intervencije as st', 'st.id', '=', 'k.id_status_intervencije')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->leftJoin('users as int', 'int.id', '=', 'k.id_user_reklamacije')
            ->leftJoin('tip_montaze as tm', 'tm.id', '=', 'k.id_tip_montaze')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime', 'u.prezime as user_prezime', 'k.zahtev_uneo', 'k.podrucje',
                'k.adresa', 's.status', 'k.datum_zahteva', 'k.tis_id', 'k.adresa', 'k.zahtev', 'prodavac', 's.id as id_status', 'k.datum_montaze',
                'k.datum_odustajanja', 'k.datum_odlaganja', 'k.datum_zakazivanja', 'br_bodova', 'st.status as status_intervencije', 'int.ime as inter_ime',
                'int.prezime as inter_prezime', 'k.datum_reklamacije', 'tm.tip', 'oprema_ugovor', 'broj_ugovora', 'razlog_odustajanja', 'datum_intervencije'
            )
            ->whereIn('k.id', $ids);

        $result = $query->get();

        return $result;
    }


    public function zakazaniMonter($datumZakazivanja, $idUser){
        $query = DB::table('klijenti_bakar as k')
            ->leftJoin('statusi as s', 's.id', '=', 'k.id_status')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_user')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as user_ime',
                'k.adresa', 'u.prezime as user_prezime', 's.status', 'k.datum_zakazivanja', 'k.datum_odustajanja',
                'id_status_intervencije'
            )
            ->whereDate('k.datum_zakazivanja', '=', $datumZakazivanja)
            ->where('k.id_status', '=', 1)
            ->where('k.id_user', '=', $idUser)
            ->orWhere(function ($q) use ($idUser){
                $q->where('k.id_status_intervencije', '=', 1)
                    ->where('k.datum_intervencije', '=', date('Y-m-d'))
                    ->where('k.id_user_reklamacije', '=', $idUser);
            })

            ->orderBy('k.datum_zakazivanja', 'ASC')
        ;

        $result = $query->get();

        return $result;
    }

}
