<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Klijenti_prodaja extends Model
{
    protected $table = 'klijenti_prodaja';
    protected $fillable = [
        'br_ugovora',
        'ime',
        'prezime',
        'jmbg',
        'mrezna_grupa',
        'tel1',
        'tel2',
        'tel3',
        'tis_id',
        'broj_lk',
        'datum_izdavanja_lk',
        'mesto_izdavanja_lk',
        'adresa_prebivalista',
        'adresa_instalacije',
        'id_paket',
        'id_vrsta_paketa',
        'id_nov_servis',
        'id_klijent_prodaja',
        'dodatni_stb',
        'broj_bodova',
        'izvodjac_prodavac',
        'id_prodavac',
        'created_by',
        'updated_by',
        'ekspedovano',
        'prihvaceno',
        'vraceno',
        'id_tip_montaze',
        'na_cekanju',
        'tip_klijenta',
        'datum_zahteva',
        'fobos_id',
        'fobos_copper_id',
        'commission'
    ];

    public function klijentiProdavac($prodavacId){
        $query = DB::table('klijenti_prodaja as k')
            ->leftJoin('paketi as p', 'p.id', '=', 'k.id_paket')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_prodavac')
            ->leftJoin('klijent as kl', 'kl.id_klijent_prodaja', '=', 'k.id')
            ->leftJoin('klijenti_optika as ko', 'ko.id_klijent_prodaja', '=', 'k.id')
            ->leftJoin('klijenti_supernova as ks', 'ks.id_klijent_prodaja', '=', 'k.id')
            ->leftJoin('klijenti_bakar as kb', 'kb.id_klijent_prodaja', '=', 'k.id')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as prodavac_ime', 'k.ekspedovano', 'k.prihvaceno',
                'k.adresa_prebivalista', 'u.prezime as prodavac_prezime', 'p.naziv as paket', 'k.created_at', 'k.mrezna_grupa',
                'k.adresa_instalacije', 'k.vraceno', 'k.na_cekanju', 'kl.id_status', 'ko.id_status as id_optika_status', 'ks.id_status as id_supernova_status',
                'kb.id_status as id_bakar_status', 'k.tip_klijenta')
            ->where('k.id_prodavac', '=', $prodavacId)
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->paginate(15);

        return $result;
    }

    public function klijentiLider($prodavciIds, $idLider){
        $query = DB::table('klijenti_prodaja as k')
            ->leftJoin('paketi as p', 'p.id', '=', 'k.id_paket')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_prodavac')
            ->leftJoin('klijent as kl', 'kl.id_klijent_prodaja', '=', 'k.id')
            ->leftJoin('klijenti_optika as ko', 'ko.id_klijent_prodaja', '=', 'k.id')
            ->leftJoin('klijenti_supernova as ks', 'ks.id_klijent_prodaja', '=', 'k.id')
            ->leftJoin('klijenti_bakar as kb', 'kb.id_klijent_prodaja', '=', 'k.id')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as prodavac_ime', 'k.ekspedovano', 'k.prihvaceno',
                'k.adresa_prebivalista', 'u.prezime as prodavac_prezime', 'p.naziv as paket', 'k.created_at', 'k.mrezna_grupa',
                'k.adresa_instalacije', 'k.vraceno', 'k.na_cekanju', 'kl.id_status', 'ko.id_status as id_optika_status', 'ks.id_status as id_supernova_status',
                'kb.id_status as id_bakar_status', 'k.tip_klijenta')
            ->whereIn('k.id_prodavac', $prodavciIds)
            ->orWhere('k.id_prodavac', '=', $idLider)
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->paginate(15);

        return $result;
    }

    public function klijentiAdmin(){
        $query = DB::table('klijenti_prodaja as k')
            ->leftJoin('paketi as p', 'p.id', '=', 'k.id_paket')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_prodavac')
            ->leftJoin('klijent as kl', 'kl.id_klijent_prodaja', '=', 'k.id')
            ->leftJoin('klijenti_optika as ko', 'ko.id_klijent_prodaja', '=', 'k.id')
            ->leftJoin('klijenti_supernova as ks', 'ks.id_klijent_prodaja', '=', 'k.id')
            ->leftJoin('klijenti_bakar as kb', 'kb.id_klijent_prodaja', '=', 'k.id')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as prodavac_ime', 'k.ekspedovano', 'k.prihvaceno',
                'k.adresa_prebivalista', 'u.prezime as prodavac_prezime', 'p.naziv as paket', 'k.created_at', 'k.mrezna_grupa',
                'k.adresa_instalacije', 'k.vraceno', 'kl.id_status', 'ko.id_status as id_optika_status', 'ks.id_status as id_supernova_status',
                'kb.id_status as id_bakar_status', 'k.tip_klijenta')
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->paginate(30);

        return $result;
    }

    public function klijentPodaci($klijentId){
        $query = DB::table('klijenti_prodaja as k')
            ->leftJoin('paketi as p', 'p.id', '=', 'k.id_paket')
            ->leftJoin('vrste_paketa as vp', 'vp.id', '=', 'k.id_vrsta_paketa')
            ->leftJoin('nov_servis as ns', 'ns.id', '=', 'k.id_nov_servis')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_prodavac')
            ->leftJoin('users as usr', 'usr.id', '=', 'k.updated_by')
            ->leftJoin('klijent as kl', 'kl.id_klijent_prodaja', '=', 'k.id')
            ->leftJoin('klijenti_optika as ko', 'ko.id_klijent_prodaja', '=', 'k.id')
            ->leftJoin('klijenti_supernova as ks', 'ks.id_klijent_prodaja', '=', 'k.id')
            ->leftJoin('klijenti_bakar as kb', 'kb.id_klijent_prodaja', '=', 'k.id')
            ->leftJoin('statusi as s', 's.id', '=', 'kl.id_status')
            ->leftJoin('statusi as so', 'so.id', '=', 'ko.id_status')
            ->leftJoin('statusi as ss', 'ss.id', '=', 'ks.id_status')
            ->leftJoin('statusi as sb', 'sb.id', '=', 'kb.id_status')
            ->select('k.id', 'k.br_ugovora','k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as prodavac_ime', 'k.id_prodavac',
                'k.adresa_prebivalista', 'u.prezime as prodavac_prezime', 'p.naziv as paket', 'k.created_at', 'k.mrezna_grupa', 'k.adresa_instalacije',
                'k.updated_at', 'k.datum_izdavanja_lk', 'k.mesto_izdavanja_lk', 'vp.vrsta as vrsta_paketa', 'ns.naziv as nov_servis', 'k.dodatni_stb',
                'k.broj_bodova', 'k.izvodjac_prodavac', 'usr.ime as promenio_ime', 'usr.prezime as promenio_prezime', 'k.tis_id', 'k.broj_lk',
                'k.ekspedovano', 's.status', 'k.prihvaceno', 'k.tip_klijenta', 'kl.id as id_dth', 'ko.id as id_optika', 'ks.id as id_supernova', 'kb.id as id_bakar',
                'so.status as status_optika', 'ss.status as status_supernova', 'sb.status as status_bakar', 'k.commission')
            ->where('k.id', '=', $klijentId)
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->get();

        return $result[0];
    }

    public function zahtevi_na_cekanju(){
        $query = DB::table('klijenti_prodaja as k')
            ->leftJoin('paketi as p', 'p.id', '=', 'k.id_paket')
            ->leftJoin('vrste_paketa as vp', 'vp.id', '=', 'k.id_vrsta_paketa')
            ->leftJoin('nov_servis as ns', 'ns.id', '=', 'k.id_nov_servis')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_prodavac')
            ->leftJoin('users as usr', 'usr.id', '=', 'k.updated_by')
            ->select('k.id', 'k.br_ugovora','k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as prodavac_ime', 'k.id_prodavac',
                'k.adresa_prebivalista', 'u.prezime as prodavac_prezime', 'p.naziv as paket', 'k.created_at', 'mrezna_grupa', 'adresa_instalacije',
                'k.updated_at', 'k.datum_izdavanja_lk', 'mesto_izdavanja_lk', 'vp.vrsta as vrsta_paketa', 'ns.naziv as nov_servis', 'k.dodatni_stb',
                'k.broj_bodova', 'izvodjac_prodavac', 'usr.ime as promenio_ime', 'usr.prezime as promenio_prezime', 'tis_id', 'broj_lk', 'ekspedovano',
                'prihvaceno')
            ->where('k.na_cekanju', '=', 1)
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->get();

        return $result;
    }

    public function zahtevi(){
        $query = DB::table('klijenti_prodaja as k')
            ->leftJoin('paketi as p', 'p.id', '=', 'k.id_paket')
            ->leftJoin('vrste_paketa as vp', 'vp.id', '=', 'k.id_vrsta_paketa')
            ->leftJoin('nov_servis as ns', 'ns.id', '=', 'k.id_nov_servis')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_prodavac')
            ->leftJoin('users as usr', 'usr.id', '=', 'k.updated_by')
            ->select('k.id', 'k.br_ugovora','k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as prodavac_ime', 'k.id_prodavac',
                'k.adresa_prebivalista', 'u.prezime as prodavac_prezime', 'p.naziv as paket', 'k.created_at', 'mrezna_grupa', 'adresa_instalacije',
                'k.updated_at', 'k.datum_izdavanja_lk', 'mesto_izdavanja_lk', 'vp.vrsta as vrsta_paketa', 'ns.naziv as nov_servis', 'k.dodatni_stb',
                'k.broj_bodova', 'izvodjac_prodavac', 'usr.ime as promenio_ime', 'usr.prezime as promenio_prezime', 'tis_id', 'broj_lk', 'ekspedovano',
                'prihvaceno', 'k.tip_klijenta')
            ->where('k.ekspedovano', '=', 1)
            ->where('k.prihvaceno', '!=', 1)
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->get();

        return $result;
    }

    public function zahtev_notifikacija(){
        $query = DB::table('klijenti_prodaja as k')
            ->select('k.id')
            ->where('k.ekspedovano', '=', 1)
            ->where('k.prihvaceno', '!=', 1)
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->get();

        if ($result->isEmpty())
            return false;
        else
            return true;
    }

    public function zahtev($id){
        $query = DB::table('klijenti_prodaja as k')
            ->leftJoin('paketi as p', 'p.id', '=', 'k.id_paket')
            ->leftJoin('vrste_paketa as vp', 'vp.id', '=', 'k.id_vrsta_paketa')
            ->leftJoin('nov_servis as ns', 'ns.id', '=', 'k.id_nov_servis')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_prodavac')
            ->leftJoin('users as usr', 'usr.id', '=', 'k.updated_by')
            ->select('k.id', 'k.br_ugovora','k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as prodavac_ime', 'k.id_prodavac',
                'k.adresa_prebivalista', 'u.prezime as prodavac_prezime', 'p.naziv as paket', 'k.created_at', 'mrezna_grupa', 'adresa_instalacije',
                'k.updated_at', 'k.datum_izdavanja_lk', 'mesto_izdavanja_lk', 'vp.vrsta as vrsta_paketa', 'ns.naziv as nov_servis', 'k.dodatni_stb',
                'k.broj_bodova', 'izvodjac_prodavac', 'usr.ime as promenio_ime', 'usr.prezime as promenio_prezime', 'tis_id', 'broj_lk', 'ekspedovano',
                'prihvaceno', 'k.id_paket', 'datum_zahteva')
            ->where('k.ekspedovano', '=', 1)
            ->where('k.prihvaceno', '!=', 1)
            ->where('k.id', '=', $id)
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->get();

        return $result[0];
    }

    /** vraca true ili false ako ima vracenih zahteva prodavcu **/
    public function vraceno($id){
        $query = DB::table('klijenti_prodaja')
            ->select('id')
            ->where('vraceno', '=', 1)
            ->where('id_prodavac', '=', $id);

        $result = $query->get();

        if (isset($result[0]))
            return true;
        else
            return false;
    }


    /** za pregled posle klika na notifikaciju
     * @param $id**/
    public function vraceni_zahtevi($id){
        $query = DB::table('klijenti_prodaja as k')
            ->leftJoin('paketi as p', 'p.id', '=', 'k.id_paket')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_prodavac')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as prodavac_ime', 'k.ekspedovano', 'k.prihvaceno',
                'k.adresa_prebivalista', 'u.prezime as prodavac_prezime', 'p.naziv as paket', 'k.created_at', 'mrezna_grupa',
                'k.adresa_instalacije', 'k.vraceno')
            ->where('vraceno', '=', 1)
            ->where('id_prodavac', '=', $id);

        $result = $query->get();

        return $result;
    }

    public function prodaja_search($idProdavac, $brUgovora, $ime, $prezime, $jmbg, $mreznaGrupa, $tel1, $tel2, $tel3, $tisId,
                                   $brojLk, $datumIzdavanjaLk, $mestoIzdavanjaLk, $adresaPrebivalista, $adresaInstalacije,
                                    $paket, $vrstaPaketa, $novServis, $dodatniStb, $brojBodova, $izvodjacProdavac, $createdStart, $createdEnd, $pagination=false){
        $query = DB::table('klijenti_prodaja as k')
            ->leftJoin('paketi as p', 'p.id', '=', 'k.id_paket')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_prodavac')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as prodavac_ime', 'k.ekspedovano', 'k.prihvaceno',
                'k.adresa_prebivalista', 'u.prezime as prodavac_prezime', 'p.naziv as paket', 'k.created_at', 'mrezna_grupa',
                'k.adresa_instalacije', 'k.vraceno', 'k.tip_klijenta')
            ->where('id_prodavac', '=', $idProdavac);

        if ($brUgovora)
            $query->where('k.br_ugovora', '=', $brUgovora);
        if ($ime)
            $query->where('k.ime', 'like', $ime.'%');
        if ($prezime)
            $query->where('k.prezime', 'like', $prezime.'%');
        if ($jmbg)
            $query->where('k.jmbg', '=', $jmbg);
        if ($mreznaGrupa)
            $query->where('k.mrezna_grupa', '=', $mreznaGrupa);
        if ($tel1)
            $query->where('k.tel1', '=', $tel1);
        if ($tel2)
            $query->where('k.tel2', '=', $tel2);
        if ($tel3)
            $query->where('k.tel3', '=', $tel3);
        if ($tisId)
            $query->where('k.tis_id', '=', $tisId);
        if ($brojLk)
            $query->where('k.broj_lk', '=', $brojLk);
        if ($datumIzdavanjaLk)
            $query->where('k.datum_izdavanja_lk', '=', $datumIzdavanjaLk);
        if ($mestoIzdavanjaLk)
            $query->where('k.mesto_izdavanja_lk', '=', $mestoIzdavanjaLk);
        if ($adresaPrebivalista)
            $query->where('k.adresa_prebivalista', 'like', '%'.$adresaPrebivalista.'%');
        if ($adresaInstalacije)
            $query->where('k.adresa_instalacije', 'like', '%'.$adresaInstalacije.'%');
        if ($paket)
            $query->where('k.id_paket', '=', $paket);
        if ($vrstaPaketa)
            $query->where('k.id_vrsta_paketa', '=', $vrstaPaketa);
        if ($novServis)
            $query->where('k.id_nov_servis', '=', $novServis);
        if ($dodatniStb)
            $query->where('k.dodatni_stb', '=', $dodatniStb);
        if ($brojBodova)
            $query->where('k.broj_bodova', '=', $brojBodova);
        if ($izvodjacProdavac)
            $query->where('k.izvodjac_prodavac', '=', $izvodjacProdavac);

        if ($createdStart && $createdEnd){
            $query->whereDate('k.datum_zahteva', '>=', $createdStart);
            $query->whereDate('k.datum_zahteva', '<=', $createdEnd);
        }

        if($pagination)
            $result = $query->paginate(100);
        else
            $result = $query->get();

        return $result;
    }

    public function prodaja_search_admin($brUgovora, $ime, $prezime, $jmbg, $mreznaGrupa, $tel1, $tel2, $tel3, $tisId,
                                   $brojLk, $datumIzdavanjaLk, $mestoIzdavanjaLk, $adresaPrebivalista, $adresaInstalacije,
                                   $paket, $vrstaPaketa, $novServis, $dodatniStb, $brojBodova, $izvodjacProdavac, $idProdavac, $createdStart, $createdEnd, $pagination=false){
        $query = DB::table('klijenti_prodaja as k')
            ->leftJoin('paketi as p', 'p.id', '=', 'k.id_paket')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_prodavac')
            ->select('k.id', 'k.ime', 'k.prezime', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as prodavac_ime', 'k.ekspedovano', 'k.prihvaceno',
                'k.adresa_prebivalista', 'u.prezime as prodavac_prezime', 'p.naziv as paket', 'k.created_at', 'mrezna_grupa',
                'k.adresa_instalacije', 'k.vraceno', 'k.tip_klijenta');

        if ($brUgovora)
            $query->where('k.br_ugovora', '=', $brUgovora);
        if ($ime)
            $query->where('k.ime', 'like', $ime.'%');
        if ($prezime)
            $query->where('k.prezime', 'like', $prezime.'%');
        if ($jmbg)
            $query->where('k.jmbg', '=', $jmbg);
        if ($mreznaGrupa)
            $query->where('k.mrezna_grupa', '=', $mreznaGrupa);
        if ($tel1)
            $query->where('k.tel1', '=', $tel1);
        if ($tel2)
            $query->where('k.tel2', '=', $tel2);
        if ($tel3)
            $query->where('k.tel3', '=', $tel3);
        if ($tisId)
            $query->where('k.tis_id', '=', $tisId);
        if ($brojLk)
            $query->where('k.broj_lk', '=', $brojLk);
        if ($datumIzdavanjaLk)
            $query->where('k.datum_izdavanja_lk', '=', $datumIzdavanjaLk);
        if ($mestoIzdavanjaLk)
            $query->where('k.mesto_izdavanja_lk', '=', $mestoIzdavanjaLk);
        if ($adresaPrebivalista)
            $query->where('k.adresa_prebivalista', 'like', '%'.$adresaPrebivalista.'%');
        if ($adresaInstalacije)
            $query->where('k.adresa_instalacije', 'like', '%'.$adresaInstalacije.'%');
        if ($paket)
            $query->where('k.id_paket', '=', $paket);
        if ($vrstaPaketa)
            $query->where('k.id_vrsta_paketa', '=', $vrstaPaketa);
        if ($novServis)
            $query->where('k.id_nov_servis', '=', $novServis);
        if ($dodatniStb)
            $query->where('k.dodatni_stb', '=', $dodatniStb);
        if ($brojBodova)
            $query->where('k.broj_bodova', '=', $brojBodova);
        if ($izvodjacProdavac)
            $query->where('k.izvodjac_prodavac', '=', $izvodjacProdavac);
        if ($idProdavac)
            $query->where('k.id_prodavac', '=', $idProdavac);

        if ($createdStart && $createdEnd){
            $query->whereDate('k.datum_zahteva', '>=', $createdStart);
            $query->whereDate('k.datum_zahteva', '<=', $createdEnd);
        }

        if($pagination)
            $result = $query->paginate(100);
        else
            $result = $query->get();

        return $result;
    }

    public function prodavac($klijentId){
        $query = DB::table('klijenti_prodaja as k')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_prodavac')
            ->select('u.ime as ime', 'u.prezime as prezime')
            ->where('k.id', '=', $klijentId);
        $result = $query->get();
        return $result[0];
    }

    public function zahtevi_pretraga($datumZahteva=null, $tipKlijenta, $start=null, $end=null, $uradu=null, $pagination=false){
        $query = DB::table('klijenti_prodaja as k')
            ->leftJoin('paketi as p', 'p.id', '=', 'k.id_paket')
            ->leftJoin('vrste_paketa as vp', 'vp.id', '=', 'k.id_vrsta_paketa')
            ->leftJoin('nov_servis as ns', 'ns.id', '=', 'k.id_nov_servis')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_prodavac')
            ->leftJoin('users as usr', 'usr.id', '=', 'k.updated_by')
            ->select('k.id', 'k.br_ugovora','k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as prodavac_ime', 'k.id_prodavac',
                'k.adresa_prebivalista', 'u.prezime as prodavac_prezime', 'p.naziv as paket', 'k.created_at', 'k.mrezna_grupa', 'k.adresa_instalacije',
                'k.updated_at', 'k.datum_izdavanja_lk', 'k.mesto_izdavanja_lk', 'vp.vrsta as vrsta_paketa', 'ns.naziv as nov_servis', 'k.dodatni_stb',
                'k.broj_bodova', 'k.izvodjac_prodavac', 'usr.ime as promenio_ime', 'usr.prezime as promenio_prezime', 'k.tis_id', 'k.broj_lk', 'k.ekspedovano',
                'k.prihvaceno', 'k.tip_klijenta');
            if (!empty($tipKlijenta))
                $query->whereIn('tip_klijenta', $tipKlijenta);
            $query->where('k.ekspedovano', '=', 1);
            if ($datumZahteva)
                $query->whereDate('k.datum_zahteva', '=', $datumZahteva);
            if ($start && $end){
                $query->whereDate('k.datum_zahteva', '>=', $start);
                $query->whereDate('k.datum_zahteva','<=', $end);
            }
            if ($uradu)
                $query->where('k.prihvaceno', '!=', 1);
            $query->orderby('created_at', 'DESC')
        ;

        if($pagination)
            $result = $query->paginate(100);
        else
            $result = $query->get();

        return $result;
    }

    public function export($ids){
        $query = DB::table('klijenti_prodaja as k')
            ->leftJoin('paketi as p', 'p.id', '=', 'k.id_paket')
            ->leftJoin('vrste_paketa as vp', 'vp.id', '=', 'k.id_vrsta_paketa')
            ->leftJoin('nov_servis as ns', 'ns.id', '=', 'k.id_nov_servis')
            ->leftJoin('users as u', 'u.id', '=', 'k.id_prodavac')
            ->leftJoin('users as usr', 'usr.id', '=', 'k.updated_by')
            ->leftJoin('klijent as kl', 'kl.id_klijent_prodaja', '=', 'k.id')
            ->leftJoin('statusi as s', 's.id', '=', 'kl.id_status')
            ->select('k.id', 'k.br_ugovora','k.ime', 'k.prezime', 'k.jmbg', 'k.tel1', 'k.tel2', 'k.tel3', 'u.ime as prodavac_ime', 'k.id_prodavac',
                'k.adresa_prebivalista', 'u.prezime as prodavac_prezime', 'p.naziv as paket', 'k.created_at', 'k.mrezna_grupa', 'k.adresa_instalacije',
                'k.updated_at', 'k.datum_izdavanja_lk', 'k.mesto_izdavanja_lk', 'vp.vrsta as vrsta_paketa', 'ns.naziv as nov_servis', 'k.dodatni_stb',
                'k.broj_bodova', 'k.izvodjac_prodavac', 'usr.ime as promenio_ime', 'usr.prezime as promenio_prezime', 'k.tis_id', 'k.broj_lk',
                'k.ekspedovano', 's.status', 'k.prihvaceno', 's.id as id_status')
            ->whereIn('k.id', $ids)
            ->orderby('created_at', 'DESC')
        ;
        $result = $query->get();

        return $result;
    }

    public function bodovi($prodavacId, $table, $start, $end){
        if ($table=='klijenti_supernova' || $table=='klijenti_bakar')
            $field = 'br_bodova';
        else
            $field = 'broj_bodova';
        $query = DB::table('klijenti_prodaja as k')
            ->leftJoin("$table as kl", 'kl.id_klijent_prodaja', '=', 'k.id')
            ->selectRaw("SUM(kl.$field) as kol")
            ->where('k.id_prodavac', '=', $prodavacId)
            ->where('kl.id_status', '=', 5)
            ->where('kl.datum_montaze', '>=', $start)
            ->where('kl.datum_montaze', '<=', $end)
        ;
        $result = $query->get();

        return $result[0];
    }

    public function potentialCommission($from,$to){
        if(!$from)
            $from = date('Y-m-01');
        if(!$to)
            $to = date('Y-m-t');
        $query = DB::table('klijenti_prodaja')
        ->selectRaw('SUM(commission) as total_commission, COUNT(id) as count')
        ->whereDate('created_at', '>=', $from)
        ->whereDate('created_at', '<=', $to)
        ;
        $result = $query->get();

        return $result[0];
    }

    public function realizedSale($from,$to){
        if(!$from)
            $from = date('Y-m-01');
        if(!$to)
            $to = date('Y-m-t');
        $query = DB::table('klijenti_prodaja as k')
        ->selectRaw('SUM(k.commission) as total_commission, COUNT(k.id) as count')
        ->whereDate('montage_date', '>=', $from)
        ->whereDate('montage_date', '<=', $to)
        ;

        $result = $query->get();
        return $result[0];
    }

    public function unrealizedSale($from,$to){
        if(!$from)
            $from = date('Y-m-01');
        if(!$to)
            $to = date('Y-m-t');
        $query = DB::table('klijenti_prodaja as k')
        ->selectRaw('SUM(k.commission) as total_commission, COUNT(k.id) as count')
        ->whereDate('created_at', '>=', $from)
        ->whereDate('created_at', '<=', $to)
        ->whereNull('montage_date')
        ;

        $result = $query->get();
        return $result[0];
    }

}
