<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Magacin extends Model
{
    protected $table = 'magacin';

    protected $fillable = [
        'serijski_broj',
        'mac1',
        'mac2',
        'id_uredjaj',
        'id_mag',
        'id_magacioner',
        'id_razlog_vracanja',
        'provider',
        'invoice_number',
        'origin',
        'state_id'
    ];

    public function deviceCount($idMag=null, $idDevice){
        $query = DB::table('magacin as m')
            ->selectRaw('count(id) as count')
            ->where('id_uredjaj', '=', $idDevice)
        ;
        if ($idMag)
            $query->where('id_mag', '=', $idMag);

        $result = $query->get();
        return $result[0];
    }

    public function serialMatch($serial){
        $query = DB::table('magacin as m')
            ->select('id', 'id_uredjaj')
            ->where('serijski_broj', '=', $serial)
        ;

        $result = $query->get();
        if (isset($result[0]))
            return true;
        else
            return false;
    }

    /**
     * serijski broj
     * @param $serial
     * da f-ja vraca true ili false
     * @param null $returnBool
     * @return mixed
     */
    public function checkSerial($serial, $returnBool=null, $device=null){
        $query = DB::table('magacin as m')
            ->select('id', 'id_uredjaj', 'id_mag', 'provider', 'invoice_number', 'origin')
            ->where('serijski_broj', '=', $serial)
        ;
        if ($device)
            $query->where('id_uredjaj', '=', $device);

        $result = $query->get();
        if ($returnBool){
            if (isset($result[0]))
                return true;
            else
                return false;
        }
        else{
            return $result;
        }

    }

    public function robaMagacin($category){
        $query = DB::table('magacin as m')
            ->leftJoin('uredjaji as u', 'm.id_uredjaj', '=', 'u.id')
            ->leftJoin('magz as mg', 'mg.id', '=', 'm.id_mag')
            ->leftJoin('tool_providers as tp', 'tp.id', '=', 'm.provider')
            ->leftJoin('tool_origins as to', 'to.id', '=', 'm.origin')
            ->select('m.serijski_broj', 'm.created_at', 'u.uredjaj', 'mg.naziv as magacin', 'm.id', 'm.invoice_number', 'tp.provider', 'to.origin')
        ;
        if($category){
            $query->where('u.category_id', '=', $category);
        }
        $query->orderBy('created_at', 'DESC');

        $result = $query->paginate(20);
        return $result;
    }

    public function magacinSearch($serijskiBroj=null, $uredjaj=null, $magacin=null, $magacioner=null, $start=null, $end=null, $notOnReverse=null){
        $query = DB::table('magacin as m')
            ->leftJoin('uredjaji as u', 'm.id_uredjaj', '=', 'u.id')
            ->leftJoin('magz as mg', 'mg.id', '=', 'm.id_mag')
            ->leftJoin('users as usr', 'usr.id', '=', 'm.id_magacioner')
            ->select('m.serijski_broj', 'm.created_at', 'u.uredjaj', 'mg.naziv as magacin', 'm.id', 'usr.ime as magacioner_ime', 'usr.prezime as magacioner_prezime')
            ->orderBy('m.id_uredjaj', 'ASC')
        ;

        if ($serijskiBroj)
            $query->where('m.serijski_broj', 'like', '%'.$serijskiBroj.'%');
        if ($uredjaj)
            $query->where('m.id_uredjaj', '=', $uredjaj);
        if ($magacin)
            $query->where('m.id_mag', '=', $magacin);
        if ($magacioner)
            $query->where('m.id_magacioner', '=', $magacioner);
        if ($start)
            $query->whereDate('m.created_at', '>=', $start);
        if ($end)
            $query->whereDate('m.created_at', '<=', $end);
        //nested query
        if($notOnReverse){
            $query->whereNotIn('m.serijski_broj', function($query) use ($magacin){
                $query->from('revers_roba')->select('serijski_broj')->where('mounted', '=', 0)->where('obsolete', '=', 0);
                if($magacin){
                    $query->where('storage_id', '=', $magacin);
                }
            });
        }


        $result = $query->get();
        return $result;
    }

        public function deviceBySerial($serial){
        $query = DB::table('magacin')
            ->select('serijski_broj', 'mac1', 'mac2', 'id_uredjaj')
            ->where('serijski_broj', '=', $serial)
        ;

        $result = $query->get();
        return $result[0];
    }

    public function fitterStock($idDevice, $fitter){
        $query = DB::table('revers_roba as rr')
            ->leftJoin('revers as r', 'r.id', '=', 'rr.id_revers')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'rr.id_uredjaj')
            ->selectRaw('COUNT(DISTINCT(serijski_broj)) as count, u.uredjaj as device')
            ->where('id_uredjaj', '=', $idDevice)
            ->where('mounted', '=', 0)
            ->where('obsolete', '=', 0)
            ->where('id_monter', '=', $fitter)
            ->orderBy('rr.id', 'DESC')
        ;
        $result = $query->get();
        return $result;
    }

    public function specificDeviceAmountInStorage($idDevice){
        $query = DB::table('magacin as m')
            ->selectRaw('count(id) as count')
            ->where('id_uredjaj', '=', $idDevice)
        ;
        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->count;
    }

    public function reversCount($deviceId, $mag=null){
        $query = DB::table('revers_roba as rr')
            ->leftJoin('revers as r', 'r.id', '=', 'rr.id_revers')
            ->selectRaw('COUNT(DISTINCT(serijski_broj)) as count')
            ->where('id_uredjaj', '=', $deviceId)
            ->where('mounted', '=', 0)
            ->where('obsolete', '=', 0)
        ;
        if($mag)
            $query->where('rr.storage_id', '=', $mag);
        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->count;
    }

    public function device_export($id){
        $query = DB::table('magacin as m')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'm.id_uredjaj')
            ->select('m.serijski_broj as serial', 'u.uredjaj as device')
            ->where('m.id', '=', $id)
        ;
        $result = $query->first();
        return $result;
    }
}
