<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;
use App\Traits\Util;

class De_construction_sites extends Model
{
    protected $fillable = [
        'id', 
        'date', 
        'polisher_report', 
        'polish_date',
        'leader', 
        'company_id', 
        'number_of_workers',
        'work_start',
        'work_end',
        'pause',
        'place',
        'provider',
        'street',
        'pop',
        'dp',
        'area',
        'cluster',
        'report_confirmed',
        'maintenance',
        'pan_id',
        'status_id',
        'knot_id',
        'connection_id',
        'work_order_number'
    ];

    public function index($leader=null,$area=null,$providers=null){
        $query = DB::table('de_construction_sites as d')
            ->leftJoin('users as u', 'u.id', '=', 'd.leader')
            ->leftJoin('clusters as cl', 'cl.id', '=', 'd.cluster')
            ->leftJoin('pans as p', 'p.id', '=', 'd.pan_id')
            ->leftJoin('de_statuses as ds', 'ds.id', '=', 'd.status_id')
            ->select('d.id', 'd.date', 'u.ime as name', 'u.prezime as surname', 'd.number_of_workers', 'd.place', 'd.place', 'd.street', 'cl.cluster', 
            'p.pan', 'ds.status', 'connection_id', 'work_order_number')
        ;
        if($leader)
            $query->where('leader', '=', $leader);
        if($area)
            $query->where('d.area', '=', $area);
        if($providers)
            $query->whereIn('d.provider', $providers);

        return $query->paginate(50);
    }

    public function data($id){
        $query = DB::table('de_construction_sites as d')
            ->leftJoin('users as u', 'u.id', '=', 'd.leader')
            ->leftJoin('areas as a', 'a.id', '=', 'd.area')
            ->leftJoin('providers as p', 'p.id', '=', 'd.provider')
            ->leftJoin('clusters as cl', 'cl.id', '=', 'd.cluster')
            ->leftJoin('pans as pn', 'pn.id', '=', 'd.pan_id')
            ->leftJoin('de_statuses as ds', 'ds.id', '=', 'd.status_id')
            ->leftJoin('distributive_knots as k', 'k.id', '=', 'd.knot_id')
            ->select('d.id', 'd.date', 'u.ime as name', 'u.prezime as surname', 'd.number_of_workers', 'd.place', 'd.place', 'd.street', 'd.polisher_report',
            'd.work_start', 'd.work_end', 'd.pause', 'd.pan_id', 'd.dp', 'a.area', 'p.provider', 'd.polish_date', 'cl.cluster', 'd.report_confirmed', 'maintenance',
            'pn.pan', 'ds.status', 'k.knot', 'connection_id', 'work_order_number')
            ->where('d.id', '=', $id)
        ;

        return $query->first();
    }

    public function filter($leader=null,$dateStart=null,$dateEnd=null,$numberOfWorkers=null,$area=null,$place=null,$street=null,$pan=null,$polishDate=null,
                            $reportConfirmed=null,$cluster=null,$providers=null, $maintenance=null, $status=null, $withoutStatus=null,$knot=null,
                            $connectionId=null,$workOrderNumber=null,$pagination=null){
        $query = DB::table('de_construction_sites as d')
            ->leftJoin('users as u', 'u.id', '=', 'd.leader')
            ->leftJoin('clusters as cl', 'cl.id', '=', 'd.cluster')
            ->leftJoin('pans as p', 'p.id', '=', 'd.pan_id')
            ->leftJoin('de_statuses as ds', 'ds.id', '=', 'd.status_id')
            ->select('d.id', 'd.date', 'u.ime as name', 'u.prezime as surname', 'p.pan', 'd.place', 'd.place', 'd.street', 'cl.cluster', 'd.report_confirmed', 
            'ds.status', 'd.connection_id', 'd.work_order_number')
        ;
        if($leader)
            $query->where('leader', '=', $leader);
        if($dateStart)
            $query->where('date', '>=', $dateStart);
        if($dateEnd)
            $query->where('date', '<=', $dateEnd);
        if($numberOfWorkers)
            $query->where('d.number_of_workers','=', $area);
        if($area)
            $query->where('d.area','=', $area);
        if($providers)
            $query->whereIn('d.provider', $providers);
        if($place)
            $query->where('d.place','=', $place);
        if($street)
            $query->where('d.street','=', $street);
        if($pan)
            $query->where('d.pan_id','=', $pan);
        if($polishDate)
            $query->where('d.polish_date','=', $polishDate);
        if($reportConfirmed)
            $query->where('d.report_confirmed','=', $reportConfirmed);
        if($cluster)
            $query->where('d.cluster','=', $cluster);
        if($maintenance)
            $query->where('d.maintenance','=', 1);
        if($status)
            $query->where('d.status_id','=', $status);
        if($withoutStatus)
            $query->whereNull('d.status_id');
        if($knot)
            $query->where('d.knot_id','=', $knot);
        if($connectionId)
            $query->where('d.connection_id','=', $connectionId);
        if($workOrderNumber)
            $query->where('d.work_order_number','=', $workOrderNumber);

        if($pagination)
            return $query->paginate(50);
        else
            return $query->get();
    }

    public function totalForSite($id){
        if(Util::isSubcontractor()){
            $query = DB::table('de_site_work')->selectRaw('SUM(sub_price) as total')->where('site_id', '=', $id);
        }
        else{
            $query = DB::table('de_site_work')->selectRaw('SUM(price) as total')->where('site_id', '=', $id);
        }
        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->total;
    }

    public function scoreboardData($date=null, $start=null, $end=null){
        $query = DB::table('de_construction_sites as d')
        ->leftJoin('users as u', 'u.id', '=', 'd.leader')
        ->leftJoin('clusters as cl', 'cl.id', '=', 'd.cluster')
        ->leftJoin('pans as p', 'p.id', '=', 'd.pan_id')
        ->select('d.id', 'd.date', 'u.ime as name', 'u.prezime as surname', 'p.pan', 'd.place', 'd.place', 'd.street', 'cl.cluster', 'd.report_confirmed')
        ;
        if($date){
            $query->where('date', '=', $date);
        }
        elseif($start && $end){
            $query->where('date', '>=', $start)->where('date', '<=', $end);
        }

        return $query->get();
    }

    public function totalForSiteS($date=null, $start=null, $end=null, $confirmed=null){
        if(Util::isSubcontractor()){
            $query = DB::table('de_construction_sites as s')
            ->join('de_site_work as sw', 's.id', '=', 'sw.site_id')
            ->selectRaw('SUM(sub_price) as total');
        }
        else{
            $query = DB::table('de_construction_sites as s')
            ->join('de_site_work as sw', 's.id', '=', 'sw.site_id')
            ->selectRaw('SUM(price) as total');
        }

        if($date){
            $query->where('s.date', '=', $date);
        }
        elseif($start && $end){
            $query->where('s.date', '>=', $start)->where('s.date', '<=', $end);
        }

        if($confirmed !== null){
            $query->where('s.report_confirmed', $confirmed);
        }
        
        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->total;
    }

    public function export($ids){
        $query = DB::table('de_construction_sites as d')
            ->leftJoin('users as u', 'u.id', '=', 'd.leader')
            ->leftJoin('areas as a', 'a.id', '=', 'd.area')
            ->leftJoin('providers as p', 'p.id', '=', 'd.provider')
            ->leftJoin('clusters as cl', 'cl.id', '=', 'd.cluster')
            ->leftJoin('pans as pn', 'pn.id', '=', 'd.pan_id')
            ->leftJoin('de_statuses as ds', 'ds.id', '=', 'd.status_id')
            ->leftJoin('distributive_knots as k', 'k.id', '=', 'd.knot_id')
            ->select('d.id', 'd.date', 'u.ime as name', 'u.prezime as surname', 'd.number_of_workers', 'd.place', 'd.place', 'd.street', 'd.polisher_report',
            'd.work_start', 'd.work_end', 'd.pause', 'd.pan_id', 'd.dp', 'a.area', 'p.provider', 'd.polish_date', 'cl.cluster', 'd.report_confirmed', 'maintenance',
            'pn.pan', 'ds.status', 'k.knot', 'connection_id', 'work_order_number')
            ->whereIn('d.id', $ids)
            ;

        $result = $query->get();
        return $result;
    }

    public function sites($start, $end, $leader, $cluster, $pan, $provider){
        $query = DB::table('de_construction_sites as s')
            ->select('s.id', 's.place', 's.street', 's.report_confirmed')
            ->where('s.date', '>=', $start)
            ->where('s.date', '<=', $end)
            ->whereIn('s.leader', $leader)
        ;

        if($cluster){
            $query->where('s.cluster', '=', $cluster);
        }
        if($pan){
            $query->where('s.pan_id', '=', $pan);
        }
        if($provider){
            $query->where('s.provider', '=', $provider);
        }

        $query->orderBy('s.report_confirmed', 'DESC');

        $result = $query->get();
        if($result->isEmpty())
            return null;
        else
            return $result;
    }

}
