<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Ger_construction_sites extends Model
{
    protected $fillable = [
        'id', 
        'date', 
        'polisher_report', 
        'polish_date',
        'leader', 
        'company_id', 
        'number_of_workers',
        'work_start',
        'work_end',
        'pause',
        'place',
        'provider',
        'street',
        'pop',
        'dp',
        'area'
    ];

    public function index($leader=null,$area=null,$provider=null){
        $query = DB::table('ger_construction_sites as d')
            ->leftJoin('users as u', 'u.id', '=', 'd.leader')
            ->select('d.id', 'd.date', 'u.ime as name', 'u.prezime as surname', 'd.number_of_workers', 'd.place', 'd.place', 'd.street')
        ;
        if($area && $provider){
            $query->where('d.area', '=', $area);
            $query->where('d.provider', '=', $provider);
        }
        if($leader)
            $query->where('leader', '=', $leader);

        return $query->paginate(50);
    }

    public function data($id){
        $query = DB::table('ger_construction_sites as d')
            ->leftJoin('users as u', 'u.id', '=', 'd.leader')
            ->leftJoin('areas as a', 'a.id', '=', 'd.area')
            ->leftJoin('providers as p', 'p.id', '=', 'd.provider')
            ->select('d.id', 'd.date', 'u.ime as name', 'u.prezime as surname', 'd.number_of_workers', 'd.place', 'd.place', 'd.street', 'd.polisher_report',
            'd.work_start', 'd.work_end', 'd.pause', 'd.pop', 'd.dp', 'a.area', 'p.provider', 'd.polish_date')
            ->where('d.id', '=', $id)
        ;

        return $query->first();
    }

    public function filter($leader=null,$dateStart=null,$dateEnd=null,$area=null,$provider=null){
        $query = DB::table('ger_construction_sites as d')
            ->leftJoin('users as u', 'u.id', '=', 'd.leader')
            ->select('d.id', 'd.date', 'u.ime as name', 'u.prezime as surname', 'd.number_of_workers', 'd.place', 'd.place', 'd.street')
        ;
        if($leader)
            $query->where('leader', '=', $leader);
        if($dateStart)
            $query->where('date', '>=', $dateStart);
        if($dateEnd)
            $query->where('date', '<=', $dateEnd);
        if($area && $provider){
            $query->where('d.area','=', $area);
            $query->where('d.provider','=', $provider);
        }

        return $query->paginate(50);
    }

    public function totalForSite($id){
        $query = DB::table('ger_site_work')->selectRaw('SUM(price) as total')->where('site_id', '=', $id);
        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->total;
    }

}
