<?php

namespace App\Models;

use App\Traits\Util;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Huawei extends Model
{
    protected $table = 'huawei';
    protected $fillable = [
        'name',
        'h_id',
        'seller',
        'contact_seller',
        'tel1',
        'tel2',
        'tel3',
        'manager',
        'm_tel1',
        'm_tel2',
        'm_tel3',
        'id_state',
        'id_city',
        'municipality',
        'id_area',
        'address',
        'number_of_floors',
        'number_of_flats',
        'id_status_vertical',
        'id_status_access',
        'id_status_splicing',
        'id_status_final',
        'project_manager',
        'construction_manager',
        'id_user_vertical',
        'id_user_access',
        'id_user_splicing',
        'appointment_date_vertical',
        'appointment_date_access',
        'appointment_date_splicing',
        'delay_date',
        'realization_date_vertical',
        'realization_date_access',
        'realization_date_splicing',
        'withdrawal_date',
        'sending_date_huawei',
        'cluster',
        'odo',
        'izvod',
        'connector',
        'created_by',
        'technical_solution_date',
        'atc_msan_olt',
        'odf_modul',
        'connector_number',
        'connection_point',
        'fiber',
        'numeration_odo',
        'dis_start_date',
        'dis_end_date',
        'sent_boq',
        'approved_boq',
        'order_number',
        'set_dis',
        'boq_send_date',
        'boq_approve_date',
        'correction_date_start',
        'correction_date_end',
        'price',
        'company_id',
        'tis_entry_date',
        'subcontractor',
        'invoice',
        'lght'
    ];
    
    public function index($idUser=null, $idConstructionManager=null, $projectManager=null, $projectAdmin=null, $huaweiAdminArea=null,$subcontractor=null,$forbiddenArea=null){
        $query = DB::table('huawei as h')
            ->leftJoin('cities as c', 'c.id', '=', 'h.id_city')
            ->leftJoin('states as s', 's.id', '=', 'h.id_state')
            ->leftJoin('areas as a', 'a.id', '=', 'h.id_area')
            ->leftJoin('huawei_vertical_statuses as hsv', 'hsv.id', '=', 'h.id_status_vertical')
            ->leftJoin('huawei_access_statuses as hsa', 'hsa.id', '=', 'h.id_status_access')
            ->leftJoin('huawei_access_statuses as spl', 'spl.id', '=', 'h.id_status_splicing')
            ->leftJoin('hw_final_statuses as fs', 'fs.id', '=', 'h.id_status_final')
            ->leftJoin('users as up', 'up.id', '=', 'h.id_user_access')
            ->leftJoin('users as uv', 'uv.id', '=', 'h.id_user_vertical')
            ->leftJoin('users as uc', 'uc.id', '=', 'h.construction_manager')
            ->select('h.name', 'h.address', 'c.city', 's.state', 'hsv.status as status_vertical', 'hsa.status as status_access', 'a.area', 'up.ime as access_name', 'up.prezime as access_surname', 'h.id', 'municipality',
                    'uv.ime as vertical_name', 'uv.prezime as vertical_surname', 'uc.ime as construction_manager_name', 'uc.prezime as construction_manager_surname', 'fs.status as final_status', 'spl.status as status_splicing');
        if ($idUser){
            $query->where('h.id_user_access', '=', $idUser);
            $query->orWhere('h.id_user_vertical', '=', $idUser);
        }
        if ($idConstructionManager)
            $query->where('h.construction_manager', '=', $idConstructionManager);
        if ($projectManager)
            $query->where('h.project_manager', '=', $projectManager);
        if($projectAdmin)
            $query->where('h.project_manager', '!=', null);
        if($huaweiAdminArea)
            $query->where('h.id_area', '=', $huaweiAdminArea);
        if($subcontractor)
            $query->where('h.subcontractor', '=', $subcontractor);
        if($forbiddenArea){
            $query->whereNotIn('h.id_area', $forbiddenArea)
                  ->orWhereNull('h.id_area');            
            ;
        }

        $query->orderBy('id', 'DESC');
        $result = $query->paginate(50);
        return $result;
    }

    public function huawei_data($id){
        $query = DB::table('huawei as hw')
            ->leftJoin('cities as c', 'c.id', '=', 'hw.id_city')
            ->leftJoin('states as s', 's.id', '=', 'hw.id_state')
            ->leftJoin('areas as a', 'a.id', '=', 'hw.id_area')
            ->leftJoin('huawei_access_statuses as sa', 'sa.id', '=', 'hw.id_status_access')
            ->leftJoin('huawei_vertical_statuses as sv', 'sv.id', '=', 'hw.id_status_vertical')
            ->leftJoin('huawei_access_statuses as spl', 'spl.id', '=', 'hw.id_status_splicing')
            ->leftJoin('hw_final_statuses as fs', 'fs.id', '=', 'hw.id_status_final')
            ->leftJoin('users as au', 'au.id', '=', 'hw.id_user_access')
            ->leftJoin('users as vu', 'vu.id', '=', 'hw.id_user_vertical')
            ->leftJoin('users as splu', 'splu.id', '=', 'hw.id_user_splicing')
            ->leftJoin('users as cu', 'cu.id', '=', 'hw.created_by')
            ->leftJoin('users as mu', 'mu.id', '=', 'hw.construction_manager')
            ->leftJoin('users as pm', 'pm.id', '=', 'hw.project_manager')
            ->leftJoin('users as sub', 'sub.id', '=', 'hw.subcontractor')
            ->leftJoin('companies as com', 'com.id', '=', 'hw.company_id')
            ->select('hw.id_user_access', 'hw.id_user_vertical', 'hw.id', 'hw.name', 'h_id', 'hw.seller', 'hw.contact_seller', 'hw.tel1', 'hw.tel2', 'hw.tel3', 'hw.manager', 'hw.m_tel1', 'hw.m_tel2',
                'hw.m_tel3', 's.state', 'c.city', 'a.area', 'hw.address', 'hw.number_of_floors', 'hw.number_of_flats', 'sv.status as status_vertical', 'sa.status as status_access', 'hw.project_manager',
                'hw.construction_manager', 'au.ime as access_name', 'au.prezime as access_surname', 'vu.ime as vertical_name', 'vu.prezime as vertical_surname', 'hw.appointment_date_vertical',
                'hw.appointment_date_access', 'hw.delay_date', 'hw.realization_date_vertical', 'hw.realization_date_access', 'hw.withdrawal_date', 'hw.sending_date_huawei', 'hw.cluster', 'hw.odo',
                'hw.izvod', 'hw.connector', 'hw.created_by', 'hw.created_at', 'mu.ime as construction_manager_name', 'mu.prezime as construction_manager_surname',
                'hw.id_status_access', 'hw.id_status_vertical', 'pm.ime as project_manager_name', 'pm.prezime as project_manager_surname', 'hw.technical_solution_date', 'hw.atc_msan_olt', 'odf_modul',
                'hw.connector_number', 'hw.connection_point', 'hw.fiber', 'hw.numeration_odo', 'hw.municipality', 'spl.status as status_splicing', 'hw.id_status_splicing', 'splu.ime as splicing_name',
                'splu.prezime as splicing_surname', 'hw.id_user_splicing', 'hw.appointment_date_splicing', 'fs.status as final_status', 'dis_start_date', 'dis_end_date', 'realization_date_splicing',
                'sent_boq', 'approved_boq', 'boq_send_date', 'boq_approve_date', 'correction_date_start', 'correction_date_end', 'price', 'com.company', 'order_number', 'set_dis', 'tis_entry_date', 'invoice',
                'sub.ime as sub_name', 'sub.prezime as sub_surname','lght')
            ->where('hw.id', '=', $id);

        $result = $query->get();
        return $result[0];
    }

    public function search($name=null,$seller=null,$hId=null,$statusAccess=null,$statusVertical=null,$statusSplicing=null,$finalStatus=null,$appointmentDateAccess=null,
                            $appointmentDateVertical=null,$appointmentDateSplicing=null,$noAccessStatus=null,$noVerticalStatus=null,$noSplicingStatus=null,$noFinalStatus=null,
                           $projectManager=null,$constructionManager=null,$area=null,$paginate=false,$forbiddenArea=null){
        $query = DB::table('huawei as h')
            ->leftJoin('cities as c', 'c.id', '=', 'h.id_city')
            ->leftJoin('states as s', 's.id', '=', 'h.id_state')
            ->leftJoin('areas as a', 'a.id', '=', 'h.id_area')
            ->leftJoin('huawei_vertical_statuses as hsv', 'hsv.id', '=', 'h.id_status_vertical')
            ->leftJoin('huawei_access_statuses as hsa', 'hsa.id', '=', 'h.id_status_access')
            ->leftJoin('huawei_access_statuses as spl', 'spl.id', '=', 'h.id_status_splicing')
            ->leftJoin('hw_final_statuses as fst', 'fst.id', '=', 'h.id_status_final')
            ->leftJoin('users as up', 'up.id', '=', 'h.id_user_access')
            ->leftJoin('users as uv', 'uv.id', '=', 'h.id_user_vertical')
            ->leftJoin('users as us', 'us.id', '=', 'h.id_user_splicing')
            ->leftJoin('users as uc', 'uc.id', '=', 'h.construction_manager')
            ->leftJoin('users as pmg', 'pmg.id', '=', 'h.project_manager')
            ->select('h.name', 'h.address', 'c.city', 's.state', 'hsv.status as status_vertical', 'hsa.status as status_access', 'a.area', 'up.ime as access_name', 'up.prezime as access_surname', 'h.id',
                    'uv.ime as vertical_name', 'uv.prezime as vertical_surname', 'uc.ime as construction_manager_name', 'uc.prezime as construction_manager_surname', 'spl.status as status_splicing', 'municipality',
                    'us.ime as splicing_name', 'us.prezime as splicing_surname', 'fst.status as final_status', 'pmg.ime as project_manager_name', 'pmg.prezime as project_manager_surname');
        if ($name)
            $query->where('h.name', 'like', $name.'%');
        if ($seller)
            $query->where('h.seller', '=', $seller);
        if ($hId)
            $query->where('h.h_id', '=', $hId);
        if ($statusAccess)
            $query->where('h.id_status_access', '=', $statusAccess);
        if ($statusVertical)
            $query->where('h.id_status_vertical', '=', $statusVertical);
        if ($statusSplicing)
            $query->where('h.id_status_splicing', '=', $statusSplicing);
        if ($finalStatus)
            $query->where('h.id_status_final', '=', $finalStatus);
        if ($appointmentDateAccess)
            $query->whereDate('h.appointment_date_access', '=', $appointmentDateAccess);
        if ($appointmentDateVertical)
            $query->whereDate('h.appointment_date_vertical', '=', $appointmentDateVertical);
        if ($appointmentDateSplicing)
            $query->whereDate('h.appointment_date_splicing', '=', $appointmentDateSplicing);
        if ($noAccessStatus)
            $query->where('h.id_status_access', '=', null);
        if ($noVerticalStatus)
            $query->where('h.id_status_vertical', '=', null);
        if ($noSplicingStatus)
            $query->where('h.id_status_splicing', '=', null);
        if ($noFinalStatus)
             $query->where('h.id_status_final', '=', null);
        if($projectManager)
            $query->where('h.project_manager', '=', $projectManager);
        if($constructionManager)
            $query->where('h.construction_manager', '=', $constructionManager);
        if($area)
            $query->where('h.id_area', '=', $area);
        if($forbiddenArea){
            $query->whereNotIn('h.id_area', $forbiddenArea);
        }

        if($paginate)
            $result = $query->paginate(50);
        else
            $result = $query->get();
        return $result;
    }

    public function advanced_search($name=null,$seller=null,$contactSeller=null,$hId=null,$tel1=null,$tel2=null,$tel3=null,$manager=null,$mTel1=null,$mTel2=null,
    $mTel3=null,$state=null,$city=null,$municipality=null,$address=null,$numberOfFloors=null,$numberOfFlats=null,$area=null,$statusAccess=null,$statusVertical=null,$statusSplicing=null, $finalStatus=null,
    $projectManager=null,$constructionManager=null,$workerAccess=null,$workerVertical=null,$workerSplicing=null,$appointmentDateAccess=null,$appointmentDateVertical=null,$appointmentDateSplicing=null,
    $delayDate=null,$realizationDateAccess=null,$realizationDateVertical=null,$withdrawalDate=null,$sendingDateHuawei=null,$cluster=null,$odo=null,$izvod=null,
    $connector=null,$realizationAccessStart=null,$realizationAccessEnd=null,$realizationVerticalStart=null,$realizationVerticalEnd=null,$realizationSplicingStart=null,$realizationSplicingEnd=null,
    $appointmentAccessStart=null,$appointmentAccessEnd=null,$appointmentVerticalStart=null,$appointmentVerticalEnd=null,$appointmentSplicingStart=null,$appointmentSplicingEnd=null,
    $noAccessStatus=null,$noVerticalStatus=null,$noSplicingStatus=null,$noFinalStatus=null,$technicalSolutionDate=null,$atcMsanOlt=null,$odfModul=null,$connectorNumber=null,$connectionPoint=null,
    $fiber=null,$numerationOdo=null,$disStartDate=null,$disEndDate=null,$flats=null,$disEndDateStart=null,$disEndDateEnd=null,$boqSendDateStart=null,
    $boqSendDateEnd=null,$boqApprovedDateStart=null, $boqApprovedDateEnd=null,$operator=null,$tisEntryDate=null,$lght=null,$userId=null,$paginate=false){
        $query = DB::table('huawei as h')
            ->leftJoin('cities as c', 'c.id', '=', 'h.id_city')
            ->leftJoin('states as s', 's.id', '=', 'h.id_state')
            ->leftJoin('areas as a', 'a.id', '=', 'h.id_area')
            ->leftJoin('huawei_vertical_statuses as hsv', 'hsv.id', '=', 'h.id_status_vertical')
            ->leftJoin('huawei_access_statuses as hsa', 'hsa.id', '=', 'h.id_status_access')
            ->leftJoin('huawei_access_statuses as spl', 'spl.id', '=', 'h.id_status_splicing')
            ->leftJoin('users as up', 'up.id', '=', 'h.id_user_access')
            ->leftJoin('users as uv', 'uv.id', '=', 'h.id_user_vertical')
            ->leftJoin('users as us', 'us.id', '=', 'h.id_user_splicing')
            ->leftJoin('users as uc', 'uc.id', '=', 'h.construction_manager')
            ->leftJoin('users as pmg', 'pmg.id', '=', 'h.project_manager')
            ->leftJoin('hw_final_statuses as fst', 'fst.id', '=', 'h.id_status_final')
            ->select('h.name', 'h.address', 'c.city', 's.state', 'hsv.status as status_vertical', 'hsa.status as status_access', 'a.area', 'up.ime as access_name', 'up.prezime as access_surname', 'h.id',
                    'uv.ime as vertical_name', 'uv.prezime as vertical_surname', 'uc.ime as construction_manager_name', 'uc.prezime as construction_manager_surname', 'spl.status as status_splicing', 'municipality',
                    'us.ime as splicing_name', 'us.prezime as splicing_surname', 'fst.status as final_status', 'pmg.ime as project_manager_name', 'pmg.prezime as project_manager_surname');
        if ($name)
            $query->where('h.name', 'like', $name.'%');
        if ($seller)
            $query->where('h.seller', '=', $seller);
        if ($contactSeller)
            $query->where('h.contact_seller', '=', $contactSeller);
        if ($hId)
            $query->where('h.h_id', '=', $hId);
        if ($tel1)
            $query->where('h.tel1', '=', $tel1);
        if ($tel2)
            $query->where('h.tel2', '=', $tel2);
        if ($tel3)
            $query->where('h.tel3', '=', $tel3);
        if ($manager)
            $query->where('h.manager', '=', $manager);
        if ($mTel1)
            $query->where('h.m_tel1', '=', $mTel1);
        if ($mTel2)
            $query->where('h.m_tel2', '=', $mTel2);
        if ($mTel1)
            $query->where('h.m_tel3', '=', $mTel3);
        if ($state)
            $query->where('h.id_state', '=', $state);
        if ($city)
            $query->where('h.id_city', '=', $city);
        if ($municipality)
            $query->where('h.municipality', 'like', $municipality.'%');
        if ($address)
            $query->where('h.address', 'like', $address.'%');
        if ($numberOfFloors)
            $query->where('h.number_of_floors', '=', $numberOfFloors);
        if ($numberOfFlats)
            $query->where('h.number_of_flats', '=', $numberOfFlats);
        if ($area)
            $query->where('h.id_area', '=', $area);
        if ($statusAccess)
            $query->where('h.id_status_access', '=', $statusAccess);
        if ($statusVertical)
            $query->where('h.id_status_vertical', '=', $statusVertical);
        if ($statusSplicing)
            $query->where('h.id_status_splicing', '=', $statusSplicing);
        if ($finalStatus)
            $query->where('h.id_status_final', '=', $finalStatus);
        if ($projectManager)
            $query->where('h.project_manager', '=', $projectManager);
        if ($constructionManager)
            $query->where('h.construction_manager', '=', $constructionManager);
        if ($workerAccess)
            $query->where('h.id_user_access', '=', $workerAccess);
        if ($workerVertical)
            $query->where('h.id_user_vertical', '=', $workerVertical);
        if ($workerSplicing)
            $query->where('h.id_user_splicing', '=', $workerSplicing);
        if ($appointmentDateAccess)
            $query->whereDate('h.appointment_date_access', '=', $appointmentDateAccess);
        if ($appointmentDateVertical)
            $query->whereDate('h.appointment_date_vertical', '=', $appointmentDateVertical);
        if ($appointmentDateSplicing)
            $query->whereDate('h.appointment_date_splicing', '=', $appointmentDateSplicing);
        if ($delayDate)
            $query->whereDate('h.delay_date', '=', $delayDate);
        if ($realizationDateAccess)
            $query->whereDate('h.realization_date_access', '=', $realizationDateAccess);
        if ($realizationDateVertical)
            $query->whereDate('h.realization_date_vertical', '=', $realizationDateVertical);
        if ($withdrawalDate)
            $query->whereDate('h.withdrawal_date', '=', $withdrawalDate);
        if ($sendingDateHuawei)
            $query->whereDate('h.sending_date_huawei', '=', $sendingDateHuawei);
        if ($cluster)
            $query->where('h.cluster', '=', $cluster);
        if ($odo)
            $query->where('h.odo', '=', $odo);
        if ($izvod)
            $query->where('h.izvod', '=', $izvod);
        if ($connector)
            $query->where('h.connector', '=', $connector);
        if ($noAccessStatus)
            $query->where('h.id_status_access', '=', null);
        if ($noVerticalStatus)
            $query->where('h.id_status_vertical', '=', null);
        if ($noSplicingStatus)
            $query->where('h.id_status_splicing', '=', null);
        if ($noFinalStatus)
            $query->where('h.id_status_final', '=', null);
        if($technicalSolutionDate)
            $query->where('h.technical_solution_date', '=', $technicalSolutionDate);
        if($atcMsanOlt)
            $query->where('h.atc_msan_olt', '=', $atcMsanOlt);
        if($odfModul)
            $query->where('h.odf_modul', '=', $odfModul);
        if($connectorNumber)
            $query->where('h.connector_number', '=', $connectorNumber);
        if($connectionPoint)
            $query->where('h.connection_point', '=', $connectionPoint);
        if($fiber)
            $query->where('h.fiber', '=', $fiber);
        if($numerationOdo)
            $query->where('h.numeration_odo', '=', $numerationOdo);
        if($disStartDate)
            $query->where('h.dis_start_date', '=', $disStartDate);
        if($disEndDate)
            $query->where('h.dis_end_date', '=', $disEndDate);
        if($userId)
            $query->where('h.construction_manager', '=', $userId);
        if($area)
            $query->where('h.id_area', '=', $area);

        if($realizationAccessStart && $realizationAccessEnd){
            $query->whereDate('realization_date_access', '>=', $realizationAccessStart);
            $query->whereDate('realization_date_access', '<=', $realizationAccessEnd);
        }
        if($realizationVerticalStart && $realizationVerticalEnd){
            $query->whereDate('realization_date_vertical', '>=', $realizationVerticalStart);
            $query->whereDate('realization_date_vertical', '<=', $realizationVerticalEnd);
        }
        if($realizationSplicingStart && $realizationSplicingEnd){
            $query->whereDate('realization_date_splicing', '>=', $realizationSplicingStart);
            $query->whereDate('realization_date_splicing', '<=', $realizationSplicingEnd);
        }
        if($appointmentAccessStart && $appointmentAccessEnd){
            $query->whereDate('appointment_date_access', '>=', $appointmentAccessStart);
            $query->whereDate('appointment_date_access', '<=', $appointmentAccessEnd);
        }
        if($appointmentVerticalStart && $appointmentVerticalEnd){
            $query->whereDate('appointment_date_vertical', '>=', $appointmentVerticalStart);
            $query->whereDate('appointment_date_vertical', '<=', $appointmentVerticalEnd);
        }
        if($appointmentSplicingStart && $appointmentSplicingEnd){
            $query->whereDate('appointment_date_splicing', '>=', $appointmentSplicingStart);
            $query->whereDate('appointment_date_splicing', '<=', $appointmentSplicingEnd);
        }
        if($disEndDateStart && $disEndDateEnd){
            $query->whereDate('dis_end_date', '>=', $disEndDateStart);
            $query->whereDate('appointment_date_vertical', '<=', $disEndDateEnd);
        }
        if($boqSendDateStart && $boqSendDateEnd){
            $query->whereDate('boq_send_date', '>=', $boqSendDateStart);
            $query->whereDate('boq_send_date', '<=', $boqSendDateEnd);
        }
        if($boqApprovedDateStart && $boqApprovedDateEnd){
            $query->whereDate('boq_approve_date', '>=', $boqApprovedDateStart);
            $query->whereDate('boq_approve_date', '<=', $boqApprovedDateEnd);
        }

        if($flats && $operator)
            $query->whereRaw("h.number_of_flats $operator $flats");

        if($tisEntryDate)
            $query->where('tis_entry_date', '=', $tisEntryDate);
        if($lght)
            $query->where('lght', '=', $lght);

        if($paginate)
            $result = $query->paginate(50);
        else
            $result = $query->get();
        return $result;
    }

    public function dashboard($idUser){
        $query = DB::table('huawei as h')
            ->leftJoin('cities as c', 'c.id', '=', 'h.id_city')
            ->leftJoin('states as s', 's.id', '=', 'h.id_state')
            ->leftJoin('areas as a', 'a.id', '=', 'h.id_area')
            ->leftJoin('huawei_vertical_statuses as hsv', 'hsv.id', '=', 'h.id_status_vertical')
            ->leftJoin('huawei_access_statuses as hsa', 'hsa.id', '=', 'h.id_status_access')
            ->select('h.name', 'h.address', 'c.city', 's.state', 'h.municipality', 'hsv.status as status_vertical', 'hsa.status as status_access', 'a.area', 'h.id')
            ->where('h.id_user_access', '=', $idUser)
            ->whereIn('h.id_status_access', [4,5])
            ->orWhere(function($q) use ($idUser){
                $q->where('h.id_user_vertical', '=', $idUser)
                ->whereIn('h.id_status_vertical', [4,5]);
            })
            ->orWhere(function($q) use ($idUser){
                $q->where('h.id_user_splicing', '=', $idUser)
                    ->whereIn('h.id_status_splicing', [4,5]);
            });

        return $query->get();
    }

    public function countByStatus($from=null,$to=null,$realizationAccessStart=null,$realizationAccessEnd=null,$realizationVerticalStart=null,$realizationVerticalEnd=null,$realizationSplicingStart=null
        ,$realizationSplicingEnd=null, $disEndStart=null,$disEndEnd=null,$boqSendStart=null,$boqSendEnd=null,$boqApproveStart=null,$boqApproveEnd=null, $singleDate=null, $status){
        $query = DB::table('huawei as h')
            ->leftJoin('hw_final_statuses as s', 's.id', '=', 'h.id_status_final')
            ->selectRaw('COUNT(h.id) as count, sum(h.price) as amount, s.status')
            ->where('h.id_status_final', '=', $status)
            ;

        if($singleDate){
            $query->whereDate('h.created_at', '=', $singleDate);
        }
        else{
            if($from && $to){
                $query->whereDate('h.created_at', '>=', $from)
                      ->whereDate('h.created_at', '<=', $to);
            }
            if($realizationAccessStart && $realizationAccessEnd){
                $query->where('h.realization_date_access', '>=', $realizationAccessStart)
                      ->where('h.realization_date_access', '<=', $realizationAccessEnd);
            }
            if($realizationVerticalStart && $realizationVerticalEnd){
                $query->where('h.realization_date_vertical', '>=', $realizationVerticalStart)
                      ->where('h.realization_date_vertical', '<=', $realizationVerticalEnd);
            }
            if($realizationSplicingStart && $realizationSplicingEnd){
                $query->where('h.realization_date_splicing', '>=', $realizationSplicingStart)
                      ->where('h.realization_date_splicing', '<=', $realizationSplicingEnd);
            }
            if($disEndStart && $disEndEnd){
                $query->where('h.dis_end_date', '>=', $disEndStart)
                      ->where('h.dis_end_date', '<=', $disEndEnd);
            }
            if($boqSendStart && $boqSendEnd){
                $query->where('h.boq_send_date', '>=', $boqSendStart)
                      ->where('h.boq_send_date', '<=', $boqSendEnd);
            }
            if($boqApproveStart && $boqApproveEnd){
                $query->where('h.boq_approve_date', '>=', $boqApproveStart)
                      ->where('h.boq_approve_date', '<=', $boqApproveEnd);
            }
        }

        $result = $query->get();
        return $result[0];
    }

    public function sumSentBoQ($from=null,$to=null,$realizationAccessStart=null,$realizationAccessEnd=null,$realizationVerticalStart=null,$realizationVerticalEnd=null,$realizationSplicingStart=null
        ,$realizationSplicingEnd=null, $disEndStart=null,$disEndEnd=null,$boqSendStart=null,$boqSendEnd=null,$boqApproveStart=null,$boqApproveEnd=null, $singleDate=null){
        $query = DB::table('huawei as h')
            ->selectRaw('sum(h.sent_boq) as sent_boq')
            ->where(function($q){
                $q->where('approved_boq', '=', 0)
                    ->orWhereNull('approved_boq');
            })
        ;
        if($singleDate){
            $query->where('h.boq_send_date', '=', $singleDate);
        }
        else{
            if($from && $to){
                $query->whereDate('h.created_at', '>=', $from)
                        ->whereDate('h.created_at', '<=', $to);
            }
            if($realizationAccessStart && $realizationAccessEnd){
                $query->where('h.realization_date_access', '>=', $realizationAccessStart)
                        ->where('h.realization_date_access', '<=', $realizationAccessEnd);
            }
            if($realizationVerticalStart && $realizationVerticalEnd){
                $query->where('h.realization_date_vertical', '>=', $realizationVerticalStart)
                        ->where('h.realization_date_vertical', '<=', $realizationVerticalEnd);
            }
            if($realizationSplicingStart && $realizationSplicingEnd){
                $query->where('h.realization_date_splicing', '>=', $realizationSplicingStart)
                        ->where('h.realization_date_splicing', '<=', $realizationSplicingEnd);
            }
            if($disEndStart && $disEndEnd){
                $query->where('h.dis_end_date', '>=', $disEndStart)
                        ->where('h.dis_end_date', '<=', $disEndEnd);
            }
            if($boqSendStart && $boqSendEnd){
                $query->where('h.boq_send_date', '>=', $boqSendStart)
                        ->where('h.boq_send_date', '<=', $boqSendEnd);
            }
            if($boqApproveStart && $boqApproveEnd){
                $query->where('h.boq_approve_date', '>=', $boqApproveStart)
                        ->where('h.boq_approve_date', '<=', $boqApproveEnd);
            }
        }

        $result = $query->get();
        return $result[0]->sent_boq;
    }

    public function sumApprovedBoQ($from=null,$to=null,$realizationAccessStart=null,$realizationAccessEnd=null,$realizationVerticalStart=null,$realizationVerticalEnd=null,$realizationSplicingStart=null
        ,$realizationSplicingEnd=null, $disEndStart=null,$disEndEnd=null,$boqSendStart=null,$boqSendEnd=null,$boqApproveStart=null,$boqApproveEnd=null, $singleDate=null){
        $query = DB::table('huawei as h')
            ->selectRaw('sum(h.approved_boq) as approved_boq' );

        if($singleDate){
            $query->where('h.boq_send_date', '=', $singleDate);
        }
        else{
            if($from && $to){
                $query->whereDate('h.created_at', '>=', $from)
                    ->whereDate('h.created_at', '<=', $to);
            }
            if($realizationAccessStart && $realizationAccessEnd){
                $query->where('h.realization_date_access', '>=', $realizationAccessStart)
                    ->where('h.realization_date_access', '<=', $realizationAccessEnd);
            }
            if($realizationVerticalStart && $realizationVerticalEnd){
                $query->where('h.realization_date_vertical', '>=', $realizationVerticalStart)
                    ->where('h.realization_date_vertical', '<=', $realizationVerticalEnd);
            }
            if($realizationSplicingStart && $realizationSplicingEnd){
                $query->where('h.realization_date_splicing', '>=', $realizationSplicingStart)
                    ->where('h.realization_date_splicing', '<=', $realizationSplicingEnd);
            }
            if($disEndStart && $disEndEnd){
                $query->where('h.dis_end_date', '>=', $disEndStart)
                    ->where('h.dis_end_date', '<=', $disEndEnd);
            }
            if($boqSendStart && $boqSendEnd){
                $query->where('h.boq_send_date', '>=', $boqSendStart)
                    ->where('h.boq_send_date', '<=', $boqSendEnd);
            }
            if($boqApproveStart && $boqApproveEnd){
                $query->where('h.boq_approve_date', '>=', $boqApproveStart)
                    ->where('h.boq_approve_date', '<=', $boqApproveEnd);
            }
        }

        $result = $query->get();
        return $result[0]->approved_boq;
    }

    public function finished($from=null,$to=null,$realizationAccessStart=null,$realizationAccessEnd=null,$realizationVerticalStart=null,$realizationVerticalEnd=null,$realizationSplicingStart=null
    ,$realizationSplicingEnd=null, $disEndStart=null,$disEndEnd=null,$boqSendStart=null,$boqSendEnd=null,$boqApproveStart=null,$boqApproveEnd=null, $singleDate=null, $finished,$finishedConstruction){
        $query = DB::table('huawei as h')
            ->selectRaw('sum(h.price) as amount' )
            ->where(function($q){
                $q->where('id_status_final', '!=', 3)
                    ->orWhereNull('id_status_final');
            })
            ;
        if($singleDate){
            if($finished){
                $query->where('id_status_access', "=", 6)
                    ->where('id_status_vertical', '=', 6)
                    ->where('id_status_splicing', '=', 6)
                    ->where(function ($q) use ($singleDate){
                        $q->where('h.realization_date_access', '=', $singleDate)
                            ->orWhere('h.realization_date_vertical', '=', $singleDate)
                            ->orWhere('h.realization_date_splicing', '=', $singleDate);
                    })
                ;
            }
            if($finishedConstruction){
                $query->where('id_status_access', "=", 6)
                    ->where('id_status_vertical', '=', 6)
                    ->where(function ($q){
                        $q->where('id_status_splicing', '!=', 6)
                            ->orWhereNull('id_status_splicing');
                    })
                    ->where(function ($q) use ($singleDate){
                        $q->where('realization_date_access', '=', $singleDate)
                            ->orWhere('realization_date_vertical', '=', $singleDate);
                    })
                ;
            }
        }
        else{
            if($from && $to){
                $query->whereDate('h.created_at', '>=', $from)
                        ->whereDate('h.created_at', '<=', $to);
            }
            if($realizationAccessStart && $realizationAccessEnd){
                $query->where('h.realization_date_access', '>=', $realizationAccessStart)
                        ->where('h.realization_date_access', '<=', $realizationAccessEnd);
            }
            if($realizationVerticalStart && $realizationVerticalEnd){
                $query->where('h.realization_date_vertical', '>=', $realizationVerticalStart)
                        ->where('h.realization_date_vertical', '<=', $realizationVerticalEnd);
            }
            if($realizationSplicingStart && $realizationSplicingEnd){
                $query->where('h.realization_date_splicing', '>=', $realizationSplicingStart)
                        ->where('h.realization_date_splicing', '<=', $realizationSplicingEnd);
            }
            if($disEndStart && $disEndEnd){
                $query->where('h.dis_end_date', '>=', $disEndStart)
                        ->where('h.dis_end_date', '<=', $disEndEnd);
            }
            if($boqSendStart && $boqSendEnd){
                $query->where('h.boq_send_date', '>=', $boqSendStart)
                        ->where('h.boq_send_date', '<=', $boqSendEnd);
            }
            if($boqApproveStart && $boqApproveEnd){
                $query->where('h.boq_approve_date', '>=', $boqApproveStart)
                        ->where('h.boq_approve_date', '<=', $boqApproveEnd);
            }
            if($finished){
                $query->where('id_status_access', "=", 6)
                    ->where('id_status_vertical', '=', 6)
                    ->where('id_status_splicing', '=', 6)
                    ;
            }
            if($finishedConstruction){
                $query->where('id_status_access', "=", 6)
                    ->where('id_status_vertical', '=', 6)
                    ->where(function ($q){
                       $q->where('id_status_splicing', '!=', 6)
                           ->orWhereNull('id_status_splicing');
                    })
                ;
            }
        }

        $result = $query->get();
        return $result[0];
    }

    public function countSitesByStatus($column, $singleDate){
        $query = DB::table('huawei')->selectRaw('COUNT(id) as count')->where($column, '=', $singleDate);
        $result = $query->get();
        return $result[0]->count;
    }

    public function updatePrice($price, $idSite){
        DB::table('huawei')->where('id', '=', $idSite)->increment('price', $price);
    }

    public function sitesAccess($singleDate=null, $from=null, $to=null, $realizationAccessStart=null, $realizationAccessEnd=null){
        $query = DB::table('huawei as h')
        ->select('h.id', 'man.ime as manager_name', 'man.prezime as manager_surname', 'h.name', 'acc.ime as access_name', 'acc.prezime as access_surname',
            'ver.ime as vertical_name', 'ver.prezime as vertical_surname')
            ->leftJoin('users as man', 'man.id', '=', 'h.construction_manager')
            ->leftJoin('users as acc', 'acc.id', '=', 'h.id_user_access')
            ->leftJoin('users as ver', 'ver.id', '=', 'h.id_user_vertical');
        if($singleDate){
            $query->whereDate('h.realization_date_access', '=', $singleDate);
        }
        elseif($realizationAccessStart && $realizationAccessEnd){
            $query->whereBetween('h.realization_date_access', [$realizationAccessStart, $realizationAccessEnd]);
        }
        else{
            $query->whereBetween('h.created_at', [$from, $to]);
        }
        $result = $query->get();
        return $result;
    }
    public function sitesSplicing($singleDate=null, $from=null, $to=null, $realizationSplicingStart=null, $realizationSplicingEnd=null){
        $query = DB::table('huawei as h')
            ->select('h.id', 'man.ime as manager_name', 'man.prezime as manager_surname', 'h.name', 'spl.ime as splicing_name', 'spl.prezime as splicing_surname')
            ->leftJoin('users as spl', 'spl.id', '=', 'h.id_user_splicing')
            ->leftJoin('users as man', 'man.id', '=', 'h.construction_manager')
            ->where('h.id_status_splicing', "=", 6);
        if($singleDate){
            $query->whereDate('h.realization_date_splicing', '=', $singleDate);
        }
        elseif($realizationSplicingStart && $realizationSplicingEnd){
            $query->whereBetween('h.realization_date_splicing', [$realizationSplicingStart, $realizationSplicingEnd]);
        }
        else{
            $query->whereBetween('h.created_at', [$from, $to]);
        }
        $result = $query->get();
        return $result;
    }

    public function sitesDoc($singleDate=null, $from=null, $to=null, $disEndStart=null, $disEndEnd=null){
        $query = DB::table('huawei as h')->select('h.id', 'pro.ime as manager_name', 'pro.prezime as manager_surname', 'h.name')
            ->leftJoin('users as pro', 'pro.id', '=', 'h.project_manager');
        if($singleDate){
            $query->where('h.dis_end_date', '=', $singleDate);
            $query->orWhere('h.technical_solution_date', '=', $singleDate);
        }
        elseif($disEndStart && $disEndEnd){
            $query->whereBetween('h.dis_end_date', [$disEndStart, $disEndEnd])
                ->orWhereNotBetween('h.technical_solution_date', [$disEndStart, $disEndEnd]);
            ;
        }
        else{
            $query->whereBetween('h.dis_end_date', [$from, $to])
                ->orWhereNotBetween('h.technical_solution_date', [$from, $to]);
            ;
        }
        $result = $query->get();
        return $result;
    }
}