<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Hw_site_equipment extends Model
{
    protected $table = 'hw_site_equipment';
    protected $fillable = ['id_site', 'id_equipment', 'quantity'];

    public function equipment($site){
        $query = DB::table('hw_site_equipment as se')
            ->leftJoin('equipment as e', 'e.id', '=', 'se.id_equipment')
            ->leftJoin('equipment_categories as ec', 'ec.id', '=', 'e.id_category')
            ->selectRaw('e.equipment, ec.category, e.id_category, SUM(se.quantity) as quantity, se.id_equipment, e.code')
            ->where('se.id_site', '=', $site)
            ->where('se.quantity', '!=', 0)
            ->groupBy('se.id_equipment')
            ->orderBy('ec.id', 'ASC')
            ->orderBy('e.id', 'ASC')
        ;

        $result = $query->get();
        return $result;
    }

    public function equipmentGroup($site, $category){
        $query = DB::table('hw_site_equipment as se')
            ->leftJoin('equipment as e', 'e.id', '=', 'se.id_equipment')
            ->leftJoin('equipment_categories as ec', 'ec.id', '=', 'e.id_category')
            ->selectRaw('e.equipment, ec.category, e.id_category, SUM(se.quantity) as quantity, se.id_equipment, e.code')
            ->where('se.id_construction_site', '=', $site)
            ->where('e.id_category', '=', $category)
            ->groupBy('se.id_equipment')
            ->orderBy('ec.id', 'ASC')
            ->orderBy('e.id', 'ASC')
        ;

        $result = $query->get();
        return $result;
    }

    public function specificEquipment($site,$code){
        $query = DB::table('hw_site_equipment as se')
            ->leftJoin('equipment as e', 'e.id', '=', 'se.id_equipment')
            ->selectRaw('SUM(se.quantity) as quantity')
            ->where('se.id_site', '=', $site)
            ->where('e.code', '=', $code)
            ->groupBy('se.id_equipment')
        ;

        $result = $query->get();
        if($result->isEmpty())
            return null;
        else    
            return $result[0]->quantity;
    }

    public function usedEquipment($type){
        $query = DB::table('hw_site_equipment as se')
            ->leftJoin('equipment as e', 'e.id', '=', 'se.id_equipment')
            ->selectRaw('SUM(se.quantity) as quantity, e.code, e.equipment')
            ->where('e.type','=', $type)
            ->groupBy('se.id_equipment')
        ;

        $result = $query->get();
        return $result;
    }

    public function specificEquipmentById($site,$equipmentId){
        $query = DB::table('hw_site_equipment as se')
            ->selectRaw('SUM(se.quantity) as quantity')
            ->where('se.id_site', '=', $site)
            ->where('se.id_equipment', '=', $equipmentId)
            ->groupBy('se.id_equipment')
        ;

        $result = $query->get();
        if($result->isEmpty())
            return null;
        else
            return $result[0]->quantity;
    }

    public function equipment_update($siteId, $equipmentId, $quantity){
        DB::table('hw_site_equipment as se')
            ->where('id_site', '=', $siteId)
            ->where('id_equipment', '=', $equipmentId)
            ->increment('quantity', $quantity);
    }
}
