<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Site_work extends Model
{
    protected $table = 'site_work';
    protected $fillable = ['id_construction_site', 'access_work_id', 'vertical_work_id', 'quantity', 'price', 'doc_work'];

    public function accessWorks($site){
        $query = DB::table('site_work as sw')
            ->leftJoin('kir_access_works as w', 'w.id', '=', 'sw.access_work_id')
            ->leftJoin('work_categories as wc', 'wc.id', '=', 'w.category_id')
            ->leftJoin('units as u', 'u.id', '=', 'w.unit_id')
            ->selectRaw('w.work, wc.category, w.category_id, SUM(sw.quantity) as quantity, sw.access_work_id, w.code, u.unit_short, w.id, w.price')
            ->where('sw.id_construction_site', '=', $site)
            ->where('sw.access_work_id', '!=', null)
            ->groupBy('sw.access_work_id')
            ->orderBy('wc.id', 'ASC')
            ->orderBy('w.id', 'ASC')
        ;

        $result = $query->get();
        return $result;
    }

    public function verticalWorks($site){
        $query = DB::table('site_work as sw')
            ->leftJoin('kir_vertical_works as w', 'w.id', '=', 'sw.vertical_work_id')
            ->leftJoin('units as u', 'u.id', '=', 'w.unit_id')
            ->selectRaw('w.work, SUM(sw.quantity) as quantity, sw.vertical_work_id, w.code, u.unit_short, w.id, w.price')
            ->where('sw.id_construction_site', '=', $site)
            ->where('sw.vertical_work_id', '!=', null)
            ->groupBy('sw.vertical_work_id')
            ->orderBy('w.id', 'ASC')
        ;

        $result = $query->get();
        return $result;
    }

    public function docWorks($site){
        $query = DB::table('site_work as sw')
            ->leftJoin('doc_works as w', 'w.id', '=', 'sw.doc_work')
            ->leftJoin('units as u', 'u.id', '=', 'w.unit_id')
            ->selectRaw('w.work, SUM(sw.quantity) as quantity, sw.doc_work, w.code, u.unit_short, w.id, w.price')
            ->where('sw.id_construction_site', '=', $site)
            ->where('sw.doc_work', '!=', null)
            ->groupBy('sw.doc_work')
            ->orderBy('w.id', 'ASC')
        ;

        $result = $query->get();
        return $result;
    }

    public function workQuantity($site,$workId){
        $query = DB::table('site_work as sw')
            ->leftJoin('hw_vertical_works as w', 'w.id', '=', 'sw.vertical_work_id')
            ->leftJoin('units as u', 'u.id', '=', 'w.unit_id')
            ->selectRaw('SUM(sw.quantity) as quantity')
            ->where('sw.id_construction_site', '=', $site)
            ->where('vertical_work_id', '=', $workId)
            ->groupBy('sw.vertical_work_id')
            ->orderBy('w.id', 'ASC')
        ;

        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->quantity;
    }

    public function specificWork($site,$code,$type){
        if($type == 'vertical'){
            $table = 'kir_vertical_works';
            $field = 'vertical_work_id';
        }
        else {
            $table = 'kir_access_works';
            $field = 'access_work_id';
        }
        $query = DB::table('site_work as sw')
            ->leftJoin("$table as w", 'w.id', '=', "sw.$field")
            ->selectRaw('SUM(sw.quantity) as quantity')
            ->where('sw.id_construction_site', '=', $site)
            ->where('code', '=', $code)
            ->groupBy("sw.$field")
        ;

        $result = $query->get();
        if($result->isEmpty())
            return null;
        else
            return $result[0]->quantity;
    }

    public function accessWorkQuantity($site,$workId){
        $query = DB::table('site_work as sw')
            ->leftJoin('hw_access_works as w', 'w.id', '=', 'sw.access_work_id')
            ->leftJoin('units as u', 'u.id', '=', 'w.unit_id')
            ->selectRaw('SUM(sw.quantity) as quantity')
            ->where('sw.id_construction_site', '=', $site)
            ->where('access_work_id', '=', $workId)
            ->groupBy('sw.access_work_id')
            ->orderBy('w.id', 'ASC')
        ;

        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->quantity;
    }

    public function verticalWorkQuantity($site,$workId){
        $query = DB::table('site_work as sw')
            ->leftJoin('hw_vertical_works as w', 'w.id', '=', 'sw.vertical_work_id')
            ->leftJoin('units as u', 'u.id', '=', 'w.unit_id')
            ->selectRaw('SUM(sw.quantity) as quantity')
            ->where('sw.id_construction_site', '=', $site)
            ->where('vertical_work_id', '=', $workId)
            ->groupBy('sw.vertical_work_id')
            ->orderBy('w.id', 'ASC')
        ;

        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->quantity;
    }

    public function docWorkQuantity($site,$workId){
        $query = DB::table('site_work as sw')
            ->leftJoin('doc_works as w', 'w.id', '=', 'sw.doc_work')
            ->leftJoin('units as u', 'u.id', '=', 'w.unit_id')
            ->selectRaw('SUM(sw.quantity) as quantity')
            ->where('sw.id_construction_site', '=', $site)
            ->where('doc_work', '=', $workId)
            ->groupBy('sw.doc_work')
            ->orderBy('w.id', 'ASC')
        ;

        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->quantity;
    }

}
