<?php

namespace App\Models;
use Illuminate\Support\Facades\DB;

use Illuminate\Database\Eloquent\Model;

class Storage_equipment extends Model
{
    protected $table = 'storage_equipment';
    protected $fillable = ['mag_id', 'equipment_id', 'mont_equipment_id', 'quantity', 'package_number'];

    public function equipment_for_storage($idStorage, $type=null){
        $query = DB::table('storage_equipment as se')
            ->leftJoin('equipment as e', 'e.id', '=', 'se.equipment_id')
            ->select('se.quantity', 'e.code', 'e.equipment', 'e.id as equipment_id')
            ->where('mag_id', '=', $idStorage)
            ->where('se.equipment_id', '!=', null)
            ->where('se.quantity', '!=', 0)
        ;
        if($type)
            $query->where('e.type', '=', $type);
        $result = $query->get();
        return $result;
    }

    public function specific_equipment($magId, $equipmentId){
        $query = DB::table('storage_equipment as se')
            ->leftJoin('equipment as e', 'e.id', '=', 'se.equipment_id')
            ->select('se.quantity', 'e.code', 'e.equipment')
            ->where('mag_id', '=', $magId)
            ->where('equipment_id', '=', $equipmentId);
        $result = $query->get();
        if ($result->isEmpty())
            return false;
        else
            return $result[0];
    }

    public function storage_update($magId, $equipmentId, $quantity){
        DB::table('storage_equipment')
            ->where('mag_id', '=', $magId)
            ->where('equipment_id', '=', $equipmentId)
            ->increment('quantity', $quantity);
    }

    public function equipment_for_storage_mont($idStorage){
        $query = DB::table('storage_equipment as se')
            ->leftJoin('oprema as o', 'o.id', '=', 'se.mont_equipment_id')
            ->leftJoin('mont_equipment_categories as mec', 'mec.id', '=', 'o.id_category')
            ->select('se.quantity', 'o.naziv as equipment', 'o.id as equipment_id', 'package_number', 'code', 'o.price', 'mec.category', 'o.id_category')
            ->where('mag_id', '=', $idStorage)
            ->where('se.mont_equipment_id', '!=', null)
            ->where('se.quantity', '!=', 0)
            ->orderBy('o.id_category', 'ASC')
            ->orderBy('o.code', 'ASC')
        ;
        $result = $query->get();
        return $result;
    }

    public function specific_equipment_mont($magId, $equipmentId, $packageNumber=null){
        $query = DB::table('storage_equipment as se')
            ->leftJoin('oprema as o', 'o.id', '=', 'se.mont_equipment_id')
            ->select('se.quantity', 'o.naziv as equipment', 'o.id as equipment_id', 'o.package')
            ->where('mag_id', '=', $magId)
            ->where('mont_equipment_id', '=', $equipmentId);
        if($packageNumber){
            $query->where('se.package_number', '=', $packageNumber);
        }
        $result = $query->get();
        if ($result->isEmpty())
            return false;
        else
            return $result[0];
    }

    public function packageAvailable($magId, $equipmentId, $packageNumber){
        $query = DB::table('storage_equipment')
            ->select('package_number')
            ->where('mag_id', '=', $magId)
            ->where('mont_equipment_id', '!=', $equipmentId)
            ->where('package_number', '=', $packageNumber);
        $result = $query->get();
        if ($result->isEmpty())
            return true;
        else
            return false;
    }

    public function storage_update_mont($magId, $equipmentId, $quantity, $packageNumber=null){
        $query = DB::table('storage_equipment')
            ->where('mag_id', '=', $magId)
            ->where('mont_equipment_id', '=', $equipmentId);
        if($packageNumber)
            $query->where('package_number', '=', $packageNumber);
        $query->increment('quantity', $quantity);
    }

    /**
     * @param null $construction
     * @param null $type connstruction = 1, huawei = 2
     * @return mixed
     */
    public function available_goods($construction=null, $type=null){
        //first solution is more elegant but not working for some reason

//        $query1 = DB::table('storage_equipment as se')
//            ->leftJoin('oprema as o', 'o.id', '=', 'se.mont_equipment_id')
//            ->select('se.quantity', 'o.naziv', 'o.id as equipment_id')
//            ->where('mag_id', '=', $storageId)
//            ->where('se.mont_equipment_id', '!=', null)
//            ->where('se.quantity', '>', 0);
//
//        $query2 = DB::table('worker_equipment as we')
//            ->leftJoin('oprema as o', 'o.id', '=', 'we.mont_equipment_id')
//            ->select('we.quantity', 'o.naziv', 'o.id as equipment_id')
//            ->where('storage_id', '=', $storageId)
//            ->where('we.mont_equipment_id', '!=', null)
//            ->where('we.quantity', '>', 0);
//
//        $unified = $query1->union($query2)->selectRaw('sum(quantity) as sumasumarum, naziv as equipment, equipment_id')->groupBy('equipment_id')->get();
        if($construction){
            $result = DB::select("
                SELECT sum(quantity) as sumasumarum, equipment, code from ((select se.quantity, e.equipment, se.equipment_id, e.code from storage_equipment se
                LEFT JOIN equipment e on e.id = se.equipment_id
                where se.equipment_id  is not null and se.quantity > 0 and e.type = $type)
                UNION
                (select sum(we.quantity) as quantity, e.equipment, we.equipment_id, e.code from worker_equipment we
                LEFT JOIN equipment e on e.id = we.equipment_id
                where we.equipment_id  is not null and we.quantity > 0 and e.type = $type group by we.equipment_id)) as unified
                group by equipment_id
            ");
            return $result;
        }
        else {
            $result = DB::select("
                SELECT sum(quantity) as sumasumarum, naziv as equipment, id_category, category, code, price 
                from ((select se.quantity, o.naziv, o.id as equipment_id, o.id_category, mec.category, o.code, o.price from storage_equipment se
                LEFT JOIN oprema o on o.id = se.mont_equipment_id
                LEFT JOIN mont_equipment_categories mec on mec.id = o.id_category
                where se.mont_equipment_id  is not null and se.quantity > 0)
                UNION
                (select sum(we.quantity), o.naziv, o.id as equipment_id, o.id_category, mec.category, o.code, o.price from worker_equipment we
                LEFT JOIN oprema o on o.id = we.mont_equipment_id
                LEFT JOIN mont_equipment_categories mec on mec.id = o.id_category
                where we.mont_equipment_id  is not null and we.quantity > 0 group by we.mont_equipment_id)) as unified
                group by equipment_id order by id_category
            ");
            return $result;
        }
    }

    public function constructionManagerRequireEquipment(){
        $query = DB::table('storage_equipment as se')
            ->leftJoin('equipment as e', 'e.id', '=', 'se.equipment_id')
            ->select('se.quantity', 'e.code', 'e.equipment', 'e.id as equipment_id')
            ->where('se.equipment_id', '!=', null)
            ->where('se.quantity', '>', 0)
            ->where('e.type', '=', 1);
        $result = $query->get();
        return $result;
    }

    public function allGoods($type){
        $result = DB::select("
                SELECT sum(quantity) as sumasumarum, equipment, code from ((select se.quantity, e.equipment, se.equipment_id, e.code from storage_equipment se
                LEFT JOIN equipment e on e.id = se.equipment_id
                where se.equipment_id  is not null and se.quantity > 0 and e.type = $type)
                UNION
                (select sum(we.quantity), e.equipment, we.equipment_id, e.code from worker_equipment we
                LEFT JOIN equipment e on e.id = we.equipment_id
                where we.equipment_id  is not null and we.quantity > 0 and e.type = $type group by we.equipment_id)
                UNION 
                (SELECT sum(hse.quantity) as quantity, e.equipment, hse.id_equipment as equipment_id, e.code from hw_site_equipment as hse
                LEFT JOIN equipment as e on e.id = hse.id_equipment where e.type = $type
                group by hse.id_equipment)) as unified
                group by equipment_id
            ");
        return $result;
    }

    public function equipmentSum($equipmentId){
        $query = DB::table('storage_equipment as se')
            ->selectRaw('SUM(se.quantity) as quantity')
            ->where('equipment_id', '=', $equipmentId);
        $result = $query->get();
        if ($result->isEmpty())
            return 0;
        else
            return $result[0]->quantity;
    }

    public function montEqupmentSum($equipmentId){
        $query = DB::table('storage_equipment as se')
            ->selectRaw('SUM(se.quantity) as quantity')
            ->where('mont_equipment_id', '=', $equipmentId);
        $result = $query->get();
        if ($result->isEmpty())
            return 0;
        else
            return $result[0]->quantity;
    }

    public function packageSum($storageId){
        $query = DB::table('storage_equipment as se')
            ->leftJoin('oprema as o', 'o.id', '=', 'se.mont_equipment_id')
            ->leftJoin('equipment_packages as pac', 'pac.id', '=', 'o.package')
            ->selectRaw('sum(se.quantity) as count, o.naziv as equipment, pac.package, o.code')
            ->where('se.package_number', '!=', null)
            ->where('se.mont_equipment_id', '!=', null)
            ->where('mag_id', '=', $storageId)
            ->where('quantity', '>', 0)
            ->groupBy('se.mont_equipment_id')
        ;

        $result = $query->get();
        return $result;
    }

    public function lastNumber(){
        $data = DB::table('storage_equipment')
            ->select('package_number')
            ->orderBy('package_number', 'DESC')
            ->first();
        ;

        if($data)
            return $data->package_number+1;
        else
            return 1;
    }

    public function packageQuantity($packageNumber,$equipmentId){
        $data = DB::table('storage_equipment')
            ->select('quantity')
            ->where('package_number', $packageNumber)
            ->where('mont_equipment_id', $equipmentId)
            ->first();
        ;

        if($data)
            return $data->quantity;
        else
            return null;
    }

    public function packageList($equipmentId){
        $query = DB::table('storage_equipment as se')
            ->leftJoin('equipment_packages as p', 'p.id', '=', 'se.package')
            ->select('se.quantity', 'se.package_number', 'p.package')
            ->where('mont_equipment_id', '=', $equipmentId);
        $result = $query->get();
        return $result;
    }

}
