<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Tool_reverse_goods extends Model
{
    protected $fillable = ['serial_number', 'reverse_id', 'device_id', 'storage_id', 'provider_id', 'invoice_number', 'origin', 'obsolete'];

    public function revGoods($idRev){
        $query = DB::table('tool_reverse_goods as r')
            ->leftJoin('uredjaji as u', 'r.device_id', '=', 'u.id')
            ->leftJoin('tool_providers as tp', 'tp.id', '=', 'r.provider_id')
            ->leftJoin('tool_origins as o', 'o.id', '=', 'r.origin')
            ->select('r.serial_number', 'u.uredjaj as device', 'r.id', 'r.device_id', 'tp.provider', 'o.origin', 'r.invoice_number', 'obsolete')
            ->orderBy('r.id', 'DESC')
            ->where('r.reverse_id', '=', $idRev);
        ;

        $result = $query->get();
        return $result;
    }

    public function reversSerials($brReversa=null){
        $query = DB::table('revers_roba as r')
            ->select('r.serijski_broj', 'id_revers as broj_reversa');
        if ($brReversa)
            $query->where('id_revers', '=', $brReversa);

        $result = $query->get();
        return $result;
    }

    public function deviceInventory($fitterId){
        $query = DB::table('revers_roba as rr')
            ->leftJoin('revers as r', 'r.id', '=', 'rr.id_revers')
            ->leftJoin('uredjaji as u', 'rr.id_uredjaj', '=', 'u.id')
            ->selectRaw('COUNT(rr.id) as quantity, u.uredjaj as device')
            ->groupBy('rr.id_uredjaj')
            ->where('r.id_monter', '=', $fitterId)
            ->where('rr.mounted', '!=', 1)
            ->where('rr.obsolete', '!=', 1)
        ;

        $result = $query->get();
        return $result;
    }

    public function specificDeviceInventory($fitterId, $device){
        $query = DB::table('revers_roba as rr')
            ->leftJoin('revers as r', 'r.id', '=', 'rr.id_revers')
            ->leftJoin('uredjaji as u', 'rr.id_uredjaj', '=', 'u.id')
            ->selectRaw('COUNT(rr.id) as quantity')
            ->groupBy('rr.id_uredjaj')
            ->where('r.id_monter', '=', $fitterId)
            ->where('rr.mounted', '!=', 1)
            ->where('rr.obsolete', '!=', 1)
            ->where('rr.id_uredjaj', '=', $device)
        ;

        $result = $query->get()->first();
        return $result;
    }

    public function workerDevices($fitterId){
        $query = DB::table('revers_roba as rr')
            ->leftJoin('revers as r', 'r.id', '=', 'rr.id_revers')
            ->leftJoin('uredjaji as u', 'rr.id_uredjaj', '=', 'u.id')
            ->select('serijski_broj as serial', 'u.uredjaj as device', 'rr.created_at')
            ->where('r.id_monter', '=', $fitterId)
            ->where('rr.mounted', '!=', 1)
            ->where('rr.obsolete', '!=', 1)
            ->orderBy('rr.id_uredjaj', 'ASC')
        ;

        $result = $query->get();
        return $result;
    }

    public function reversCount($deviceId, $mag=null){
        $query = DB::table('tool_reverse_goods as rr')
            ->leftJoin('tool_reverse as r', 'r.id', '=', 'rr.reverse_id')
            ->selectRaw('COUNT(DISTINCT(serial_number)) as count')
            ->where('device_id', '=', $deviceId)
        ;
        if($mag)
            $query->where('rr.storage_id', '=', $mag);
        $result = $query->get();
        if($result->isEmpty())
            return 0;
        else
            return $result[0]->count;
    }

    public function revGoodsForWorker($worker, $obsolete=null){
        $query = DB::table('tool_reverse_goods as r')
            ->leftJoin('uredjaji as u', 'r.device_id', '=', 'u.id')
            ->leftJoin('tool_providers as tp', 'tp.id', '=', 'r.provider_id')
            ->leftJoin('tool_origins as o', 'o.id', '=', 'r.origin')
            ->leftJoin('tool_reverse as tr', 'tr.id', '=', 'r.reverse_id')
            ->select('r.serial_number', 'u.uredjaj as device', 'r.id', 'r.device_id', 'tp.provider', 'o.origin', 'r.invoice_number', 'obsolete')
            ->orderBy('r.id', 'DESC');

        if($worker)
            $query->where('tr.worker_id', '=', $worker);
        if($obsolete)
            $query->where('r.obsolete', '=', 1);
        else
            $query->where('r.obsolete', '=', 0);
        $result = $query->get();
        return $result;
    }
}
