<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Otpremnice extends Model
{
    protected $table = 'otpremnice';

    protected $fillable = [
        'id_monter',
        'id_magacioner',
        'robu_preuzeo',
        'naziv_firme',
        'br_lk',
        'reg_br',
        'jmbg',
        'tel'
    ];

    public function otpremnice(){
        $query = DB::table('otpremnice as o')
            ->leftJoin('users as mon', 'o.id_monter', '=', 'mon.id')
            ->leftJoin('users as mag', 'o.id_magacioner', '=', 'mag.id')
            ->select('mon.ime as monter_ime', 'mon.prezime as monter_prezime', 'mag.ime as magacioner_ime', 'o.jmbg', 'o.tel',
                'mag.prezime as magacioner_prezime', 'o.robu_preuzeo', 'o.created_at', 'o.id', 'naziv_firme', 'reg_br', 'br_lk',
                'mon.id as monter_id')
            ->orderBy('o.created_at', 'DESC')
        ;

        $result = $query->paginate(50);
        return $result;
    }

    public function otpremnica($idOtp){
        $query = DB::table('otpremnice as o')
            ->leftJoin('users as mon', 'o.id_monter', '=', 'mon.id')
            ->leftJoin('users as mag', 'o.id_magacioner', '=', 'mag.id')
            ->select('mon.ime as monter_ime', 'mon.prezime as monter_prezime', 'mag.ime as magacioner_ime', 'o.jmbg', 'o.tel',
                'mag.prezime as magacioner_prezime', 'o.robu_preuzeo', 'o.created_at', 'o.id', 'o.reg_br')
            ->where('o.id', '=', $idOtp)
            ->orderBy('o.created_at', 'DESC')
        ;

        $result = $query->get();
        return $result[0];
    }

    public function robaStavke($idOtp){
        $query = DB::table('otpremljena_roba as otp')
            ->leftJoin('otpremnice as o', 'otp.id_otpremnice', '=', 'o.id')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'otp.id_uredjaj')
            ->select('otp.serijski_broj', 'otp.id_uredjaj', 'u.uredjaj')
            ->where('o.id', '=', $idOtp)
            ->orderBy('otp.id_uredjaj', 'ASC')
        ;

        $result = $query->get();
        return $result;
    }

    public function robaCount($idOtp){
        $query = DB::table('otpremljena_roba as o')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'o.id_uredjaj')
            ->select(DB::raw('COUNT(o.id) as count, u.uredjaj'))
            ->where('o.id_otpremnice', '=', $idOtp)
            ->groupBy('o.id_uredjaj')
        ;

        $result = $query->get();
        return $result;
    }

    public function otpremniceSearch($monter=null, $magacioner=null, $serijskiBroj=null, $start=null, $end=null, $brojOtpremnice=null){
        $query = DB::table('otpremnice as o')
            ->leftJoin('users as mon', 'o.id_monter', '=', 'mon.id')
            ->leftJoin('users as mag', 'o.id_magacioner', '=', 'mag.id')
            ->leftJoin('otpremljena_roba as or', 'or.id_otpremnice', '=', 'o.id')
            ->select('mon.ime as monter_ime', 'mon.prezime as monter_prezime', 'mag.ime as magacioner_ime',
                'mag.prezime as magacioner_prezime', 'o.robu_preuzeo', 'o.created_at', 'o.id', 'naziv_firme', 'reg_br', 'br_lk')
            ->orderBy('o.created_at', 'DESC')
            ->groupBy('o.id')
        ;

        if ($monter)
            $query->where('o.id_monter', '=', $monter);
        if ($magacioner)
            $query->where('o.id_magacioner', '=', $magacioner);
        if ($serijskiBroj)
            $query->where('or.serijski_broj', '=', $serijskiBroj);
        if ($start)
            $query->whereDate('o.created_at', '>=', $start);
        if ($end)
            $query->whereDate('o.created_at', '<=', $end);
        if ($brojOtpremnice)
            $query->where('o.id', '=', $brojOtpremnice);

        $result = $query->get();
        return $result;
    }
}
