<?php

namespace App;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Povratnice extends Model
{
    protected $table = 'povratnice';

    protected $fillable = [
        'id_monter',
        'id_magacioner',
        'robu_preuzeo',
        'naziv_firme',
        'br_lk',
        'reg_br',
        'storage_id',
        'sent_to_warehouse',
        'send_date',
        'printed'
    ];

    public function povratnice(){
        $query = DB::table('povratnice as p')
            ->leftJoin('users as mon', 'p.id_monter', '=', 'mon.id')
            ->leftJoin('users as mag', 'p.id_magacioner', '=', 'mag.id')
            ->leftJoin('magz as mz', 'p.storage_id', '=', 'mz.id')
            ->select('mon.ime as monter_ime', 'mon.prezime as monter_prezime', 'mag.ime as magacioner_ime',
                'mag.prezime as magacioner_prezime', 'p.robu_preuzeo', 'p.created_at', 'p.id', 'p.reg_br', 'p.br_lk', 'naziv_firme', 'mz.naziv as storage',
                'p.sent_to_warehouse', 'p.send_date', 'p.printed')
            ->orderBy('p.created_at', 'DESC')
        ;

        $result = $query->paginate(50);
        return $result;
    }

    public function povratnica($idPov){
        $query = DB::table('povratnice as p')
            ->leftJoin('users as mon', 'p.id_monter', '=', 'mon.id')
            ->leftJoin('users as mag', 'p.id_magacioner', '=', 'mag.id')
            ->select('mon.ime as monter_ime', 'mon.prezime as monter_prezime', 'mag.ime as magacioner_ime',
                'mag.prezime as magacioner_prezime', 'p.robu_preuzeo', 'p.created_at', 'p.id', 'p.reg_br')
            ->where('p.id', '=', $idPov)
            ->orderBy('p.created_at', 'DESC')
        ;

        $result = $query->get();
        return $result[0];
    }

    public function robaStavke($idPov){
        $query = DB::table('povratnice as p')
            ->leftJoin('povratna_roba as pr', 'pr.id_povratnica', '=', 'p.id')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'pr.id_uredjaj')
            ->leftJoin('statusi_uredjaja as su', 'su.id', '=', 'pr.id_status_uredjaja')
            ->leftJoin('stanje_uredjaja as stu', 'stu.id', '=', 'pr.id_stanje_uredjaja')
            ->select('pr.serijski_broj', 'pr.id_uredjaj', 'su.status', 'pr.id_status_uredjaja', 'u.uredjaj', 'stu.stanje', 'zamena')
            ->where('p.id', '=', $idPov)
            ->orderByRaw('FIELD(pr.id_status_uredjaja, 3, 2)')
            ->orderBy('pr.id_status_uredjaja', 'ASC')
            ->orderBy('pr.id_uredjaj', 'ASC')
            ->orderBy('pr.id_stanje_uredjaja', 'ASC')
        ;

        $result = $query->get();
        return $result;
    }

    public function robaCount($idPov, $idUredjaj, $idStatus){
        $query = DB::table('povratna_roba as pr')
            ->leftJoin('uredjaji as u', 'u.id', '=', 'pr.id_uredjaj')
            ->select(DB::raw('COUNT(pr.id) as count'))
            ->where('pr.id_povratnica', '=', $idPov)
            ->where('pr.id_uredjaj', '=', $idUredjaj)
            ->where('pr.id_status_uredjaja', '=', $idStatus)
            ->groupBy('pr.id_uredjaj')
        ;

        $result = $query->get();
        return $result;
    }

    public function povratniceSearch($monter=null, $magacioner=null, $serijskiBroj=null, $start=null, $end=null, $brojPovratnice=null){
        $query = DB::table('povratnice as p')
            ->leftJoin('users as mon', 'p.id_monter', '=', 'mon.id')
            ->leftJoin('users as mag', 'p.id_magacioner', '=', 'mag.id')
            ->leftJoin('povratna_roba as pr', 'pr.id_povratnica', '=', 'p.id')
            ->select('mon.ime as monter_ime', 'mon.prezime as monter_prezime', 'mag.ime as magacioner_ime',
                'mag.prezime as magacioner_prezime', 'p.robu_preuzeo', 'p.created_at', 'p.id', 'p.reg_br', 'p.br_lk', 'naziv_firme')
            ->orderBy('p.created_at', 'DESC')
            ->groupBy('p.id')
        ;

        if ($monter)
            $query->where('p.id_monter', '=', $monter);
        if ($magacioner)
            $query->where('p.id_magacioner', '=', $magacioner);
        if ($serijskiBroj)
            $query->where('pr.serijski_broj', '=', $serijskiBroj);
        if ($start)
            $query->whereDate('p.created_at', '>=', $start);
        if ($end)
            $query->whereDate('p.created_at', '<=', $end);
        if ($brojPovratnice)
            $query->where('p.id', '=', $brojPovratnice);

        $result = $query->get();
        return $result;
    }
}
