@extends('layouts.app')

@section('content')
    <section class="panel">
        <header class="panel-heading panel-align">
            <h2 class="panel-title">{{$site->name}}<small> &nbsp&nbsp&nbsp(ID: {{$site->id}})</small></h2>
            <div class="panel-actions">
                @if(session('search_route'))
                    <a href="{{route('redirector')}}"
                       data-toggle="tooltip" data-placement="top"
                       data-original-title="{{__('Return to search page')}}"><button class="btn btn-danger"><i class="fa fa-backward"></i></button></a>
                @endif
                <a href="/ger_construction_sites/{{$site->id}}/edit"><button type="button" class="mb-xs mt-xs mr-xs btn btn-primary">{{__('Edit')}} <i class="fa fa-cogs"></i></button></a>
            </div>
        </header>
        <div class="panel-body">
            <div class="row">
                <div class="col-md-4">
                    <p>{{__('Date')}}: <div class="highlight">{{date('d.m.Y.', strtotime($site->date))}}</div></p>
                </div>
                <div class="col-md-4">
                    <p>{{__('Polish date')}}: <div class="highlight">@if($site->polish_date){{date('d.m.Y', strtotime($site->polish_date))}}@endif</div></p>
                </div>
                <div class="col-md-4">
                    <p>{{__('User')}}: <div class="highlight">{{$changedBy}}
                    @if(count($logs) > 1)
                    <a href="#logsModal" class="btn-logs modal-basic" style="float:right" data-toggle="tooltip" data-placement="top"
                        data-original-title="{{__('Logs')}}"><i class="fa fa-eye"></i></a>
                        @endif
                    </div></p>
                </div>
            </div>
            <div class="row">
                <div class="col-md-4">
                    <p>{{__('Column leader')}}: <div class="highlight">{{$site->name.' '.$site->surname}}</div></p>
                </div>
                <div class="col-md-4">
                    <p>{{__('Area')}}: <div class="highlight">{{$site->area}}</div></p>
                </div>
                <div class="col-md-4">
                    <p>{{__('Number of workers')}}: <div class="highlight">{{$site->number_of_workers}}</div></p>
                </div>
            </div>
            <div class="row">
                <div class="col-md-4">
                    <p>{{__('Work').' '.__("start")}}: <div class="highlight">{{$site->work_start}}</div></p>
                </div>
                <div class="col-md-4">
                    <p>{{__('Work').' '.__("end")}}: <div class="highlight">{{$site->work_end}}</div></p>
                </div>
                <div class="col-md-4">
                    <p>{{__('Pause')}}: <div class="highlight">{{$site->pause}} min.</div></p>
                </div>
            </div>
            <div class="row">
                <div class="col-md-4">
                    <p>{{__('Work hours')}}: <div class="highlight">{{date('H:i', strtotime("-$site->pause minutes", strtotime($workHours)))}}</div></p>
                </div>
                <div class="col-md-4">
                    <p>{{__('City')}}: <div class="highlight">{{$site->place}}</div></p>
                </div>
                <div class="col-md-4">
                    <p>{{__('Provider')}}: <div class="highlight">{{$site->provider}}</div></p>
                </div>
            </div>
            <div class="row">
                <div class="col-md-4">
                    <p>{{__('Street')}}: <div class="highlight">{{$site->street}}</div></p>
                </div>
                <div class="col-md-4">
                    <p>POP: <div class="highlight">{{$site->pop}}</div></p>
                </div>
                <div class="col-md-4">
                    <p>DP: <div class="highlight">{{$site->dp}}</div></p>
                </div>
            </div>
            @if(count($history) >= 1)
                <div clsss="row">
                    <a href="#listingModal" class="btn btn-sm btn-warning btn-listing modal-basic" style="float:right" data-toggle="tooltip" data-placement="top"
                       data-original-title="{{__('History')}}"><i class="fa fa-eye"></i></a>
                </div>
            @endif
        </div>
    </section>
    @if(!$comments->isEmpty())
        <section class="panel">
            <header class="panel-heading">
                <h2 class="panel-title">{{(__('Comments'))}} </h2>
            </header>
            <div class="panel-body">
                @foreach($comments as $br=>$comment)
                    <code>{{(__('comment'))}} {{$br+1}}</code>
                    <blockquote class="success">
                        <p>{{$comment->comment}}</p>
                        <small>{{$comment->ime.' '.$comment->prezime}} <cite title="Magazine X">{{date('d.m.Y. H:i:s', strtotime($comment->created_at))}}</cite></small>
                    </blockquote>
                @endforeach
            </div>
        </section>
    @endif
    @if(!$images->isEmpty())
        <section class="panel">
            <header class="panel-heading panel-align">
                <h2 class="panel-title">{{(__('Images'))}}</h2>
            </header>
            <div class="panel-body">
                @foreach($images as $img)
                    <div class="col-md-2">
                        <div class="popup-gallery">
                            <a class="pull-left mb-xs mr-xs" href="{{$img->url}}" title="{{$img->description.' '.date('d.m.Y. H:i:s', strtotime($img->created_at))}}" rel="group1">
                                <div class="img-responsive">
                                    <img src="{{$img->url}}" width="105">
                                </div>
                            </a>
                        </div>
                    </div>
                @endforeach
            </div>
        </section>
    @endif
    @if(!$works->isEmpty())
    <section class="panel">
        <header class="panel-heading">
            <h2 class="panel-title">{{(__('Works'))}}</h2>
        </header>
        <div class="panel-body">
            <div class="table-mobile">
                <table class="table table-bordered table-striped mb-none" id="datatable-default">
                    <thead>
                    <tr>
                        <th>{{(__('Code'))}}</th>
                        <th>{{(__('Works'))}}</th>
                        <th>{{(__('Unit'))}}</th>
                        <th>{{(__('Quantity'))}}</th>
                        @if($isColumnLeader || $isSuperAdmin)
                        <th>{{(__('Price'))}}</th>
                        <th>{{(__('Total'))}}</th>
                        @endif
                    </tr>
                    </thead>
                    <tbody>
                    <?php $total=0 ?>
                    @foreach($works as $work)
                        <tr class="gradeX">
                            <td>{{$work->code}}</td>
                            <td>{{$work->work}}</td>
                            <td>{{$work->unit_short}}</td>
                            <td>{{$work->quantity}}</td>
                            @if($isColumnLeader || $isSuperAdmin)
                            <td>{{$work->price}}</td>
                            <td>{{$work->quantity*$work->price}}</td>
                            @endif
                        </tr>
                        <?php $total += $work->quantity*$work->price;?>
                    @endforeach
                    @if($isColumnLeader || $isSuperAdmin)
                        <tr class="success">
                            <td></td>
                            <td></td>
                            <td></td>
                            <td></td>
                            <td><strong>{{__("Total")}}:</strong></td>
                            <td><strong>{{$total}}</strong></td>
                        </tr>
                    @endif
                    </tbody>
                </table>
            </div>
        </div>
    </section>
    @endif
    <div id="listingModal" class="modal-block modal-full-color modal-block-warning mfp-hide">
        <section class="panel">
            <header class="panel-heading">
                <h2 class="panel-title">{{(__('Change log'))}}</h2>
            </header>
            <div class="panel-body">
                <div class="modal-wrapper">
                    <div class="modal-icon">
                        <i class="fa fa-eye"></i>
                    </div>
                    <div class="modal-text">
                        @foreach($history as $edit)
                            <p>{{$edit->user_ime.' '.$edit->user_prezime.' ('.date('d.m.Y. H:i:s', strtotime($edit->edit_time)).')'}}</p>
                        @endforeach
                    </div>
                </div>
            </div>
            <footer class="panel-footer">
                <div class="row">
                    <div class="col-md-12 text-right">
                        <button class="btn btn-default modal-dismiss">{{(__('Close'))}}</button>
                    </div>
                </div>
            </footer>
        </section>
    </div>
    <div id="logsModal" class="modal-block modal-full-color modal-block-success mfp-hide">
        <section class="panel">
            <header class="panel-heading">
                <h2 class="panel-title">{{(__('Change log'))}}</h2>
            </header>
            <div class="panel-body">
                <div class="modal-wrapper">
                    <div class="modal-icon">
                        <i class="fa fa-eye"></i>
                    </div>
                    <div class="modal-text">
                        @foreach($logs as $log)
                            <p>{{$log->name.' '.$log->surname.' ('.date('d.m.Y. H:i:s', strtotime($log->created_at)).')'}}</p>
                        @endforeach
                    </div>
                </div>
            </div>
            <footer class="panel-footer">
                <div class="row">
                    <div class="col-md-12 text-right">
                        <button class="btn btn-default modal-dismiss">{{(__('Close'))}}</button>
                    </div>
                </div>
            </footer>
        </section>
    </div>


@endsection
